<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Access
 *
 * @ORM\Table(name="access")
 * @ORM\Entity 
 */
class Access
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_access", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idAccess;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_access", type="string", length=100, nullable=true)
     */
    private $cdAccess;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_access", type="string", length=255, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(50)       
     */
    private $lbAccess;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var string
     *
     * @ORM\Column(name="cm_comment", type="text", nullable=true)
     */
    private $cmComment;

        /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    /**
     * @var \Branch
     *
     * @ORM\ManyToOne(targetEntity="Branch")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_branch", referencedColumnName="id_branch")
     * })
     * @Assert\NotNull()     
     */
    private $idBranch;

    /**
     * @var \Address
     *
     * @ORM\ManyToOne(targetEntity="Address",cascade={"persist","remove"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_address", referencedColumnName="id_address")
     * })
     * @Assert\NotNull()      
     */
    private $idAddress;
    
    /**
     * @var \Pop     
     * 
     * @ORM\OneToMany(targetEntity="Pop", mappedBy="idAccess") 
     */

    private $idPop;
    
    
    /**
     * @var \Customer
     * 
     * @ORM\OneToMany(targetEntity="Customer", mappedBy="idAccess") 
     */

    private $idCustomer;
    
    public static function getModifierRoles()
    {
        return array("ROLE_SUPER_ADMINISTRATOR","ROLE_NETWORK_ENGINEER_ADMIN","ROLE_NETWORK_ENGINEER","ROLE_BACKBONE_LINK_ADMINISTRATOR");
    }
    
    public static function getReaderRoles()
    {
        return array("ROLE_EQUIPMENT_ADMINISTRATOR","ROLE_SUPER_ADMINISTRATOR","ROLE_ENTMC_INDIA", "ROLE_CSC_FRANCE", "ROLE_NETWORK_ACCOUNTING","ROLE_NETWORK_ADMINISTRATOR","ROLE_NETWORK_ENGINEER_ADMIN","ROLE_NETWORK_ENGINEER","ROLE_MARKETING_PRE_SALES","ROLE_SALES_ADMINISTRATOR","ROLE_BACKBONE_LINK_ADMINISTRATOR");
    }    
    
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbAccess().'';
    }    
    /**
     * Get idAccess
     *
     * @return integer 
     */
    public function getIdAccess()
    {
        return $this->idAccess;
    }

    /**
     * Set cdAccess
     *
     * @param string $cdAccess
     * @return Access
     */
    public function setCdAccess($cdAccess)
    {
        $this->cdAccess = $cdAccess;
    
        return $this;
    }

    /**
     * Get cdAccess
     *
     * @return string 
     */
    public function getCdAccess()
    {
        return $this->cdAccess;
    }

    /**
     * Set lbAccess
     *
     * @param string $lbAccess
     * @return Access
     */
    public function setLbAccess($lbAccess)
    {
        $this->lbAccess = $lbAccess;
    
        return $this;
    }

    /**
     * Get lbAccess
     *
     * @return string 
     */
    public function getLbAccess()
    {
        return $this->lbAccess;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Access
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set cmComment
     *
     * @param string $cmComment
     * @return Access
     */
    public function setCmComment($cmComment)
    {
        $this->cmComment = $cmComment;
    
        return $this;
    }

    /**
     * Get cmComment
     *
     * @return string 
     */
    public function getCmComment()
    {
        return $this->cmComment;
    }

    /**
     * Set dtStart
     *
     * @param \DateTime $dtStart
     * @return Access
     */
    public function setDtStart($dtStart)
    {
        $this->dtStart = $dtStart;
    
        return $this;
    }

    /**
     * Get dtStart
     *
     * @return \DateTime 
     */
    public function getDtStart()
    {
        return $this->dtStart;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return Access
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Access
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set idBranch
     *
     * @param \Etrali\GinangBundle\Entity\Branch $idBranch
     * @return Access
     */
    public function setIdBranch(\Etrali\GinangBundle\Entity\Branch $idBranch = null)
    {
        $this->idBranch = $idBranch;
    
        return $this;
    }

    /**
     * Get idBranch
     *
     * @return \Etrali\GinangBundle\Entity\Branch 
     */
    public function getIdBranch()
    {
        return $this->idBranch;
    }

    /**
     * Set idAddress
     *
     * @param \Etrali\GinangBundle\Entity\Address $idAddress
     * @return Access
     */
    public function setIdAddress(\Etrali\GinangBundle\Entity\Address $idAddress = null)
    {
        $this->idAddress = $idAddress;
    
        return $this;
    }

    /**
     * Get idAddress
     *
     * @return \Etrali\GinangBundle\Entity\Address 
     */
    public function getIdAddress()
    {
        return $this->idAddress;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idPop = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCustomer = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Access
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Access
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Add idPop
     *
     * @param \Etrali\GinangBundle\Entity\Pop $idPop
     * @return Access
     */
    public function addIdPop(\Etrali\GinangBundle\Entity\Pop $idPop)
    {
        $this->idPop[] = $idPop;
    
        return $this;
    }

    /**
     * Remove idPop
     *
     * @param \Etrali\GinangBundle\Entity\Pop $idPop
     */
    public function removeIdPop(\Etrali\GinangBundle\Entity\Pop $idPop)
    {
        $this->idPop->removeElement($idPop);
    }

    /**
     * Get idPop
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPop()
    {
        return $this->idPop;
    }

    /**
     * Add idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     * @return Access
     */
    public function addIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer)
    {
        $this->idCustomer[] = $idCustomer;
    
        return $this;
    }

    /**
     * Remove idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     */
    public function removeIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer)
    {
        $this->idCustomer->removeElement($idCustomer);
    }

    /**
     * Get idCustomer
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCustomer()
    {
        return $this->idCustomer;
    }public function getParentBranch() { return NULL; }  }