<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Address
 *
 * @ORM\Table(name="address")
 * @ORM\Entity
 */
class Address
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_address", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idAddress;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_address", type="string", length=255, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(100) 
     */
    private $lbAddress;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_zip_code", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20) 
     */
    private $cdZipCode;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_phone", type="string", length=20, nullable=true)
     * @Assert\MaxLength(30) 
     * 
     */
    private $lbPhone;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_fax", type="string", length=20, nullable=true)
     * @Assert\MaxLength(30) 
     */
    private $lbFax;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_email", type="string", length=100, nullable=true)
     * @Assert\MaxLength(128) 
     * @Assert\Email(
     *     message = "'{{ value }}' n'est pas un email valide."
     * )
     */
    private $lbEmail;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_status", type="boolean", nullable=true)
     */
    private $blStatus=true;

    /**
     * @var string
     *
     * @ORM\Column(name="comment", type="text", nullable=true)
     */
    private $comment;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_french_local_loop", type="boolean", nullable=true)
     */
    private $blFrenchLocalLoop;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_magellan", type="string", length=15, nullable=true)
     * @Assert\MaxLength(30) 
     */
    private $cdMagellan;
    
    /**
     * @var string
     *
     * @ORM\Column(name="cd_account_magellan", type="string", length=15, nullable=true)
     * @Assert\MaxLength(30) 
     */
    private $cdAccountMagellan;    

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_on_net_voice", type="boolean", nullable=true)
     */
    private $blOnNetVoice;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_on_net_data", type="boolean", nullable=true)
     */
    private $blOnNetData;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_siret", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20) 
     */
    private $lbSiret;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_ls_account", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20) 
     */
    private $lbLsAccount;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_private_installer", type="string", length=100, nullable=true)
     */
    private $lbPrivateInstaller;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_ptt_head", type="string", length=100, nullable=true)
     */
    private $lbPttHead;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_maintenance", type="boolean", nullable=true)
     */
    private $blMaintenance;

    /**
     * @var string
     *
     * @ORM\Column(name="room", type="string", length=255, nullable=true)
     */
    private $room;

    /**
     * @var string
     *
     * @ORM\Column(name="floor", type="string", length=255, nullable=true)
     */
    private $floor;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_pi_address", type="string", length=255, nullable=true)
     */
    private $lbPiAddress;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_pi_phone", type="string", length=20, nullable=true)
     */
    private $lbPiPhone;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_pi_fax", type="string", length=20, nullable=true)
     */
    private $lbPiFax;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_pi_corres", type="string", length=255, nullable=true)
     */
    private $lbPiCorres;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_entretien", type="string", length=255, nullable=true)
     */
    private $lbEntretien;


    /**
     * @var \City
     *
     * @ORM\ManyToOne(targetEntity="City")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_city", referencedColumnName="id_city")
     * })
     * @Assert\NotNull() 
     */
    private $idCity;

    /**
     * @var \Country
     *
     * @ORM\ManyToOne(targetEntity="Country")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_country", referencedColumnName="id_country")
     * })
     * @Assert\NotNull() 
     */
    private $idCountry;

    /**
     * @var \AddressType
     *
     * @ORM\ManyToOne(targetEntity="AddressType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_address_type", referencedColumnName="id_address_type")
     * })
     * @Assert\NotNull() 
     */
    private $idAddressType;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \Customer
     *
     * @ORM\ManyToOne(targetEntity="Customer", inversedBy="idAddress")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_customer", referencedColumnName="id_customer")
     * })
     */
    private $idCustomer;
    
    /**
     * @var BillingGroup
     *
     * @ORM\OneToMany(targetEntity="BillingGroup",mappedBy="idAddress",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"lbGroup" = "asc"})           
     */
    private $idBillingGroup; 
    
        /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;
    
    /**
     * Get __toString
     *
     * @return string
     */    
    public function __toString()
    {
        return $this->getLbAddress()." ".$this->getCdZipCode()." ".$this->getIdCity();
    }
    
    public function getHeadInfo()
    {
            return "<td>".$this->getIdAddressType()."</td><td >".$this->getLbAddress()."</td><td>".$this->getIdCity()."</td><td>".$this->getCdZipCode()."</td><td>".$this->getIdCountry()."</td><td>".($this->getBlOnNetVoice()?"yes":"no")."</td><td>".($this->getBlOnNetData()?"yes":"no")."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Type</th><th>Address</th><th>City</th><th>Post code</th><th>Country</th><th>On-net Voice</th><th>On-net Data</th>";
    }     

        /**
     * Called just before saveObject that persists the object
     *
     * @param \Symfony\Component\Form\Form $form the valid form
     */
    public function preSave(\Symfony\Component\Form\Form $form,$em)
    {
        if ($this->getIdBillingGroup())
        {
            foreach ($this->getIdBillingGroup() as $line)
            {
                $line->setIdAddress($this);
            }
        }
    }
    
    /**
     * Get idAddress
     *
     * @return integer 
     */
    public function getIdAddress()
    {
        return $this->idAddress;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Address
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Address
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set lbAddress
     *
     * @param string $lbAddress
     * @return Address
     */
    public function setLbAddress($lbAddress)
    {
        $this->lbAddress = $lbAddress;
    
        return $this;
    }

    /**
     * Get lbAddress
     *
     * @return string 
     */
    public function getLbAddress()
    {
        return $this->lbAddress;
    }

    /**
     * Set cdZipCode
     *
     * @param string $cdZipCode
     * @return Address
     */
    public function setCdZipCode($cdZipCode)
    {
        $this->cdZipCode = $cdZipCode;
    
        return $this;
    }

    /**
     * Get cdZipCode
     *
     * @return string 
     */
    public function getCdZipCode()
    {
        return $this->cdZipCode;
    }

    /**
     * Set lbPhone
     *
     * @param string $lbPhone
     * @return Address
     */
    public function setLbPhone($lbPhone)
    {
        $this->lbPhone = $lbPhone;
    
        return $this;
    }

    /**
     * Get lbPhone
     *
     * @return string 
     */
    public function getLbPhone()
    {
        return $this->lbPhone;
    }

    /**
     * Set lbFax
     *
     * @param string $lbFax
     * @return Address
     */
    public function setLbFax($lbFax)
    {
        $this->lbFax = $lbFax;
    
        return $this;
    }

    /**
     * Get lbFax
     *
     * @return string 
     */
    public function getLbFax()
    {
        return $this->lbFax;
    }

    /**
     * Set lbEmail
     *
     * @param string $lbEmail
     * @return Address
     */
    public function setLbEmail($lbEmail)
    {
        $this->lbEmail = $lbEmail;
    
        return $this;
    }

    /**
     * Get lbEmail
     *
     * @return string 
     */
    public function getLbEmail()
    {
        return $this->lbEmail;
    }

    /**
     * Set blStatus
     *
     * @param boolean $blStatus
     * @return Address
     */
    public function setBlStatus($blStatus)
    {
        $this->blStatus = $blStatus;
    
        return $this;
    }

    /**
     * Get blStatus
     *
     * @return boolean 
     */
    public function getBlStatus()
    {
        return $this->blStatus;
    }

    /**
     * Set comment
     *
     * @param string $comment
     * @return Address
     */
    public function setComment($comment)
    {
        $this->comment = $comment;
    
        return $this;
    }

    /**
     * Get comment
     *
     * @return string 
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * Set blEtranetReady
     *
     * @param boolean $blEtranetReady
     * @return Address
     */
    public function setBlEtranetReady($blEtranetReady)
    {
        $this->blEtranetReady = $blEtranetReady;
    
        return $this;
    }

    /**
     * Get blEtranetReady
     *
     * @return boolean 
     */
    public function getBlEtranetReady()
    {
        return $this->blEtranetReady;
    }

    /**
     * Set cdMagellan
     *
     * @param string $cdMagellan
     * @return Address
     */
    public function setCdMagellan($cdMagellan)
    {
        $this->cdMagellan = $cdMagellan;
    
        return $this;
    }

    /**
     * Get cdMagellan
     *
     * @return string 
     */
    public function getCdMagellan()
    {
        return $this->cdMagellan;
    }

    /**
     * Set blOnNetVoice
     *
     * @param boolean $blOnNetVoice
     * @return Address
     */
    public function setBlOnNetVoice($blOnNetVoice)
    {
        $this->blOnNetVoice = $blOnNetVoice;
    
        return $this;
    }

    /**
     * Get blOnNetVoice
     *
     * @return boolean 
     */
    public function getBlOnNetVoice()
    {
        return $this->blOnNetVoice;
    }

    /**
     * Set blOnNetData
     *
     * @param boolean $blOnNetData
     * @return Address
     */
    public function setBlOnNetData($blOnNetData)
    {
        $this->blOnNetData = $blOnNetData;
    
        return $this;
    }

    /**
     * Get blOnNetData
     *
     * @return boolean 
     */
    public function getBlOnNetData()
    {
        return $this->blOnNetData;
    }

    /**
     * Set lbSiret
     *
     * @param string $lbSiret
     * @return Address
     */
    public function setLbSiret($lbSiret)
    {
        $this->lbSiret = $lbSiret;
    
        return $this;
    }

    /**
     * Get lbSiret
     *
     * @return string 
     */
    public function getLbSiret()
    {
        return $this->lbSiret;
    }

    /**
     * Set lbLsAccount
     *
     * @param string $lbLsAccount
     * @return Address
     */
    public function setLbLsAccount($lbLsAccount)
    {
        $this->lbLsAccount = $lbLsAccount;
    
        return $this;
    }

    /**
     * Get lbLsAccount
     *
     * @return string 
     */
    public function getLbLsAccount()
    {
        return $this->lbLsAccount;
    }

    /**
     * Set lbPrivateInstaller
     *
     * @param string $lbPrivateInstaller
     * @return Address
     */
    public function setLbPrivateInstaller($lbPrivateInstaller)
    {
        $this->lbPrivateInstaller = $lbPrivateInstaller;
    
        return $this;
    }

    /**
     * Get lbPrivateInstaller
     *
     * @return string 
     */
    public function getLbPrivateInstaller()
    {
        return $this->lbPrivateInstaller;
    }

    /**
     * Set lbPttHead
     *
     * @param string $lbPttHead
     * @return Address
     */
    public function setLbPttHead($lbPttHead)
    {
        $this->lbPttHead = $lbPttHead;
    
        return $this;
    }

    /**
     * Get lbPttHead
     *
     * @return string 
     */
    public function getLbPttHead()
    {
        return $this->lbPttHead;
    }

    /**
     * Set lbIpe
     *
     * @param string $lbIpe
     * @return Address
     */
    public function setLbIpe($lbIpe)
    {
        $this->lbIpe = $lbIpe;
    
        return $this;
    }

    /**
     * Get lbIpe
     *
     * @return string 
     */
    public function getLbIpe()
    {
        return $this->lbIpe;
    }

    /**
     * Set blMaintenance
     *
     * @param boolean $blMaintenance
     * @return Address
     */
    public function setBlMaintenance($blMaintenance)
    {
        $this->blMaintenance = $blMaintenance;
    
        return $this;
    }

    /**
     * Get blMaintenance
     *
     * @return boolean 
     */
    public function getBlMaintenance()
    {
        return $this->blMaintenance;
    }

    /**
     * Set room
     *
     * @param string $room
     * @return Address
     */
    public function setRoom($room)
    {
        $this->room = $room;
    
        return $this;
    }

    /**
     * Get room
     *
     * @return string 
     */
    public function getRoom()
    {
        return $this->room;
    }

    /**
     * Set floor
     *
     * @param string $floor
     * @return Address
     */
    public function setFloor($floor)
    {
        $this->floor = $floor;
    
        return $this;
    }

    /**
     * Get floor
     *
     * @return string 
     */
    public function getFloor()
    {
        return $this->floor;
    }

    /**
     * Set lbPiAddress
     *
     * @param string $lbPiAddress
     * @return Address
     */
    public function setLbPiAddress($lbPiAddress)
    {
        $this->lbPiAddress = $lbPiAddress;
    
        return $this;
    }

    /**
     * Get lbPiAddress
     *
     * @return string 
     */
    public function getLbPiAddress()
    {
        return $this->lbPiAddress;
    }

    /**
     * Set lbPiPhone
     *
     * @param string $lbPiPhone
     * @return Address
     */
    public function setLbPiPhone($lbPiPhone)
    {
        $this->lbPiPhone = $lbPiPhone;
    
        return $this;
    }

    /**
     * Get lbPiPhone
     *
     * @return string 
     */
    public function getLbPiPhone()
    {
        return $this->lbPiPhone;
    }

    /**
     * Set lbPiFax
     *
     * @param string $lbPiFax
     * @return Address
     */
    public function setLbPiFax($lbPiFax)
    {
        $this->lbPiFax = $lbPiFax;
    
        return $this;
    }

    /**
     * Get lbPiFax
     *
     * @return string 
     */
    public function getLbPiFax()
    {
        return $this->lbPiFax;
    }

    /**
     * Set lbPiCorres
     *
     * @param string $lbPiCorres
     * @return Address
     */
    public function setLbPiCorres($lbPiCorres)
    {
        $this->lbPiCorres = $lbPiCorres;
    
        return $this;
    }

    /**
     * Get lbPiCorres
     *
     * @return string 
     */
    public function getLbPiCorres()
    {
        return $this->lbPiCorres;
    }

    /**
     * Set lbEntretien
     *
     * @param string $lbEntretien
     * @return Address
     */
    public function setLbEntretien($lbEntretien)
    {
        $this->lbEntretien = $lbEntretien;
    
        return $this;
    }

    /**
     * Get lbEntretien
     *
     * @return string 
     */
    public function getLbEntretien()
    {
        return $this->lbEntretien;
    }

    /**
     * Set billingGroup
     *
     * @param integer $billingGroup
     * @return Address
     */
    public function setBillingGroup($billingGroup)
    {
        $this->billingGroup = $billingGroup;
    
        return $this;
    }

    /**
     * Get billingGroup
     *
     * @return integer 
     */
    public function getBillingGroup()
    {
        return $this->billingGroup;
    }

    /**
     * Set idCity
     *
     * @param \Etrali\GinangBundle\Entity\City $idCity
     * @return Address
     */
    public function setIdCity(\Etrali\GinangBundle\Entity\City $idCity = null)
    {
        $this->idCity = $idCity;
    
        return $this;
    }

    /**
     * Get idCity
     *
     * @return \Etrali\GinangBundle\Entity\City 
     */
    public function getIdCity()
    {
        return $this->idCity;
    }

    /**
     * Set idCountry
     *
     * @param \Etrali\GinangBundle\Entity\Country $idCountry
     * @return Address
     */
    public function setIdCountry(\Etrali\GinangBundle\Entity\Country $idCountry = null)
    {
        $this->idCountry = $idCountry;
    
        return $this;
    }

    /**
     * Get idCountry
     *
     * @return \Etrali\GinangBundle\Entity\Country 
     */
    public function getIdCountry()
    {
        return $this->idCountry;
    }

    /**
     * Set idAddressType
     *
     * @param \Etrali\GinangBundle\Entity\AddressType $idAddressType
     * @return Address
     */
    public function setIdAddressType(\Etrali\GinangBundle\Entity\AddressType $idAddressType = null)
    {
        $this->idAddressType = $idAddressType;
    
        return $this;
    }

    /**
     * Get idAddressType
     *
     * @return \Etrali\GinangBundle\Entity\AddressType 
     */
    public function getIdAddressType()
    {
        return $this->idAddressType;
    }

    
    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Address
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Address
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set blFrenchLocalLoop
     *
     * @param boolean $blFrenchLocalLoop
     * @return Address
     */
    public function setBlFrenchLocalLoop($blFrenchLocalLoop)
    {
        $this->blFrenchLocalLoop = $blFrenchLocalLoop;
    
        return $this;
    }

    /**
     * Get blFrenchLocalLoop
     *
     * @return boolean 
     */
    public function getBlFrenchLocalLoop()
    {
        return $this->blFrenchLocalLoop;
    }

    /**
     * Set cdAccountMagellan
     *
     * @param string $cdAccountMagellan
     * @return Address
     */
    public function setCdAccountMagellan($cdAccountMagellan)
    {
        $this->cdAccountMagellan = $cdAccountMagellan;
    
        return $this;
    }

    /**
     * Get cdAccountMagellan
     *
     * @return string 
     */
    public function getCdAccountMagellan()
    {
        return $this->cdAccountMagellan;
    }

    /**
     * Set idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     * @return Address
     */
    public function setIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer = null)
    {
        $this->idCustomer = $idCustomer;
    
        return $this;
    }

    /**
     * Get idCustomer
     *
     * @return \Etrali\GinangBundle\Entity\Customer 
     */
    public function getIdCustomer()
    {
        return $this->idCustomer;
    }

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idBillingGroup = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Add idBillingGroup
     *
     * @param \Etrali\GinangBundle\Entity\BillingGroup $idBillingGroup
     * @return Address
     */
    public function addIdBillingGroup(\Etrali\GinangBundle\Entity\BillingGroup $idBillingGroup)
    {
        $this->idBillingGroup[] = $idBillingGroup;
    
        return $this;
    }

    /**
     * Remove idBillingGroup
     *
     * @param \Etrali\GinangBundle\Entity\BillingGroup $idBillingGroup
     */
    public function removeIdBillingGroup(\Etrali\GinangBundle\Entity\BillingGroup $idBillingGroup)
    {
        $this->idBillingGroup->removeElement($idBillingGroup);
    }

    /**
     * Get idBillingGroup
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingGroup()
    {
        return $this->idBillingGroup;
    }
            
    /**
     * 
     * @return Branch
     */
    public function getParentBranch() {
        if ($this->getIdCustomer()!=null)
            return $this->getIdCustomer()->getIdBranch();
        return NULL;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Address
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}