<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * AddressProvider
 *
 * @ORM\Table(name="address_provider")
 * @ORM\Entity
 */
class AddressProvider
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_address_provider", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idAddressProvider;

     /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_address", type="string", length=255, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(100) 
     */
    private $lbAddress;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_zip_code", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20) 
     */
    private $cdZipCode;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_phone", type="string", length=20, nullable=true)
     * @Assert\MaxLength(30) 
     * 
     */
    private $lbPhone;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_fax", type="string", length=20, nullable=true)
     * @Assert\MaxLength(30) 
     */
    private $lbFax;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_email", type="string", length=100, nullable=true)
     * @Assert\MaxLength(128) 
     * @Assert\Email(
     *     message = "'{{ value }}' n'est pas un email valide."
     * )
     */
    private $lbEmail;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_status", type="boolean", nullable=true)
     */
    private $blStatus=true;

    /**
     * @var string
     *
     * @ORM\Column(name="comment", type="text", nullable=true)
     */
    private $comment;


    /**
     * @var string
     *
     * @ORM\Column(name="room", type="string", length=255, nullable=true)
     */
    private $room;

    /**
     * @var string
     *
     * @ORM\Column(name="floor", type="string", length=255, nullable=true)
     */
    private $floor;


    /**
     * @var \City
     *
     * @ORM\ManyToOne(targetEntity="City")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_city", referencedColumnName="id_city")
     * })
     * @Assert\NotNull() 
     */
    private $idCity;

    /**
     * @var \Country
     *
     * @ORM\ManyToOne(targetEntity="Country")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_country", referencedColumnName="id_country")
     * })
     * @Assert\NotNull() 
     */
    private $idCountry;

    /**
     * @var \AddressType
     *
     * @ORM\ManyToOne(targetEntity="AddressType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_address_type", referencedColumnName="id_address_type")
     * })
     * @Assert\NotNull() 
     */
    private $idAddressType;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;
    
    /**
     * @var \Provider
     *
     * @ORM\ManyToOne(targetEntity="Provider", inversedBy="idAddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * })
     */
    private $idProvider;   
    
        /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;
    
    /**
     * Get __toString
     *
     * @return string
     */    
    public function __toString()
    {
        return $this->getLbAddress()." ".$this->getCdZipCode()." ".$this->getIdCity();
    }
    
    public function getHeadInfo()
    {
            return "<td>".$this->getIdAddressType()."</td><td >".$this->getLbAddress()."</td><td>".$this->getIdCity()."</td><td>".$this->getCdZipCode()."</td><td>".$this->getIdCountry()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Type</th><th>Address</th><th>City</th><th>Post code</th><th>Country</th>";
    }      
  

    /**
     * Get idAddressProvider
     *
     * @return integer 
     */
    public function getIdAddressProvider()
    {
        return $this->idAddressProvider;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return AddressProvider
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return AddressProvider
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set lbAddress
     *
     * @param string $lbAddress
     * @return AddressProvider
     */
    public function setLbAddress($lbAddress)
    {
        $this->lbAddress = $lbAddress;
    
        return $this;
    }

    /**
     * Get lbAddress
     *
     * @return string 
     */
    public function getLbAddress()
    {
        return $this->lbAddress;
    }

    /**
     * Set cdZipCode
     *
     * @param string $cdZipCode
     * @return AddressProvider
     */
    public function setCdZipCode($cdZipCode)
    {
        $this->cdZipCode = $cdZipCode;
    
        return $this;
    }

    /**
     * Get cdZipCode
     *
     * @return string 
     */
    public function getCdZipCode()
    {
        return $this->cdZipCode;
    }

    /**
     * Set lbPhone
     *
     * @param string $lbPhone
     * @return AddressProvider
     */
    public function setLbPhone($lbPhone)
    {
        $this->lbPhone = $lbPhone;
    
        return $this;
    }

    /**
     * Get lbPhone
     *
     * @return string 
     */
    public function getLbPhone()
    {
        return $this->lbPhone;
    }

    /**
     * Set lbFax
     *
     * @param string $lbFax
     * @return AddressProvider
     */
    public function setLbFax($lbFax)
    {
        $this->lbFax = $lbFax;
    
        return $this;
    }

    /**
     * Get lbFax
     *
     * @return string 
     */
    public function getLbFax()
    {
        return $this->lbFax;
    }

    /**
     * Set lbEmail
     *
     * @param string $lbEmail
     * @return AddressProvider
     */
    public function setLbEmail($lbEmail)
    {
        $this->lbEmail = $lbEmail;
    
        return $this;
    }

    /**
     * Get lbEmail
     *
     * @return string 
     */
    public function getLbEmail()
    {
        return $this->lbEmail;
    }

    /**
     * Set blStatus
     *
     * @param boolean $blStatus
     * @return AddressProvider
     */
    public function setBlStatus($blStatus)
    {
        $this->blStatus = $blStatus;
    
        return $this;
    }

    /**
     * Get blStatus
     *
     * @return boolean 
     */
    public function getBlStatus()
    {
        return $this->blStatus;
    }

    /**
     * Set comment
     *
     * @param string $comment
     * @return AddressProvider
     */
    public function setComment($comment)
    {
        $this->comment = $comment;
    
        return $this;
    }

    /**
     * Get comment
     *
     * @return string 
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * Set room
     *
     * @param string $room
     * @return AddressProvider
     */
    public function setRoom($room)
    {
        $this->room = $room;
    
        return $this;
    }

    /**
     * Get room
     *
     * @return string 
     */
    public function getRoom()
    {
        return $this->room;
    }

    /**
     * Set floor
     *
     * @param string $floor
     * @return AddressProvider
     */
    public function setFloor($floor)
    {
        $this->floor = $floor;
    
        return $this;
    }

    /**
     * Get floor
     *
     * @return string 
     */
    public function getFloor()
    {
        return $this->floor;
    }

    /**
     * Set idCity
     *
     * @param \Etrali\GinangBundle\Entity\City $idCity
     * @return AddressProvider
     */
    public function setIdCity(\Etrali\GinangBundle\Entity\City $idCity = null)
    {
        $this->idCity = $idCity;
    
        return $this;
    }

    /**
     * Get idCity
     *
     * @return \Etrali\GinangBundle\Entity\City 
     */
    public function getIdCity()
    {
        return $this->idCity;
    }

    /**
     * Set idCountry
     *
     * @param \Etrali\GinangBundle\Entity\Country $idCountry
     * @return AddressProvider
     */
    public function setIdCountry(\Etrali\GinangBundle\Entity\Country $idCountry = null)
    {
        $this->idCountry = $idCountry;
    
        return $this;
    }

    /**
     * Get idCountry
     *
     * @return \Etrali\GinangBundle\Entity\Country 
     */
    public function getIdCountry()
    {
        return $this->idCountry;
    }

    /**
     * Set idAddressType
     *
     * @param \Etrali\GinangBundle\Entity\AddressType $idAddressType
     * @return AddressProvider
     */
    public function setIdAddressType(\Etrali\GinangBundle\Entity\AddressType $idAddressType = null)
    {
        $this->idAddressType = $idAddressType;
    
        return $this;
    }

    /**
     * Get idAddressType
     *
     * @return \Etrali\GinangBundle\Entity\AddressType 
     */
    public function getIdAddressType()
    {
        return $this->idAddressType;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return AddressProvider
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return AddressProvider
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return AddressProvider
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }
public function getParentBranch() { return NULL; }  
    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return AddressProvider
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}