<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * AddressSimple
 *
 * @ORM\Table(name="address_simple")
 * @ORM\Entity
 */
class AddressSimple
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_address_simple", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idAddressSimple;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_address", type="string", length=255, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(100) 
     */
    private $lbAddress;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_zip_code", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20) 
     */
    private $cdZipCode;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_phone", type="string", length=20, nullable=true)
     * @Assert\MaxLength(30) 
     * 
     */
    private $lbPhone;


    /**
     * @var \City
     *
     * @ORM\ManyToOne(targetEntity="City")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_city", referencedColumnName="id_city")
     * })
     * @Assert\NotNull() 
     */
    private $idCity;

    /**
     * @var \Country
     *
     * @ORM\ManyToOne(targetEntity="Country")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_country", referencedColumnName="id_country")
     * })
     * @Assert\NotNull() 
     */
    private $idCountry;


    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    
    /**
     * Get __toString
     *
     * @return string
     */    
    public function __toString()
    {
        return $this->getLbAddress()." ".$this->getCdZipCode()." ".$this->getIdCity()." ".$this->getIdCountry();
    }
    

    
    public function getHeadInfo()
    {
            return "<td >".$this->getLbAddress()."</td><td>".$this->getIdCity()."</td><td>".$this->getCdZipCode()."</td><td>".$this->getIdCountry()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Address</th><th>City</th><th>Post code</th><th>Country</th>";
    } 

   

    /**
     * Get idAddressSimple
     *
     * @return integer 
     */
    public function getIdAddressSimple()
    {
        return $this->idAddressSimple;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return AddressSimple
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return AddressSimple
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set lbAddress
     *
     * @param string $lbAddress
     * @return AddressSimple
     */
    public function setLbAddress($lbAddress)
    {
        $this->lbAddress = $lbAddress;
    
        return $this;
    }

    /**
     * Get lbAddress
     *
     * @return string 
     */
    public function getLbAddress()
    {
        return $this->lbAddress;
    }

    /**
     * Set cdZipCode
     *
     * @param string $cdZipCode
     * @return AddressSimple
     */
    public function setCdZipCode($cdZipCode)
    {
        $this->cdZipCode = $cdZipCode;
    
        return $this;
    }

    /**
     * Get cdZipCode
     *
     * @return string 
     */
    public function getCdZipCode()
    {
        return $this->cdZipCode;
    }

    /**
     * Set lbPhone
     *
     * @param string $lbPhone
     * @return AddressSimple
     */
    public function setLbPhone($lbPhone)
    {
        $this->lbPhone = $lbPhone;
    
        return $this;
    }

    /**
     * Get lbPhone
     *
     * @return string 
     */
    public function getLbPhone()
    {
        return $this->lbPhone;
    }

    /**
     * Set idCity
     *
     * @param \Etrali\GinangBundle\Entity\City $idCity
     * @return AddressSimple
     */
    public function setIdCity(\Etrali\GinangBundle\Entity\City $idCity = null)
    {
        $this->idCity = $idCity;
    
        return $this;
    }

    /**
     * Get idCity
     *
     * @return \Etrali\GinangBundle\Entity\City 
     */
    public function getIdCity()
    {
        return $this->idCity;
    }

    /**
     * Set idCountry
     *
     * @param \Etrali\GinangBundle\Entity\Country $idCountry
     * @return AddressSimple
     */
    public function setIdCountry(\Etrali\GinangBundle\Entity\Country $idCountry = null)
    {
        $this->idCountry = $idCountry;
    
        return $this;
    }

    /**
     * Get idCountry
     *
     * @return \Etrali\GinangBundle\Entity\Country 
     */
    public function getIdCountry()
    {
        return $this->idCountry;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return AddressSimple
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return AddressSimple
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }public function getParentBranch() { return NULL; }  }