<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Bandwidth
 *
 * @ORM\Table(name="bandwidth")
 * @ORM\Entity
 */
class Bandwidth
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_bandwidth", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idBandwidth;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_bandwidth", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(10)     
     */
    private $cdBandwidth;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_bandwidth", type="string", length=100, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(50)
     */
    private $lbBandwidth;

    /**
     * @var float
     *
     * @ORM\Column(name="nb_bandwidth", type="decimal", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Bandwidth can not be zero")     
     */
    private $nbBandwidth;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_reactivated", type="datetime", nullable=true)
     */
    private $dtReactivated;   
      
    /**
     * __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
        return $this->lbBandwidth.'';
    }
    
    
    public function getHeadInfo()
    {
            return "<td>".$this->getCdBandwidth()."</td><td >".$this->getLbBandwidth()."</td><td>".$this->getNbBandwidth()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Bandwidth code</th><th>Bandwidth description</th><th>Bandwidth rate</th>";
    }     
    
    public function preSave(\Symfony\Component\Form\Form $form,$em)
    {
        if (!$this->getBlDeactivated() && $this->getDtDeactivated()==NULL)
            $this->setDtDeactivated(new \DateTime());
            
    } 
    
    /**
     * Get idBandwidth
     *
     * @return integer 
     */
    public function getIdBandwidth()
    {
        return $this->idBandwidth;
    }


    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idBandwidthAssignee = new \Doctrine\Common\Collections\ArrayCollection();
    }
 

    /**
     * Set cdBandwidth
     *
     * @param string $cdBandwidth
     * @return Bandwidth
     */
    public function setCdBandwidth($cdBandwidth)
    {
        $this->cdBandwidth = $cdBandwidth;
    
        return $this;
    }

    /**
     * Get cdBandwidth
     *
     * @return string 
     */
    public function getCdBandwidth()
    {
        return $this->cdBandwidth;
    }

    /**
     * Set lbBandwidth
     *
     * @param string $lbBandwidth
     * @return Bandwidth
     */
    public function setLbBandwidth($lbBandwidth)
    {
        $this->lbBandwidth = $lbBandwidth;
    
        return $this;
    }

    /**
     * Get lbBandwidth
     *
     * @return string 
     */
    public function getLbBandwidth()
    {
        return $this->lbBandwidth;
    }

    /**
     * Set nbBandwidth
     *
     * @param float $nbBandwidth
     * @return Bandwidth
     */
    public function setNbBandwidth($nbBandwidth)
    {
        $this->nbBandwidth = $nbBandwidth;
    
        return $this;
    }

    /**
     * Get nbBandwidth
     *
     * @return float 
     */
    public function getNbBandwidth()
    {
        return $this->nbBandwidth;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Bandwidth
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Bandwidth
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Bandwidth
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Bandwidth
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set dtReactivated
     *
     * @param \DateTime $dtReactivated
     * @return Bandwidth
     */
    public function setDtReactivated($dtReactivated)
    {
        $this->dtReactivated = $dtReactivated;
    
        return $this;
    }

    /**
     * Get dtReactivated
     *
     * @return \DateTime 
     */
    public function getDtReactivated()
    {
        return $this->dtReactivated;
    }

    /**
     * Set idBandwidthAssignee
     *
     * @param \Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidthAssignee
     * @return Bandwidth
     */
    public function setIdBandwidthAssignee(\Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidthAssignee = null)
    {
        $this->idBandwidthAssignee = $idBandwidthAssignee;
    
        return $this;
    }

    /**
     * Get idBandwidthAssignee
     *
     * @return \Etrali\GinangBundle\Entity\BandwidthAssignee 
     */
    public function getIdBandwidthAssignee()
    {
        return $this->idBandwidthAssignee;
    }
public function getParentBranch() { return NULL; }  }