<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Validator\ExecutionContext;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * BandwidthAssignee
 *
 * @ORM\Table(name="bandwidth_assignee")
 * @ORM\Entity
 * @Assert\Callback(methods={"hasOneBooleanValid"})  
 */
class BandwidthAssignee
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_bandwidth_assignee", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idBandwidthAssignee;
    
        /**
     * @var string
     *
     * @ORM\Column(name="cd_bandwidth_assignee", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(10)     
     */
    private $cdBandwidthAssignee;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_bandwidth_assignee", type="string", length=100, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(50)
     */
    private $lbBandwidthAssignee;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_product", type="boolean", nullable=true)
     */
    private $blProduct;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_local_loop", type="boolean", nullable=true)
     */
    private $blLocalLoop;    
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_backbone_link", type="boolean", nullable=true)
     */
    private $blBackboneLink;    
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_timeslot", type="boolean", nullable=true)
     */
    private $blTimeslot;   
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_device", type="boolean", nullable=true)
     */
    private $blDevice;       
    
    /**
     * @var \Product
     *
     * @ORM\OneToMany(targetEntity="Product", mappedBy="idBandwidthAssignee",cascade={"persist","remove"}, orphanRemoval=true )   
     */  
    private $idProduct;    
    
    /**
     * @var float
     *
     * @ORM\Column(name="nb_bandwidth", type="decimal", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Bandwidth can not be zero")     
     */
    private $nbBandwidth;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;
   

    
    /**
     * __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
        return $this->getLbBandwidthAssignee().'';
    }
    
      
     /**
     * Checks that at least one boolean is checked on form submission. If blProduct is checked, verifies that at least one product type has been selected.
     * 
     * @param \Etrali\GinangBundle\Entity\ExecutionContextInterface $context
     * 
     */
    
    public function hasOneBooleanValid(ExecutionContext $context)
    {
        if (!$this->getBlProduct() && !$this->getBlBackboneLink() && !$this->getBlLocalLoop() && !$this->getBlTimeslot()) {
            $context->addViolationAtSubPath('blProduct', 'At least one type checkbox should be checked', array(), null);            
        }

    }
    
    /**
     * Called just before saveObject that persists the object
     *
     * @param \Symfony\Component\Form\Form $form the valid form
     */
    public function preSave(\Symfony\Component\Form\Form $form, $em)
    {
        if ($this->getIdProduct())
        {
            foreach ($this->getIdProduct() as $line)
            {
                $line->setIdBandwidthAssignee($this);
            }
        }
    } 
    
    /**
     * Get idBandwidthAssignee
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->idBandwidthAssignee;
    }    
   
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idProduct = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idBandwidthAssignee
     *
     * @return integer 
     */
    public function getIdBandwidthAssignee()
    {
        return $this->idBandwidthAssignee;
    }

    
    /**
     * Set cdBandwidthAssignee
     *
     * @param string $cdBandwidthAssignee
     * @return BandwidthAssignee
     */
    public function setCdBandwidthAssignee($cdBandwidthAssignee)
    {
        $this->cdBandwidthAssignee = $cdBandwidthAssignee;
    
        return $this;
    }

    /**
     * Get cdBandwidthAssignee
     *
     * @return string 
     */
    public function getCdBandwidthAssignee()
    {
        return $this->cdBandwidthAssignee;
    }

    /**
     * Set lbBandwidthAssignee
     *
     * @param string $lbBandwidthAssignee
     * @return BandwidthAssignee
     */
    public function setLbBandwidthAssignee($lbBandwidthAssignee)
    {
        $this->lbBandwidthAssignee = $lbBandwidthAssignee;
    
        return $this;
    }

    /**
     * Get lbBandwidthAssignee
     *
     * @return string 
     */
    public function getLbBandwidthAssignee()
    {
        return $this->lbBandwidthAssignee;
    }

    /**
     * Set blProduct
     *
     * @param boolean $blProduct
     * @return BandwidthAssignee
     */
    public function setBlProduct($blProduct)
    {
        $this->blProduct = $blProduct;
    
        return $this;
    }

    /**
     * Get blProduct
     *
     * @return boolean 
     */
    public function getBlProduct()
    {
        return $this->blProduct;
    }

    /**
     * Set blLocalLoop
     *
     * @param boolean $blLocalLoop
     * @return BandwidthAssignee
     */
    public function setBlLocalLoop($blLocalLoop)
    {
        $this->blLocalLoop = $blLocalLoop;
    
        return $this;
    }

    /**
     * Get blLocalLoop
     *
     * @return boolean 
     */
    public function getBlLocalLoop()
    {
        return $this->blLocalLoop;
    }

    /**
     * Set blBackboneLink
     *
     * @param boolean $blBackboneLink
     * @return BandwidthAssignee
     */
    public function setBlBackboneLink($blBackboneLink)
    {
        $this->blBackboneLink = $blBackboneLink;
    
        return $this;
    }

    /**
     * Get blBackboneLink
     *
     * @return boolean 
     */
    public function getBlBackboneLink()
    {
        return $this->blBackboneLink;
    }

    /**
     * Set blTimeslot
     *
     * @param boolean $blTimeslot
     * @return BandwidthAssignee
     */
    public function setBlTimeslot($blTimeslot)
    {
        $this->blTimeslot = $blTimeslot;
    
        return $this;
    }

    /**
     * Get blTimeslot
     *
     * @return boolean 
     */
    public function getBlTimeslot()
    {
        return $this->blTimeslot;
    }

    /**
     * Set nbBandwidth
     *
     * @param float $nbBandwidth
     * @return BandwidthAssignee
     */
    public function setNbBandwidth($nbBandwidth)
    {
        $this->nbBandwidth = $nbBandwidth;
    
        return $this;
    }

    /**
     * Get nbBandwidth
     *
     * @return float 
     */
    public function getNbBandwidth()
    {
        return $this->nbBandwidth;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return BandwidthAssignee
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return BandwidthAssignee
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return BandwidthAssignee
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return BandwidthAssignee
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Add idProduct
     *
     * @param \Etrali\GinangBundle\Entity\Product $idProduct
     * @return BandwidthAssignee
     */
    public function addIdProduct(\Etrali\GinangBundle\Entity\Product $idProduct)
    {
        $this->idProduct[] = $idProduct;
    
        return $this;
    }

    /**
     * Remove idProduct
     *
     * @param \Etrali\GinangBundle\Entity\Product $idProduct
     */
    public function removeIdProduct(\Etrali\GinangBundle\Entity\Product $idProduct)
    {
        $this->idProduct->removeElement($idProduct);
    }

    /**
     * Get idProduct
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdProduct()
    {
        return $this->idProduct;
    }
public function getParentBranch() { return NULL; }  
    /**
     * Set blDevice
     *
     * @param boolean $blDevice
     * @return BandwidthAssignee
     */
    public function setBlDevice($blDevice)
    {
        $this->blDevice = $blDevice;
    
        return $this;
    }

    /**
     * Get blDevice
     *
     * @return boolean 
     */
    public function getBlDevice()
    {
        return $this->blDevice;
    }
}