<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * BillingService
 *
 * @ORM\Table(name="billing_service")
 * @ORM\Entity
 */
class BillingService
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_billing_service", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idBillingService;


    /**
     * @var string
     *
     * @ORM\Column(name="cd_contract", type="string", length=15, nullable=true)
     */
    private $cdContract;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_account", type="string", length=15, nullable=true)
     */
    private $cdAccount;

    /**
     * @var \BillingGroup
     *
     * @ORM\ManyToOne(targetEntity="BillingGroup")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_group", referencedColumnName="id_billing_group")
     * })
     */
    private $idBillingGroup;

    /**
     * @var string
     *
     * @ORM\Column(name="cm_billing", type="string", length=255, nullable=true)
     */
    private $cmBilling;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \NoticePeriod
     *
     * @ORM\ManyToOne(targetEntity="NoticePeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_notice_period", referencedColumnName="id_notice_period")
     * })
     * @Assert\NotNull();     
     */
    private $idNoticePeriod;

    /**
     * @var \BillingFrequency
     *
     * @ORM\ManyToOne(targetEntity="BillingFrequency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_frequency", referencedColumnName="id_billing_frequency")
     * })
     * @Assert\NotNull();     
     */
    private $idBillingFrequency;

    /**
     * @var \Customer
     *
     * @ORM\ManyToOne(targetEntity="Customer")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_customer", referencedColumnName="id_customer")
     * })
     * @Assert\NotNull();
     */
    private $idCustomer;


    /**
     * @var \Address
     *
     * @ORM\ManyToOne(targetEntity="Address")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_address", referencedColumnName="id_address")
     * })
     * @Assert\NotNull();     
     */
    private $idAddress;

    /**
     * @var \Contact
     *
     * @ORM\ManyToOne(targetEntity="Contact")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact")
     * })
     * @Assert\NotNull();     
     */
    private $idContact;

    /**
     * @var \Branch
     *
     * @ORM\ManyToOne(targetEntity="Branch")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_branch", referencedColumnName="id_branch")
     * })
     * @Assert\NotNull();     
     */
    private $idBranch;
    
    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_customer_manager", referencedColumnName="id")
     * })
     * @Assert\NotNull();      
     */
    private $idCustomerManager;     

    /**
     * @var \Service
     *
     * @ORM\ManyToOne(targetEntity="Service", inversedBy="idBillingService")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_service", referencedColumnName="id_service")
     * })
     */
    private $idService;

     /**
     * @var \BillingServiceLine
     *
     * @ORM\OneToMany(targetEntity="BillingServiceLine", mappedBy="idBillingService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"dtEndMrc" = "asc","idBillingServiceLine" = "asc"})         
     */
    private $idBillingServiceLine;
    
 /**
     * @var \BillingOneShot
     *
     * @ORM\OneToMany(targetEntity="BillingOneShot", mappedBy="idBillingService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idBillingOneShot" = "asc"})         
     */
    private $idBillingOneShot;      
    
/**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start", type="datetime", nullable=true)        
     */
    private $dtStart;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end", type="datetime", nullable=true)
     */
    private $dtEnd;


    /**
     * @var integer
     *
     * @ORM\Column(name="nb_contract_duration", type="integer", nullable=true)
     * @Assert\NotBlank();     
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Contract duration can not be zero")  
     */
    private $nbContractDuration;

    /**
     * @var float
     *
     * @ORM\Column(name="nb_percent", type="decimal", nullable=true)
     * @Assert\Regex("/^[0-9]+(\.[0-9]+)?$/")
     * @Assert\Range(
     *      min = "0",
     *      max = "100",
     *      minMessage = "Percent can not be zero",
     *      maxMessage = "Percent can not exceed 100")     
     */
    private $nbPercent;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 
    
        
    /**
     * Called just before saveObject that persists the object
     *
     * @param \Symfony\Component\Form\Form $form the valid form
     */
    public function preSave(\Symfony\Component\Form\Form $form, $em)
    {
            foreach ($this->getIdBillingServiceLine() as $line)
            {
                if ($line->getIdServiceExtremity()->count()==0)
                    $em->remove($line);                    
                else
                    $line->setIdBillingService($this);
            }
            if ($this->getIdBillingOneShot())
            {
                foreach ($this->getIdBillingOneShot() as $line)
                {
                    if ($line->getIdServiceExtremity()->count()==0)
                        $em->remove($line);                    
                    else                    
                        $line->setIdBillingService($this);
                }         
            }
            $em->flush();
    }     

    public function __toString() {
        if ($this->getIdCustomer()==NULL)
            return "[To be assigned to a customer]";
        return $this->getIdCustomer()."";
    }
    

    public function getHeadInfo()
    {
        $lastline=NULL;
        $id=0;        
        foreach ($this->getIdBillingServiceLine() as $line)
        {
            if ($line->getIdBillingServiceLine() > $id)
                $lastline=$line;
        }
        $currency="";
        $mrc="";
        $mrcdate="";
        if ($lastline!=NULL)
        {
            $currency=$lastline->getIdCurrency();
            $mrc=$lastline->getMtMrcEuro();
            $mrcdate=($lastline->getDtStartMrc()!=NULL?$lastline->getDtStartMrc()->format("d/m/Y H:i"):"");
        }
        return "<td></td><td>".$this."&nbsp;</td><td>".$this->getIdAddress()."</td><td>".$currency."</td><td>".$mrc."</td><td>".$mrcdate."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Extremity ref</th><th>Billed customer</th><th>Billing address</th><th>Currency</th><th>MRC</th><th>MRC start date</th>";
    }    
    
    public function getEditType($type)
    {
        $idtrans=$this->getIdService()->getIdTransactionStatus()->getIdTransactionStatus();
        $idtype=$this->getIdService()->getIdTransactionType()->getIdTransactionType();        
        $type->setTransaction($idtype,$idtrans); 
        $type->setObject($this);
        return $type;
    }    

   
    public function getParentBranch() { return NULL; }  
/**
     * Constructor
     */
    public function __construct()
    {
        $this->idBillingServiceLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idBillingService
     *
     * @return integer 
     */
    public function getIdBillingService()
    {
        return $this->idBillingService;
    }

    /**
     * Set cdContract
     *
     * @param string $cdContract
     * @return BillingService
     */
    public function setCdContract($cdContract)
    {
        $this->cdContract = $cdContract;
    
        return $this;
    }

    /**
     * Get cdContract
     *
     * @return string 
     */
    public function getCdContract()
    {
        return $this->cdContract;
    }

    /**
     * Set cdAccount
     *
     * @param string $cdAccount
     * @return BillingService
     */
    public function setCdAccount($cdAccount)
    {
        $this->cdAccount = $cdAccount;
    
        return $this;
    }

    /**
     * Get cdAccount
     *
     * @return string 
     */
    public function getCdAccount()
    {
        return $this->cdAccount;
    }

    /**
     * Set cmBilling
     *
     * @param string $cmBilling
     * @return BillingService
     */
    public function setCmBilling($cmBilling)
    {
        $this->cmBilling = $cmBilling;
    
        return $this;
    }

    /**
     * Get cmBilling
     *
     * @return string 
     */
    public function getCmBilling()
    {
        return $this->cmBilling;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return BillingService
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return BillingService
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set idBillingGroup
     *
     * @param \Etrali\GinangBundle\Entity\BillingGroup $idBillingGroup
     * @return BillingService
     */
    public function setIdBillingGroup(\Etrali\GinangBundle\Entity\BillingGroup $idBillingGroup = null)
    {
        $this->idBillingGroup = $idBillingGroup;
    
        return $this;
    }

    /**
     * Get idBillingGroup
     *
     * @return \Etrali\GinangBundle\Entity\BillingGroup 
     */
    public function getIdBillingGroup()
    {
        return $this->idBillingGroup;
    }

    /**
     * Set idNoticePeriod
     *
     * @param \Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod
     * @return BillingService
     */
    public function setIdNoticePeriod(\Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod = null)
    {
        $this->idNoticePeriod = $idNoticePeriod;
    
        return $this;
    }

    /**
     * Get idNoticePeriod
     *
     * @return \Etrali\GinangBundle\Entity\NoticePeriod 
     */
    public function getIdNoticePeriod()
    {
        return $this->idNoticePeriod;
    }

    /**
     * Set idBillingFrequency
     *
     * @param \Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency
     * @return BillingService
     */
    public function setIdBillingFrequency(\Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency = null)
    {
        $this->idBillingFrequency = $idBillingFrequency;
    
        return $this;
    }

    /**
     * Get idBillingFrequency
     *
     * @return \Etrali\GinangBundle\Entity\BillingFrequency 
     */
    public function getIdBillingFrequency()
    {
        return $this->idBillingFrequency;
    }

    /**
     * Set idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     * @return BillingService
     */
    public function setIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer = null)
    {
        $this->idCustomer = $idCustomer;
    
        return $this;
    }

    /**
     * Get idCustomer
     *
     * @return \Etrali\GinangBundle\Entity\Customer 
     */
    public function getIdCustomer()
    {
        return $this->idCustomer;
    }

    /**
     * Set idAddress
     *
     * @param \Etrali\GinangBundle\Entity\Address $idAddress
     * @return BillingService
     */
    public function setIdAddress(\Etrali\GinangBundle\Entity\Address $idAddress = null)
    {
        $this->idAddress = $idAddress;
    
        return $this;
    }

    /**
     * Get idAddress
     *
     * @return \Etrali\GinangBundle\Entity\Address 
     */
    public function getIdAddress()
    {
        return $this->idAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\Contact $idContact
     * @return BillingService
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\Contact $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\Contact 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Set idBranch
     *
     * @param \Etrali\GinangBundle\Entity\Branch $idBranch
     * @return BillingService
     */
    public function setIdBranch(\Etrali\GinangBundle\Entity\Branch $idBranch = null)
    {
        $this->idBranch = $idBranch;
    
        return $this;
    }

    /**
     * Get idBranch
     *
     * @return \Etrali\GinangBundle\Entity\Branch 
     */
    public function getIdBranch()
    {
        return $this->idBranch;
    }

    /**
     * Set idCustomerManager
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idCustomerManager
     * @return BillingService
     */
    public function setIdCustomerManager(\Etrali\GinangBundle\Entity\Myuser $idCustomerManager = null)
    {
        $this->idCustomerManager = $idCustomerManager;
    
        return $this;
    }

    /**
     * Get idCustomerManager
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdCustomerManager()
    {
        return $this->idCustomerManager;
    }

    /**
     * Set idService
     *
     * @param \Etrali\GinangBundle\Entity\Service $idService
     * @return BillingService
     */
    public function setIdService(\Etrali\GinangBundle\Entity\Service $idService = null)
    {
        $this->idService = $idService;
    
        return $this;
    }

    /**
     * Get idService
     *
     * @return \Etrali\GinangBundle\Entity\Service 
     */
    public function getIdService()
    {
        return $this->idService;
    }

    /**
     * Add idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     * @return BillingService
     */
    public function addIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine[] = $idBillingServiceLine;
    
        return $this;
    }

    /**
     * Remove idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     */
    public function removeIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine->removeElement($idBillingServiceLine);
    }

    /**
     * Get idBillingServiceLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingServiceLine()
    {
        return $this->idBillingServiceLine;
    }

    /**
     * Add idBillingOneShot
     *
     * @param \Etrali\GinangBundle\Entity\BillingOneShot $idBillingOneShot
     * @return BillingService
     */
    public function addIdBillingOneShot(\Etrali\GinangBundle\Entity\BillingOneShot $idBillingOneShot)
    {
        $this->idBillingOneShot[] = $idBillingOneShot;
    
        return $this;
    }

    /**
     * Remove idBillingOneShot
     *
     * @param \Etrali\GinangBundle\Entity\BillingOneShot $idBillingOneShot
     */
    public function removeIdBillingOneShot(\Etrali\GinangBundle\Entity\BillingOneShot $idBillingOneShot)
    {
        $this->idBillingOneShot->removeElement($idBillingOneShot);
    }

    /**
     * Get idBillingOneShot
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingOneShot()
    {
        return $this->idBillingOneShot;
    }

    /**
     * Set dtStart
     *
     * @param \DateTime $dtStart
     * @return BillingService
     */
    public function setDtStart($dtStart)
    {
        $this->dtStart = $dtStart;
    
        return $this;
    }

    /**
     * Get dtStart
     *
     * @return \DateTime 
     */
    public function getDtStart()
    {
        return $this->dtStart;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return BillingService
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set nbContractDuration
     *
     * @param integer $nbContractDuration
     * @return BillingService
     */
    public function setNbContractDuration($nbContractDuration)
    {
        $this->nbContractDuration = $nbContractDuration;
    
        return $this;
    }

    /**
     * Get nbContractDuration
     *
     * @return integer 
     */
    public function getNbContractDuration()
    {
        return $this->nbContractDuration;
    }

    /**
     * Set nbPercent
     *
     * @param float $nbPercent
     * @return BillingService
     */
    public function setNbPercent($nbPercent)
    {
        $this->nbPercent = $nbPercent;
    
        return $this;
    }

    /**
     * Get nbPercent
     *
     * @return float 
     */
    public function getNbPercent()
    {
        return $this->nbPercent;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return BillingService
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}