<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Branch
 *
 * @ORM\Table(name="branch")
 * @ORM\Entity
 */
class Branch
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_branch", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idBranch;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_branch", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(10)       
     */
    private $cdBranch;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_branch", type="string", length=100, nullable=false)
     */
    private $lbBranch;


    /**
     * @var string
     *
     * @ORM\Column(name="nb_gmt", type="string", length=15, nullable=true)
     * @Assert\Regex("/^[\-]?[0-9]+$/")
     * @Assert\Range(
     *      min = "-12",
     *      max = "12",
     *      minMessage = "Time Zone must be greater than -12",
     *      maxMessage = "Time Zone must be lesser than 12"
     * )     
     */
    private $nbGmt;

    /**
     * @var float
     *
     * @ORM\Column(name="nb_day_in_service", type="decimal", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of units can not be zero")        
     */
    private $nbDayInService;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end", type="datetime", nullable=true)
     */
    private $dtEnd;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;
    
    /**
     * @var \AddressSimple
     *
     * @ORM\ManyToOne(targetEntity="AddressSimple",cascade={"persist","remove"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_address_simple", referencedColumnName="id_address_simple")
     * })
     * @Assert\NotNull() 
     */
    private $idAddressSimple;    

    /**
     * @var \BranchCluster
     *
     * @ORM\ManyToOne(targetEntity="BranchCluster", inversedBy="idBranch")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_branch_cluster", referencedColumnName="id_branch_cluster")
     * }) 
     */
    private $idBranchCluster;
    
    /**
     * @var \Customer
     *
     * @ORM\OneToMany(targetEntity="Customer", mappedBy="idBranch") 
     *
     */
    
    private $idCustomer;
    
    /**
     * @var \BillingPeriodRef
     *
     * @ORM\OneToMany(targetEntity="BillingPeriodRef", mappedBy="idBranch",cascade={"persist","remove"})
     * @ORM\OrderBy({"dtBillingStart" = "asc"})       
     */
    
    private $idBillingPeriodRef;    

    
    /**
     * @var \UserInBranch
     *
     * @ORM\OneToMany(targetEntity="UserInBranch", mappedBy="idBranch",cascade={"persist","remove"}, orphanRemoval=true )     
     */
    private $idUserInBranch;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbBranch().'';
    }
  
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCustomer = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idBillingPeriodRef = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idBranch
     *
     * @return integer 
     */
    public function getIdBranch()
    {
        return $this->idBranch;
    }

    /**
     * Set cdBranch
     *
     * @param string $cdBranch
     * @return Branch
     */
    public function setCdBranch($cdBranch)
    {
        $this->cdBranch = $cdBranch;
    
        return $this;
    }

    /**
     * Get cdBranch
     *
     * @return string 
     */
    public function getCdBranch()
    {
        return $this->cdBranch;
    }

    /**
     * Set lbBranch
     *
     * @param string $lbBranch
     * @return Branch
     */
    public function setLbBranch($lbBranch)
    {
        $this->lbBranch = $lbBranch;
    
        return $this;
    }

    /**
     * Get lbBranch
     *
     * @return string 
     */
    public function getLbBranch()
    {
        return $this->lbBranch;
    }

    /**
     * Set nbGmt
     *
     * @param string $nbGmt
     * @return Branch
     */
    public function setNbGmt($nbGmt)
    {
        $this->nbGmt = $nbGmt;
    
        return $this;
    }

    /**
     * Get nbGmt
     *
     * @return string 
     */
    public function getNbGmt()
    {
        return $this->nbGmt;
    }

    /**
     * Set nbDayInService
     *
     * @param float $nbDayInService
     * @return Branch
     */
    public function setNbDayInService($nbDayInService)
    {
        $this->nbDayInService = $nbDayInService;
    
        return $this;
    }

    /**
     * Get nbDayInService
     *
     * @return float 
     */
    public function getNbDayInService()
    {
        return $this->nbDayInService;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Branch
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Branch
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Branch
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate() 
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return Branch
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Branch
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Branch
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idAddressSimple
     *
     * @param \Etrali\GinangBundle\Entity\AddressSimple $idAddressSimple
     * @return Branch
     */
    public function setIdAddressSimple(\Etrali\GinangBundle\Entity\AddressSimple $idAddressSimple = null)
    {
        $this->idAddressSimple = $idAddressSimple;
    
        return $this;
    }

    /**
     * Get idAddressSimple
     *
     * @return \Etrali\GinangBundle\Entity\AddressSimple 
     */
    public function getIdAddressSimple()
    {
        return $this->idAddressSimple;
    }

    /**
     * Set idBranchCluster
     *
     * @param \Etrali\GinangBundle\Entity\BranchCluster $idBranchCluster
     * @return Branch
     */
    public function setIdBranchCluster(\Etrali\GinangBundle\Entity\BranchCluster $idBranchCluster = null)
    {
        $this->idBranchCluster = $idBranchCluster;
    
        return $this;
    }

    /**
     * Get idBranchCluster
     *
     * @return \Etrali\GinangBundle\Entity\BranchCluster 
     */
    public function getIdBranchCluster()
    {
        return $this->idBranchCluster;
    }

    /**
     * Add idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     * @return Branch
     */
    public function addIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer)
    {
        $this->idCustomer[] = $idCustomer;
    
        return $this;
    }

    /**
     * Remove idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     */
    public function removeIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer)
    {
        $this->idCustomer->removeElement($idCustomer);
    }

    /**
     * Get idCustomer
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCustomer()
    {
        return $this->idCustomer;
    }

    /**
     * Add idBillingPeriodRef
     *
     * @param \Etrali\GinangBundle\Entity\BillingPeriodRef $idBillingPeriodRef
     * @return Branch
     */
    public function addIdBillingPeriodRef(\Etrali\GinangBundle\Entity\BillingPeriodRef $idBillingPeriodRef)
    {
        $this->idBillingPeriodRef[] = $idBillingPeriodRef;
    
        return $this;
    }

    /**
     * Remove idBillingPeriodRef
     *
     * @param \Etrali\GinangBundle\Entity\BillingPeriodRef $idBillingPeriodRef
     */
    public function removeIdBillingPeriodRef(\Etrali\GinangBundle\Entity\BillingPeriodRef $idBillingPeriodRef)
    {
        $this->idBillingPeriodRef->removeElement($idBillingPeriodRef);
    }

    /**
     * Get idBillingPeriodRef
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingPeriodRef()
    {
        return $this->idBillingPeriodRef;
    }
    /**
     * Add idMailUser
     *
     * @param \Etrali\GinangBundle\Entity\MailUser $idMailUser
     * @return Branch
     */
    public function addIdMailUser(\Etrali\GinangBundle\Entity\MailUser $idMailUser)
    {
        $this->idMailUser[] = $idMailUser;
    
        return $this;
    }

    /**
     * Remove idMailUser
     *
     * @param \Etrali\GinangBundle\Entity\MailUser $idMailUser
     */
    public function removeIdMailUser(\Etrali\GinangBundle\Entity\MailUser $idMailUser)
    {
        $this->idMailUser->removeElement($idMailUser);
    }

    /**
     * Get idMailUser
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdMailUser()
    {
        return $this->idMailUser;
    }

    /**
     * Add idUserInBranch
     *
     * @param \Etrali\GinangBundle\Entity\UserInBranch $idUserInBranch
     * @return Branch
     */
    public function addIdUserInBranch(\Etrali\GinangBundle\Entity\UserInBranch $idUserInBranch)
    {
        $this->idUserInBranch[] = $idUserInBranch;
    
        return $this;
    }

    /**
     * Remove idUserInBranch
     *
     * @param \Etrali\GinangBundle\Entity\UserInBranch $idUserInBranch
     */
    public function removeIdUserInBranch(\Etrali\GinangBundle\Entity\UserInBranch $idUserInBranch)
    {
        $this->idUserInBranch->removeElement($idUserInBranch);
    }

    /**
     * Get idUserInBranch
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdUserInBranch()
    {
        return $this->idUserInBranch;
    }
public function getParentBranch() { return NULL; }  
    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Branch
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}