<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
/**
 * Cabinet
 *
 * @ORM\Table(name="cabinet")
 * @ORM\Entity
 */
class Cabinet
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_cabinet", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCabinet;

    
    /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="CabinetType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cabinet_type", referencedColumnName="id_cabinet_type")
     * })
     * @Assert\NotNull() 
     */
    private $idCabinetType;    


    /**
     * @var string
     *
     * @ORM\Column(name="cd_cabinet", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(10)   
     */
    private $cdCabinet;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_cabinet", type="string", length=100, nullable=false)
     * @Assert\MaxLength(30)  
     */
    private $lbCabinet;



    /**
     * @var string
     *
     * @ORM\Column(name="cm_cabinet", type="string", length=255, nullable=true)
     */
    private $cmCabinet;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;


    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var integer
     *
     * @ORM\Column(name="id_user_create_by", type="integer", nullable=true)
     */
    private $idUserCreateBy;

    /**
     * @var integer
     *
     * @ORM\Column(name="id_user_update_by", type="integer", nullable=true)
     */
    private $idUserUpdateBy;

    /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * }) 
     * @Assert\NotNull()       
     */
    private $idProvider;
    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()  	          
     */
    private $idProviderAddress;    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * }) 
     * @Assert\NotNull()     
     */
    private $idContact;

    /**
     * @var string
     *
     * @ORM\Column(name="url_image", type="string", length=100, nullable=true)
     */
    private $urlImage;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_units", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of units can not be zero")   
     */
    private $nbUnits;

    /**
     * @var \CabinetSize
     *
     * @ORM\ManyToOne(targetEntity="CabinetSize")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cabinet_size", referencedColumnName="id_cabinet_size")
     * })
     * @Assert\NotNull()      
     */
    private $idCabinetSize;
    

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_frontback", type="boolean", nullable=true)
     */
    private $blFrontback;  
    

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_model", type="boolean", nullable=true)
     */
    private $blModel=true;   
    
    /**
     * @var \CostingCabinetLine
     *
     * @ORM\OneToMany(targetEntity="CostingCabinetLine", mappedBy="idCabinet",cascade={"persist","remove"}, orphanRemoval=true )

     */
    private $idCostingCabinetLine;   
     

    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel", inversedBy="idCabinet")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     */
    private $idComplexModel;   
    
    /**
     * @var \Equipment
     *
     * @ORM\OneToMany(targetEntity="Equipment", mappedBy="idCabinet",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idEquipment;    
    
    /**
     * @var \PatchPanel
     *
     * @ORM\OneToMany(targetEntity="PatchPanel", mappedBy="idCabinet",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idPatchPanel;     
         
    public function getCollections()
    {
        return array("Costings"=>"CostingCabinetLine");       
    }       
     
    
    /**
     * @return string
     *
     */
    public function __toString()
    {
        return $this->lbCabinet.'';
    }    
    
    /**
     * Clone function. Clones an entity and all necessary ManyToOne relations. 
     * Parent entities are not cloned but only children
     *
     * @return Cabinet
     */    
    public function duplique() {
        if ($this->idCabinet) {
            $this->idCabinet=null;
            $ac = new ArrayCollection();                
            foreach ($this->idCostingCabinetLine as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->setIdCabinet($this);
                $ac->add($cloneElem);                
            }
            $this->idCostingCabinetLine=$ac;                         
            $ac = new ArrayCollection();            
            foreach ($this->idEquipment as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);
                $cloneElem->setIdCabinet($this);                  
            }            
            $this->idEquipment=$ac;
            $ac = new ArrayCollection();                
            foreach ($this->idPatchPanel as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);                
                $cloneElem->setIdCabinet($this);                                  
            }            
            $this->idPatchPanel=$ac;
        }
    }   
    
    public function setIdEquipment(\Doctrine\Common\Collections\ArrayCollection $ac)
    {
         $this->idEquipment = $ac;
        return $this;         
    }
    
    public function setIdPatchPanel(\Doctrine\Common\Collections\ArrayCollection $ac)
    {
         $this->idPatchPanel = $ac;
        return $this;         
    }
    
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCostingCabinetLine = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idEquipment = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idPatchPanel = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idCabinet
     *
     * @return integer 
     */
    public function getIdCabinet()
    {
        return $this->idCabinet;
    }

    /**
     * Set cdCabinet
     *
     * @param string $cdCabinet
     * @return Cabinet
     */
    public function setCdCabinet($cdCabinet)
    {
        $this->cdCabinet = $cdCabinet;
    
        return $this;
    }

    /**
     * Get cdCabinet
     *
     * @return string 
     */
    public function getCdCabinet()
    {
        return $this->cdCabinet;
    }

    /**
     * Set lbCabinet
     *
     * @param string $lbCabinet
     * @return Cabinet
     */
    public function setLbCabinet($lbCabinet)
    {
        $this->lbCabinet = $lbCabinet;
    
        return $this;
    }

    /**
     * Get lbCabinet
     *
     * @return string 
     */
    public function getLbCabinet()
    {
        return $this->lbCabinet;
    }

    /**
     * Set cmCabinet
     *
     * @param string $cmCabinet
     * @return Cabinet
     */
    public function setCmCabinet($cmCabinet)
    {
        $this->cmCabinet = $cmCabinet;
    
        return $this;
    }

    /**
     * Get cmCabinet
     *
     * @return string 
     */
    public function getCmCabinet()
    {
        return $this->cmCabinet;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Cabinet
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Cabinet
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Cabinet
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set idUserCreateBy
     *
     * @param integer $idUserCreateBy
     * @return Cabinet
     */
    public function setIdUserCreateBy($idUserCreateBy)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return integer 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param integer $idUserUpdateBy
     * @return Cabinet
     */
    public function setIdUserUpdateBy($idUserUpdateBy)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return integer 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set urlImage
     *
     * @param string $urlImage
     * @return Cabinet
     */
    public function setUrlImage($urlImage)
    {
        $this->urlImage = $urlImage;
    
        return $this;
    }

    /**
     * Get urlImage
     *
     * @return string 
     */
    public function getUrlImage()
    {
        return $this->urlImage;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Cabinet
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set nbUnits
     *
     * @param integer $nbUnits
     * @return Cabinet
     */
    public function setNbUnits($nbUnits)
    {
        $this->nbUnits = $nbUnits;
    
        return $this;
    }

    /**
     * Get nbUnits
     *
     * @return integer 
     */
    public function getNbUnits()
    {
        return $this->nbUnits;
    }

    /**
     * Set blFrontback
     *
     * @param boolean $blFrontback
     * @return Cabinet
     */
    public function setBlFrontback($blFrontback)
    {
        $this->blFrontback = $blFrontback;
    
        return $this;
    }

    /**
     * Get blFrontback
     *
     * @return boolean 
     */
    public function getBlFrontback()
    {
        return $this->blFrontback;
    }

    /**
     * Set blModel
     *
     * @param boolean $blModel
     * @return Cabinet
     */
    public function setBlModel($blModel)
    {
        $this->blModel = $blModel;
    
        return $this;
    }

    /**
     * Get blModel
     *
     * @return boolean 
     */
    public function getBlModel()
    {
        return $this->blModel;
    }

    /**
     * Set idCabinetType
     *
     * @param \Etrali\GinangBundle\Entity\CabinetType $idCabinetType
     * @return Cabinet
     */
    public function setIdCabinetType(\Etrali\GinangBundle\Entity\CabinetType $idCabinetType = null)
    {
        $this->idCabinetType = $idCabinetType;
    
        return $this;
    }

    /**
     * Get idCabinetType
     *
     * @return \Etrali\GinangBundle\Entity\CabinetType 
     */
    public function getIdCabinetType()
    {
        return $this->idCabinetType;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return Cabinet
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return Cabinet
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return Cabinet
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Set idCabinetSize
     *
     * @param \Etrali\GinangBundle\Entity\CabinetSize $idCabinetSize
     * @return Cabinet
     */
    public function setIdCabinetSize(\Etrali\GinangBundle\Entity\CabinetSize $idCabinetSize = null)
    {
        $this->idCabinetSize = $idCabinetSize;
    
        return $this;
    }

    /**
     * Get idCabinetSize
     *
     * @return \Etrali\GinangBundle\Entity\CabinetSize 
     */
    public function getIdCabinetSize()
    {
        return $this->idCabinetSize;
    }

    /**
     * Add idCostingCabinetLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine
     * @return Cabinet
     */
    public function addIdCostingCabinetLine(\Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine)
    {
        $this->idCostingCabinetLine[] = $idCostingCabinetLine;
    
        return $this;
    }

    /**
     * Remove idCostingCabinetLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine
     */
    public function removeIdCostingCabinetLine(\Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine)
    {
        $this->idCostingCabinetLine->removeElement($idCostingCabinetLine);
    }

    /**
     * Get idCostingCabinetLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingCabinetLine()
    {
        return $this->idCostingCabinetLine;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return Cabinet
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Add idEquipment
     *
     * @param \Etrali\GinangBundle\Entity\Equipment $idEquipment
     * @return Cabinet
     */
    public function addIdEquipment(\Etrali\GinangBundle\Entity\Equipment $idEquipment)
    {
        $this->idEquipment[] = $idEquipment;
    
        return $this;
    }

    /**
     * Remove idEquipment
     *
     * @param \Etrali\GinangBundle\Entity\Equipment $idEquipment
     */
    public function removeIdEquipment(\Etrali\GinangBundle\Entity\Equipment $idEquipment)
    {
        $this->idEquipment->removeElement($idEquipment);
    }

    /**
     * Get idEquipment
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdEquipment()
    {
        return $this->idEquipment;
    }

    /**
     * Add idPatchPanel
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel
     * @return Cabinet
     */
    public function addIdPatchPanel(\Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel)
    {
        $this->idPatchPanel[] = $idPatchPanel;
    
        return $this;
    }

    /**
     * Remove idPatchPanel
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel
     */
    public function removeIdPatchPanel(\Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel)
    {
        $this->idPatchPanel->removeElement($idPatchPanel);
    }

    /**
     * Get idPatchPanel
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPatchPanel()
    {
        return $this->idPatchPanel;
    }public function getParentBranch() { return NULL; }  }