<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
/**
 * CabinetInstance
 *
 * @ORM\Table(name="cabinet_instance")
 * @ORM\Entity
 */
class CabinetInstance
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_cabinet_instance", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCabinetInstance;

    

    /**
     * @var string
     *
     * @ORM\Column(name="cd_cabinet_instance", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(10)   
     */
    private $cdCabinetInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_cabinet_instance", type="string", length=100, nullable=true)
     * @Assert\MaxLength(30)  
     */
    private $lbCabinetInstance;


    /**
     * @var string
     *
     * @ORM\Column(name="cd_serial_number", type="string", length=50, nullable=true)
     * @Assert\MaxLength(30)   
     */
    private $cdSerialNumber;

    /**
     * @var string
     *
     * @ORM\Column(name="cm_cabinet_instance", type="string", length=255, nullable=true)
     */
    private $cmCabinetInstance;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;


    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var integer
     *
     * @ORM\Column(name="id_user_create_by", type="integer", nullable=true)
     */
    private $idUserCreateBy;

    /**
     * @var integer
     *
     * @ORM\Column(name="id_user_update_by", type="integer", nullable=true)
     */
    private $idUserUpdateBy;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;


    /**
     * @var \Pop
     *
     * @ORM\ManyToOne(targetEntity="Pop", inversedBy="idCabinetInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_pop", referencedColumnName="id_pop")
     * })
     */
    private $idPop;   
    
    /**
     * @var \Cabinet
     *
     * @ORM\ManyToOne(targetEntity="Cabinet")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cabinet", referencedColumnName="id_cabinet")
     * })
     */
    private $idCabinet;     
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     * @Assert\NotNull()
     */
    private $idComplexModel;      
    
    /**
     * @var \EquipmentInstance
     *
     * @ORM\OneToMany(targetEntity="EquipmentInstance", mappedBy="idCabinetInstance",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idEquipmentInstance;    
    
    /**
     * @var \PatchPanelInstance
     *
     * @ORM\OneToMany(targetEntity="PatchPanelInstance", mappedBy="idCabinetInstance",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idPatchPanelInstance;     
    
    /**
     * @var \CostingCabinetLine
     *
     * @ORM\OneToMany(targetEntity="CostingCabinetLine", mappedBy="idCabinetInstance",cascade={"persist","remove"}, orphanRemoval=true )

     */
    private $idCostingCabinetLine;   
    
        /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProvider;

    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProviderAddress;

    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * })
     * @Assert\NotNull()
     */
    private $idContact;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     *
     * @Assert\MaxLength(20)
     */
    private $cdProviderAccount;  
    
    
    public function getCollections()
    {
        return array("Costings"=>"CostingCabinetLine");       
    } 
    
    /**
     * @return string
     *
     */
    public function __toString()
    {
        return $this->lbCabinetInstance.'';
    }    

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idEquipmentInstance = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idPatchPanelInstance = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingCabinetLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idCabinetInstance
     *
     * @return integer 
     */
    public function getIdCabinetInstance()
    {
        return $this->idCabinetInstance;
    }

    /**
     * Set cdCabinetInstance
     *
     * @param string $cdCabinetInstance
     * @return CabinetInstance
     */
    public function setCdCabinetInstance($cdCabinetInstance)
    {
        $this->cdCabinetInstance = $cdCabinetInstance;
    
        return $this;
    }

    /**
     * Get cdCabinetInstance
     *
     * @return string 
     */
    public function getCdCabinetInstance()
    {
        return $this->cdCabinetInstance;
    }

    /**
     * Set lbCabinetInstance
     *
     * @param string $lbCabinetInstance
     * @return CabinetInstance
     */
    public function setLbCabinetInstance($lbCabinetInstance)
    {
        $this->lbCabinetInstance = $lbCabinetInstance;
    
        return $this;
    }

    /**
     * Get lbCabinetInstance
     *
     * @return string 
     */
    public function getLbCabinetInstance()
    {
        return $this->lbCabinetInstance;
    }

    /**
     * Set cdSerialNumber
     *
     * @param string $cdSerialNumber
     * @return CabinetInstance
     */
    public function setCdSerialNumber($cdSerialNumber)
    {
        $this->cdSerialNumber = $cdSerialNumber;
    
        return $this;
    }

    /**
     * Get cdSerialNumber
     *
     * @return string 
     */
    public function getCdSerialNumber()
    {
        return $this->cdSerialNumber;
    }

    /**
     * Set cmCabinetInstance
     *
     * @param string $cmCabinetInstance
     * @return CabinetInstance
     */
    public function setCmCabinetInstance($cmCabinetInstance)
    {
        $this->cmCabinetInstance = $cmCabinetInstance;
    
        return $this;
    }

    /**
     * Get cmCabinetInstance
     *
     * @return string 
     */
    public function getCmCabinetInstance()
    {
        return $this->cmCabinetInstance;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return CabinetInstance
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return CabinetInstance
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return CabinetInstance
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set idUserCreateBy
     *
     * @param integer $idUserCreateBy
     * @return CabinetInstance
     */
    public function setIdUserCreateBy($idUserCreateBy)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return integer 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param integer $idUserUpdateBy
     * @return CabinetInstance
     */
    public function setIdUserUpdateBy($idUserUpdateBy)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return integer 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return CabinetInstance
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set idPop
     *
     * @param \Etrali\GinangBundle\Entity\Pop $idPop
     * @return CabinetInstance
     */
    public function setIdPop(\Etrali\GinangBundle\Entity\Pop $idPop = null)
    {
        $this->idPop = $idPop;
    
        return $this;
    }

    /**
     * Get idPop
     *
     * @return \Etrali\GinangBundle\Entity\Pop 
     */
    public function getIdPop()
    {
        return $this->idPop;
    }

    /**
     * Set idCabinet
     *
     * @param \Etrali\GinangBundle\Entity\Cabinet $idCabinet
     * @return CabinetInstance
     */
    public function setIdCabinet(\Etrali\GinangBundle\Entity\Cabinet $idCabinet = null)
    {
        $this->idCabinet = $idCabinet;
    
        return $this;
    }

    /**
     * Get idCabinet
     *
     * @return \Etrali\GinangBundle\Entity\Cabinet 
     */
    public function getIdCabinet()
    {
        return $this->idCabinet;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return CabinetInstance
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Add idEquipmentInstance
     *
     * @param \Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance
     * @return CabinetInstance
     */
    public function addIdEquipmentInstance(\Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance)
    {
        $this->idEquipmentInstance[] = $idEquipmentInstance;
    
        return $this;
    }

    /**
     * Remove idEquipmentInstance
     *
     * @param \Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance
     */
    public function removeIdEquipmentInstance(\Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance)
    {
        $this->idEquipmentInstance->removeElement($idEquipmentInstance);
    }

    /**
     * Get idEquipmentInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdEquipmentInstance()
    {
        return $this->idEquipmentInstance;
    }

    /**
     * Add idPatchPanelInstance
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance
     * @return CabinetInstance
     */
    public function addIdPatchPanelInstance(\Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance)
    {
        $this->idPatchPanelInstance[] = $idPatchPanelInstance;
    
        return $this;
    }

    /**
     * Remove idPatchPanelInstance
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance
     */
    public function removeIdPatchPanelInstance(\Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance)
    {
        $this->idPatchPanelInstance->removeElement($idPatchPanelInstance);
    }

    /**
     * Get idPatchPanelInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPatchPanelInstance()
    {
        return $this->idPatchPanelInstance;
    }

    /**
     * Add idCostingCabinetLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine
     * @return CabinetInstance
     */
    public function addIdCostingCabinetLine(\Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine)
    {
        $this->idCostingCabinetLine[] = $idCostingCabinetLine;
    
        return $this;
    }

    /**
     * Remove idCostingCabinetLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine
     */
    public function removeIdCostingCabinetLine(\Etrali\GinangBundle\Entity\CostingCabinetLine $idCostingCabinetLine)
    {
        $this->idCostingCabinetLine->removeElement($idCostingCabinetLine);
    }

    /**
     * Get idCostingCabinetLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingCabinetLine()
    {
        return $this->idCostingCabinetLine;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return CabinetInstance
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return CabinetInstance
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return CabinetInstance
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return CabinetInstance
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }public function getParentBranch() { return NULL; }  }