<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Cable
 *
 * @ORM\Table(name="cable")
 * @ORM\Entity
 */
class Cable
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_cable", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCable;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_cable", type="string", length=100, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)      
     */
    private $cdCable;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_cable", type="string", length=255, nullable=true)
     */
    private $lbCable;

    /**
     * @var \CableType
     *
     * @ORM\ManyToOne(targetEntity="CableType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cable_type", referencedColumnName="id_cable_type")
     * })
     * @Assert\NotNull() 
     */
    private $idCableType;



    /**
     * @var integer
     *
     * @ORM\Column(name="id_provider", type="integer", nullable=true)
     */
    private $idProvider;


    /**
     * @var integer
     *
     * @ORM\Column(name="nb_capacity", type="integer", nullable=true)
     */
    private $nbCapacity;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()  	          
     */
    private $idProviderAddress;    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * }) 
     * @Assert\NotNull()     
     */
    private $idContact;

    /**
     * @var string
     *
     * @ORM\Column(name="cm_cable", type="string", length=255, nullable=true)
     */
    private $cmCable;
    
    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var integer
     *
     * @ORM\Column(name="id_user_create_by", type="integer", nullable=true)
     */
    private $idUserCreateBy;

    /**
     * @var integer
     *
     * @ORM\Column(name="id_user_update_by", type="integer", nullable=true)
     */
    private $idUserUpdateBy;  
     
    
  
    
    public function getCollections()
    {
        return array("Costings"=>"CostingCableLine");       
    }   

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idPort = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingCableLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idCable
     *
     * @return integer 
     */
    public function getIdCable()
    {
        return $this->idCable;
    }

    /**
     * Set cdCable
     *
     * @param string $cdCable
     * @return Cable
     */
    public function setCdCable($cdCable)
    {
        $this->cdCable = $cdCable;
    
        return $this;
    }

    /**
     * Get cdCable
     *
     * @return string 
     */
    public function getCdCable()
    {
        return $this->cdCable;
    }

    /**
     * Set lbCable
     *
     * @param string $lbCable
     * @return Cable
     */
    public function setLbCable($lbCable)
    {
        $this->lbCable = $lbCable;
    
        return $this;
    }

    /**
     * Get lbCable
     *
     * @return string 
     */
    public function getLbCable()
    {
        return $this->lbCable;
    }

    /**
     * Set idProvider
     *
     * @param integer $idProvider
     * @return Cable
     */
    public function setIdProvider($idProvider)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return integer 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set nbCapacity
     *
     * @param integer $nbCapacity
     * @return Cable
     */
    public function setNbCapacity($nbCapacity)
    {
        $this->nbCapacity = $nbCapacity;
    
        return $this;
    }

    /**
     * Get nbCapacity
     *
     * @return integer 
     */
    public function getNbCapacity()
    {
        return $this->nbCapacity;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Cable
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set cmCable
     *
     * @param string $cmCable
     * @return Cable
     */
    public function setCmCable($cmCable)
    {
        $this->cmCable = $cmCable;
    
        return $this;
    }

    /**
     * Get cmCable
     *
     * @return string 
     */
    public function getCmCable()
    {
        return $this->cmCable;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Cable
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Cable
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set idUserCreateBy
     *
     * @param integer $idUserCreateBy
     * @return Cable
     */
    public function setIdUserCreateBy($idUserCreateBy)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return integer 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param integer $idUserUpdateBy
     * @return Cable
     */
    public function setIdUserUpdateBy($idUserUpdateBy)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return integer 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idCableType
     *
     * @param \Etrali\GinangBundle\Entity\CableType $idCableType
     * @return Cable
     */
    public function setIdCableType(\Etrali\GinangBundle\Entity\CableType $idCableType = null)
    {
        $this->idCableType = $idCableType;
    
        return $this;
    }

    /**
     * Get idCableType
     *
     * @return \Etrali\GinangBundle\Entity\CableType 
     */
    public function getIdCableType()
    {
        return $this->idCableType;
    }

    /**
     * Add idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     * @return Cable
     */
    public function addIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort[] = $idPort;
    
        return $this;
    }

    /**
     * Remove idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     */
    public function removeIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort->removeElement($idPort);
    }

    /**
     * Get idPort
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPort()
    {
        return $this->idPort;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return Cable
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return Cable
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Add idCostingCableLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCableLine $idCostingCableLine
     * @return Cable
     */
    public function addIdCostingCableLine(\Etrali\GinangBundle\Entity\CostingCableLine $idCostingCableLine)
    {
        $this->idCostingCableLine[] = $idCostingCableLine;
    
        return $this;
    }

    /**
     * Remove idCostingCableLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCableLine $idCostingCableLine
     */
    public function removeIdCostingCableLine(\Etrali\GinangBundle\Entity\CostingCableLine $idCostingCableLine)
    {
        $this->idCostingCableLine->removeElement($idCostingCableLine);
    }

    /**
     * Get idCostingCableLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingCableLine()
    {
        return $this->idCostingCableLine;
    }
public function __toString() { return ''; } public function getParentBranch() { return NULL; }  }