<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
/**
 * Card
 *
 * @ORM\Table(name="card")
 * @ORM\Entity
 */
class Card
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_card", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCard;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_card", type="string", length=15, nullable=false)
     */
    private $cdCard;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_card", type="string", length=100, nullable=false)
     */
    private $lbCard;



 /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;    
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     * @Gedmo\Timestampable(on="create")      
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     * @Gedmo\Timestampable(on="update")     
     */
    private $dtUpdate;   
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;       
    
 /**
     * @var string
     *
     * @ORM\Column(name="url_image", type="string", length=100, nullable=true)
     */
    private $urlImage;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_daughter", type="boolean", nullable=true)
     */
    private $blDaughter;
    
 /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    
       /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * }) 
     * @Assert\NotNull()       
     */
    private $idProvider;
    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()  	          
     */
    private $idProviderAddress;    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * }) 
     * @Assert\NotNull()     
     */
    private $idContact;

    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel", inversedBy="idCard")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     */
    private $idComplexModel;    
    
    /**
     * @var \Slot
     *
     * @ORM\ManyToOne(targetEntity="Slot", inversedBy="idCard")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_slot", referencedColumnName="id_slot")
     * })
     */
    private $idSlot;       

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_virtual", type="boolean", nullable=true)
     */
    private $blVirtual;
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nbNumber", type="integer", nullable=true)
     */
    private $nbNumber=1000000;     
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_card_for_ref", type="boolean", nullable=true)
     */
    private $blCardForRef;   
       
    
    /**
     * @var \Equipment
     *
     * @ORM\ManyToOne(targetEntity="Equipment", inversedBy="idCard")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_equipment", referencedColumnName="id_equipment")
     * })
     */
    private $idEquipment;    
    
    /**
     * @var \Card
     *
     * @ORM\ManyToOne(targetEntity="Card", inversedBy="idDaughterCard")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_mother_card", referencedColumnName="id_card")
     * })
     */
    private $idMotherCard;  
    
    /**
     * @var \Card
     *
     * @ORM\OneToMany(targetEntity="Card", mappedBy="idMotherCard",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"nbNumber" = "ASC"})       
     */
    private $idDaughterCard;      
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_ports", type="integer", nullable=true)
     * @Assert\NotBlank()       
     */
    private $nbPorts;  
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_rows", type="integer", nullable=true)
     * @Assert\NotBlank()      
     */
    private $nbRows;      
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_model", type="boolean", nullable=true)
     */
    private $blModel=true;  
    
    /**
     * @var \Port
     *
     * @ORM\OneToMany(targetEntity="Port", mappedBy="idCard",cascade={"persist","remove"}, orphanRemoval=true)
     */
    private $idPort;      
    
    /**
     * @var \CostingCardLine
     *
     * @ORM\OneToMany(targetEntity="CostingCardLine", mappedBy="idCard",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idCostingCardLine;  
        
    
    public function getCollections()
    {
        return array("Costings"=>"CostingCardLine");       
    }    
    
    /**
     * Get idCard
     *
     * @return integer 
     */
    public function getIdCard()
    {
        return $this->idCard;
    }

    
    /**
     * @return string
     *
     */
    public function __toString()
    {
        return $this->lbCard.'';
    }  


    
    /**
     * Clone function. Clones an entity and all necessary ManyToOne relations. 
     * Parent entities are not cloned but only children
     *
     * @return Card
     */    
    public function duplique() {
        if ($this->idCard) {
            $this->idCard=null;
            $ac = new ArrayCollection();  
            foreach ($this->idCostingCardLine as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->setIdCard($this); 
                $ac->add($cloneElem);
            }
            $this->idCostingCardLine=$ac;
          
            $ac = new ArrayCollection();   
            foreach ($this->idPort as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);                
                $cloneElem->setIdCard($this); 
            }
            $this->idPort=$ac;
            $ac = new ArrayCollection();   
            foreach ($this->idDaughterCard as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);                
                $cloneElem->setIdMotherCard($this); 
            }  
            $this->idDaughterCard=$ac;
        }
    }
    
    public function setIdDaughterCard(\Doctrine\Common\Collections\ArrayCollection $ac)
    {
         $this->idDaughterCard = $ac;
         return $this;
    }
    
    public function setIdPort(\Doctrine\Common\Collections\ArrayCollection $ac)
    {
         $this->idPort = $ac;
        return $this;         
    }

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idDaughterCard = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idPort = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingCardLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Set cdCard
     *
     * @param string $cdCard
     * @return Card
     */
    public function setCdCard($cdCard)
    {
        $this->cdCard = $cdCard;
    
        return $this;
    }

    /**
     * Get cdCard
     *
     * @return string 
     */
    public function getCdCard()
    {
        return $this->cdCard;
    }

    /**
     * Set lbCard
     *
     * @param string $lbCard
     * @return Card
     */
    public function setLbCard($lbCard)
    {
        $this->lbCard = $lbCard;
    
        return $this;
    }

    /**
     * Get lbCard
     *
     * @return string 
     */
    public function getLbCard()
    {
        return $this->lbCard;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Card
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Card
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Card
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Card
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set urlImage
     *
     * @param string $urlImage
     * @return Card
     */
    public function setUrlImage($urlImage)
    {
        $this->urlImage = $urlImage;
    
        return $this;
    }

    /**
     * Get urlImage
     *
     * @return string 
     */
    public function getUrlImage()
    {
        return $this->urlImage;
    }

    /**
     * Set blDaughter
     *
     * @param boolean $blDaughter
     * @return Card
     */
    public function setBlDaughter($blDaughter)
    {
        $this->blDaughter = $blDaughter;
    
        return $this;
    }

    /**
     * Get blDaughter
     *
     * @return boolean 
     */
    public function getBlDaughter()
    {
        return $this->blDaughter;
    }

    /**
     * Set blVirtual
     *
     * @param boolean $blVirtual
     * @return Card
     */
    public function setBlVirtual($blVirtual)
    {
        $this->blVirtual = $blVirtual;
    
        return $this;
    }

    /**
     * Get blVirtual
     *
     * @return boolean 
     */
    public function getBlVirtual()
    {
        return $this->blVirtual;
    }

    /**
     * Set nbNumber
     *
     * @param integer $nbNumber
     * @return Card
     */
    public function setNbNumber($nbNumber)
    {
        $this->nbNumber = $nbNumber;
    
        return $this;
    }

    /**
     * Get nbNumber
     *
     * @return integer 
     */
    public function getNbNumber()
    {
        return $this->nbNumber;
    }

    /**
     * Set blCardForRef
     *
     * @param boolean $blCardForRef
     * @return Card
     */
    public function setBlCardForRef($blCardForRef)
    {
        $this->blCardForRef = $blCardForRef;
    
        return $this;
    }

    /**
     * Get blCardForRef
     *
     * @return boolean 
     */
    public function getBlCardForRef()
    {
        return $this->blCardForRef;
    }

    /**
     * Set nbPorts
     *
     * @param integer $nbPorts
     * @return Card
     */
    public function setNbPorts($nbPorts)
    {
        $this->nbPorts = $nbPorts;
    
        return $this;
    }

    /**
     * Get nbPorts
     *
     * @return integer 
     */
    public function getNbPorts()
    {
        return $this->nbPorts;
    }

    /**
     * Set nbRows
     *
     * @param integer $nbRows
     * @return Card
     */
    public function setNbRows($nbRows)
    {
        $this->nbRows = $nbRows;
    
        return $this;
    }

    /**
     * Get nbRows
     *
     * @return integer 
     */
    public function getNbRows()
    {
        return $this->nbRows;
    }

    /**
     * Set blModel
     *
     * @param boolean $blModel
     * @return Card
     */
    public function setBlModel($blModel)
    {
        $this->blModel = $blModel;
    
        return $this;
    }

    /**
     * Get blModel
     *
     * @return boolean 
     */
    public function getBlModel()
    {
        return $this->blModel;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Card
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Card
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return Card
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return Card
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return Card
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return Card
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Set idSlot
     *
     * @param \Etrali\GinangBundle\Entity\Slot $idSlot
     * @return Card
     */
    public function setIdSlot(\Etrali\GinangBundle\Entity\Slot $idSlot = null)
    {
        $this->idSlot = $idSlot;
    
        return $this;
    }

    /**
     * Get idSlot
     *
     * @return \Etrali\GinangBundle\Entity\Slot 
     */
    public function getIdSlot()
    {
        return $this->idSlot;
    }

    /**
     * Set idEquipment
     *
     * @param \Etrali\GinangBundle\Entity\Equipment $idEquipment
     * @return Card
     */
    public function setIdEquipment(\Etrali\GinangBundle\Entity\Equipment $idEquipment = null)
    {
        $this->idEquipment = $idEquipment;
    
        return $this;
    }

    /**
     * Get idEquipment
     *
     * @return \Etrali\GinangBundle\Entity\Equipment 
     */
    public function getIdEquipment()
    {
        return $this->idEquipment;
    }

    /**
     * Set idMotherCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idMotherCard
     * @return Card
     */
    public function setIdMotherCard(\Etrali\GinangBundle\Entity\Card $idMotherCard = null)
    {
        $this->idMotherCard = $idMotherCard;
    
        return $this;
    }

    /**
     * Get idMotherCard
     *
     * @return \Etrali\GinangBundle\Entity\Card 
     */
    public function getIdMotherCard()
    {
        return $this->idMotherCard;
    }

    /**
     * Add idDaughterCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idDaughterCard
     * @return Card
     */
    public function addIdDaughterCard(\Etrali\GinangBundle\Entity\Card $idDaughterCard)
    {
        $this->idDaughterCard[] = $idDaughterCard;
    
        return $this;
    }

    /**
     * Remove idDaughterCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idDaughterCard
     */
    public function removeIdDaughterCard(\Etrali\GinangBundle\Entity\Card $idDaughterCard)
    {
        $this->idDaughterCard->removeElement($idDaughterCard);
    }

    /**
     * Get idDaughterCard
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdDaughterCard()
    {
        return $this->idDaughterCard;
    }

    /**
     * Add idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     * @return Card
     */
    public function addIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort[] = $idPort;
    
        return $this;
    }

    /**
     * Remove idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     */
    public function removeIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort->removeElement($idPort);
    }

    /**
     * Get idPort
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPort()
    {
        return $this->idPort;
    }

    /**
     * Add idCostingCardLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine
     * @return Card
     */
    public function addIdCostingCardLine(\Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine)
    {
        $this->idCostingCardLine[] = $idCostingCardLine;
    
        return $this;
    }

    /**
     * Remove idCostingCardLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine
     */
    public function removeIdCostingCardLine(\Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine)
    {
        $this->idCostingCardLine->removeElement($idCostingCardLine);
    }

    /**
     * Get idCostingCardLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingCardLine()
    {
        return $this->idCostingCardLine;
    }public function getParentBranch() { return NULL; }  }