<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
/**
 * CardInstance
 *
 * @ORM\Table(name="card_instance")
 * @ORM\Entity
 */
class CardInstance
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_card_instance", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCardInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_card_instance", type="string", length=15, nullable=false)
     */
    private $cdCardInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_card_instance", type="string", length=100, nullable=true)
     */
    private $lbCardInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_serial_number", type="string", length=15, nullable=true)
     */
    private $cdSerialNumber;

 /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;    
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     * @Gedmo\Timestampable(on="create")      
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     * @Gedmo\Timestampable(on="update")     
     */
    private $dtUpdate;   
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;       
        
 /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;
    
    /**
     * @var \SlotInstance
     *
     * @ORM\ManyToOne(targetEntity="SlotInstance", inversedBy="idCardInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_slot_instance", referencedColumnName="id_slot_instance")
     * })
     */
    private $idSlotInstance;       
    
    /**
     * @var \EquipmentInstance
     *
     * @ORM\ManyToOne(targetEntity="EquipmentInstance", inversedBy="idCardInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_equipment_instance", referencedColumnName="id_equipment_instance")
     * })
     */
    private $idEquipmentInstance;    
    
    /**
     * @var \CardInstance
     *
     * @ORM\ManyToOne(targetEntity="CardInstance", inversedBy="idDaughterCard")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_mother_card", referencedColumnName="id_card_instance")
     * })
     */
    private $idMotherCard;  
    
    /**
     * @var \CardInstance
     *
     * @ORM\OneToMany(targetEntity="CardInstance", mappedBy="idMotherCard",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"nbNumber" = "ASC"})       
     */
    private $idDaughterCard;      
    
    /**
     * @var \Card
     *
     * @ORM\ManyToOne(targetEntity="Card")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_card", referencedColumnName="id_card")
     * })   
     */
    private $idCard;      
    
    /**
     * @var \Port
     *
     * @ORM\OneToMany(targetEntity="PortInstance", mappedBy="idCardInstance",cascade={"persist","remove"}, orphanRemoval=true)
     */
    private $idPortInstance;
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nbNumber", type="integer", nullable=true)
     */
    private $nbNumber=1000000; 
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     * @Assert\NotNull()     
     */
    private $idComplexModel; 
    
    /**
     * @var \CostingCardLine
     *
     * @ORM\OneToMany(targetEntity="CostingCardLine", mappedBy="idCardInstance",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idCostingCardLine;  

        /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProvider;

    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProviderAddress;

    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * })
     * @Assert\NotNull()
     */
    private $idContact;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     *
     * @Assert\MaxLength(20)
     */
    private $cdProviderAccount;  
    
    public function getCollections()
    {
        return array("Costings"=>"CostingCardLine");       
    } 
    
    /**
     * @return string
     *
     */
    public function __toString()
    {
        return $this->lbCardInstance.'';
    }  

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idDaughterCard = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idPortInstance = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingCardLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idCardInstance
     *
     * @return integer 
     */
    public function getIdCardInstance()
    {
        return $this->idCardInstance;
    }

    /**
     * Set cdCardInstance
     *
     * @param string $cdCardInstance
     * @return CardInstance
     */
    public function setCdCardInstance($cdCardInstance)
    {
        $this->cdCardInstance = $cdCardInstance;
    
        return $this;
    }

    /**
     * Get cdCardInstance
     *
     * @return string 
     */
    public function getCdCardInstance()
    {
        return $this->cdCardInstance;
    }

    /**
     * Set lbCardInstance
     *
     * @param string $lbCardInstance
     * @return CardInstance
     */
    public function setLbCardInstance($lbCardInstance)
    {
        $this->lbCardInstance = $lbCardInstance;
    
        return $this;
    }

    /**
     * Get lbCardInstance
     *
     * @return string 
     */
    public function getLbCardInstance()
    {
        return $this->lbCardInstance;
    }

    /**
     * Set cdSerialNumber
     *
     * @param string $cdSerialNumber
     * @return CardInstance
     */
    public function setCdSerialNumber($cdSerialNumber)
    {
        $this->cdSerialNumber = $cdSerialNumber;
    
        return $this;
    }

    /**
     * Get cdSerialNumber
     *
     * @return string 
     */
    public function getCdSerialNumber()
    {
        return $this->cdSerialNumber;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return CardInstance
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return CardInstance
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return CardInstance
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return CardInstance
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set nbNumber
     *
     * @param integer $nbNumber
     * @return CardInstance
     */
    public function setNbNumber($nbNumber)
    {
        $this->nbNumber = $nbNumber;
    
        return $this;
    }

    /**
     * Get nbNumber
     *
     * @return integer 
     */
    public function getNbNumber()
    {
        return $this->nbNumber;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return CardInstance
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return CardInstance
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idSlotInstance
     *
     * @param \Etrali\GinangBundle\Entity\SlotInstance $idSlotInstance
     * @return CardInstance
     */
    public function setIdSlotInstance(\Etrali\GinangBundle\Entity\SlotInstance $idSlotInstance = null)
    {
        $this->idSlotInstance = $idSlotInstance;
    
        return $this;
    }

    /**
     * Get idSlotInstance
     *
     * @return \Etrali\GinangBundle\Entity\SlotInstance 
     */
    public function getIdSlotInstance()
    {
        return $this->idSlotInstance;
    }

    /**
     * Set idEquipmentInstance
     *
     * @param \Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance
     * @return CardInstance
     */
    public function setIdEquipmentInstance(\Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance = null)
    {
        $this->idEquipmentInstance = $idEquipmentInstance;
    
        return $this;
    }

    /**
     * Get idEquipmentInstance
     *
     * @return \Etrali\GinangBundle\Entity\EquipmentInstance 
     */
    public function getIdEquipmentInstance()
    {
        return $this->idEquipmentInstance;
    }

    /**
     * Set idMotherCard
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idMotherCard
     * @return CardInstance
     */
    public function setIdMotherCard(\Etrali\GinangBundle\Entity\CardInstance $idMotherCard = null)
    {
        $this->idMotherCard = $idMotherCard;
    
        return $this;
    }

    /**
     * Get idMotherCard
     *
     * @return \Etrali\GinangBundle\Entity\CardInstance 
     */
    public function getIdMotherCard()
    {
        return $this->idMotherCard;
    }

    /**
     * Add idDaughterCard
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idDaughterCard
     * @return CardInstance
     */
    public function addIdDaughterCard(\Etrali\GinangBundle\Entity\CardInstance $idDaughterCard)
    {
        $this->idDaughterCard[] = $idDaughterCard;
    
        return $this;
    }

    /**
     * Remove idDaughterCard
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idDaughterCard
     */
    public function removeIdDaughterCard(\Etrali\GinangBundle\Entity\CardInstance $idDaughterCard)
    {
        $this->idDaughterCard->removeElement($idDaughterCard);
    }

    /**
     * Get idDaughterCard
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdDaughterCard()
    {
        return $this->idDaughterCard;
    }

    /**
     * Set idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     * @return CardInstance
     */
    public function setIdCard(\Etrali\GinangBundle\Entity\Card $idCard = null)
    {
        $this->idCard = $idCard;
    
        return $this;
    }

    /**
     * Get idCard
     *
     * @return \Etrali\GinangBundle\Entity\Card 
     */
    public function getIdCard()
    {
        return $this->idCard;
    }

    /**
     * Add idPortInstance
     *
     * @param \Etrali\GinangBundle\Entity\PortInstance $idPortInstance
     * @return CardInstance
     */
    public function addIdPortInstance(\Etrali\GinangBundle\Entity\PortInstance $idPortInstance)
    {
        $this->idPortInstance[] = $idPortInstance;
    
        return $this;
    }

    /**
     * Remove idPortInstance
     *
     * @param \Etrali\GinangBundle\Entity\PortInstance $idPortInstance
     */
    public function removeIdPortInstance(\Etrali\GinangBundle\Entity\PortInstance $idPortInstance)
    {
        $this->idPortInstance->removeElement($idPortInstance);
    }

    /**
     * Get idPortInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPortInstance()
    {
        return $this->idPortInstance;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return CardInstance
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Add idCostingCardLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine
     * @return CardInstance
     */
    public function addIdCostingCardLine(\Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine)
    {
        $this->idCostingCardLine[] = $idCostingCardLine;
    
        return $this;
    }

    /**
     * Remove idCostingCardLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine
     */
    public function removeIdCostingCardLine(\Etrali\GinangBundle\Entity\CostingCardLine $idCostingCardLine)
    {
        $this->idCostingCardLine->removeElement($idCostingCardLine);
    }

    /**
     * Get idCostingCardLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingCardLine()
    {
        return $this->idCostingCardLine;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return CardInstance
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return CardInstance
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return CardInstance
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return CardInstance
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }public function getParentBranch() { return NULL; }  }