<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * City
 *
 * @ORM\Table(name="city")
 * @ORM\Entity
 */
class City
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_city", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCity;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_city", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(15)
     */
    private $cdCity;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_city", type="string", length=100, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(50)
     */
    private $lbCity;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     * 
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $dtCreate;

    /**
     * @var \DateTime  
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $dtUpdate;

    /**
     * @var string
     *
     * @ORM\Column(name="nb_gmt", type="string", length=15, nullable=true)
     * @Assert\Regex("/^[\-]?[0-9]+$/")
     * @Assert\Range(
     *      min = "-12",
     *      max = "12",
     *      minMessage = "Time Zone must be greater than -12",
     *      maxMessage = "Time Zone must be lesser than 12"
     * )
     */
    private $nbGmt;


    /**
     * @var \User
     * 
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *     
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")	 
     */
    private $idUserUpdateBy;

    /**
     * @var \Country
     *
     * @ORM\ManyToOne(targetEntity="Country")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_country", referencedColumnName="id_country")
     * })
     * @Assert\NotNull()
     */
    private $idCountry;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 

    /**
     * Get idCity
     *
     * @return integer 
     */
    public function getIdCity()
    {
        return $this->idCity;
    }

    /**
     * Set cdCity
     *
     * @param string $cdCity
     * @return City
     */
    public function setCdCity($cdCity)
    {
        $this->cdCity = $cdCity;
    
        return $this;
    }

    /**
     * Get cdCity
     *
     * @return string 
     */
    public function getCdCity()
    {
        return $this->cdCity;
    }

    /**
     * Set lbCity
     *
     * @param string $lbCity
     * @return City
     */
    public function setLbCity($lbCity)
    {
        $this->lbCity = $lbCity;
    
        return $this;
    }

    /**
     * Get lbCity
     *
     * @return string 
     */
    public function getLbCity()
    {
        return $this->lbCity;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return City
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return City
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return City
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set nbGmt
     *
     * @param string $nbGmt
     * @return City
     */
    public function setNbGmt($nbGmt)
    {
        $this->nbGmt = $nbGmt;
    
        return $this;
    }

    /**
     * Get nbGmt
     *
     * @return string 
     */
    public function getNbGmt()
    {
        return $this->nbGmt;
    }

    /**
     * Set cdRoute
     *
     * @param string $cdRoute
     * @return City
     */
    public function setCdRoute($cdRoute)
    {
        $this->cdRoute = $cdRoute;
    
        return $this;
    }

    /**
     * Get cdRoute
     *
     * @return string 
     */
    public function getCdRoute()
    {
        return $this->cdRoute;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return City
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return City
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idCountry
     *
     * @param \Etrali\GinangBundle\Entity\Country $idCountry
     * @return City
     */
    public function setIdCountry(\Etrali\GinangBundle\Entity\Country $idCountry = null)
    {
        $this->idCountry = $idCountry;
    
        return $this;
    }

    /**
     * Get idCountry
     *
     * @return \Etrali\GinangBundle\Entity\Country 
     */
    public function getIdCountry()
    {
        return $this->idCountry;
    }
    public function __toString()
    {
        return $this->getLbCity().'';
    }    
public function getParentBranch() { return NULL; }  
    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return City
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}