<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Cluster
 *
 * @ORM\Table(name="cluster")
 * @ORM\Entity
 */
class Cluster
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_cluster", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCluster;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_cluster", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(30) 
     */
    private $cdCluster;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_cluster", type="string", length=100, nullable=false)
     * @Assert\MaxLength(30) 
     */
    private $lbCluster;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var string
     *
     * @ORM\Column(name="comment", type="text", nullable=true)
     */
    private $comment;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \ProviderWorldwideGroup
     *
     * @ORM\ManyToOne(targetEntity="ProviderWorldwideGroup",inversedBy="idCluster")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_worldwide_group", referencedColumnName="id_provider_worldwide_group")
     * })
     */
    private $idProviderWorldwideGroup;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbCluster().' ';
    }      
    
    public function getHeadInfo()
    {
            return "<td>".$this->getBlDeactivated()."</td><td >".$this->getLbCluster()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Active</th><th>Cluster name</th>";
    }     

    /**
     * Get idCluster
     *
     * @return integer 
     */
    public function getIdCluster()
    {
        return $this->idCluster;
    }

    /**
     * Set cdCluster
     *
     * @param string $cdCluster
     * @return Cluster
     */
    public function setCdCluster($cdCluster)
    {
        $this->cdCluster = $cdCluster;
    
        return $this;
    }

    /**
     * Get cdCluster
     *
     * @return string 
     */
    public function getCdCluster()
    {
        return $this->cdCluster;
    }

    /**
     * Set lbCluster
     *
     * @param string $lbCluster
     * @return Cluster
     */
    public function setLbCluster($lbCluster)
    {
        $this->lbCluster = $lbCluster;
    
        return $this;
    }

    /**
     * Get lbCluster
     *
     * @return string 
     */
    public function getLbCluster()
    {
        return $this->lbCluster;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Cluster
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Cluster
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Cluster
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set comment
     *
     * @param string $comment
     * @return Cluster
     */
    public function setComment($comment)
    {
        $this->comment = $comment;
    
        return $this;
    }

    /**
     * Get comment
     *
     * @return string 
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Cluster
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Cluster
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idWorldwideGroup
     *
     * @param \Etrali\GinangBundle\Entity\WorldwideGroup $idWorldwideGroup
     * @return Cluster
     */
    public function setIdWorldwideGroup(\Etrali\GinangBundle\Entity\WorldwideGroup $idWorldwideGroup = null)
    {
        $this->idWorldwideGroup = $idWorldwideGroup;
    
        return $this;
    }

    /**
     * Get idWorldwideGroup
     *
     * @return \Etrali\GinangBundle\Entity\WorldwideGroup 
     */
    public function getIdWorldwideGroup()
    {
        return $this->idWorldwideGroup;
    }

    /**
     * Set idProviderWorldwideGroup
     *
     * @param \Etrali\GinangBundle\Entity\ProviderWorldwideGroup $idProviderWorldwideGroup
     * @return Cluster
     */
    public function setIdProviderWorldwideGroup(\Etrali\GinangBundle\Entity\ProviderWorldwideGroup $idProviderWorldwideGroup = null)
    {
        $this->idProviderWorldwideGroup = $idProviderWorldwideGroup;
    
        return $this;
    }

    /**
     * Get idProviderWorldwideGroup
     *
     * @return \Etrali\GinangBundle\Entity\ProviderWorldwideGroup 
     */
    public function getIdProviderWorldwideGroup()
    {
        return $this->idProviderWorldwideGroup;
    }
public function getParentBranch() { return NULL; }  
    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Cluster
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}