<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * ComplexModel
 *
 * @ORM\Table(name="complex_model")
 * @ORM\Entity
 */
class ComplexModel
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_complex_model", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idComplexModel;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_complex_model", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)  
     */
    private $cdComplexModel;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_complex_model", type="string", length=100, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(100) 
     */
    private $lbComplexModel;

    /**
     * @var string
     *
     * @ORM\Column(name="url_image", type="string", length=100, nullable=true)
     */
    private $urlImage;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_model", type="boolean", nullable=false)
     */
    private $blModel=true;    

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

        /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

 /**
     * @var float
     *
     * @ORM\Column(name="one_off_cost", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "One-off cost of model can not be negative")    
     */
    private $oneOffCost;

    /**
     * @var float
     *
     * @ORM\Column(name="rec_off_cost", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "Recurring cost of model can not be zero")     
     */
    private $recOffCost;
    

    /**
     * @var \Cabinet
     *
     * @ORM\OneToMany(targetEntity="Cabinet", mappedBy="idComplexModel",cascade={"persist","remove"}, orphanRemoval=true )      
     * 
     */

    private $idCabinet;
    
    /**
     * @var \Equipment
     *
     * @ORM\OneToMany(targetEntity="Equipment", mappedBy="idComplexModel",cascade={"persist","remove"}, orphanRemoval=true )
     * 
     */

    private $idEquipment;   
    
    /**
     * @var \PatchPanel
     *
     * @ORM\OneToMany(targetEntity="PatchPanel", mappedBy="idComplexModel",cascade={"persist","remove"}, orphanRemoval=true ) 
     * 
     */

    private $idPatchPanel;    
    
    /**
     * @var \Slot
     *
     * @ORM\OneToMany(targetEntity="Slot", mappedBy="idComplexModel",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"nbNumber" = "ASC"})        
     * 
     */

    private $idSlot;    
    
    /**
     * @var \Card
     *
     * @ORM\OneToMany(targetEntity="Card", mappedBy="idComplexModel",cascade={"persist","remove"}, orphanRemoval=true ) 
     * 
     */

    private $idCard;    
    
    /**
     * @var \Port
     *
     * @ORM\OneToMany(targetEntity="Port", mappedBy="idComplexModel",cascade={"persist","remove"}, orphanRemoval=true )
     * 
     */

    private $idPort;
    
    /**
     * @return string
     *
     */
    public function __toString()
    {
        return $this->lbComplexModel.'';
    }    

    /**
     * Set idEquipment
     *
     * @param \Doctrine\Common\Collections\Collection  $idEquipment
     * @return ComplexModel
     */
    public function setIdEquipment(\Doctrine\Common\Collections\Collection $idEquipment = null)
    {
        $this->idEquipment = $idEquipment;
    
        return $this;
    }    
    
    /**
     * Set idPatchPanel
     *
     * @param \Doctrine\Common\Collections\Collection  $idPatchPanel
     * @return ComplexModel
     */
    public function setIdPatchPanel(\Doctrine\Common\Collections\Collection $idPatchPanel = null)
    {
        $this->idPatchPanel = $idPatchPanel;
    
        return $this;
    }  
    
    /**
     * Set idCabinet
     *
     * @param \Doctrine\Common\Collections\Collection  $idCabinet
     * @return ComplexModel
     */
    public function setIdCabinet(\Doctrine\Common\Collections\Collection $idCabinet = null)
    {
        $this->idCabinet = $idCabinet;
    
        return $this;
    }  
    
    /**
     * Set idCard
     *
     * @param \Doctrine\Common\Collections\Collection  $idCard
     * @return ComplexModel
     */
    public function setIdCard(\Doctrine\Common\Collections\Collection $idCard = null)
    {
        $this->idCard = $idCard;
    
        return $this;
    }    
    
    /**
     * Set idSlot
     *
     * @param \Doctrine\Common\Collections\Collection  $idSlot
     * @return ComplexModel
     */
    public function setIdSlot(\Doctrine\Common\Collections\Collection $idSlot = null)
    {
        $this->idSlot = $idSlot;
    
        return $this;
    }     
    
    /**
     * Set idPort
     *
     * @param \Doctrine\Common\Collections\Collection  $idPort
     * @return ComplexModel
     */
    public function setIdPort(\Doctrine\Common\Collections\Collection $idPort = null)
    {
        $this->idPort = $idPort;
    
        return $this;
    }       
   
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCabinet = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idEquipment = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idPatchPanel = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idSlot = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCard = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idPort = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    
    /**
     * Get idComplexModel
     *
     * @return integer 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Set cdComplexModel
     *
     * @param string $cdComplexModel
     * @return ComplexModel
     */
    public function setCdComplexModel($cdComplexModel)
    {
        $this->cdComplexModel = $cdComplexModel;
    
        return $this;
    }

    /**
     * Get cdComplexModel
     *
     * @return string 
     */
    public function getCdComplexModel()
    {
        return $this->cdComplexModel;
    }

    /**
     * Set lbComplexModel
     *
     * @param string $lbComplexModel
     * @return ComplexModel
     */
    public function setLbComplexModel($lbComplexModel)
    {
        $this->lbComplexModel = $lbComplexModel;
    
        return $this;
    }

    /**
     * Get lbComplexModel
     *
     * @return string 
     */
    public function getLbComplexModel()
    {
        return $this->lbComplexModel;
    }

    /**
     * Set urlImage
     *
     * @param string $urlImage
     * @return ComplexModel
     */
    public function setUrlImage($urlImage)
    {
        $this->urlImage = $urlImage;
    
        return $this;
    }

    /**
     * Get urlImage
     *
     * @return string 
     */
    public function getUrlImage()
    {
        return $this->urlImage;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return ComplexModel
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set blModel
     *
     * @param boolean $blModel
     * @return ComplexModel
     */
    public function setBlModel($blModel)
    {
        $this->blModel = $blModel;
    
        return $this;
    }

    /**
     * Get blModel
     *
     * @return boolean 
     */
    public function getBlModel()
    {
        return $this->blModel;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return ComplexModel
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return ComplexModel
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return ComplexModel
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set oneOffCost
     *
     * @param float $oneOffCost
     * @return ComplexModel
     */
    public function setOneOffCost($oneOffCost)
    {
        $this->oneOffCost = $oneOffCost;
    
        return $this;
    }

    /**
     * Get oneOffCost
     *
     * @return float 
     */
    public function getOneOffCost()
    {
        return $this->oneOffCost;
    }

    /**
     * Set recOffCost
     *
     * @param float $recOffCost
     * @return ComplexModel
     */
    public function setRecOffCost($recOffCost)
    {
        $this->recOffCost = $recOffCost;
    
        return $this;
    }

    /**
     * Get recOffCost
     *
     * @return float 
     */
    public function getRecOffCost()
    {
        return $this->recOffCost;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return ComplexModel
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return ComplexModel
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Add idCabinet
     *
     * @param \Etrali\GinangBundle\Entity\Cabinet $idCabinet
     * @return ComplexModel
     */
    public function addIdCabinet(\Etrali\GinangBundle\Entity\Cabinet $idCabinet)
    {
        $this->idCabinet[] = $idCabinet;
    
        return $this;
    }

    /**
     * Remove idCabinet
     *
     * @param \Etrali\GinangBundle\Entity\Cabinet $idCabinet
     */
    public function removeIdCabinet(\Etrali\GinangBundle\Entity\Cabinet $idCabinet)
    {
        $this->idCabinet->removeElement($idCabinet);
    }

    /**
     * Get idCabinet
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCabinet()
    {
        return $this->idCabinet;
    }

    /**
     * Add idEquipment
     *
     * @param \Etrali\GinangBundle\Entity\Equipment $idEquipment
     * @return ComplexModel
     */
    public function addIdEquipment(\Etrali\GinangBundle\Entity\Equipment $idEquipment)
    {
        $this->idEquipment[] = $idEquipment;
    
        return $this;
    }

    /**
     * Remove idEquipment
     *
     * @param \Etrali\GinangBundle\Entity\Equipment $idEquipment
     */
    public function removeIdEquipment(\Etrali\GinangBundle\Entity\Equipment $idEquipment)
    {
        $this->idEquipment->removeElement($idEquipment);
    }

    /**
     * Get idEquipment
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdEquipment()
    {
        return $this->idEquipment;
    }

    /**
     * Add idPatchPanel
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel
     * @return ComplexModel
     */
    public function addIdPatchPanel(\Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel)
    {
        $this->idPatchPanel[] = $idPatchPanel;
    
        return $this;
    }

    /**
     * Remove idPatchPanel
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel
     */
    public function removeIdPatchPanel(\Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel)
    {
        $this->idPatchPanel->removeElement($idPatchPanel);
    }

    /**
     * Get idPatchPanel
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPatchPanel()
    {
        return $this->idPatchPanel;
    }

    /**
     * Add idSlot
     *
     * @param \Etrali\GinangBundle\Entity\Slot $idSlot
     * @return ComplexModel
     */
    public function addIdSlot(\Etrali\GinangBundle\Entity\Slot $idSlot)
    {
        $this->idSlot[] = $idSlot;
    
        return $this;
    }

    /**
     * Remove idSlot
     *
     * @param \Etrali\GinangBundle\Entity\Slot $idSlot
     */
    public function removeIdSlot(\Etrali\GinangBundle\Entity\Slot $idSlot)
    {
        $this->idSlot->removeElement($idSlot);
    }

    /**
     * Get idSlot
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdSlot()
    {
        return $this->idSlot;
    }

    /**
     * Add idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     * @return ComplexModel
     */
    public function addIdCard(\Etrali\GinangBundle\Entity\Card $idCard)
    {
        $this->idCard[] = $idCard;
    
        return $this;
    }

    /**
     * Remove idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     */
    public function removeIdCard(\Etrali\GinangBundle\Entity\Card $idCard)
    {
        $this->idCard->removeElement($idCard);
    }

    /**
     * Get idCard
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCard()
    {
        return $this->idCard;
    }

    /**
     * Add idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     * @return ComplexModel
     */
    public function addIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort[] = $idPort;
    
        return $this;
    }

    /**
     * Remove idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     */
    public function removeIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort->removeElement($idPort);
    }

    /**
     * Get idPort
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPort()
    {
        return $this->idPort;
    }
public function getParentBranch() { return NULL; }  }