<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * ContactPop
 *
 * @ORM\Table(name="contact_pop")
 * @ORM\Entity
 */
class ContactPop
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_contact_pop", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idContactPop;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_title", type="string", length=255, nullable=true)
     */
    private $lbTitle;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_firstname", type="string", length=50, nullable=true)
     * @Assert\NotBlank()      
     */
    private $lbFirstname;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_lastname", type="string", length=50, nullable=true)
     * @Assert\NotBlank()       
     */
    private $lbLastname;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_email", type="string", length=100, nullable=true)
     * @Assert\Email(
     *     message = "'{{ value }}' n'est pas un email valide."
     * ) 
     */
    private $lbEmail;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_phone", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20)      
     */
    private $lbPhone;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_mobile", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20)    
     */
    private $lbMobile;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_fax", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20)   
     */
    private $lbFax;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_default", type="boolean", nullable=true)
     */
    private $blDefault;

    /**
     * @var string
     *
     * @ORM\Column(name="comment", type="text", nullable=true)
     */
    private $comment;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \Pop
     *
     * @ORM\ManyToOne(targetEntity="Pop", inversedBy="idContactPop")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_pop", referencedColumnName="id_pop")
     * })
     */
    private $idPop;
        
    /**
     * @var \ContactType
     *
     * @ORM\ManyToOne(targetEntity="ContactType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact_type", referencedColumnName="id_contact_type")
     * })
     * @Assert\NotNull()       
     */
    private $idContactType;      

    /**
     * @var \Civility
     *
     * @ORM\ManyToOne(targetEntity="Civility")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_civility", referencedColumnName="id_civility")
     * })
     * @Assert\NotNull()       
     */
    private $idCivility;


    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbFirstname()." ".$this->getLbLastname();
    }

    public function getHeadInfo()
    {
            return "<td>".$this->getLbLastname()."</td><td>".$this->getLbFirstname()."</td><td >".$this->getLbPhone()."</td><td>".$this->getLbMobile()."</td><td>".$this->getLbEmail()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Last name</th><th>First name</th><th>Phone nb</th><th>Mobile nb</th><th>Email</th>";
    }   
    
    /**
     * Get idContactPop
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->idContactPop;
    }


    /**
     * Get idContactPop
     *
     * @return integer 
     */
    public function getIdContactPop()
    {
        return $this->idContactPop;
    }

    /**
     * Set lbTitle
     *
     * @param string $lbTitle
     * @return ContactPop
     */
    public function setLbTitle($lbTitle)
    {
        $this->lbTitle = $lbTitle;
    
        return $this;
    }

    /**
     * Get lbTitle
     *
     * @return string 
     */
    public function getLbTitle()
    {
        return $this->lbTitle;
    }

    /**
     * Set lbFirstname
     *
     * @param string $lbFirstname
     * @return ContactPop
     */
    public function setLbFirstname($lbFirstname)
    {
        $this->lbFirstname = $lbFirstname;
    
        return $this;
    }

    /**
     * Get lbFirstname
     *
     * @return string 
     */
    public function getLbFirstname()
    {
        return $this->lbFirstname;
    }

    /**
     * Set lbLastname
     *
     * @param string $lbLastname
     * @return ContactPop
     */
    public function setLbLastname($lbLastname)
    {
        $this->lbLastname = $lbLastname;
    
        return $this;
    }

    /**
     * Get lbLastname
     *
     * @return string 
     */
    public function getLbLastname()
    {
        return $this->lbLastname;
    }

    /**
     * Set lbEmail
     *
     * @param string $lbEmail
     * @return ContactPop
     */
    public function setLbEmail($lbEmail)
    {
        $this->lbEmail = $lbEmail;
    
        return $this;
    }

    /**
     * Get lbEmail
     *
     * @return string 
     */
    public function getLbEmail()
    {
        return $this->lbEmail;
    }

    /**
     * Set lbPhone
     *
     * @param string $lbPhone
     * @return ContactPop
     */
    public function setLbPhone($lbPhone)
    {
        $this->lbPhone = $lbPhone;
    
        return $this;
    }

    /**
     * Get lbPhone
     *
     * @return string 
     */
    public function getLbPhone()
    {
        return $this->lbPhone;
    }

    /**
     * Set lbMobile
     *
     * @param string $lbMobile
     * @return ContactPop
     */
    public function setLbMobile($lbMobile)
    {
        $this->lbMobile = $lbMobile;
    
        return $this;
    }

    /**
     * Get lbMobile
     *
     * @return string 
     */
    public function getLbMobile()
    {
        return $this->lbMobile;
    }

    /**
     * Set lbFax
     *
     * @param string $lbFax
     * @return ContactPop
     */
    public function setLbFax($lbFax)
    {
        $this->lbFax = $lbFax;
    
        return $this;
    }

    /**
     * Get lbFax
     *
     * @return string 
     */
    public function getLbFax()
    {
        return $this->lbFax;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return ContactPop
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return ContactPop
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return ContactPop
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactived
     *
     * @param \DateTime $dtDeactived
     * @return ContactPop
     */
    public function setDtDeactived($dtDeactived)
    {
        $this->dtDeactived = $dtDeactived;
    
        return $this;
    }

    /**
     * Get dtDeactived
     *
     * @return \DateTime 
     */
    public function getDtDeactived()
    {
        return $this->dtDeactived;
    }

    /**
     * Set blDefault
     *
     * @param boolean $blDefault
     * @return ContactPop
     */
    public function setBlDefault($blDefault)
    {
        $this->blDefault = $blDefault;
    
        return $this;
    }

    /**
     * Get blDefault
     *
     * @return boolean 
     */
    public function getBlDefault()
    {
        return $this->blDefault;
    }

    /**
     * Set comment
     *
     * @param string $comment
     * @return ContactPop
     */
    public function setComment($comment)
    {
        $this->comment = $comment;
    
        return $this;
    }

    /**
     * Get comment
     *
     * @return string 
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return ContactPop
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return ContactPop
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idPop
     *
     * @param \Etrali\GinangBundle\Entity\Pop $idPop
     * @return ContactPop
     */
    public function setIdPop(\Etrali\GinangBundle\Entity\Pop $idPop = null)
    {
        $this->idPop = $idPop;
    
        return $this;
    }

    /**
     * Get idPop
     *
     * @return \Etrali\GinangBundle\Entity\Pop 
     */
    public function getIdPop()
    {
        return $this->idPop;
    }

    /**
     * Set idCivility
     *
     * @param \Etrali\GinangBundle\Entity\Civility $idCivility
     * @return ContactPop
     */
    public function setIdCivility(\Etrali\GinangBundle\Entity\Civility $idCivility = null)
    {
        $this->idCivility = $idCivility;
    
        return $this;
    }

    /**
     * Get idCivility
     *
     * @return \Etrali\GinangBundle\Entity\Civility 
     */
    public function getIdCivility()
    {
        return $this->idCivility;
    }

    /**
     * Set idContactType
     *
     * @param \Etrali\GinangBundle\Entity\ContactType $idContactType
     * @return ContactPop
     */
    public function setIdContactType(\Etrali\GinangBundle\Entity\ContactType $idContactType = null)
    {
        $this->idContactType = $idContactType;
    
        return $this;
    }

    /**
     * Get idContactType
     *
     * @return \Etrali\GinangBundle\Entity\ContactType 
     */
    public function getIdContactType()
    {
        return $this->idContactType;
    }
            
    /**
     * 
     * @return Branch
     */
    public function getParentBranch() {
        if ($this->getIdPop()!=null)
            return $this->getIdPop()->getIdBranch();
        return NULL;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return ContactPop
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}