<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * ContactProvider
 *
 * @ORM\Table(name="contact_provider")
 * @ORM\Entity
 */
class ContactProvider
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_contact_provider", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idContactProvider;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_title", type="string", length=255, nullable=true)
     */
    private $lbTitle;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_firstname", type="string", length=50, nullable=true)
     * @Assert\NotBlank()      
     */
    private $lbFirstname;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_lastname", type="string", length=50, nullable=true)
     * @Assert\NotBlank()       
     */
    private $lbLastname;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_email", type="string", length=100, nullable=true)
     */
    private $lbEmail;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_phone", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20)      
     */
    private $lbPhone;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_mobile", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20)    
     */
    private $lbMobile;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_fax", type="string", length=20, nullable=true)
     * @Assert\MaxLength(20)   
     */
    private $lbFax;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactived", type="datetime", nullable=true)
     */
    private $dtDeactived;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_default", type="boolean", nullable=true)
     */
    private $blDefault;

    /**
     * @var string
     *
     * @ORM\Column(name="comment", type="text", nullable=true)
     */
    private $comment;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \ContactType
     *
     * @ORM\ManyToOne(targetEntity="ContactType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact_type", referencedColumnName="id_contact_type")
     * })
     * @Assert\NotNull()       
     */
    private $idContactType;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

  
    /**
     * @var \Provider
     *
     * @ORM\ManyToOne(targetEntity="Provider", inversedBy="idContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * })
     */
    private $idProvider;       

    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_address_provider", referencedColumnName="id_address_provider")
     * })
     */
    private $idAddressProvider;    
           

    /**
     * @var \Civility
     *
     * @ORM\ManyToOne(targetEntity="Civility")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_civility", referencedColumnName="id_civility")
     * })
     * @Assert\NotNull()       
     */
    private $idCivility;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbFirstname()." ".$this->getLbLastname();
    }

    public function getHeadInfo()
    {
            return "<td>".$this->getLbLastname()."</td><td>".$this->getLbFirstname()."</td><td>".$this->getIdContactType()."</td><td >".$this->getLbPhone()."</td><td>".$this->getLbMobile()."</td><td>".$this->getLbEmail()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Last name</th><th>First name</th><th>Type</th><th>Phone nb</th><th>Mobile nb</th><th>Email</th>";
    } 
    
    /**
     * Get idContact
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->idContact;
    }
    
    /**
     * Get idContact
     *
     * @return integer 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Set lbTitle
     *
     * @param string $lbTitle
     * @return Contact
     */
    public function setLbTitle($lbTitle)
    {
        $this->lbTitle = $lbTitle;
    
        return $this;
    }

    /**
     * Get lbTitle
     *
     * @return string 
     */
    public function getLbTitle()
    {
        return $this->lbTitle;
    }

    /**
     * Set lbFirstname
     *
     * @param string $lbFirstname
     * @return Contact
     */
    public function setLbFirstname($lbFirstname)
    {
        $this->lbFirstname = $lbFirstname;
    
        return $this;
    }

    /**
     * Get lbFirstname
     *
     * @return string 
     */
    public function getLbFirstname()
    {
        return $this->lbFirstname;
    }

    /**
     * Set lbLastname
     *
     * @param string $lbLastname
     * @return Contact
     */
    public function setLbLastname($lbLastname)
    {
        $this->lbLastname = $lbLastname;
    
        return $this;
    }

    /**
     * Get lbLastname
     *
     * @return string 
     */
    public function getLbLastname()
    {
        return $this->lbLastname;
    }

    /**
     * Set lbEmail
     *
     * @param string $lbEmail
     * @return Contact
     */
    public function setLbEmail($lbEmail)
    {
        $this->lbEmail = $lbEmail;
    
        return $this;
    }

    /**
     * Get lbEmail
     *
     * @return string 
     */
    public function getLbEmail()
    {
        return $this->lbEmail;
    }

    /**
     * Set lbPhone
     *
     * @param string $lbPhone
     * @return Contact
     */
    public function setLbPhone($lbPhone)
    {
        $this->lbPhone = $lbPhone;
    
        return $this;
    }

    /**
     * Get lbPhone
     *
     * @return string 
     */
    public function getLbPhone()
    {
        return $this->lbPhone;
    }

    /**
     * Set lbMobile
     *
     * @param string $lbMobile
     * @return Contact
     */
    public function setLbMobile($lbMobile)
    {
        $this->lbMobile = $lbMobile;
    
        return $this;
    }

    /**
     * Get lbMobile
     *
     * @return string 
     */
    public function getLbMobile()
    {
        return $this->lbMobile;
    }

    /**
     * Set lbFax
     *
     * @param string $lbFax
     * @return Contact
     */
    public function setLbFax($lbFax)
    {
        $this->lbFax = $lbFax;
    
        return $this;
    }

    /**
     * Get lbFax
     *
     * @return string 
     */
    public function getLbFax()
    {
        return $this->lbFax;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Contact
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Contact
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Contact
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactived
     *
     * @param \DateTime $dtDeactived
     * @return Contact
     */
    public function setDtDeactived($dtDeactived)
    {
        $this->dtDeactived = $dtDeactived;
    
        return $this;
    }

    /**
     * Get dtDeactived
     *
     * @return \DateTime 
     */
    public function getDtDeactived()
    {
        return $this->dtDeactived;
    }

    /**
     * Set blDefault
     *
     * @param boolean $blDefault
     * @return Contact
     */
    public function setBlDefault($blDefault)
    {
        $this->blDefault = $blDefault;
    
        return $this;
    }

    /**
     * Get blDefault
     *
     * @return boolean 
     */
    public function getBlDefault()
    {
        return $this->blDefault;
    }

    /**
     * Set comment
     *
     * @param string $comment
     * @return Contact
     */
    public function setComment($comment)
    {
        $this->comment = $comment;
    
        return $this;
    }

    /**
     * Get comment
     *
     * @return string 
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Contact
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idContactType
     *
     * @param \Etrali\GinangBundle\Entity\ContactType $idContactType
     * @return Contact
     */
    public function setIdContactType(\Etrali\GinangBundle\Entity\ContactType $idContactType = null)
    {
        $this->idContactType = $idContactType;
    
        return $this;
    }

    /**
     * Get idContactType
     *
     * @return \Etrali\GinangBundle\Entity\ContactType 
     */
    public function getIdContactType()
    {
        return $this->idContactType;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Contact
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     * @return Contact
     */
    public function setIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer = null)
    {
        $this->idCustomer = $idCustomer;
    
        return $this;
    }

    /**
     * Get idCustomer
     *
     * @return \Etrali\GinangBundle\Entity\Customer 
     */
    public function getIdCustomer()
    {
        return $this->idCustomer;
    }

    /**
     * Set idCivility
     *
     * @param \Etrali\GinangBundle\Entity\Civility $idCivility
     * @return Contact
     */
    public function setIdCivility(\Etrali\GinangBundle\Entity\Civility $idCivility = null)
    {
        $this->idCivility = $idCivility;
    
        return $this;
    }

    /**
     * Get idCivility
     *
     * @return \Etrali\GinangBundle\Entity\Civility 
     */
    public function getIdCivility()
    {
        return $this->idCivility;
    }

    /**
     * Set idNature
     *
     * @param \Etrali\GinangBundle\Entity\Nature $idNature
     * @return Contact
     */
    public function setIdNature(\Etrali\GinangBundle\Entity\Nature $idNature = null)
    {
        $this->idNature = $idNature;
    
        return $this;
    }

    /**
     * Get idNature
     *
     * @return \Etrali\GinangBundle\Entity\Nature 
     */
    public function getIdNature()
    {
        return $this->idNature;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return Contact
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Get idContactProvider
     *
     * @return integer 
     */
    public function getIdContactProvider()
    {
        return $this->idContactProvider;
    }

    /**
     * Set idAddressProvider
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idAddressProvider
     * @return ContactProvider
     */
    public function setIdAddressProvider(\Etrali\GinangBundle\Entity\AddressProvider $idAddressProvider = null)
    {
        $this->idAddressProvider = $idAddressProvider;
    
        return $this;
    }

    /**
     * Get idAddressProvider
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdAddressProvider()
    {
        return $this->idAddressProvider;
    }

public function getParentBranch() { return NULL; }  
    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return ContactProvider
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}