<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * CostingBackboneLinkLine
 *
 * @ORM\Table(name="costing_backbone_link_line")
 * @ORM\Entity
 */
class CostingBackboneLinkLine
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_costing_backbone_link_line", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCostingBackboneLinkLine;

        /**
     * @var float
     *
     * @ORM\Column(name="mt_nrc", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "NRC can not be zero") 
     */
    private $mtNrc;

    /**
     * @var float
     *
     * @ORM\Column(name="mt_mrc", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "MRC can not be zero")  
     */
    private $mtMrc;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_nrc", type="string", length=255, nullable=true)
     */
    private $lbNrc;
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_mrc", type="string", length=255, nullable=true)
     */
    private $lbMrc;    
    
    /**
     * @var float
     *
     * @ORM\Column(name="mt_nrc_euro", type="decimal", nullable=true)
     *     
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "NRC euro can not be zero") 
     */
    private $mtNrcEuro;

    /**
     * @var float
     *
     * @ORM\Column(name="mt_mrc_euro", type="decimal", nullable=true)
     *     
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "MRC euro can not be zero")  
     */
    private $mtMrcEuro;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start_mrc", type="datetime", nullable=true)    
     */
    private $dtStartMrc;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end_mrc", type="datetime", nullable=true)
     */
    private $dtEndMrc;


    
        /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * }) 
     * @Assert\NotNull()       
     */
    private $idProvider;
    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()  	          
     */
    private $idProviderAddress;    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * }) 
     * @Assert\NotNull()     
     */
    private $idContact;
    
    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     * 
     * @Assert\MaxLength(20)   
     */
    private $cdProviderAccount;    
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start", type="datetime", nullable=true) 
     */
    private $dtStart;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end", type="datetime", nullable=true)
     */
    private $dtEnd;


    /**
     * @var integer
     *
     * @ORM\Column(name="nb_contract_duration", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Contract duration can not be zero")  
     */
    private $nbContractDuration;

    /**
     * @var \NoticePeriod
     *
     * @ORM\ManyToOne(targetEntity="NoticePeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_notice_period", referencedColumnName="id_notice_period")
     * })
     * @Assert\NotNull();     
     */
    private $idNoticePeriod;


    /**
     * @var \BillingFrequency
     *
     * @ORM\ManyToOne(targetEntity="BillingFrequency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_frequency", referencedColumnName="id_billing_frequency")
     * })
     * @Assert\NotNull() 
     */
    private $idBillingFrequency;

    /**
     * @var \Currency
     *
     * @ORM\ManyToOne(targetEntity="Currency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_currency", referencedColumnName="id_currency")
     * })
     * @Assert\NotNull() 
     */
    private $idCurrency;


    /**
     * @var \BackboneLink
     *
     * @ORM\ManyToOne(targetEntity="BackboneLink", inversedBy="idCostingBackboneLinkLine")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_backbone_link", referencedColumnName="id_backbone_link")
     * })
     */
    private $idBackboneLink;

    /**
     * @var \BackboneLinkOption
     *
     * @ORM\ManyToOne(targetEntity="BackboneLinkOption")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_backbone_link_option", referencedColumnName="id_backbone_link_option")
     * })
     */
    private $idBackboneLinkOption;

    public function __toString()
    {
        return $this->getIdBackboneLink().":".$this->getIdBackboneLinkOption();
    }
        
    public function getHeadInfo()
    {
            return "<td>".$this->getIdBackboneLinkOption()."</td><td>".$this->getIdProvider()."</td><td>".$this->getIdProvider()->getCdProviderAccount()."</td><td>".$this->getIdCurrency()."</td>";
    }  
    public function getHeadColumns()
    {
            return "<th>Option</th><th>Carrier</th><th>Carrier account</th><th>Currency</th>";
    }  
 
    
   
    
    /**
     * 
     * @return Branch
     */
    public function getParentBranch() {
        if ($this->getIdBackboneLink()!=null)
            return $this->getIdBackboneLink()->getIdBranch();
        return NULL;
    }

    /**
     * Get idCostingBackboneLinkLine
     *
     * @return integer 
     */
    public function getIdCostingBackboneLinkLine()
    {
        return $this->idCostingBackboneLinkLine;
    }

    /**
     * Set mtNrc
     *
     * @param float $mtNrc
     * @return CostingBackboneLinkLine
     */
    public function setMtNrc($mtNrc)
    {
        $this->mtNrc = $mtNrc;
    
        return $this;
    }

    /**
     * Get mtNrc
     *
     * @return float 
     */
    public function getMtNrc()
    {
        return $this->mtNrc;
    }

    /**
     * Set mtMrc
     *
     * @param float $mtMrc
     * @return CostingBackboneLinkLine
     */
    public function setMtMrc($mtMrc)
    {
        $this->mtMrc = $mtMrc;
    
        return $this;
    }

    /**
     * Get mtMrc
     *
     * @return float 
     */
    public function getMtMrc()
    {
        return $this->mtMrc;
    }

    /**
     * Set lbNrc
     *
     * @param string $lbNrc
     * @return CostingBackboneLinkLine
     */
    public function setLbNrc($lbNrc)
    {
        $this->lbNrc = $lbNrc;
    
        return $this;
    }

    /**
     * Get lbNrc
     *
     * @return string 
     */
    public function getLbNrc()
    {
        return $this->lbNrc;
    }

    /**
     * Set lbMrc
     *
     * @param string $lbMrc
     * @return CostingBackboneLinkLine
     */
    public function setLbMrc($lbMrc)
    {
        $this->lbMrc = $lbMrc;
    
        return $this;
    }

    /**
     * Get lbMrc
     *
     * @return string 
     */
    public function getLbMrc()
    {
        return $this->lbMrc;
    }

    /**
     * Set mtNrcEuro
     *
     * @param float $mtNrcEuro
     * @return CostingBackboneLinkLine
     */
    public function setMtNrcEuro($mtNrcEuro)
    {
        $this->mtNrcEuro = $mtNrcEuro;
    
        return $this;
    }

    /**
     * Get mtNrcEuro
     *
     * @return float 
     */
    public function getMtNrcEuro()
    {
        return $this->mtNrcEuro;
    }

    /**
     * Set mtMrcEuro
     *
     * @param float $mtMrcEuro
     * @return CostingBackboneLinkLine
     */
    public function setMtMrcEuro($mtMrcEuro)
    {
        $this->mtMrcEuro = $mtMrcEuro;
    
        return $this;
    }

    /**
     * Get mtMrcEuro
     *
     * @return float 
     */
    public function getMtMrcEuro()
    {
        return $this->mtMrcEuro;
    }

    /**
     * Set dtStartMrc
     *
     * @param \DateTime $dtStartMrc
     * @return CostingBackboneLinkLine
     */
    public function setDtStartMrc($dtStartMrc)
    {
        $this->dtStartMrc = $dtStartMrc;
    
        return $this;
    }

    /**
     * Get dtStartMrc
     *
     * @return \DateTime 
     */
    public function getDtStartMrc()
    {
        return $this->dtStartMrc;
    }

    /**
     * Set dtEndMrc
     *
     * @param \DateTime $dtEndMrc
     * @return CostingBackboneLinkLine
     */
    public function setDtEndMrc($dtEndMrc)
    {
        $this->dtEndMrc = $dtEndMrc;
    
        return $this;
    }

    /**
     * Get dtEndMrc
     *
     * @return \DateTime 
     */
    public function getDtEndMrc()
    {
        return $this->dtEndMrc;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return CostingBackboneLinkLine
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set dtStart
     *
     * @param \DateTime $dtStart
     * @return CostingBackboneLinkLine
     */
    public function setDtStart($dtStart)
    {
        $this->dtStart = $dtStart;
    
        return $this;
    }

    /**
     * Get dtStart
     *
     * @return \DateTime 
     */
    public function getDtStart()
    {
        return $this->dtStart;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return CostingBackboneLinkLine
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set nbContractDuration
     *
     * @param integer $nbContractDuration
     * @return CostingBackboneLinkLine
     */
    public function setNbContractDuration($nbContractDuration)
    {
        $this->nbContractDuration = $nbContractDuration;
    
        return $this;
    }

    /**
     * Get nbContractDuration
     *
     * @return integer 
     */
    public function getNbContractDuration()
    {
        return $this->nbContractDuration;
    }

    /**
     * Set idBillingPeriod
     *
     * @param \Etrali\GinangBundle\Entity\BillingPeriod $idBillingPeriod
     * @return CostingBackboneLinkLine
     */
    public function setIdBillingPeriod(\Etrali\GinangBundle\Entity\BillingPeriod $idBillingPeriod = null)
    {
        $this->idBillingPeriod = $idBillingPeriod;
    
        return $this;
    }

    /**
     * Get idBillingPeriod
     *
     * @return \Etrali\GinangBundle\Entity\BillingPeriod 
     */
    public function getIdBillingPeriod()
    {
        return $this->idBillingPeriod;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return CostingBackboneLinkLine
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return CostingBackboneLinkLine
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return CostingBackboneLinkLine
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Set idNoticePeriod
     *
     * @param \Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod
     * @return CostingBackboneLinkLine
     */
    public function setIdNoticePeriod(\Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod = null)
    {
        $this->idNoticePeriod = $idNoticePeriod;
    
        return $this;
    }

    /**
     * Get idNoticePeriod
     *
     * @return \Etrali\GinangBundle\Entity\NoticePeriod 
     */
    public function getIdNoticePeriod()
    {
        return $this->idNoticePeriod;
    }

    /**
     * Set idBillingFrequency
     *
     * @param \Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency
     * @return CostingBackboneLinkLine
     */
    public function setIdBillingFrequency(\Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency = null)
    {
        $this->idBillingFrequency = $idBillingFrequency;
    
        return $this;
    }

    /**
     * Get idBillingFrequency
     *
     * @return \Etrali\GinangBundle\Entity\BillingFrequency 
     */
    public function getIdBillingFrequency()
    {
        return $this->idBillingFrequency;
    }

    /**
     * Set idCurrency
     *
     * @param \Etrali\GinangBundle\Entity\Currency $idCurrency
     * @return CostingBackboneLinkLine
     */
    public function setIdCurrency(\Etrali\GinangBundle\Entity\Currency $idCurrency = null)
    {
        $this->idCurrency = $idCurrency;
    
        return $this;
    }

    /**
     * Get idCurrency
     *
     * @return \Etrali\GinangBundle\Entity\Currency 
     */
    public function getIdCurrency()
    {
        return $this->idCurrency;
    }

    /**
     * Set idBackboneLink
     *
     * @param \Etrali\GinangBundle\Entity\BackboneLink $idBackboneLink
     * @return CostingBackboneLinkLine
     */
    public function setIdBackboneLink(\Etrali\GinangBundle\Entity\BackboneLink $idBackboneLink = null)
    {
        $this->idBackboneLink = $idBackboneLink;
    
        return $this;
    }

    /**
     * Get idBackboneLink
     *
     * @return \Etrali\GinangBundle\Entity\BackboneLink 
     */
    public function getIdBackboneLink()
    {
        return $this->idBackboneLink;
    }

    /**
     * Set idBackboneLinkOption
     *
     * @param \Etrali\GinangBundle\Entity\BackboneLinkOption $idBackboneLinkOption
     * @return CostingBackboneLinkLine
     */
    public function setIdBackboneLinkOption(\Etrali\GinangBundle\Entity\BackboneLinkOption $idBackboneLinkOption = null)
    {
        $this->idBackboneLinkOption = $idBackboneLinkOption;
    
        return $this;
    }

    /**
     * Get idBackboneLinkOption
     *
     * @return \Etrali\GinangBundle\Entity\BackboneLinkOption 
     */
    public function getIdBackboneLinkOption()
    {
        return $this->idBackboneLinkOption;
    }
}