<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * CostingPatchPanelLine
 *
 * @ORM\Table(name="costing_patch_panel_line")
 * @ORM\Entity
 */
class CostingPatchPanelLine
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_costing_patch_panel_line", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCostingPatchPanelLine;

        /**
     * @var float
     *
     * @ORM\Column(name="mt_nrc", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "NRC can not be zero") 
     */
    private $mtNrc;

    /**
     * @var float
     *
     * @ORM\Column(name="mt_mrc", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "MRC can not be zero")  
     */
    private $mtMrc;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_nrc", type="string", length=255, nullable=true)
     */
    private $lbNrc;
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_mrc", type="string", length=255, nullable=true)
     */
    private $lbMrc;    
    
    /**
     * @var float
     *
     * @ORM\Column(name="mt_nrc_euro", type="decimal", nullable=true)
     *     
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "NRC euro can not be zero") 
     */
    private $mtNrcEuro;

    /**
     * @var float
     *
     * @ORM\Column(name="mt_mrc_euro", type="decimal", nullable=true)
     *     
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "MRC euro can not be zero")  
     */
    private $mtMrcEuro;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start_mrc", type="datetime", nullable=true)
     * @Assert\NotNull()      
     */
    private $dtStartMrc;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end_mrc", type="datetime", nullable=true)
     */
    private $dtEndMrc;


    
     /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start", type="datetime", nullable=true)
     * @Assert\NotNull()   
     */
    private $dtStart;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end", type="datetime", nullable=true)
     */
    private $dtEnd;


    /**
     * @var integer
     *
     * @ORM\Column(name="nb_contract_duration", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Contract duration can not be zero")  
     */
    private $nbContractDuration;

    /**
     * @var \NoticePeriod
     *
     * @ORM\ManyToOne(targetEntity="NoticePeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_notice_period", referencedColumnName="id_notice_period")
     * })
     * @Assert\NotNull();     
     */
    private $idNoticePeriod;


    /**
     * @var \BillingFrequency
     *
     * @ORM\ManyToOne(targetEntity="BillingFrequency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_frequency", referencedColumnName="id_billing_frequency")
     * })
     * @Assert\NotNull() 
     */
    private $idBillingFrequency;

    /**
     * @var \Currency
     *
     * @ORM\ManyToOne(targetEntity="Currency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_currency", referencedColumnName="id_currency")
     * })
     * @Assert\NotNull() 
     */
    private $idCurrency;


    /**
     * @var \PatchPanel
     *
     * @ORM\ManyToOne(targetEntity="PatchPanel", inversedBy="idCostingPatchPanelLine", cascade={"persist"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_patch_panel", referencedColumnName="id_patch_panel")
     * })    
     */
    private $idPatchPanel;
    
    /**
     * @var \PatchPanelInstance
     *
     * @ORM\ManyToOne(targetEntity="PatchPanelInstance", inversedBy="idCostingPatchPanelLine", cascade={"persist"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_patch_panel_instance", referencedColumnName="id_patch_panel_instance")
     * })    
     */
    private $idPatchPanelInstance;    

      /**
     * @var \BillingPeriod
     *
     * @ORM\ManyToOne(targetEntity="BillingPeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_period", referencedColumnName="id_billing_period")
     * })
     */
    private $idBillingPeriod;
    
    public function getHeadInfo()
    {
            return "<td>".($this->getDtStart()?$this->getDtStart()->format("d/m/Y"):"&nbsp;")."</td><td >".($this->getDtEnd()?$this->getDtEnd()->format("d/m/Y"):"&nbsp;")."</td><td>".$this->getNbContractDuration()."</td><td>".$this->getIdNoticePeriod()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Start</th><th>End</th><th>Contract duration</th><th>Notice period</th>";
    }  
    
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return "".$this->getNbContractDuration();
    }


public function getParentBranch() { return NULL; }  
    /**
     * Get idCostingPatchPanelLine
     *
     * @return integer 
     */
    public function getIdCostingPatchPanelLine()
    {
        return $this->idCostingPatchPanelLine;
    }

    /**
     * Set mtNrc
     *
     * @param float $mtNrc
     * @return CostingPatchPanelLine
     */
    public function setMtNrc($mtNrc)
    {
        $this->mtNrc = $mtNrc;
    
        return $this;
    }

    /**
     * Get mtNrc
     *
     * @return float 
     */
    public function getMtNrc()
    {
        return $this->mtNrc;
    }

    /**
     * Set mtMrc
     *
     * @param float $mtMrc
     * @return CostingPatchPanelLine
     */
    public function setMtMrc($mtMrc)
    {
        $this->mtMrc = $mtMrc;
    
        return $this;
    }

    /**
     * Get mtMrc
     *
     * @return float 
     */
    public function getMtMrc()
    {
        return $this->mtMrc;
    }

    /**
     * Set lbNrc
     *
     * @param string $lbNrc
     * @return CostingPatchPanelLine
     */
    public function setLbNrc($lbNrc)
    {
        $this->lbNrc = $lbNrc;
    
        return $this;
    }

    /**
     * Get lbNrc
     *
     * @return string 
     */
    public function getLbNrc()
    {
        return $this->lbNrc;
    }

    /**
     * Set lbMrc
     *
     * @param string $lbMrc
     * @return CostingPatchPanelLine
     */
    public function setLbMrc($lbMrc)
    {
        $this->lbMrc = $lbMrc;
    
        return $this;
    }

    /**
     * Get lbMrc
     *
     * @return string 
     */
    public function getLbMrc()
    {
        return $this->lbMrc;
    }

    /**
     * Set mtNrcEuro
     *
     * @param float $mtNrcEuro
     * @return CostingPatchPanelLine
     */
    public function setMtNrcEuro($mtNrcEuro)
    {
        $this->mtNrcEuro = $mtNrcEuro;
    
        return $this;
    }

    /**
     * Get mtNrcEuro
     *
     * @return float 
     */
    public function getMtNrcEuro()
    {
        return $this->mtNrcEuro;
    }

    /**
     * Set mtMrcEuro
     *
     * @param float $mtMrcEuro
     * @return CostingPatchPanelLine
     */
    public function setMtMrcEuro($mtMrcEuro)
    {
        $this->mtMrcEuro = $mtMrcEuro;
    
        return $this;
    }

    /**
     * Get mtMrcEuro
     *
     * @return float 
     */
    public function getMtMrcEuro()
    {
        return $this->mtMrcEuro;
    }

    /**
     * Set dtStartMrc
     *
     * @param \DateTime $dtStartMrc
     * @return CostingPatchPanelLine
     */
    public function setDtStartMrc($dtStartMrc)
    {
        $this->dtStartMrc = $dtStartMrc;
    
        return $this;
    }

    /**
     * Get dtStartMrc
     *
     * @return \DateTime 
     */
    public function getDtStartMrc()
    {
        return $this->dtStartMrc;
    }

    /**
     * Set dtEndMrc
     *
     * @param \DateTime $dtEndMrc
     * @return CostingPatchPanelLine
     */
    public function setDtEndMrc($dtEndMrc)
    {
        $this->dtEndMrc = $dtEndMrc;
    
        return $this;
    }

    /**
     * Get dtEndMrc
     *
     * @return \DateTime 
     */
    public function getDtEndMrc()
    {
        return $this->dtEndMrc;
    }

    /**
     * Set dtStart
     *
     * @param \DateTime $dtStart
     * @return CostingPatchPanelLine
     */
    public function setDtStart($dtStart)
    {
        $this->dtStart = $dtStart;
    
        return $this;
    }

    /**
     * Get dtStart
     *
     * @return \DateTime 
     */
    public function getDtStart()
    {
        return $this->dtStart;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return CostingPatchPanelLine
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set nbContractDuration
     *
     * @param integer $nbContractDuration
     * @return CostingPatchPanelLine
     */
    public function setNbContractDuration($nbContractDuration)
    {
        $this->nbContractDuration = $nbContractDuration;
    
        return $this;
    }

    /**
     * Get nbContractDuration
     *
     * @return integer 
     */
    public function getNbContractDuration()
    {
        return $this->nbContractDuration;
    }

    /**
     * Set idBillingPeriod
     *
     * @param \Etrali\GinangBundle\Entity\BillingPeriod $idBillingPeriod
     * @return CostingPatchPanelLine
     */
    public function setIdBillingPeriod(\Etrali\GinangBundle\Entity\BillingPeriod $idBillingPeriod = null)
    {
        $this->idBillingPeriod = $idBillingPeriod;
    
        return $this;
    }

    /**
     * Get idBillingPeriod
     *
     * @return \Etrali\GinangBundle\Entity\BillingPeriod 
     */
    public function getIdBillingPeriod()
    {
        return $this->idBillingPeriod;
    }

    /**
     * Set idNoticePeriod
     *
     * @param \Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod
     * @return CostingPatchPanelLine
     */
    public function setIdNoticePeriod(\Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod = null)
    {
        $this->idNoticePeriod = $idNoticePeriod;
    
        return $this;
    }

    /**
     * Get idNoticePeriod
     *
     * @return \Etrali\GinangBundle\Entity\NoticePeriod 
     */
    public function getIdNoticePeriod()
    {
        return $this->idNoticePeriod;
    }

    /**
     * Set idBillingFrequency
     *
     * @param \Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency
     * @return CostingPatchPanelLine
     */
    public function setIdBillingFrequency(\Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency = null)
    {
        $this->idBillingFrequency = $idBillingFrequency;
    
        return $this;
    }

    /**
     * Get idBillingFrequency
     *
     * @return \Etrali\GinangBundle\Entity\BillingFrequency 
     */
    public function getIdBillingFrequency()
    {
        return $this->idBillingFrequency;
    }

    /**
     * Set idCurrency
     *
     * @param \Etrali\GinangBundle\Entity\Currency $idCurrency
     * @return CostingPatchPanelLine
     */
    public function setIdCurrency(\Etrali\GinangBundle\Entity\Currency $idCurrency = null)
    {
        $this->idCurrency = $idCurrency;
    
        return $this;
    }

    /**
     * Get idCurrency
     *
     * @return \Etrali\GinangBundle\Entity\Currency 
     */
    public function getIdCurrency()
    {
        return $this->idCurrency;
    }

    /**
     * Set idPatchPanel
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel
     * @return CostingPatchPanelLine
     */
    public function setIdPatchPanel(\Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel = null)
    {
        $this->idPatchPanel = $idPatchPanel;
    
        return $this;
    }

    /**
     * Get idPatchPanel
     *
     * @return \Etrali\GinangBundle\Entity\PatchPanel 
     */
    public function getIdPatchPanel()
    {
        return $this->idPatchPanel;
    }

    /**
     * Set idPatchPanelInstance
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance
     * @return CostingPatchPanelLine
     */
    public function setIdPatchPanelInstance(\Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance = null)
    {
        $this->idPatchPanelInstance = $idPatchPanelInstance;
    
        return $this;
    }

    /**
     * Get idPatchPanelInstance
     *
     * @return \Etrali\GinangBundle\Entity\PatchPanelInstance 
     */
    public function getIdPatchPanelInstance()
    {
        return $this->idPatchPanelInstance;
    }
}