<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * CostingPopLine
 *
 * @ORM\Table(name="costing_pop_line")
 * @ORM\Entity
 */
class CostingPopLine
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_costing_pop_line", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCostingPopLine;

        /**
     * @var float
     *
     * @ORM\Column(name="mt_nrc", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "NRC can not be zero") 
     */
    private $mtNrc;

    /**
     * @var float
     *
     * @ORM\Column(name="mt_mrc", type="decimal", nullable=true)
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "MRC can not be zero")  
     */
    private $mtMrc;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_nrc", type="string", length=255, nullable=true)
     */
    private $lbNrc;
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_mrc", type="string", length=255, nullable=true)
     */
    private $lbMrc;    
    
    /**
     * @var float
     *
     * @ORM\Column(name="mt_nrc_euro", type="decimal", nullable=true)
     *     
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "NRC euro can not be zero") 
     */
    private $mtNrcEuro;

    /**
     * @var float
     *
     * @ORM\Column(name="mt_mrc_euro", type="decimal", nullable=true)
     *     
     * @Assert\Range(
     *      min = "0",
     *      minMessage = "MRC euro can not be zero")  
     */
    private $mtMrcEuro;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start_mrc", type="datetime", nullable=true)
     * @Assert\NotNull()      
     */
    private $dtStartMrc;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end_mrc", type="datetime", nullable=true)
     */
    private $dtEndMrc;


    /**
     * @var \BillingPeriod
     *
     * @ORM\ManyToOne(targetEntity="BillingPeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_period", referencedColumnName="id_billing_period")
     * })
     */
    private $idBillingPeriod;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start", type="datetime", nullable=true)
     * @Assert\NotNull()      
     */
    private $dtStart;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end", type="datetime", nullable=true)
     */
    private $dtEnd;


    /**
     * @var integer
     *
     * @ORM\Column(name="nb_contract_duration", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Contract duration can not be zero")  
     */
    private $nbContractDuration;



    /**
     * @var \BillingFrequency
     *
     * @ORM\ManyToOne(targetEntity="BillingFrequency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_frequency", referencedColumnName="id_billing_frequency")
     * })
     * @Assert\NotNull() 
     */
    private $idBillingFrequency;

    /**
     * @var \Currency
     *
     * @ORM\ManyToOne(targetEntity="Currency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_currency", referencedColumnName="id_currency")
     * })
     * @Assert\NotNull() 
     */
    private $idCurrency;

    /**
     * @var \NoticePeriod
     *
     * @ORM\ManyToOne(targetEntity="NoticePeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_notice_period", referencedColumnName="id_notice_period")
     * })
     * @Assert\NotNull();     
     */
    private $idNoticePeriod;
    
    /**
     * @var \CostingPop
     *
     * @ORM\ManyToOne(targetEntity="CostingPop",  inversedBy="idCostingPopLine", cascade={"persist"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_costing_pop", referencedColumnName="id_costing_pop")
     * })    
     */
    private $idCostingPop;

            /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * }) 
     * @Assert\NotNull()       
     */
    private $idProvider;
    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()  	          
     */
    private $idProviderAddress;    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * }) 
     * @Assert\NotNull()     
     */
    private $idContact;
    
    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     * 
     * @Assert\MaxLength(20)   
     */
    private $cdProviderAccount;     
    
    public function __toString()
    {
        return $this->getIdCurrency()."";
    }
    
public function getParentBranch() { return NULL; }  
    /**
     * Get idCostingPopLine
     *
     * @return integer 
     */
    public function getIdCostingPopLine()
    {
        return $this->idCostingPopLine;
    }

    /**
     * Set mtNrc
     *
     * @param float $mtNrc
     * @return CostingPopLine
     */
    public function setMtNrc($mtNrc)
    {
        $this->mtNrc = $mtNrc;
    
        return $this;
    }

    /**
     * Get mtNrc
     *
     * @return float 
     */
    public function getMtNrc()
    {
        return $this->mtNrc;
    }

    /**
     * Set mtMrc
     *
     * @param float $mtMrc
     * @return CostingPopLine
     */
    public function setMtMrc($mtMrc)
    {
        $this->mtMrc = $mtMrc;
    
        return $this;
    }

    /**
     * Get mtMrc
     *
     * @return float 
     */
    public function getMtMrc()
    {
        return $this->mtMrc;
    }

    /**
     * Set lbNrc
     *
     * @param string $lbNrc
     * @return CostingPopLine
     */
    public function setLbNrc($lbNrc)
    {
        $this->lbNrc = $lbNrc;
    
        return $this;
    }

    /**
     * Get lbNrc
     *
     * @return string 
     */
    public function getLbNrc()
    {
        return $this->lbNrc;
    }

    /**
     * Set lbMrc
     *
     * @param string $lbMrc
     * @return CostingPopLine
     */
    public function setLbMrc($lbMrc)
    {
        $this->lbMrc = $lbMrc;
    
        return $this;
    }

    /**
     * Get lbMrc
     *
     * @return string 
     */
    public function getLbMrc()
    {
        return $this->lbMrc;
    }

    /**
     * Set mtNrcEuro
     *
     * @param float $mtNrcEuro
     * @return CostingPopLine
     */
    public function setMtNrcEuro($mtNrcEuro)
    {
        $this->mtNrcEuro = $mtNrcEuro;
    
        return $this;
    }

    /**
     * Get mtNrcEuro
     *
     * @return float 
     */
    public function getMtNrcEuro()
    {
        return $this->mtNrcEuro;
    }

    /**
     * Set mtMrcEuro
     *
     * @param float $mtMrcEuro
     * @return CostingPopLine
     */
    public function setMtMrcEuro($mtMrcEuro)
    {
        $this->mtMrcEuro = $mtMrcEuro;
    
        return $this;
    }

    /**
     * Get mtMrcEuro
     *
     * @return float 
     */
    public function getMtMrcEuro()
    {
        return $this->mtMrcEuro;
    }

    /**
     * Set dtStartMrc
     *
     * @param \DateTime $dtStartMrc
     * @return CostingPopLine
     */
    public function setDtStartMrc($dtStartMrc)
    {
        $this->dtStartMrc = $dtStartMrc;
    
        return $this;
    }

    /**
     * Get dtStartMrc
     *
     * @return \DateTime 
     */
    public function getDtStartMrc()
    {
        return $this->dtStartMrc;
    }

    /**
     * Set dtEndMrc
     *
     * @param \DateTime $dtEndMrc
     * @return CostingPopLine
     */
    public function setDtEndMrc($dtEndMrc)
    {
        $this->dtEndMrc = $dtEndMrc;
    
        return $this;
    }

    /**
     * Get dtEndMrc
     *
     * @return \DateTime 
     */
    public function getDtEndMrc()
    {
        return $this->dtEndMrc;
    }

    /**
     * Set dtStart
     *
     * @param \DateTime $dtStart
     * @return CostingPopLine
     */
    public function setDtStart($dtStart)
    {
        $this->dtStart = $dtStart;
    
        return $this;
    }

    /**
     * Get dtStart
     *
     * @return \DateTime 
     */
    public function getDtStart()
    {
        return $this->dtStart;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return CostingPopLine
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set nbContractDuration
     *
     * @param integer $nbContractDuration
     * @return CostingPopLine
     */
    public function setNbContractDuration($nbContractDuration)
    {
        $this->nbContractDuration = $nbContractDuration;
    
        return $this;
    }

    /**
     * Get nbContractDuration
     *
     * @return integer 
     */
    public function getNbContractDuration()
    {
        return $this->nbContractDuration;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return CostingPopLine
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set idBillingPeriod
     *
     * @param \Etrali\GinangBundle\Entity\BillingPeriod $idBillingPeriod
     * @return CostingPopLine
     */
    public function setIdBillingPeriod(\Etrali\GinangBundle\Entity\BillingPeriod $idBillingPeriod = null)
    {
        $this->idBillingPeriod = $idBillingPeriod;
    
        return $this;
    }

    /**
     * Get idBillingPeriod
     *
     * @return \Etrali\GinangBundle\Entity\BillingPeriod 
     */
    public function getIdBillingPeriod()
    {
        return $this->idBillingPeriod;
    }

    /**
     * Set idNoticePeriod
     *
     * @param \Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod
     * @return CostingPopLine
     */
    public function setIdNoticePeriod(\Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod = null)
    {
        $this->idNoticePeriod = $idNoticePeriod;
    
        return $this;
    }

    /**
     * Get idNoticePeriod
     *
     * @return \Etrali\GinangBundle\Entity\NoticePeriod 
     */
    public function getIdNoticePeriod()
    {
        return $this->idNoticePeriod;
    }

    /**
     * Set idBillingFrequency
     *
     * @param \Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency
     * @return CostingPopLine
     */
    public function setIdBillingFrequency(\Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency = null)
    {
        $this->idBillingFrequency = $idBillingFrequency;
    
        return $this;
    }

    /**
     * Get idBillingFrequency
     *
     * @return \Etrali\GinangBundle\Entity\BillingFrequency 
     */
    public function getIdBillingFrequency()
    {
        return $this->idBillingFrequency;
    }

    /**
     * Set idCurrency
     *
     * @param \Etrali\GinangBundle\Entity\Currency $idCurrency
     * @return CostingPopLine
     */
    public function setIdCurrency(\Etrali\GinangBundle\Entity\Currency $idCurrency = null)
    {
        $this->idCurrency = $idCurrency;
    
        return $this;
    }

    /**
     * Get idCurrency
     *
     * @return \Etrali\GinangBundle\Entity\Currency 
     */
    public function getIdCurrency()
    {
        return $this->idCurrency;
    }

    /**
     * Set idCostingPop
     *
     * @param \Etrali\GinangBundle\Entity\CostingPop $idCostingPop
     * @return CostingPopLine
     */
    public function setIdCostingPop(\Etrali\GinangBundle\Entity\CostingPop $idCostingPop = null)
    {
        $this->idCostingPop = $idCostingPop;
    
        return $this;
    }

    /**
     * Get idCostingPop
     *
     * @return \Etrali\GinangBundle\Entity\CostingPop 
     */
    public function getIdCostingPop()
    {
        return $this->idCostingPop;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return CostingPopLine
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return CostingPopLine
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return CostingPopLine
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }
}