<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Customer
 *
 * @ORM\Table(name="customer")
 * @ORM\Entity
 */
class Customer
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_customer", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idCustomer;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_magellan", type="string", length=15, nullable=true)
     * @Assert\NotBlank() 
     */
    private $cdMagellan;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_customer", type="string", length=100, nullable=true)
     * @Assert\NotBlank()     
     */
    private $lbCustomer;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_customer", type="string", length=100, nullable=true)    
     */
    private $cdCustomer;   
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_address", type="string", length=100, nullable=true)   
     */    
    private $lbAddress;
    
    /**
     * @var \Address
     *
     * @ORM\OneToMany(targetEntity="Address", mappedBy="idCustomer",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"blStatus" = "desc","lbAddress" = "asc"})         
     */
    private $idAddress;
    
   
    
    /**
     * @var \Contact
     *
     * @ORM\OneToMany(targetEntity="Contact", mappedBy="idCustomer",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"blDeactivated" = "desc","lbLastname" = "asc"})   
     */
    private $idContact;    
    
    /**
     * @var \Project
     *
     * @ORM\OneToMany(targetEntity="Project", mappedBy="idCustomer",cascade={"persist","remove"}, orphanRemoval=true ) 
     * @ORM\OrderBy({"descr" = "asc"})     
     */
    private $idProject;     

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_web", type="string", length=100, nullable=true)
     */
    private $lbWeb;

    /**
     * @var integer
     *
     * @ORM\Column(name="nb_contract_duration", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Contract duration can not be zero")  
     */
    private $nbContractDuration;

    /**
     * @var \NoticePeriod
     *
     * @ORM\ManyToOne(targetEntity="NoticePeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_notice_period", referencedColumnName="id_notice_period")
     * })
     * @Assert\NotNull();     
     */
    private $idNoticePeriod;

    /**
     * @var string
     *
     * @ORM\Column(name="comment", type="text", nullable=true)
     */
    private $comment;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    /**
     * @var \CustomerNature
     *
     * @ORM\ManyToOne(targetEntity="CustomerNature")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_customer_nature", referencedColumnName="id_customer_nature")
     * })
     * @Assert\NotNull()      
     */
    private $idCustomerNature;

    /**
     * @var \Currency
     *
     * @ORM\ManyToOne(targetEntity="Currency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_currency", referencedColumnName="id_currency")
     * })  
     */
    private $idCurrency;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_customer_manager", referencedColumnName="id")
     * })
     */
    private $idCustomerManager;

    /**
     * @var \FirmType
     *
     * @ORM\ManyToOne(targetEntity="FirmType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_firm_type", referencedColumnName="id_firm_type")
     * })   
     */
    private $idFirmType;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_account_manager", referencedColumnName="id")
     * })
     * @Assert\NotNull()  
     */
    private $idAccountManager;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \BillingFrequency
     *
     * @ORM\ManyToOne(targetEntity="BillingFrequency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_frequency", referencedColumnName="id_billing_frequency")
     * })
     */
    private $idBillingFrequency;

    
    /**
     * @var \Access
     * 
     * @ORM\ManyToOne(targetEntity="Access", inversedBy="idCustomer")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_access", referencedColumnName="id_access")
     * })         
     */
    private $idAccess;  

    /**
     * @var \Branch
     *
     * @ORM\ManyToOne(targetEntity="Branch",inversedBy="idCustomer")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_branch", referencedColumnName="id_branch")
     * })             
     * @Assert\NotNull()  
     */
    private $idBranch;
    
    /**
     * @var \Activity
     *
     * @ORM\ManyToOne(targetEntity="Activity")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_activity", referencedColumnName="id_activity")
     * })
     *
     */
    private $idActivity;   
    
    /**
     * @var \CustomerGroup
     *
     * @ORM\ManyToOne(targetEntity="CustomerGroup",inversedBy="idCustomer")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_customer_group", referencedColumnName="id_customer_group")
     * })
     *
     */
    private $idCustomerGroup;     

    public static function getModifierRoles()
    {
        return array("ROLE_SUPER_ADMINISTRATOR","ROLE_NETWORK_ENGINEER_ADMIN","ROLE_NETWORK_ENGINEER","ROLE_SALES_ADMINISTRATOR");
    }
    
    public static function getReaderRoles()
    {
        return array("ROLE_SUPER_ADMINISTRATOR","ROLE_ENTMC_INDIA", "ROLE_CSC_FRANCE", "ROLE_NETWORK_ACCOUNTING","ROLE_NETWORK_ADMINISTRATOR","ROLE_NETWORK_ENGINEER_ADMIN","ROLE_NETWORK_ENGINEER","ROLE_MARKETING_PRE_SALES","ROLE_SALES_ADMINISTRATOR");
    } 
    
    public function getCollections()
    {
        return array("Addresses"=>"Address","Contacts"=>"Contact","Projects"=>"Project");       
    }
    
    public function getTechnicalContacts()
    {
        $res=array();
        foreach ($this->getIdContact() as $contact)
        {
            if ($contact->getIdContactType()->getIdContactType()==3)
                $res[]=$contact;
        }
        return $res;
    }
    
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getCdCustomer()." : ".$this->getLbCustomer();
    }    
    
 
public function getParentBranch() { return NULL; }      /**
     * Constructor
     */
    public function __construct()
    {
        $this->idAddress = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idContact = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idProject = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idCustomer
     *
     * @return integer 
     */
    public function getIdCustomer()
    {
        return $this->idCustomer;
    }

    /**
     * Set cdMagellan
     *
     * @param string $cdMagellan
     * @return Customer
     */
    public function setCdMagellan($cdMagellan)
    {
        $this->cdMagellan = $cdMagellan;
    
        return $this;
    }

    /**
     * Get cdMagellan
     *
     * @return string 
     */
    public function getCdMagellan()
    {
        return $this->cdMagellan;
    }

    /**
     * Set lbCustomer
     *
     * @param string $lbCustomer
     * @return Customer
     */
    public function setLbCustomer($lbCustomer)
    {
        $this->lbCustomer = $lbCustomer;
    
        return $this;
    }

    /**
     * Get lbCustomer
     *
     * @return string 
     */
    public function getLbCustomer()
    {
        return $this->lbCustomer;
    }

    /**
     * Set cdCustomer
     *
     * @param string $cdCustomer
     * @return Customer
     */
    public function setCdCustomer($cdCustomer)
    {
        $this->cdCustomer = $cdCustomer;
    
        return $this;
    }

    /**
     * Get cdCustomer
     *
     * @return string 
     */
    public function getCdCustomer()
    {
        return $this->cdCustomer;
    }

    /**
     * Set lbAddress
     *
     * @param string $lbAddress
     * @return Customer
     */
    public function setLbAddress($lbAddress)
    {
        $this->lbAddress = $lbAddress;
    
        return $this;
    }

    /**
     * Get lbAddress
     *
     * @return string 
     */
    public function getLbAddress()
    {
        return $this->lbAddress;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Customer
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Customer
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Customer
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set lbWeb
     *
     * @param string $lbWeb
     * @return Customer
     */
    public function setLbWeb($lbWeb)
    {
        $this->lbWeb = $lbWeb;
    
        return $this;
    }

    /**
     * Get lbWeb
     *
     * @return string 
     */
    public function getLbWeb()
    {
        return $this->lbWeb;
    }

    /**
     * Set nbContractDuration
     *
     * @param integer $nbContractDuration
     * @return Customer
     */
    public function setNbContractDuration($nbContractDuration)
    {
        $this->nbContractDuration = $nbContractDuration;
    
        return $this;
    }

    /**
     * Get nbContractDuration
     *
     * @return integer 
     */
    public function getNbContractDuration()
    {
        return $this->nbContractDuration;
    }

    /**
     * Set comment
     *
     * @param string $comment
     * @return Customer
     */
    public function setComment($comment)
    {
        $this->comment = $comment;
    
        return $this;
    }

    /**
     * Get comment
     *
     * @return string 
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Customer
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Add idAddress
     *
     * @param \Etrali\GinangBundle\Entity\Address $idAddress
     * @return Customer
     */
    public function addIdAddres(\Etrali\GinangBundle\Entity\Address $idAddress)
    {
        $this->idAddress[] = $idAddress;
    
        return $this;
    }

    /**
     * Remove idAddress
     *
     * @param \Etrali\GinangBundle\Entity\Address $idAddress
     */
    public function removeIdAddres(\Etrali\GinangBundle\Entity\Address $idAddress)
    {
        $this->idAddress->removeElement($idAddress);
    }

    /**
     * Get idAddress
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdAddress()
    {
        return $this->idAddress;
    }

    /**
     * Add idContact
     *
     * @param \Etrali\GinangBundle\Entity\Contact $idContact
     * @return Customer
     */
    public function addIdContact(\Etrali\GinangBundle\Entity\Contact $idContact)
    {
        $this->idContact[] = $idContact;
    
        return $this;
    }

    /**
     * Remove idContact
     *
     * @param \Etrali\GinangBundle\Entity\Contact $idContact
     */
    public function removeIdContact(\Etrali\GinangBundle\Entity\Contact $idContact)
    {
        $this->idContact->removeElement($idContact);
    }

    /**
     * Get idContact
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }
    
    

    /**
     * Add idProject
     *
     * @param \Etrali\GinangBundle\Entity\Project $idProject
     * @return Customer
     */
    public function addIdProject(\Etrali\GinangBundle\Entity\Project $idProject)
    {
        $this->idProject[] = $idProject;
    
        return $this;
    }

    /**
     * Remove idProject
     *
     * @param \Etrali\GinangBundle\Entity\Project $idProject
     */
    public function removeIdProject(\Etrali\GinangBundle\Entity\Project $idProject)
    {
        $this->idProject->removeElement($idProject);
    }

    /**
     * Get idProject
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdProject()
    {
        return $this->idProject;
    }

    /**
     * Set idNoticePeriod
     *
     * @param \Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod
     * @return Customer
     */
    public function setIdNoticePeriod(\Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod = null)
    {
        $this->idNoticePeriod = $idNoticePeriod;
    
        return $this;
    }

    /**
     * Get idNoticePeriod
     *
     * @return \Etrali\GinangBundle\Entity\NoticePeriod 
     */
    public function getIdNoticePeriod()
    {
        return $this->idNoticePeriod;
    }

    /**
     * Set idCustomerNature
     *
     * @param \Etrali\GinangBundle\Entity\CustomerNature $idCustomerNature
     * @return Customer
     */
    public function setIdCustomerNature(\Etrali\GinangBundle\Entity\CustomerNature $idCustomerNature = null)
    {
        $this->idCustomerNature = $idCustomerNature;
    
        return $this;
    }

    /**
     * Get idCustomerNature
     *
     * @return \Etrali\GinangBundle\Entity\CustomerNature 
     */
    public function getIdCustomerNature()
    {
        return $this->idCustomerNature;
    }

    /**
     * Set idCurrency
     *
     * @param \Etrali\GinangBundle\Entity\Currency $idCurrency
     * @return Customer
     */
    public function setIdCurrency(\Etrali\GinangBundle\Entity\Currency $idCurrency = null)
    {
        $this->idCurrency = $idCurrency;
    
        return $this;
    }

    /**
     * Get idCurrency
     *
     * @return \Etrali\GinangBundle\Entity\Currency 
     */
    public function getIdCurrency()
    {
        return $this->idCurrency;
    }

    /**
     * Set idCustomerManager
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idCustomerManager
     * @return Customer
     */
    public function setIdCustomerManager(\Etrali\GinangBundle\Entity\Myuser $idCustomerManager = null)
    {
        $this->idCustomerManager = $idCustomerManager;
    
        return $this;
    }

    /**
     * Get idCustomerManager
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdCustomerManager()
    {
        return $this->idCustomerManager;
    }

    /**
     * Set idFirmType
     *
     * @param \Etrali\GinangBundle\Entity\FirmType $idFirmType
     * @return Customer
     */
    public function setIdFirmType(\Etrali\GinangBundle\Entity\FirmType $idFirmType = null)
    {
        $this->idFirmType = $idFirmType;
    
        return $this;
    }

    /**
     * Get idFirmType
     *
     * @return \Etrali\GinangBundle\Entity\FirmType 
     */
    public function getIdFirmType()
    {
        return $this->idFirmType;
    }

    /**
     * Set idAccountManager
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idAccountManager
     * @return Customer
     */
    public function setIdAccountManager(\Etrali\GinangBundle\Entity\Myuser $idAccountManager = null)
    {
        $this->idAccountManager = $idAccountManager;
    
        return $this;
    }

    /**
     * Get idAccountManager
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdAccountManager()
    {
        return $this->idAccountManager;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Customer
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Customer
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idBillingFrequency
     *
     * @param \Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency
     * @return Customer
     */
    public function setIdBillingFrequency(\Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency = null)
    {
        $this->idBillingFrequency = $idBillingFrequency;
    
        return $this;
    }

    /**
     * Get idBillingFrequency
     *
     * @return \Etrali\GinangBundle\Entity\BillingFrequency 
     */
    public function getIdBillingFrequency()
    {
        return $this->idBillingFrequency;
    }

    /**
     * Set idAccess
     *
     * @param \Etrali\GinangBundle\Entity\Access $idAccess
     * @return Customer
     */
    public function setIdAccess(\Etrali\GinangBundle\Entity\Access $idAccess = null)
    {
        $this->idAccess = $idAccess;
    
        return $this;
    }

    /**
     * Get idAccess
     *
     * @return \Etrali\GinangBundle\Entity\Access 
     */
    public function getIdAccess()
    {
        return $this->idAccess;
    }

    /**
     * Set idBranch
     *
     * @param \Etrali\GinangBundle\Entity\Branch $idBranch
     * @return Customer
     */
    public function setIdBranch(\Etrali\GinangBundle\Entity\Branch $idBranch = null)
    {
        $this->idBranch = $idBranch;
    
        return $this;
    }

    /**
     * Get idBranch
     *
     * @return \Etrali\GinangBundle\Entity\Branch 
     */
    public function getIdBranch()
    {
        return $this->idBranch;
    }

    /**
     * Set idActivity
     *
     * @param \Etrali\GinangBundle\Entity\Activity $idActivity
     * @return Customer
     */
    public function setIdActivity(\Etrali\GinangBundle\Entity\Activity $idActivity = null)
    {
        $this->idActivity = $idActivity;
    
        return $this;
    }

    /**
     * Get idActivity
     *
     * @return \Etrali\GinangBundle\Entity\Activity 
     */
    public function getIdActivity()
    {
        return $this->idActivity;
    }

    /**
     * Set idCustomerGroup
     *
     * @param \Etrali\GinangBundle\Entity\CustomerGroup $idCustomerGroup
     * @return Customer
     */
    public function setIdCustomerGroup(\Etrali\GinangBundle\Entity\CustomerGroup $idCustomerGroup = null)
    {
        $this->idCustomerGroup = $idCustomerGroup;
    
        return $this;
    }

    /**
     * Get idCustomerGroup
     *
     * @return \Etrali\GinangBundle\Entity\CustomerGroup 
     */
    public function getIdCustomerGroup()
    {
        return $this->idCustomerGroup;
    }
    
    /**
     * 
     * @return Address
     */    
    public function getAddressDelivery(){
        foreach($this->idAddress as $address){
            if($address && $address->getIdAddressType() && $address->getIdAddressType()->getLbAddressType()=="Delivery")
                return $address;
        }
        return null;
    }
}