<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Equipment
 *
 * @ORM\Table(name="equipment")
 * @ORM\Entity
 */
class Equipment
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_equipment", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idEquipment;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_equipment", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)    
     */
    private $cdEquipment;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_equipment", type="string", length=100, nullable=false)
     * @Assert\MaxLength(40)    
     */
    private $lbEquipment;

    
    /**
     * @var string
     *
     * @ORM\Column(name="url_image", type="string", length=100, nullable=true)
     */
    private $urlImage;

    
    /**
     * @var string
     *
     * @ORM\Column(name="cm_equipment", type="string", length=255, nullable=true)
     */
    private $cmEquipment;

    
        /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;
    

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;


    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

     /**
     * @var \Provider
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * }) 
     * @Assert\NotNull()       
     */
    private $idProvider;
    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()  	          
     */
    private $idProviderAddress;    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * }) 
     * @Assert\NotNull()     
     */
    private $idContact;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    /**
     * @var integer
     *
     * @ORM\Column(name="nb_units", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of units can not be zero")   
     */
    private $nbUnits;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_has_slot", type="boolean", nullable=true)
     */
    private $blHasSlot;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_slots", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of slots can not be zero")  
     */
    private $nbSlots;    
   
    /**
     * @var \Slot
     * 
     * @ORM\OneToMany(targetEntity="Slot", mappedBy="idEquipment",cascade={"persist","remove"}, orphanRemoval=true )    
     * @ORM\OrderBy({"nbNumber" = "ASC"})  
     */
    private $idSlot;    
    
    /**
     * @var \Card
     *
     * @ORM\OneToMany(targetEntity="Card", mappedBy="idEquipment",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"nbNumber" = "ASC"})  
     */
    private $idCard;      
    
    /**
     * @var \Cabinet
     *
     * @ORM\ManyToOne(targetEntity="Cabinet", inversedBy="idEquipment")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cabinet", referencedColumnName="id_cabinet")
     * })
     */
    private $idCabinet;   
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_card_horizontal", type="boolean", nullable=true)
     */
    private $blCardHorizontal;  
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nb_cards", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of cards can not be zero")       
     */
    private $nbCards;     
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_model", type="boolean", nullable=true)
     */
    private $blModel=true;      
    
    /**
     * @var \CostingEquipmentLine
     *
     * @ORM\OneToMany(targetEntity="CostingEquipmentLine", mappedBy="idEquipment",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idCostingEquipmentLine;   
       
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel", inversedBy="idEquipment")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     */
    private $idComplexModel;   

        public function getCollections()
    {
        return array("Costings"=>"CostingEquipmentLine");       
    }   

    /**
     * Clone function. Clones an entity and all necessary ManyToOne relations. 
     * Parent entities are not cloned but only children
     *
     * @return Equipment
     */    
    public function duplique() {
        if ($this->idEquipment) {
            $this->idEquipment=null;
            $ac = new ArrayCollection();              
            foreach ($this->idCostingEquipmentLine as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->setIdEquipment($this);  
                $ac->add($cloneElem);                       
            }
            $this->idCostingEquipmentLine=$ac;                       
            $ac = new ArrayCollection();   
            foreach ($this->idSlot as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);                
                $cloneElem->setIdEquipment($this); 
            }
            $this->idSlot=$ac;
            $ac = new ArrayCollection();   
            foreach ($this->idCard as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);                
                $cloneElem->setIdEquipment($this); 
            }            
            $this->idCard=$ac;
        }
    }    
    
    /**
     * Called just before saveObject that persists the object
     *
     * @param \Symfony\Component\Form\Form $form the valid form

     */
    public function postSave(\Symfony\Component\Form\Form $form, $em)
    {
        if ($this->getBlHasSlot() && $this->getNbSlots()>0)
        {
            $nbactu=$this->getIdSlot()->count();
            if ($nbactu<$this->getNbSlots())
            {
                $nbadd=$this->getNbSlots()-$nbactu;
                for ($i=0;$i<$nbadd;$i++)
                {
                    $slot=new Slot();
                    $slot->setCdSlot("Slot ".($this->getNbSlots()+$i));
                    $slot->setIdEquipment($this);
                    $slot->setNbNumber($this->getNbSlots()+$i);
                    $em->persist($slot);
                }
            }
            else
            {
                $nbremoved=$nbactu-$this->getNbSlots();
                foreach ($this->getIdSlot() as $slot)
                {
                    if ($slot->getIdCard()->count()==0)
                    {
                        $em->remove($slot);
                        $nbremoved--;
                        if ($nbremoved==0)
                            break;
                    }
                }
            }
        }
        else 
        {
            foreach ($this->getIdSlot() as $slot)
            {
                if ($slot->getIdCard()->count()==0)
                    $em->remove($slot);
            }
        }
        $em->flush();
    }
    
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbEquipment().'';
    }
    
    public function setIdSlot(\Doctrine\Common\Collections\ArrayCollection $ac)
    {
         $this->idSlot = $ac;
        return $this;         
    }
    
    public function setIdCard(\Doctrine\Common\Collections\ArrayCollection $ac)
    {
         $this->idCard = $ac;
        return $this;         
    }    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idSlot = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCard = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingEquipmentLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idEquipment
     *
     * @return integer 
     */
    public function getIdEquipment()
    {
        return $this->idEquipment;
    }

    /**
     * Set cdEquipment
     *
     * @param string $cdEquipment
     * @return Equipment
     */
    public function setCdEquipment($cdEquipment)
    {
        $this->cdEquipment = $cdEquipment;
    
        return $this;
    }

    /**
     * Get cdEquipment
     *
     * @return string 
     */
    public function getCdEquipment()
    {
        return $this->cdEquipment;
    }

    /**
     * Set lbEquipment
     *
     * @param string $lbEquipment
     * @return Equipment
     */
    public function setLbEquipment($lbEquipment)
    {
        $this->lbEquipment = $lbEquipment;
    
        return $this;
    }

    /**
     * Get lbEquipment
     *
     * @return string 
     */
    public function getLbEquipment()
    {
        return $this->lbEquipment;
    }

    /**
     * Set urlImage
     *
     * @param string $urlImage
     * @return Equipment
     */
    public function setUrlImage($urlImage)
    {
        $this->urlImage = $urlImage;
    
        return $this;
    }

    /**
     * Get urlImage
     *
     * @return string 
     */
    public function getUrlImage()
    {
        return $this->urlImage;
    }

    /**
     * Set cmEquipment
     *
     * @param string $cmEquipment
     * @return Equipment
     */
    public function setCmEquipment($cmEquipment)
    {
        $this->cmEquipment = $cmEquipment;
    
        return $this;
    }

    /**
     * Get cmEquipment
     *
     * @return string 
     */
    public function getCmEquipment()
    {
        return $this->cmEquipment;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Equipment
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Equipment
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Equipment
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Equipment
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set nbUnits
     *
     * @param integer $nbUnits
     * @return Equipment
     */
    public function setNbUnits($nbUnits)
    {
        $this->nbUnits = $nbUnits;
    
        return $this;
    }

    /**
     * Get nbUnits
     *
     * @return integer 
     */
    public function getNbUnits()
    {
        return $this->nbUnits;
    }

    /**
     * Set blHasSlot
     *
     * @param boolean $blHasSlot
     * @return Equipment
     */
    public function setBlHasSlot($blHasSlot)
    {
        $this->blHasSlot = $blHasSlot;
    
        return $this;
    }

    /**
     * Get blHasSlot
     *
     * @return boolean 
     */
    public function getBlHasSlot()
    {
        return $this->blHasSlot;
    }

    /**
     * Set nbSlots
     *
     * @param integer $nbSlots
     * @return Equipment
     */
    public function setNbSlots($nbSlots)
    {
        $this->nbSlots = $nbSlots;
    
        return $this;
    }

    /**
     * Get nbSlots
     *
     * @return integer 
     */
    public function getNbSlots()
    {
        return $this->nbSlots;
    }

    /**
     * Set blCardHorizontal
     *
     * @param boolean $blCardHorizontal
     * @return Equipment
     */
    public function setBlCardHorizontal($blCardHorizontal)
    {
        $this->blCardHorizontal = $blCardHorizontal;
    
        return $this;
    }

    /**
     * Get blCardHorizontal
     *
     * @return boolean 
     */
    public function getBlCardHorizontal()
    {
        return $this->blCardHorizontal;
    }

    /**
     * Set nbCards
     *
     * @param integer $nbCards
     * @return Equipment
     */
    public function setNbCards($nbCards)
    {
        $this->nbCards = $nbCards;
    
        return $this;
    }

    /**
     * Get nbCards
     *
     * @return integer 
     */
    public function getNbCards()
    {
        return $this->nbCards;
    }

    /**
     * Set blModel
     *
     * @param boolean $blModel
     * @return Equipment
     */
    public function setBlModel($blModel)
    {
        $this->blModel = $blModel;
    
        return $this;
    }

    /**
     * Get blModel
     *
     * @return boolean 
     */
    public function getBlModel()
    {
        return $this->blModel;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Equipment
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Equipment
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return Equipment
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return Equipment
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return Equipment
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Add idSlot
     *
     * @param \Etrali\GinangBundle\Entity\Slot $idSlot
     * @return Equipment
     */
    public function addIdSlot(\Etrali\GinangBundle\Entity\Slot $idSlot)
    {
        $this->idSlot[] = $idSlot;
    
        return $this;
    }

    /**
     * Remove idSlot
     *
     * @param \Etrali\GinangBundle\Entity\Slot $idSlot
     */
    public function removeIdSlot(\Etrali\GinangBundle\Entity\Slot $idSlot)
    {
        $this->idSlot->removeElement($idSlot);
    }

    /**
     * Get idSlot
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdSlot()
    {
        return $this->idSlot;
    }

    /**
     * Add idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     * @return Equipment
     */
    public function addIdCard(\Etrali\GinangBundle\Entity\Card $idCard)
    {
        $this->idCard[] = $idCard;
    
        return $this;
    }

    /**
     * Remove idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     */
    public function removeIdCard(\Etrali\GinangBundle\Entity\Card $idCard)
    {
        $this->idCard->removeElement($idCard);
    }

    /**
     * Get idCard
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCard()
    {
        return $this->idCard;
    }

    /**
     * Set idCabinet
     *
     * @param \Etrali\GinangBundle\Entity\Cabinet $idCabinet
     * @return Equipment
     */
    public function setIdCabinet(\Etrali\GinangBundle\Entity\Cabinet $idCabinet = null)
    {
        $this->idCabinet = $idCabinet;
    
        return $this;
    }

    /**
     * Get idCabinet
     *
     * @return \Etrali\GinangBundle\Entity\Cabinet 
     */
    public function getIdCabinet()
    {
        return $this->idCabinet;
    }

    /**
     * Add idCostingEquipmentLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine
     * @return Equipment
     */
    public function addIdCostingEquipmentLine(\Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine)
    {
        $this->idCostingEquipmentLine[] = $idCostingEquipmentLine;
    
        return $this;
    }

    /**
     * Remove idCostingEquipmentLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine
     */
    public function removeIdCostingEquipmentLine(\Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine)
    {
        $this->idCostingEquipmentLine->removeElement($idCostingEquipmentLine);
    }

    /**
     * Get idCostingEquipmentLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingEquipmentLine()
    {
        return $this->idCostingEquipmentLine;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return Equipment
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }public function getParentBranch() { return NULL; }  }