<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * EquipmentInstance
 *
 * @ORM\Table(name="equipment_instance")
 * @ORM\Entity
 */
class EquipmentInstance
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_equipment_instance", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idEquipmentInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_equipment_instance", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)    
     */
    private $cdEquipmentInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_equipment_instance", type="string", length=100, nullable=true)
     * @Assert\MaxLength(40)    
     */
    private $lbEquipmentInstance;

    
    
    /**
     * @var string
     *
     * @ORM\Column(name="cm_equipment_instance", type="string", length=255, nullable=true)
     */
    private $cmEquipmentInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_serial_number", type="string", length=15, nullable=true)
     * @Assert\MaxLength(30)  
     */
    private $cdSerialNumber;
    
        /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;
    

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;


    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;
   
    /**
     * @var \SlotInstance
     * 
     * @ORM\OneToMany(targetEntity="SlotInstance", mappedBy="idEquipmentInstance",cascade={"persist","remove"}, orphanRemoval=true )    
     * @ORM\OrderBy({"nbNumber" = "ASC"})  
     */
    private $idSlotInstance;    
    
    /**
     * @var \CardInstance
     *
     * @ORM\OneToMany(targetEntity="CardInstance", mappedBy="idEquipmentInstance",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"nbNumber" = "ASC"})  
     */
    private $idCardInstance;      
    
    /**
     * @var \CabinetInstance
     *
     * @ORM\ManyToOne(targetEntity="CabinetInstance", inversedBy="idEquipmentInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cabinet_instance", referencedColumnName="id_cabinet_instance")
     * })
     */
    private $idCabinetInstance;   
    
    /**
     * @var \Equipment
     *
     * @ORM\ManyToOne(targetEntity="Equipment")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_equipment", referencedColumnName="id_equipment")
     * })  
     */
    private $idEquipment;  
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     * @Assert\NotNull()     
     */
    private $idComplexModel;  
    
    /**
     * @var \CostingEquipmentLine
     *
     * @ORM\OneToMany(targetEntity="CostingEquipmentLine", mappedBy="idEquipmentInstance",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idCostingEquipmentLine;   

        /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProvider;

    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProviderAddress;

    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * })
     * @Assert\NotNull()
     */
    private $idContact;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     *
     * @Assert\MaxLength(20)
     */
    private $cdProviderAccount;  

    public function getCollections()
    {
        return array("Costings"=>"CostingEquipmentLine");       
    } 
    
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbEquipmentInstance().'';
    }

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idSlotInstance = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCardInstance = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingEquipmentLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idEquipmentInstance
     *
     * @return integer 
     */
    public function getIdEquipmentInstance()
    {
        return $this->idEquipmentInstance;
    }

    /**
     * Set cdEquipmentInstance
     *
     * @param string $cdEquipmentInstance
     * @return EquipmentInstance
     */
    public function setCdEquipmentInstance($cdEquipmentInstance)
    {
        $this->cdEquipmentInstance = $cdEquipmentInstance;
    
        return $this;
    }

    /**
     * Get cdEquipmentInstance
     *
     * @return string 
     */
    public function getCdEquipmentInstance()
    {
        return $this->cdEquipmentInstance;
    }

    /**
     * Set lbEquipmentInstance
     *
     * @param string $lbEquipmentInstance
     * @return EquipmentInstance
     */
    public function setLbEquipmentInstance($lbEquipmentInstance)
    {
        $this->lbEquipmentInstance = $lbEquipmentInstance;
    
        return $this;
    }

    /**
     * Get lbEquipmentInstance
     *
     * @return string 
     */
    public function getLbEquipmentInstance()
    {
        return $this->lbEquipmentInstance;
    }

    /**
     * Set cmEquipmentInstance
     *
     * @param string $cmEquipmentInstance
     * @return EquipmentInstance
     */
    public function setCmEquipmentInstance($cmEquipmentInstance)
    {
        $this->cmEquipmentInstance = $cmEquipmentInstance;
    
        return $this;
    }

    /**
     * Get cmEquipmentInstance
     *
     * @return string 
     */
    public function getCmEquipmentInstance()
    {
        return $this->cmEquipmentInstance;
    }

    /**
     * Set cdSerialNumber
     *
     * @param string $cdSerialNumber
     * @return EquipmentInstance
     */
    public function setCdSerialNumber($cdSerialNumber)
    {
        $this->cdSerialNumber = $cdSerialNumber;
    
        return $this;
    }

    /**
     * Get cdSerialNumber
     *
     * @return string 
     */
    public function getCdSerialNumber()
    {
        return $this->cdSerialNumber;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return EquipmentInstance
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return EquipmentInstance
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return EquipmentInstance
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return EquipmentInstance
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return EquipmentInstance
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return EquipmentInstance
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Add idSlotInstance
     *
     * @param \Etrali\GinangBundle\Entity\SlotInstance $idSlotInstance
     * @return EquipmentInstance
     */
    public function addIdSlotInstance(\Etrali\GinangBundle\Entity\SlotInstance $idSlotInstance)
    {
        $this->idSlotInstance[] = $idSlotInstance;
    
        return $this;
    }

    /**
     * Remove idSlotInstance
     *
     * @param \Etrali\GinangBundle\Entity\SlotInstance $idSlotInstance
     */
    public function removeIdSlotInstance(\Etrali\GinangBundle\Entity\SlotInstance $idSlotInstance)
    {
        $this->idSlotInstance->removeElement($idSlotInstance);
    }

    /**
     * Get idSlotInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdSlotInstance()
    {
        return $this->idSlotInstance;
    }

    /**
     * Add idCardInstance
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idCardInstance
     * @return EquipmentInstance
     */
    public function addIdCardInstance(\Etrali\GinangBundle\Entity\CardInstance $idCardInstance)
    {
        $this->idCardInstance[] = $idCardInstance;
    
        return $this;
    }

    /**
     * Remove idCardInstance
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idCardInstance
     */
    public function removeIdCardInstance(\Etrali\GinangBundle\Entity\CardInstance $idCardInstance)
    {
        $this->idCardInstance->removeElement($idCardInstance);
    }

    /**
     * Get idCardInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCardInstance()
    {
        return $this->idCardInstance;
    }

    /**
     * Set idCabinetInstance
     *
     * @param \Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance
     * @return EquipmentInstance
     */
    public function setIdCabinetInstance(\Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance = null)
    {
        $this->idCabinetInstance = $idCabinetInstance;
    
        return $this;
    }

    /**
     * Get idCabinetInstance
     *
     * @return \Etrali\GinangBundle\Entity\CabinetInstance 
     */
    public function getIdCabinetInstance()
    {
        return $this->idCabinetInstance;
    }

    /**
     * Set idEquipment
     *
     * @param \Etrali\GinangBundle\Entity\Equipment $idEquipment
     * @return EquipmentInstance
     */
    public function setIdEquipment(\Etrali\GinangBundle\Entity\Equipment $idEquipment = null)
    {
        $this->idEquipment = $idEquipment;
    
        return $this;
    }

    /**
     * Get idEquipment
     *
     * @return \Etrali\GinangBundle\Entity\Equipment 
     */
    public function getIdEquipment()
    {
        return $this->idEquipment;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return EquipmentInstance
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Add idCostingEquipmentLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine
     * @return EquipmentInstance
     */
    public function addIdCostingEquipmentLine(\Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine)
    {
        $this->idCostingEquipmentLine[] = $idCostingEquipmentLine;
    
        return $this;
    }

    /**
     * Remove idCostingEquipmentLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine
     */
    public function removeIdCostingEquipmentLine(\Etrali\GinangBundle\Entity\CostingEquipmentLine $idCostingEquipmentLine)
    {
        $this->idCostingEquipmentLine->removeElement($idCostingEquipmentLine);
    }

    /**
     * Get idCostingEquipmentLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingEquipmentLine()
    {
        return $this->idCostingEquipmentLine;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return EquipmentInstance
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return EquipmentInstance
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return EquipmentInstance
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return EquipmentInstance
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }public function getParentBranch() { return NULL; }  }