<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * LocalLoopOption
 *
 * @ORM\Table(name="local_loop_option")
 * @ORM\Entity
 */
class LocalLoopOption
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_local_loop_option", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idLocalLoopOption;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_option", type="string", nullable=true)
     * @Assert\NotBlank()
     */
    private $cdOption;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_option", type="string", nullable=true)
     */
    private $lbOption;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_quantity", type="integer", nullable=true)
     */
    private $nbQuantity;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=false)
     */
    private $blDeactivated=true;

    /**
     * @var \LocalLoop
     *
     * @ORM\ManyToOne(targetEntity="LocalLoop", inversedBy="idLocalLoopOption")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_local_loop", referencedColumnName="id_local_loop")
     * })
     */
    private $idLocalLoop;

    /**
     * @var \OptionType
     *
     * @ORM\ManyToOne(targetEntity="OptionType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_option_type", referencedColumnName="id_option_type")
     * })
     */
    private $idOptionType;
    
    /**
     * @var \CostingLocalLoopLine
     *
     * @ORM\OneToMany(targetEntity="CostingLocalLoopLine",mappedBy="idLocalLoopOption",cascade={"persist","remove"}, orphanRemoval=true )  
     */
    private $idCostingLocalLoopLine; 
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;     

    public function __toString()
    {
        return $this->getCdOption().":".$this->getLbOption();
    }
    
    

    public function getHeadInfo()
    {
            return "<td>".$this->getCdOption()."</td><td >".$this->getLbOption()."</td><td >".$this->getNbQuantity()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Ref</th><th>Description</th><th>Quantity</th>";
    }   

    /**
     * Get idLocalLoopOption
     *
     * @return integer 
     */
    public function getIdLocalLoopOption()
    {
        return $this->idLocalLoopOption;
    }

    /**
     * Set nbQuantity
     *
     * @param integer $nbQuantity
     * @return LocalLoopOption
     */
    public function setNbQuantity($nbQuantity)
    {
        $this->nbQuantity = $nbQuantity;
    
        return $this;
    }

    /**
     * Get nbQuantity
     *
     * @return integer 
     */
    public function getNbQuantity()
    {
        return $this->nbQuantity;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return LocalLoopOption
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return LocalLoopOption
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return LocalLoopOption
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set idLocalLoop
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoop $idLocalLoop
     * @return LocalLoopOption
     */
    public function setIdLocalLoop(\Etrali\GinangBundle\Entity\LocalLoop $idLocalLoop = null)
    {
        $this->idLocalLoop = $idLocalLoop;
    
        return $this;
    }

    /**
     * Get idLocalLoop
     *
     * @return \Etrali\GinangBundle\Entity\LocalLoop 
     */
    public function getIdLocalLoop()
    {
        return $this->idLocalLoop;
    }

    /**
     * Set idOptionType
     *
     * @param \Etrali\GinangBundle\Entity\OptionType $idOptionType
     * @return LocalLoopOption
     */
    public function setIdOptionType(\Etrali\GinangBundle\Entity\OptionType $idOptionType = null)
    {
        $this->idOptionType = $idOptionType;
    
        return $this;
    }

    /**
     * Get idOptionType
     *
     * @return \Etrali\GinangBundle\Entity\OptionType 
     */
    public function getIdOptionType()
    {
        return $this->idOptionType;
    }

    /**
     * Set cdOption
     *
     * @param string $cdOption
     * @return LocalLoopOption
     */
    public function setCdOption($cdOption)
    {
        $this->cdOption = $cdOption;
    
        return $this;
    }

    /**
     * Get cdOption
     *
     * @return string 
     */
    public function getCdOption()
    {
        return $this->cdOption;
    }

    /**
     * Set lbOption
     *
     * @param string $lbOption
     * @return LocalLoopOption
     */
    public function setLbOption($lbOption)
    {
        $this->lbOption = $lbOption;
    
        return $this;
    }

    /**
     * Get lbOption
     *
     * @return string 
     */
    public function getLbOption()
    {
        return $this->lbOption;
    }
        
    /**
     * 
     * @return Branch
     */
    public function getParentBranch() {
        if ($this->getIdLocalLoop()!=null)
            return $this->getIdLocalLoop()->getIdBranch();
        return NULL;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCostingLocalLoopLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Add idCostingLocalLoopLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingLocalLoopLine $idCostingLocalLoopLine
     * @return LocalLoopOption
     */
    public function addIdCostingLocalLoopLine(\Etrali\GinangBundle\Entity\CostingLocalLoopLine $idCostingLocalLoopLine)
    {
        $this->idCostingLocalLoopLine[] = $idCostingLocalLoopLine;
    
        return $this;
    }

    /**
     * Remove idCostingLocalLoopLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingLocalLoopLine $idCostingLocalLoopLine
     */
    public function removeIdCostingLocalLoopLine(\Etrali\GinangBundle\Entity\CostingLocalLoopLine $idCostingLocalLoopLine)
    {
        $this->idCostingLocalLoopLine->removeElement($idCostingLocalLoopLine);
    }

    /**
     * Get idCostingLocalLoopLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingLocalLoopLine()
    {
        return $this->idCostingLocalLoopLine;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return LocalLoopOption
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}