<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * OptionType
 *
 * @ORM\Table(name="option_type")
 * @ORM\Entity
 */
class OptionType
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_option_type", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idOptionType;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_option_type", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(10) 
     */
    private $cdOptionType;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_option_type", type="string", length=250, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(255)  
     */
    private $lbOptionType;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_create", type="datetime", nullable=false)
     * @Gedmo\Timestampable(on="create")
     * @Assert\DateTime()* 
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_billable", type="boolean", nullable=false)
     */
    private $blBillable;

    /**
     * @var \ApplicationType
     *
     * @ORM\ManyToOne(targetEntity="ApplicationType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_application_type", referencedColumnName="id_application_type")
     * })
     * @Assert\NotNull() 
     */
    private $idApplicationType;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;


    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbOptionType().'';
    }      

    /**
     * Get idOptionType
     *
     * @return integer 
     */
    public function getIdOptionType()
    {
        return $this->idOptionType;
    }

    

    /**
     * Set cdOptionType
     *
     * @param string $cdOptionType
     * @return OptionType
     */
    public function setCdOptionType($cdOptionType)
    {
        $this->cdOptionType = $cdOptionType;
    
        return $this;
    }

    /**
     * Get cdOptionType
     *
     * @return string 
     */
    public function getCdOptionType()
    {
        return $this->cdOptionType;
    }

    /**
     * Set lbOptionType
     *
     * @param string $lbOptionType
     * @return OptionType
     */
    public function setLbOptionType($lbOptionType)
    {
        $this->lbOptionType = $lbOptionType;
    
        return $this;
    }

    /**
     * Get lbOptionType
     *
     * @return string 
     */
    public function getLbOptionType()
    {
        return $this->lbOptionType;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return OptionType
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return OptionType
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return OptionType
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return OptionType
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set blBillable
     *
     * @param boolean $blBillable
     * @return OptionType
     */
    public function setBlBillable($blBillable)
    {
        $this->blBillable = $blBillable;
    
        return $this;
    }

    /**
     * Get blBillable
     *
     * @return boolean 
     */
    public function getBlBillable()
    {
        return $this->blBillable;
    }

    /**
     * Set idApplicationType
     *
     * @param \Etrali\GinangBundle\Entity\ApplicationType $idApplicationType
     * @return OptionType
     */
    public function setIdApplicationType(\Etrali\GinangBundle\Entity\ApplicationType $idApplicationType = null)
    {
        $this->idApplicationType = $idApplicationType;
    
        return $this;
    }

    /**
     * Get idApplicationType
     *
     * @return \Etrali\GinangBundle\Entity\ApplicationType 
     */
    public function getIdApplicationType()
    {
        return $this->idApplicationType;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return OptionType
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return OptionType
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }
public function getParentBranch() { return NULL; }  }