<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * PatchPanel
 *
 * @ORM\Table(name="patch_panel")
 * @ORM\Entity
 */
class PatchPanel
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_patch_panel", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idPatchPanel;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_patch_panel", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)     
     */
    private $cdPatchPanel;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_patch_panel", type="string", length=100, nullable=false)
     * @Assert\MaxLength(40)   
     */
    private $lbPatchPanel;

    
    /**
     * @var string
     *
     * @ORM\Column(name="url_image", type="string", length=100, nullable=true)
     */
    private $urlImage;

    
    /**
     * @var string
     *
     * @ORM\Column(name="cm_patch_panel", type="string", length=255, nullable=true)
     */
    private $cmPatchPanel;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_start", type="datetime", nullable=true)
     */
    private $dtStart;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end", type="datetime", nullable=true)
     */
    private $dtEnd;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

      /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * }) 
     * @Assert\NotNull()       
     */
    private $idProvider;
    
    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()  	          
     */
    private $idProviderAddress;    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * }) 
     * @Assert\NotNull()     
     */
    private $idContact;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;
 
    
    /**
     * @var \Cabinet
     *
     * @ORM\ManyToOne(targetEntity="Cabinet", inversedBy="idPatchPanel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cabinet", referencedColumnName="id_cabinet")
     * })
     */

    private $idCabinet;   
    
    /**
     * @var \Port
     *
     * @ORM\OneToMany(targetEntity="Port", mappedBy="idPatchPanel",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idPort;   
    
/**
     * @var integer
     *
     * @ORM\Column(name="nb_ports", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of ports can not be zero")  
     * @Assert\NotBlank()
     */
    private $nbPorts;  
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_rows", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of rows can not be zero")  
     * @Assert\NotBlank()
     */
    private $nbRows;              
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_model", type="boolean", nullable=true)
     */
    private $blModel=true;      
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_panel_for_ref", type="boolean", nullable=true)
     */
    private $blPanelForRef;    
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel", inversedBy="idPatchPanel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     */
    private $idComplexModel; 
    
    /**
     * @var \CostingPatchPanelLine
     *
     * @ORM\OneToMany(targetEntity="CostingPatchPanelLine", mappedBy="idPatchPanel",cascade={"persist","remove"}, orphanRemoval=true )

     */
    private $idCostingPatchPanelLine;   
        

    
    public function getCollections()
    {
        return array("Costings"=>"CostingPatchPanelLine");       
    }   
    
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbPatchPanel().'';
    }
    
    public function setIdPort(\Doctrine\Common\Collections\ArrayCollection $ac)
    {
         $this->idPort = $ac;
        return $this;         
    }
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idPort = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Clone function. Clones an entity and all necessary ManyToOne relations. 
     * Parent entities are not cloned but only children
     *
     * @return PatchPanel
     */    
    public function duplique() {
        if ($this->idPatchPanel) {
            $this->idPatchPanel=null;
            $ac = new ArrayCollection(); 
            foreach ($this->idCostingPatchPanelLine as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->setIdPatchPanel($this); 
                $ac->add($cloneElem);                              
            }
            $this->idCostingPatchPanelLine=$ac;
            $ac = new ArrayCollection();   
            foreach ($this->idPort as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);                
                $cloneElem->setIdPatchPanel($this); 
            }
            $this->idPort=$ac;
        }
    }


    /**
     * Get idPatchPanel
     *
     * @return integer 
     */
    public function getIdPatchPanel()
    {
        return $this->idPatchPanel;
    }

    /**
     * Set cdPatchPanel
     *
     * @param string $cdPatchPanel
     * @return PatchPanel
     */
    public function setCdPatchPanel($cdPatchPanel)
    {
        $this->cdPatchPanel = $cdPatchPanel;
    
        return $this;
    }

    /**
     * Get cdPatchPanel
     *
     * @return string 
     */
    public function getCdPatchPanel()
    {
        return $this->cdPatchPanel;
    }

    /**
     * Set lbPatchPanel
     *
     * @param string $lbPatchPanel
     * @return PatchPanel
     */
    public function setLbPatchPanel($lbPatchPanel)
    {
        $this->lbPatchPanel = $lbPatchPanel;
    
        return $this;
    }

    /**
     * Get lbPatchPanel
     *
     * @return string 
     */
    public function getLbPatchPanel()
    {
        return $this->lbPatchPanel;
    }

    /**
     * Set urlImage
     *
     * @param string $urlImage
     * @return PatchPanel
     */
    public function setUrlImage($urlImage)
    {
        $this->urlImage = $urlImage;
    
        return $this;
    }

    /**
     * Get urlImage
     *
     * @return string 
     */
    public function getUrlImage()
    {
        return $this->urlImage;
    }

    /**
     * Set cmPatchPanel
     *
     * @param string $cmPatchPanel
     * @return PatchPanel
     */
    public function setCmPatchPanel($cmPatchPanel)
    {
        $this->cmPatchPanel = $cmPatchPanel;
    
        return $this;
    }

    /**
     * Get cmPatchPanel
     *
     * @return string 
     */
    public function getCmPatchPanel()
    {
        return $this->cmPatchPanel;
    }

    /**
     * Set dtStart
     *
     * @param \DateTime $dtStart
     * @return PatchPanel
     */
    public function setDtStart($dtStart)
    {
        $this->dtStart = $dtStart;
    
        return $this;
    }

    /**
     * Get dtStart
     *
     * @return \DateTime 
     */
    public function getDtStart()
    {
        return $this->dtStart;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return PatchPanel
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return PatchPanel
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return PatchPanel
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set nbPorts
     *
     * @param integer $nbPorts
     * @return PatchPanel
     */
    public function setNbPorts($nbPorts)
    {
        $this->nbPorts = $nbPorts;
    
        return $this;
    }

    /**
     * Get nbPorts
     *
     * @return integer 
     */
    public function getNbPorts()
    {
        return $this->nbPorts;
    }

    /**
     * Set nbRows
     *
     * @param integer $nbRows
     * @return PatchPanel
     */
    public function setNbRows($nbRows)
    {
        $this->nbRows = $nbRows;
    
        return $this;
    }

    /**
     * Get nbRows
     *
     * @return integer 
     */
    public function getNbRows()
    {
        return $this->nbRows;
    }

    /**
     * Set blModel
     *
     * @param boolean $blModel
     * @return PatchPanel
     */
    public function setBlModel($blModel)
    {
        $this->blModel = $blModel;
    
        return $this;
    }

    /**
     * Get blModel
     *
     * @return boolean 
     */
    public function getBlModel()
    {
        return $this->blModel;
    }

    /**
     * Set blPanelForRef
     *
     * @param boolean $blPanelForRef
     * @return PatchPanel
     */
    public function setBlPanelForRef($blPanelForRef)
    {
        $this->blPanelForRef = $blPanelForRef;
    
        return $this;
    }

    /**
     * Get blPanelForRef
     *
     * @return boolean 
     */
    public function getBlPanelForRef()
    {
        return $this->blPanelForRef;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return PatchPanel
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return PatchPanel
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return PatchPanel
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return PatchPanel
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return PatchPanel
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Set idCabinet
     *
     * @param \Etrali\GinangBundle\Entity\Cabinet $idCabinet
     * @return PatchPanel
     */
    public function setIdCabinet(\Etrali\GinangBundle\Entity\Cabinet $idCabinet = null)
    {
        $this->idCabinet = $idCabinet;
    
        return $this;
    }

    /**
     * Get idCabinet
     *
     * @return \Etrali\GinangBundle\Entity\Cabinet 
     */
    public function getIdCabinet()
    {
        return $this->idCabinet;
    }

    /**
     * Add idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     * @return PatchPanel
     */
    public function addIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort[] = $idPort;
    
        return $this;
    }

    /**
     * Remove idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     */
    public function removeIdPort(\Etrali\GinangBundle\Entity\Port $idPort)
    {
        $this->idPort->removeElement($idPort);
    }

    /**
     * Get idPort
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPort()
    {
        return $this->idPort;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return PatchPanel
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Add idCostingPatchPanelLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine
     * @return PatchPanel
     */
    public function addIdCostingPatchPanelLine(\Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine)
    {
        $this->idCostingPatchPanelLine[] = $idCostingPatchPanelLine;
    
        return $this;
    }

    /**
     * Remove idCostingPatchPanelLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine
     */
    public function removeIdCostingPatchPanelLine(\Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine)
    {
        $this->idCostingPatchPanelLine->removeElement($idCostingPatchPanelLine);
    }

    /**
     * Get idCostingPatchPanelLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingPatchPanelLine()
    {
        return $this->idCostingPatchPanelLine;
    }public function getParentBranch() { return NULL; }  }