<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * PatchPanelInstance
 *
 * @ORM\Table(name="patch_panel_instance")
 * @ORM\Entity
 */
class PatchPanelInstance
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_patch_panel_instance", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idPatchPanelInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_patch_panel_instance", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)     
     */
    private $cdPatchPanelInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_patch_panel_instance", type="string", length=100, nullable=true)
     * @Assert\MaxLength(40)   
     */
    private $lbPatchPanelInstance;

        
    /**
     * @var string
     *
     * @ORM\Column(name="cm_patch_panel_instance", type="string", length=255, nullable=true)
     */
    private $cmPatchPanelInstance;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;
     
    /**
     * @var \CabinetInstance
     *
     * @ORM\ManyToOne(targetEntity="CabinetInstance", inversedBy="idPatchPanelInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cabinet_instance", referencedColumnName="id_cabinet_instance")
     * })
     */

    private $idCabinetInstance;   
    
    /**
     * @var \PatchPanel
     *
     * @ORM\ManyToOne(targetEntity="PatchPanel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_patch_panel", referencedColumnName="id_patch_panel")
     * }) 
     */
    private $idPatchPanel;  
    
    /**
     * @var \PortInstance
     *
     * @ORM\OneToMany(targetEntity="PortInstance", mappedBy="idPatchPanelInstance",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idPortInstance;  
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     * @Assert\NotNull()     
     */
    private $idComplexModel;  
    
    /**
     * @var \CostingPatchPanelLine
     *
     * @ORM\OneToMany(targetEntity="CostingPatchPanelLine", mappedBy="idPatchPanelInstance",cascade={"persist","remove"}, orphanRemoval=true )

     */
    private $idCostingPatchPanelLine;   
    

            /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProvider;

    /**
     * @var \AddressProvider
     *
     * @ORM\ManyToOne(targetEntity="AddressProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider_address", referencedColumnName="id_address_provider")
     * })
     * @Assert\NotNull()
     */
    private $idProviderAddress;

    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * })
     * @Assert\NotNull()
     */
    private $idContact;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     *
     * @Assert\MaxLength(20)
     */
    private $cdProviderAccount;  
    
    
    public function getCollections()
    {
        return array("Costings"=>"CostingPatchPanelLine");       
    } 
    
    
    public function __toString()
    {
        return $this->getLbPatchPanelInstance()."";
    }


    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idPortInstance = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingPatchPanelLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idPatchPanelInstance
     *
     * @return integer 
     */
    public function getIdPatchPanelInstance()
    {
        return $this->idPatchPanelInstance;
    }

    /**
     * Set cdPatchPanelInstance
     *
     * @param string $cdPatchPanelInstance
     * @return PatchPanelInstance
     */
    public function setCdPatchPanelInstance($cdPatchPanelInstance)
    {
        $this->cdPatchPanelInstance = $cdPatchPanelInstance;
    
        return $this;
    }

    /**
     * Get cdPatchPanelInstance
     *
     * @return string 
     */
    public function getCdPatchPanelInstance()
    {
        return $this->cdPatchPanelInstance;
    }

    /**
     * Set lbPatchPanelInstance
     *
     * @param string $lbPatchPanelInstance
     * @return PatchPanelInstance
     */
    public function setLbPatchPanelInstance($lbPatchPanelInstance)
    {
        $this->lbPatchPanelInstance = $lbPatchPanelInstance;
    
        return $this;
    }

    /**
     * Get lbPatchPanelInstance
     *
     * @return string 
     */
    public function getLbPatchPanelInstance()
    {
        return $this->lbPatchPanelInstance;
    }

    /**
     * Set cmPatchPanelInstance
     *
     * @param string $cmPatchPanelInstance
     * @return PatchPanelInstance
     */
    public function setCmPatchPanelInstance($cmPatchPanelInstance)
    {
        $this->cmPatchPanelInstance = $cmPatchPanelInstance;
    
        return $this;
    }

    /**
     * Get cmPatchPanelInstance
     *
     * @return string 
     */
    public function getCmPatchPanelInstance()
    {
        return $this->cmPatchPanelInstance;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return PatchPanelInstance
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return PatchPanelInstance
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return PatchPanelInstance
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return PatchPanelInstance
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idCabinetInstance
     *
     * @param \Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance
     * @return PatchPanelInstance
     */
    public function setIdCabinetInstance(\Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance = null)
    {
        $this->idCabinetInstance = $idCabinetInstance;
    
        return $this;
    }

    /**
     * Get idCabinetInstance
     *
     * @return \Etrali\GinangBundle\Entity\CabinetInstance 
     */
    public function getIdCabinetInstance()
    {
        return $this->idCabinetInstance;
    }

    /**
     * Set idPatchPanel
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel
     * @return PatchPanelInstance
     */
    public function setIdPatchPanel(\Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel = null)
    {
        $this->idPatchPanel = $idPatchPanel;
    
        return $this;
    }

    /**
     * Get idPatchPanel
     *
     * @return \Etrali\GinangBundle\Entity\PatchPanel 
     */
    public function getIdPatchPanel()
    {
        return $this->idPatchPanel;
    }

    /**
     * Add idPortInstance
     *
     * @param \Etrali\GinangBundle\Entity\PortInstance $idPortInstance
     * @return PatchPanelInstance
     */
    public function addIdPortInstance(\Etrali\GinangBundle\Entity\PortInstance $idPortInstance)
    {
        $this->idPortInstance[] = $idPortInstance;
    
        return $this;
    }

    /**
     * Remove idPortInstance
     *
     * @param \Etrali\GinangBundle\Entity\PortInstance $idPortInstance
     */
    public function removeIdPortInstance(\Etrali\GinangBundle\Entity\PortInstance $idPortInstance)
    {
        $this->idPortInstance->removeElement($idPortInstance);
    }

    /**
     * Get idPortInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdPortInstance()
    {
        return $this->idPortInstance;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return PatchPanelInstance
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Add idCostingPatchPanelLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine
     * @return PatchPanelInstance
     */
    public function addIdCostingPatchPanelLine(\Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine)
    {
        $this->idCostingPatchPanelLine[] = $idCostingPatchPanelLine;
    
        return $this;
    }

    /**
     * Remove idCostingPatchPanelLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine
     */
    public function removeIdCostingPatchPanelLine(\Etrali\GinangBundle\Entity\CostingPatchPanelLine $idCostingPatchPanelLine)
    {
        $this->idCostingPatchPanelLine->removeElement($idCostingPatchPanelLine);
    }

    /**
     * Get idCostingPatchPanelLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingPatchPanelLine()
    {
        return $this->idCostingPatchPanelLine;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return PatchPanelInstance
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return PatchPanelInstance
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idProviderAddress
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress
     * @return PatchPanelInstance
     */
    public function setIdProviderAddress(\Etrali\GinangBundle\Entity\AddressProvider $idProviderAddress = null)
    {
        $this->idProviderAddress = $idProviderAddress;
    
        return $this;
    }

    /**
     * Get idProviderAddress
     *
     * @return \Etrali\GinangBundle\Entity\AddressProvider 
     */
    public function getIdProviderAddress()
    {
        return $this->idProviderAddress;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return PatchPanelInstance
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }public function getParentBranch() { return NULL; }  }