<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Pop
 *
 * @ORM\Table(name="pop")
 * @ORM\Entity
 */
class Pop
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_pop", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idPop;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_pop", type="string", length=15, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(40)       
     */
    private $cdPop;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_pop", type="string", length=100, nullable=true)
     * @Assert\MaxLength(60)       
     */
    private $lbPop;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    
        /**
     * @var \Provider
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_housing_provider", referencedColumnName="id_provider")
     * })
     */
    private $idHousingProvider;
    
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_contact", referencedColumnName="id_contact_provider")
     * })     
     */
    private $idContact;

    
    /**
     * @var string
     *
     * @ORM\Column(name="cm_pop", type="string", length=255, nullable=true)
     */
    private $cmPop;         



    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;    

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \Branch
     *
     * @ORM\ManyToOne(targetEntity="Branch")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_branch", referencedColumnName="id_branch")
     * })
     * @Assert\NotNull()
     *  
     */
    private $idBranch;
    
    /**
     * @var \PopType
     *
     * @ORM\ManyToOne(targetEntity="PopType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_pop_type", referencedColumnName="id_pop_type")
     * })
     * @Assert\NotNull()
     *  
     */
    private $idPopType;    


    /**
     * @var \Access
     * 
     * @ORM\ManyToOne(targetEntity="Access", inversedBy="idPop")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_access", referencedColumnName="id_access")
     * })    
     */
    private $idAccess;

    
    /**
     * @var \CabinetInstance
     *
     * @ORM\OneToMany(targetEntity="CabinetInstance", mappedBy="idPop",cascade={"persist","remove"}, orphanRemoval=true )
     */
    private $idCabinetInstance;  
    
    
    /**
     * @var \AddressPop
     *
     * @ORM\OneToMany(targetEntity="AddressPop", mappedBy="idPop",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idAddressPop" = "asc"})         
     */
    private $idAddressPop;
    

        /**
     * @var \ContactPop
     *
     * @ORM\OneToMany(targetEntity="ContactPop", mappedBy="idPop",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idContactPop" = "asc"})         
     */
    private $idContactPop;
    
        /**
     * @var \CostingPop
     *
     * @ORM\OneToMany(targetEntity="CostingPop", mappedBy="idPop",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idCostingPop" = "asc"})         
     */
    private $idCostingPop;    
     
    
    
    public function getCollections()
    {
        return array("Providers"=>"CostingPop","Contacts"=>"ContactPop","Addresses"=>"AddressPop");       
    }       
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getCdPop()." > ".$this->getLbPop();
    }
    
    public function getTechnicalContacts()
    {
        $res=array();
        foreach ($this->getIdContactPop() as $contact)
        {
             if ($contact->getIdContactType()->getIdContactType()==3)
                 $res[]=$contact;
        }
        return $res;
    }
    
    public function getAdminContacts()
    {
        $res=array();
        foreach ($this->getIdContactPop() as $contact)
        {
             if ($contact->getIdContactType()->getIdContactType()==2)
                 $res[]=$contact;
        }
        return $res;
    }    
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCabinetInstance = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idAddressPop = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idContactPop = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idCostingPop = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idPop
     *
     * @return integer 
     */
    public function getIdPop()
    {
        return $this->idPop;
    }

    /**
     * Set cdPop
     *
     * @param string $cdPop
     * @return Pop
     */
    public function setCdPop($cdPop)
    {
        $this->cdPop = $cdPop;
    
        return $this;
    }

    /**
     * Get cdPop
     *
     * @return string 
     */
    public function getCdPop()
    {
        return $this->cdPop;
    }

    /**
     * Set lbPop
     *
     * @param string $lbPop
     * @return Pop
     */
    public function setLbPop($lbPop)
    {
        $this->lbPop = $lbPop;
    
        return $this;
    }

    /**
     * Get lbPop
     *
     * @return string 
     */
    public function getLbPop()
    {
        return $this->lbPop;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Pop
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set cmPop
     *
     * @param string $cmPop
     * @return Pop
     */
    public function setCmPop($cmPop)
    {
        $this->cmPop = $cmPop;
    
        return $this;
    }

    /**
     * Get cmPop
     *
     * @return string 
     */
    public function getCmPop()
    {
        return $this->cmPop;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Pop
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Pop
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Pop
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set idHousingProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idHousingProvider
     * @return Pop
     */
    public function setIdHousingProvider(\Etrali\GinangBundle\Entity\Provider $idHousingProvider = null)
    {
        $this->idHousingProvider = $idHousingProvider;
    
        return $this;
    }

    /**
     * Get idHousingProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdHousingProvider()
    {
        return $this->idHousingProvider;
    }

    /**
     * Set idContact
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContact
     * @return Pop
     */
    public function setIdContact(\Etrali\GinangBundle\Entity\ContactProvider $idContact = null)
    {
        $this->idContact = $idContact;
    
        return $this;
    }

    /**
     * Get idContact
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdContact()
    {
        return $this->idContact;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Pop
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Pop
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idBranch
     *
     * @param \Etrali\GinangBundle\Entity\Branch $idBranch
     * @return Pop
     */
    public function setIdBranch(\Etrali\GinangBundle\Entity\Branch $idBranch = null)
    {
        $this->idBranch = $idBranch;
    
        return $this;
    }

    /**
     * Get idBranch
     *
     * @return \Etrali\GinangBundle\Entity\Branch 
     */
    public function getIdBranch()
    {
        return $this->idBranch;
    }

    /**
     * Set idPopType
     *
     * @param \Etrali\GinangBundle\Entity\PopType $idPopType
     * @return Pop
     */
    public function setIdPopType(\Etrali\GinangBundle\Entity\PopType $idPopType = null)
    {
        $this->idPopType = $idPopType;
    
        return $this;
    }

    /**
     * Get idPopType
     *
     * @return \Etrali\GinangBundle\Entity\PopType 
     */
    public function getIdPopType()
    {
        return $this->idPopType;
    }

    /**
     * Set idAccess
     *
     * @param \Etrali\GinangBundle\Entity\Access $idAccess
     * @return Pop
     */
    public function setIdAccess(\Etrali\GinangBundle\Entity\Access $idAccess = null)
    {
        $this->idAccess = $idAccess;
    
        return $this;
    }

    /**
     * Get idAccess
     *
     * @return \Etrali\GinangBundle\Entity\Access 
     */
    public function getIdAccess()
    {
        return $this->idAccess;
    }

    /**
     * Add idCabinetInstance
     *
     * @param \Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance
     * @return Pop
     */
    public function addIdCabinetInstance(\Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance)
    {
        $this->idCabinetInstance[] = $idCabinetInstance;
    
        return $this;
    }

    /**
     * Remove idCabinetInstance
     *
     * @param \Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance
     */
    public function removeIdCabinetInstance(\Etrali\GinangBundle\Entity\CabinetInstance $idCabinetInstance)
    {
        $this->idCabinetInstance->removeElement($idCabinetInstance);
    }

    /**
     * Get idCabinetInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCabinetInstance()
    {
        return $this->idCabinetInstance;
    }

    /**
     * Add idAddressPop
     *
     * @param \Etrali\GinangBundle\Entity\AddressPop $idAddressPop
     * @return Pop
     */
    public function addIdAddressPop(\Etrali\GinangBundle\Entity\AddressPop $idAddressPop)
    {
        $this->idAddressPop[] = $idAddressPop;
    
        return $this;
    }

    /**
     * Remove idAddressPop
     *
     * @param \Etrali\GinangBundle\Entity\AddressPop $idAddressPop
     */
    public function removeIdAddressPop(\Etrali\GinangBundle\Entity\AddressPop $idAddressPop)
    {
        $this->idAddressPop->removeElement($idAddressPop);
    }

    /**
     * Get idAddressPop
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdAddressPop()
    {
        return $this->idAddressPop;
    }

    /**
     * Add idContactPop
     *
     * @param \Etrali\GinangBundle\Entity\ContactPop $idContactPop
     * @return Pop
     */
    public function addIdContactPop(\Etrali\GinangBundle\Entity\ContactPop $idContactPop)
    {
        $this->idContactPop[] = $idContactPop;
    
        return $this;
    }

    /**
     * Remove idContactPop
     *
     * @param \Etrali\GinangBundle\Entity\ContactPop $idContactPop
     */
    public function removeIdContactPop(\Etrali\GinangBundle\Entity\ContactPop $idContactPop)
    {
        $this->idContactPop->removeElement($idContactPop);
    }

    /**
     * Get idContactPop
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdContactPop()
    {
        return $this->idContactPop;
    }

    /**
     * Add idCostingPop
     *
     * @param \Etrali\GinangBundle\Entity\CostingPop $idCostingPop
     * @return Pop
     */
    public function addIdCostingPop(\Etrali\GinangBundle\Entity\CostingPop $idCostingPop)
    {
        $this->idCostingPop[] = $idCostingPop;
    
        return $this;
    }

    /**
     * Remove idCostingPop
     *
     * @param \Etrali\GinangBundle\Entity\CostingPop $idCostingPop
     */
    public function removeIdCostingPop(\Etrali\GinangBundle\Entity\CostingPop $idCostingPop)
    {
        $this->idCostingPop->removeElement($idCostingPop);
    }

    /**
     * Get idCostingPop
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingPop()
    {
        return $this->idCostingPop;
    }
public function getParentBranch() { return NULL; }  }