<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Port
 *
 * @ORM\Table(name="port")
 * @ORM\Entity
 */
class Port
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_port", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idPort;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_port", type="string", length=50, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)   
     */
    private $cdPort;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_port", type="string", length=100, nullable=false)
     * @Assert\MaxLength(40)  
     */
    private $lbPort;
      

    /**
     * @var string
     *
     * @ORM\Column(name="cm_port", type="string", length=255, nullable=true)
     */
    private $cmPort;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_full", type="boolean", nullable=true)
     */
    private $blFull;

    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_link_ha", type="boolean", nullable=true)
     */
    private $blLinkHa;    


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \PortType
     *
     * @ORM\ManyToOne(targetEntity="PortType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_port_type", referencedColumnName="id_port_type")
     * })
     * @Assert\NotNull() 
     */
    private $idPortType;
    
    /**
     * @var \PortSubType
     *
     * @ORM\ManyToOne(targetEntity="PortSubType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_port_sub_type", referencedColumnName="id_port_sub_type")
     * })
     * @Assert\NotNull()      
     */
    private $idPortSubType;  
    
    /**
     * @var \SfpModuleType
     *
     * @ORM\ManyToOne(targetEntity="SfpModuleType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_sfp_module_type", referencedColumnName="id_sfp_module_type")
     * })
     */
    private $idSfpModuleType;     

    /**
     * @var integer
     *
     * @ORM\Column(name="nb_timeslots", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of timeslots can not be zero")   
     */
    private $nbTimeslots;  
    
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_channels", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of channels can not be zero")       
     */
    private $nbChannels;  
    
    /**
     * @var \PatchPanel
     *
     * @ORM\ManyToOne(targetEntity="PatchPanel", inversedBy="idPort")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_patch_panel", referencedColumnName="id_patch_panel")
     * })
     */
    private $idPatchPanel;    
    
    /**
     * @var \Card
     *
     * @ORM\ManyToOne(targetEntity="Card", inversedBy="idPort")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_card", referencedColumnName="id_card")
     * })
     */
    private $idCard;   
     
    
  
    
         /**
     * @var integer
     *
     * @ORM\Column(name="nb_number", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Port number can not be zero")    
     */
    private $nbNumber;

    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel", inversedBy="idPort")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     */
    private $idComplexModel;  
    
     /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 
    
    
        /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getLbPort().'';
    }
    
    /**
     * Clone function. Clones an entity and all necessary ManyToOne relations. 
     * Parent entities are not cloned but only children
     *
     * @return Port
     */    
    public function duplique() {
        if ($this->idPort) {
            $this->idPort=null;
        }
    }

  public function getParentBranch() { return NULL; } 
  
  

    
    /**
     * Get idPort
     *
     * @return integer 
     */
    public function getIdPort()
    {
        return $this->idPort;
    }

    /**
     * Set cdPort
     *
     * @param string $cdPort
     * @return Port
     */
    public function setCdPort($cdPort)
    {
        $this->cdPort = $cdPort;
    
        return $this;
    }

    /**
     * Get cdPort
     *
     * @return string 
     */
    public function getCdPort()
    {
        return $this->cdPort;
    }

    /**
     * Set lbPort
     *
     * @param string $lbPort
     * @return Port
     */
    public function setLbPort($lbPort)
    {
        $this->lbPort = $lbPort;
    
        return $this;
    }

    /**
     * Get lbPort
     *
     * @return string 
     */
    public function getLbPort()
    {
        return $this->lbPort;
    }


    /**
     * Set cmPort
     *
     * @param string $cmPort
     * @return Port
     */
    public function setCmPort($cmPort)
    {
        $this->cmPort = $cmPort;
    
        return $this;
    }

    /**
     * Get cmPort
     *
     * @return string 
     */
    public function getCmPort()
    {
        return $this->cmPort;
    }

    /**
     * Set blFull
     *
     * @param boolean $blFull
     * @return Port
     */
    public function setBlFull($blFull)
    {
        $this->blFull = $blFull;
    
        return $this;
    }

    /**
     * Get blFull
     *
     * @return boolean 
     */
    public function getBlFull()
    {
        return $this->blFull;
    }

    /**
     * Set blLinkHa
     *
     * @param boolean $blLinkHa
     * @return Port
     */
    public function setBlLinkHa($blLinkHa)
    {
        $this->blLinkHa = $blLinkHa;
    
        return $this;
    }

    /**
     * Get blLinkHa
     *
     * @return boolean 
     */
    public function getBlLinkHa()
    {
        return $this->blLinkHa;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Port
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Port
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Port
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set nbTimeslots
     *
     * @param integer $nbTimeslots
     * @return Port
     */
    public function setNbTimeslots($nbTimeslots)
    {
        $this->nbTimeslots = $nbTimeslots;
    
        return $this;
    }

    /**
     * Get nbTimeslots
     *
     * @return integer 
     */
    public function getNbTimeslots()
    {
        return $this->nbTimeslots;
    }

    /**
     * Set nbChannels
     *
     * @param integer $nbChannels
     * @return Port
     */
    public function setNbChannels($nbChannels)
    {
        $this->nbChannels = $nbChannels;
    
        return $this;
    }

    /**
     * Get nbChannels
     *
     * @return integer 
     */
    public function getNbChannels()
    {
        return $this->nbChannels;
    }

    /**
     * Set nbNumber
     *
     * @param integer $nbNumber
     * @return Port
     */
    public function setNbNumber($nbNumber)
    {
        $this->nbNumber = $nbNumber;
    
        return $this;
    }

    /**
     * Get nbNumber
     *
     * @return integer 
     */
    public function getNbNumber()
    {
        return $this->nbNumber;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Port
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Port
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idPortType
     *
     * @param \Etrali\GinangBundle\Entity\PortType $idPortType
     * @return Port
     */
    public function setIdPortType(\Etrali\GinangBundle\Entity\PortType $idPortType = null)
    {
        $this->idPortType = $idPortType;
    
        return $this;
    }

    /**
     * Get idPortType
     *
     * @return \Etrali\GinangBundle\Entity\PortType 
     */
    public function getIdPortType()
    {
        return $this->idPortType;
    }

    /**
     * Set idPortSubType
     *
     * @param \Etrali\GinangBundle\Entity\PortSubType $idPortSubType
     * @return Port
     */
    public function setIdPortSubType(\Etrali\GinangBundle\Entity\PortSubType $idPortSubType = null)
    {
        $this->idPortSubType = $idPortSubType;
    
        return $this;
    }

    /**
     * Get idPortSubType
     *
     * @return \Etrali\GinangBundle\Entity\PortSubType 
     */
    public function getIdPortSubType()
    {
        return $this->idPortSubType;
    }

    /**
     * Set idSfpModuleType
     *
     * @param \Etrali\GinangBundle\Entity\SfpModuleType $idSfpModuleType
     * @return Port
     */
    public function setIdSfpModuleType(\Etrali\GinangBundle\Entity\SfpModuleType $idSfpModuleType = null)
    {
        $this->idSfpModuleType = $idSfpModuleType;
    
        return $this;
    }

    /**
     * Get idSfpModuleType
     *
     * @return \Etrali\GinangBundle\Entity\SfpModuleType 
     */
    public function getIdSfpModuleType()
    {
        return $this->idSfpModuleType;
    }

  
    /**
     * Set idPatchPanel
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel
     * @return Port
     */
    public function setIdPatchPanel(\Etrali\GinangBundle\Entity\PatchPanel $idPatchPanel = null)
    {
        $this->idPatchPanel = $idPatchPanel;
    
        return $this;
    }

    /**
     * Get idPatchPanel
     *
     * @return \Etrali\GinangBundle\Entity\PatchPanel 
     */
    public function getIdPatchPanel()
    {
        return $this->idPatchPanel;
    }

    /**
     * Set idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     * @return Port
     */
    public function setIdCard(\Etrali\GinangBundle\Entity\Card $idCard = null)
    {
        $this->idCard = $idCard;
    
        return $this;
    }

    /**
     * Get idCard
     *
     * @return \Etrali\GinangBundle\Entity\Card 
     */
    public function getIdCard()
    {
        return $this->idCard;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return Port
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Port
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}