<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * PortInstance
 *
 * @ORM\Table(name="port_instance")
 * @ORM\Entity
 */
class PortInstance
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_port_instance", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idPortInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_port_instance", type="string", length=50, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)   
     */
    private $cdPortInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_port_instance", type="string", length=100, nullable=true)
     * @Assert\MaxLength(40)  
     */
    private $lbPortInstance;
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_cross_connect", type="string", length=50, nullable=true)
     * @Assert\MaxLength(50)  
     */
    private $lbCrossConnect;     
    

    /**
     * @var string
     *
     * @ORM\Column(name="cm_port_instance", type="string", length=255, nullable=true)
     */
    private $cmPortInstance;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;
    
    /**
     * @var \PatchPanelInstance
     *
     * @ORM\ManyToOne(targetEntity="PatchPanelInstance", inversedBy="idPortInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_patch_panel_instance", referencedColumnName="id_patch_panel_instance")
     * })
     */
    private $idPatchPanelInstance;    
    
    /**
     * @var \CardInstance
     *
     * @ORM\ManyToOne(targetEntity="CardInstance", inversedBy="idPortInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_card_instance", referencedColumnName="id_card_instance")
     * })
     */
    private $idCardInstance;   
    
    
    /**
     * @var \Cable
     *
     * @ORM\ManyToOne(targetEntity="Cable")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_cable", referencedColumnName="id_cable")
     * })
     */
    private $idCable;   
    
    /**
     * @var \Port
     *
     * @ORM\ManyToOne(targetEntity="Port")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_port", referencedColumnName="id_port")
     * })  
     */
    private $idPort;     
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * }) 
     */
    private $idComplexModel;      

    /**
     * @var integer
     *
     * @ORM\Column(name="nb_number", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Port number can not be zero")    
     */
    private $nbNumber;
    
    /**
     * @var \PortType
     *
     * @ORM\ManyToOne(targetEntity="PortType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_port_type", referencedColumnName="id_port_type")
     * })
     * @Assert\NotNull() 
     */
    private $idPortType;    
    
    /**
     * @var \CostingPortLine
     *
     * @ORM\OneToMany(targetEntity="CostingPortLine", mappedBy="idPortInstance",cascade={"persist","remove"}, orphanRemoval=true)

     */
    private $idCostingPortLine;   
    

    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     *
     * @Assert\MaxLength(20)
     */
    private $cdProviderAccount; 
    
    /**
     * @var \Ts
     *
     * @ORM\OneToMany(targetEntity="Ts", mappedBy="idPortInstance",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"nbTs"="asc"})
     */
    private $idTs;  
    
    /**
     * @var \Vlan
     *
     * @ORM\OneToMany(targetEntity="Vlan", mappedBy="idPortInstance",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"lbVlan"="asc"})
     */
    private $idVlan;    
         
    
    /**
     * @var \BackboneLinkExtremityTech
     * @ORM\ManyToOne(targetEntity="BackboneLinkExtremityTech", inversedBy="idOutPortInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_backbone_link_extremity_tech", referencedColumnName="id_backbone_link_extremity_tech")
     * })
     */

    private $idBackboneLinkExtremityTech;  
    
    /**
     * @var \BackboneLinkExtremityTech     
     * @ORM\OneToMany(targetEntity="BackboneLinkExtremityTech", mappedBy="idPortInstance")
     */

    private $idInBackboneLinkExtremityTech;  
    
    
    /**
     * @var \LocalLoopExtremityTech     
     * @ORM\ManyToOne(targetEntity="LocalLoopExtremityTech", inversedBy="idOutPortInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_local_loop_extremity_tech", referencedColumnName="id_local_loop_extremity_tech")
     * })     
     */

    private $idLocalLoopExtremityTech;  
    
    /**
     * @var \LocalLoopExtremityAdditional   
     *   
     * @ORM\OneToMany(targetEntity="LocalLoopExtremityAdditional", mappedBy="idPortInstance") 
     */

    private $idLocalLoopExtremityAdditional;      
    
    /**
     * @var \LocalLoopExtremityTech     
     * 
     * @ORM\OneToMany(targetEntity="LocalLoopExtremityTech", mappedBy="idPortInstance")
     */

    private $idInLocalLoopExtremityTech;      
    
    /**
     * 
     * @var \ServiceExtremityTech          
     * @ORM\OneToMany(targetEntity="ServiceExtremityTech", mappedBy="idPortInstance")
     */

    private $idServiceExtremityTech;  
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;     
    
    public function getCollections()
    {
        $tab= array("Costings"=>"CostingPortLine");
        if ($this->getIdTs() && $this->getIdTs()->count()>0)
            $tab["Timeslots"]="Ts";
        if ($this->getIdVlan() && $this->getIdVlan()->count()>0)
            $tab["Vlans"]="Vlan";  
        if ($this->getIdServiceExtremityTech() && $this->getIdServiceExtremityTech()->count()>0)
            $tab["Service extremities"]="ServiceExtremityTech";           
            //$tab["Service extremities"]=array('idname'=>"idLocalLoopExtremityTech", 'idval'=>'InLocalLoopExtremityTech');           
        return $tab;
    }     

    public function getTsByNumber($number)
    {
        foreach ($this->getIdTs() as $bbts) {
            if ($bbts->getNbTs() == $number)
                return $bbts;
        }
        return NULL;
    }
    
    public function __toString()
    {
        return $this->getNbNumber()."";
    }

    public function getParentBranch() { return NULL; }  
   
   
       /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCostingPortLine = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idTs = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idVlan = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idInBackboneLinkExtremityTech = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idInLocalLoopExtremityTech = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idPortInstance
     *
     * @return integer 
     */
    public function getIdPortInstance()
    {
        return $this->idPortInstance;
    }

    /**
     * Set cdPortInstance
     *
     * @param string $cdPortInstance
     * @return PortInstance
     */
    public function setCdPortInstance($cdPortInstance)
    {
        $this->cdPortInstance = $cdPortInstance;
    
        return $this;
    }

    /**
     * Get cdPortInstance
     *
     * @return string 
     */
    public function getCdPortInstance()
    {
        return $this->cdPortInstance;
    }

    /**
     * Set lbPortInstance
     *
     * @param string $lbPortInstance
     * @return PortInstance
     */
    public function setLbPortInstance($lbPortInstance)
    {
        $this->lbPortInstance = $lbPortInstance;
    
        return $this;
    }

    /**
     * Get lbPortInstance
     *
     * @return string 
     */
    public function getLbPortInstance()
    {
        return $this->lbPortInstance;
    }

    /**
     * Set cmPortInstance
     *
     * @param string $cmPortInstance
     * @return PortInstance
     */
    public function setCmPortInstance($cmPortInstance)
    {
        $this->cmPortInstance = $cmPortInstance;
    
        return $this;
    }

    /**
     * Get cmPortInstance
     *
     * @return string 
     */
    public function getCmPortInstance()
    {
        return $this->cmPortInstance;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return PortInstance
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return PortInstance
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return PortInstance
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set nbNumber
     *
     * @param integer $nbNumber
     * @return PortInstance
     */
    public function setNbNumber($nbNumber)
    {
        $this->nbNumber = $nbNumber;
    
        return $this;
    }

    /**
     * Get nbNumber
     *
     * @return integer 
     */
    public function getNbNumber()
    {
        return $this->nbNumber;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return PortInstance
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return PortInstance
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return PortInstance
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idPatchPanelInstance
     *
     * @param \Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance
     * @return PortInstance
     */
    public function setIdPatchPanelInstance(\Etrali\GinangBundle\Entity\PatchPanelInstance $idPatchPanelInstance = null)
    {
        $this->idPatchPanelInstance = $idPatchPanelInstance;
    
        return $this;
    }

    /**
     * Get idPatchPanelInstance
     *
     * @return \Etrali\GinangBundle\Entity\PatchPanelInstance 
     */
    public function getIdPatchPanelInstance()
    {
        return $this->idPatchPanelInstance;
    }

    /**
     * Set idCardInstance
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idCardInstance
     * @return PortInstance
     */
    public function setIdCardInstance(\Etrali\GinangBundle\Entity\CardInstance $idCardInstance = null)
    {
        $this->idCardInstance = $idCardInstance;
    
        return $this;
    }

    /**
     * Get idCardInstance
     *
     * @return \Etrali\GinangBundle\Entity\CardInstance 
     */
    public function getIdCardInstance()
    {
        return $this->idCardInstance;
    }

    /**
     * Set idCable
     *
     * @param \Etrali\GinangBundle\Entity\Cable $idCable
     * @return PortInstance
     */
    public function setIdCable(\Etrali\GinangBundle\Entity\Cable $idCable = null)
    {
        $this->idCable = $idCable;
    
        return $this;
    }

    /**
     * Get idCable
     *
     * @return \Etrali\GinangBundle\Entity\Cable 
     */
    public function getIdCable()
    {
        return $this->idCable;
    }

    /**
     * Set idPort
     *
     * @param \Etrali\GinangBundle\Entity\Port $idPort
     * @return PortInstance
     */
    public function setIdPort(\Etrali\GinangBundle\Entity\Port $idPort = null)
    {
        $this->idPort = $idPort;
    
        return $this;
    }

    /**
     * Get idPort
     *
     * @return \Etrali\GinangBundle\Entity\Port 
     */
    public function getIdPort()
    {
        return $this->idPort;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return PortInstance
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }

    /**
     * Add idCostingPortLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingPortLine $idCostingPortLine
     * @return PortInstance
     */
    public function addIdCostingPortLine(\Etrali\GinangBundle\Entity\CostingPortLine $idCostingPortLine)
    {
        $this->idCostingPortLine[] = $idCostingPortLine;
    
        return $this;
    }

    /**
     * Remove idCostingPortLine
     *
     * @param \Etrali\GinangBundle\Entity\CostingPortLine $idCostingPortLine
     */
    public function removeIdCostingPortLine(\Etrali\GinangBundle\Entity\CostingPortLine $idCostingPortLine)
    {
        $this->idCostingPortLine->removeElement($idCostingPortLine);
    }

    /**
     * Get idCostingPortLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCostingPortLine()
    {
        return $this->idCostingPortLine;
    }


    /**
     * Add idTs
     *
     * @param \Etrali\GinangBundle\Entity\Ts $idTs
     * @return PortInstance
     */
    public function addIdT(\Etrali\GinangBundle\Entity\Ts $idTs)
    {
        $this->idTs[] = $idTs;
    
        return $this;
    }

    /**
     * Remove idTs
     *
     * @param \Etrali\GinangBundle\Entity\Ts $idTs
     */
    public function removeIdT(\Etrali\GinangBundle\Entity\Ts $idTs)
    {
        $this->idTs->removeElement($idTs);
    }

    /**
     * Get idTs
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdTs()
    {
        return $this->idTs;
    }

    /**
     * Add idVlan
     *
     * @param \Etrali\GinangBundle\Entity\Vlan $idVlan
     * @return PortInstance
     */
    public function addIdVlan(\Etrali\GinangBundle\Entity\Vlan $idVlan)
    {
        $this->idVlan[] = $idVlan;
    
        return $this;
    }

    /**
     * Remove idVlan
     *
     * @param \Etrali\GinangBundle\Entity\Vlan $idVlan
     */
    public function removeIdVlan(\Etrali\GinangBundle\Entity\Vlan $idVlan)
    {
        $this->idVlan->removeElement($idVlan);
    }

    /**
     * Get idVlan
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdVlan()
    {
        return $this->idVlan;
    }

    /**
     * Add idBackboneLinkExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idBackboneLinkExtremityTech
     * @return PortInstance
     */
    public function addIdBackboneLinkExtremityTech(\Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idBackboneLinkExtremityTech)
    {
        $this->idBackboneLinkExtremityTech[] = $idBackboneLinkExtremityTech;
    
        return $this;
    }

    /**
     * Remove idBackboneLinkExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idBackboneLinkExtremityTech
     */
    public function removeIdBackboneLinkExtremityTech(\Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idBackboneLinkExtremityTech)
    {
        $this->idBackboneLinkExtremityTech->removeElement($idBackboneLinkExtremityTech);
    }

    /**
     * Get idBackboneLinkExtremityTech
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBackboneLinkExtremityTech()
    {
        return $this->idBackboneLinkExtremityTech;
    }

    /**
     * Add idInBackboneLinkExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idInBackboneLinkExtremityTech
     * @return PortInstance
     */
    public function addIdInBackboneLinkExtremityTech(\Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idInBackboneLinkExtremityTech)
    {
        $this->idInBackboneLinkExtremityTech[] = $idInBackboneLinkExtremityTech;
    
        return $this;
    }

    /**
     * Remove idInBackboneLinkExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idInBackboneLinkExtremityTech
     */
    public function removeIdInBackboneLinkExtremityTech(\Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idInBackboneLinkExtremityTech)
    {
        $this->idInBackboneLinkExtremityTech->removeElement($idInBackboneLinkExtremityTech);
    }

    /**
     * Get idInBackboneLinkExtremityTech
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdInBackboneLinkExtremityTech()
    {
        return $this->idInBackboneLinkExtremityTech;
    }

    /**
     * Add idLocalLoopExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idLocalLoopExtremityTech
     * @return PortInstance
     */
    public function addIdLocalLoopExtremityTech(\Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idLocalLoopExtremityTech)
    {
        $this->idLocalLoopExtremityTech[] = $idLocalLoopExtremityTech;
    
        return $this;
    }

    /**
     * Remove idLocalLoopExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idLocalLoopExtremityTech
     */
    public function removeIdLocalLoopExtremityTech(\Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idLocalLoopExtremityTech)
    {
        $this->idLocalLoopExtremityTech->removeElement($idLocalLoopExtremityTech);
    }

    /**
     * Get idLocalLoopExtremityTech
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdLocalLoopExtremityTech()
    {
        return $this->idLocalLoopExtremityTech;
    }

    /**
     * Add idInLocalLoopExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idInLocalLoopExtremityTech
     * @return PortInstance
     */
    public function addIdInLocalLoopExtremityTech(\Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idInLocalLoopExtremityTech)
    {
        $this->idInLocalLoopExtremityTech[] = $idInLocalLoopExtremityTech;
    
        return $this;
    }

    /**
     * Remove idInLocalLoopExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idInLocalLoopExtremityTech
     */
    public function removeIdInLocalLoopExtremityTech(\Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idInLocalLoopExtremityTech)
    {
        $this->idInLocalLoopExtremityTech->removeElement($idInLocalLoopExtremityTech);
    }

    /**
     * Get idInLocalLoopExtremityTech
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdInLocalLoopExtremityTech()
    {
        return $this->idInLocalLoopExtremityTech;
    }

    /**
     * Add idServiceExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech
     * @return PortInstance
     */
    public function addIdServiceExtremityTech(\Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech)
    {
        $this->idServiceExtremityTech[] = $idServiceExtremityTech;
    
        return $this;
    }

    /**
     * Remove idServiceExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech
     */
    public function removeIdServiceExtremityTech(\Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech)
    {
        $this->idServiceExtremityTech->removeElement($idServiceExtremityTech);
    }

    /**
     * Get idServiceExtremityTech
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceExtremityTech()
    {
        return $this->idServiceExtremityTech;
    }

    /**
     * Set idBackboneLinkExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idBackboneLinkExtremityTech
     * @return PortInstance
     */
    public function setIdBackboneLinkExtremityTech(\Etrali\GinangBundle\Entity\BackboneLinkExtremityTech $idBackboneLinkExtremityTech = null)
    {
        $this->idBackboneLinkExtremityTech = $idBackboneLinkExtremityTech;
    
        return $this;
    }

    /**
     * Set idLocalLoopExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idLocalLoopExtremityTech
     * @return PortInstance
     */
    public function setIdLocalLoopExtremityTech(\Etrali\GinangBundle\Entity\LocalLoopExtremityTech $idLocalLoopExtremityTech = null)
    {
        $this->idLocalLoopExtremityTech = $idLocalLoopExtremityTech;
    
        return $this;
    }

    /**
     * Set idPortType
     *
     * @param \Etrali\GinangBundle\Entity\PortType $idPortType
     * @return PortInstance
     */
    public function setIdPortType(\Etrali\GinangBundle\Entity\PortType $idPortType = null)
    {
        $this->idPortType = $idPortType;
    
        return $this;
    }

    /**
     * Get idPortType
     *
     * @return \Etrali\GinangBundle\Entity\PortType 
     */
    public function getIdPortType()
    {
        return $this->idPortType;
    }

    /**
     * Set idLocalLoopExtremityAdditional
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional
     * @return PortInstance
     */
    public function setIdLocalLoopExtremityAdditional(\Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional = null)
    {
        $this->idLocalLoopExtremityAdditional = $idLocalLoopExtremityAdditional;
    
        return $this;
    }

    /**
     * Get idLocalLoopExtremityAdditional
     *
     * @return \Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional 
     */
    public function getIdLocalLoopExtremityAdditional()
    {
        return $this->idLocalLoopExtremityAdditional;
    }

    /**
     * Add idLocalLoopExtremityAdditional
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional
     * @return PortInstance
     */
    public function addIdLocalLoopExtremityAdditional(\Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional)
    {
        $this->idLocalLoopExtremityAdditional[] = $idLocalLoopExtremityAdditional;
    
        return $this;
    }

    /**
     * Remove idLocalLoopExtremityAdditional
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional
     */
    public function removeIdLocalLoopExtremityAdditional(\Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional)
    {
        $this->idLocalLoopExtremityAdditional->removeElement($idLocalLoopExtremityAdditional);
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return PortInstance
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set lbCrossConnect
     *
     * @param string $lbCrossConnect
     * @return PortInstance
     */
    public function setLbCrossConnect($lbCrossConnect)
    {
        $this->lbCrossConnect = $lbCrossConnect;
    
        return $this;
    }

    /**
     * Get lbCrossConnect
     *
     * @return string 
     */
    public function getLbCrossConnect()
    {
        return $this->lbCrossConnect;
    }
}