<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * PortType
 *
 * @ORM\Table(name="port_type")
 * @ORM\Entity
 */
class PortType
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_port_type", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idPortType;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_port_type", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20) 
     */
    private $cdPortType;



    /**
     * @var \PortSegmentationType
     *
     * @ORM\ManyToOne(targetEntity="PortSegmentationType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_port_segmentation_type", referencedColumnName="id_port_segmentation_type")
     * })
     * @Assert\NotNull()
     */
    private $idPortSegmentationType;    
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_max_services", type="integer",  nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Max services can not be zero")   
     */
    private $nbMaxServices;   
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_ts_start", type="integer",  nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Timeslot start can not be zero")   
     */
    private $nbTsStart;       
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_channels", type="integer",  nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Channels number can not be zero")  
     */
    private $nbChannels;  
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_channel_start", type="integer",  nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Channels start number can not be zero")  * 
     */
    private $nbChannelStart;     

    /**
     * @var integer
     *
     * @ORM\Column(name="nb_ts", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Timeslots number can not be zero")   
     */
    private $nbTs;

    /**
     * @var float
     *
     * @ORM\Column(name="nb_max_capacity", type="decimal", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Max port capacity can not be zero")  * 
     */
    private $nbMaxCapacity;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \BandwidthAssignee
     *
     * @ORM\ManyToOne(targetEntity="BandwidthAssignee")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_bandwidth_assignee", referencedColumnName="id_bandwidth_assignee")
     * })
     * @Assert\NotNull()
     */
    private $idBandwidth;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;    

    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getCdPortType().'';
    }
    
    /**
     * Get idPortType
     *
     * @return integer 
     */
    public function getIdPortType()
    {
        return $this->idPortType;
    }

 

    /**
     * Set cdPortType
     *
     * @param string $cdPortType
     * @return PortType
     */
    public function setCdPortType($cdPortType)
    {
        $this->cdPortType = $cdPortType;
    
        return $this;
    }

    /**
     * Get cdPortType
     *
     * @return string 
     */
    public function getCdPortType()
    {
        return $this->cdPortType;
    }

    /**
     * Set lbPortType
     *
     * @param string $lbPortType
     * @return PortType
     */
    public function setLbPortType($lbPortType)
    {
        $this->lbPortType = $lbPortType;
    
        return $this;
    }

    /**
     * Get lbPortType
     *
     * @return string 
     */
    public function getLbPortType()
    {
        return $this->lbPortType;
    }

    /**
     * Set nbMaxServices
     *
     * @param integer $nbMaxServices
     * @return PortType
     */
    public function setNbMaxServices($nbMaxServices)
    {
        $this->nbMaxServices = $nbMaxServices;
    
        return $this;
    }

    /**
     * Get nbMaxServices
     *
     * @return integer 
     */
    public function getNbMaxServices()
    {
        return $this->nbMaxServices;
    }

    /**
     * Set nbTsStart
     *
     * @param integer $nbTsStart
     * @return PortType
     */
    public function setNbTsStart($nbTsStart)
    {
        $this->nbTsStart = $nbTsStart;
    
        return $this;
    }

    /**
     * Get nbTsStart
     *
     * @return integer 
     */
    public function getNbTsStart()
    {
        return $this->nbTsStart;
    }

    /**
     * Set nbChannels
     *
     * @param integer $nbChannels
     * @return PortType
     */
    public function setNbChannels($nbChannels)
    {
        $this->nbChannels = $nbChannels;
    
        return $this;
    }

    /**
     * Get nbChannels
     *
     * @return integer 
     */
    public function getNbChannels()
    {
        return $this->nbChannels;
    }

    /**
     * Set nbChannelStart
     *
     * @param integer $nbChannelStart
     * @return PortType
     */
    public function setNbChannelStart($nbChannelStart)
    {
        $this->nbChannelStart = $nbChannelStart;
    
        return $this;
    }

    /**
     * Get nbChannelStart
     *
     * @return integer 
     */
    public function getNbChannelStart()
    {
        return $this->nbChannelStart;
    }

    /**
     * Set nbTs
     *
     * @param integer $nbTs
     * @return PortType
     */
    public function setNbTs($nbTs)
    {
        $this->nbTs = $nbTs;
    
        return $this;
    }

    /**
     * Get nbTs
     *
     * @return integer 
     */
    public function getNbTs()
    {
        return $this->nbTs;
    }

    /**
     * Set nbMaxCapacity
     *
     * @param float $nbMaxCapacity
     * @return PortType
     */
    public function setNbMaxCapacity($nbMaxCapacity)
    {
        $this->nbMaxCapacity = $nbMaxCapacity;
    
        return $this;
    }

    /**
     * Get nbMaxCapacity
     *
     * @return float 
     */
    public function getNbMaxCapacity()
    {
        return $this->nbMaxCapacity;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return PortType
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return PortType
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return PortType
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set idPortSegmentationType
     *
     * @param \Etrali\GinangBundle\Entity\PortSegmentationType $idPortSegmentationType
     * @return PortType
     */
    public function setIdPortSegmentationType(\Etrali\GinangBundle\Entity\PortSegmentationType $idPortSegmentationType = null)
    {
        $this->idPortSegmentationType = $idPortSegmentationType;
    
        return $this;
    }

    /**
     * Get idPortSegmentationType
     *
     * @return \Etrali\GinangBundle\Entity\PortSegmentationType 
     */
    public function getIdPortSegmentationType()
    {
        return $this->idPortSegmentationType;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return PortType
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idBandwidth
     *
     * @param \Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidth
     * @return PortType
     */
    public function setIdBandwidth(\Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidth = null)
    {
        $this->idBandwidth = $idBandwidth;
    
        return $this;
    }

    /**
     * Get idBandwidth
     *
     * @return \Etrali\GinangBundle\Entity\BandwidthAssignee
     */
    public function getIdBandwidth()
    {
        return $this->idBandwidth;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return PortType
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return PortType
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }public function getParentBranch() { return NULL; }  }