<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * ProductType
 *
 * @ORM\Table(name="product_type")
 * @ORM\Entity
 */
class ProductType
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_product_type", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idProductType;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_product_type", type="string", length=15, nullable=false)
     * @Assert\NotBlank();* 
     */
    private $cdProductType;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_product_type", type="text", nullable=false)
     * @Assert\NotBlank();      
     */
    private $lbProductType;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_end", type="datetime", nullable=true)
     */
    private $dtEnd;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_install_account", type="string", length=15, nullable=false)
     */
    private $lbInstallAccount;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_monthly_account", type="string", length=15, nullable=false)
     */
    private $lbMonthlyAccount;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_legacy", type="boolean", nullable=false)
     */
    private $blLegacy;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_provisioning", type="boolean", nullable=false)
     */
    private $blProvisioning;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_connected", type="boolean", nullable=false)
     */
    private $blConnected;    
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nb_extremities", type="integer", nullable=true)
     */
    private $nbExtremities=2; 
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nb_max_extremities", type="integer", nullable=false)
     */
    private $nbMaxExtremities=2;     
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=false)
     */
    private $blDeactivated=true;    

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_billable", type="boolean", nullable=false)
     */
    private $blBillable;

    /**
     * @var \ProductCategory
     *
     * @ORM\ManyToOne(targetEntity="ProductCategory",inversedBy="idProductType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_product_category", referencedColumnName="id_product_category")
     * })
     * @Assert\NotNull();
     */
    private $idProductCategory;
    
    /**
     * @ORM\ManyToMany(targetEntity="ProductCaracs", inversedBy="idProductType")
     * @ORM\JoinTable(name="product_type_product_caracs",
     *      inverseJoinColumns={@ORM\JoinColumn(name="id_product_caracs", referencedColumnName="id_product_caracs")},
     *      joinColumns={@ORM\JoinColumn(name="id_product_type", referencedColumnName="id_product_type")}
     *      )
     * @ORM\OrderBy({"position" = "asc"})        
     */
    private $idProductCaracs;   
    
    /**
     * @ORM\ManyToMany(targetEntity="ProductType", inversedBy="idProductInvDependence")
     * @ORM\JoinTable(name="product_type_product_dependence",
     *      inverseJoinColumns={@ORM\JoinColumn(name="id_product_dependence", referencedColumnName="id_product_type")},
     *      joinColumns={@ORM\JoinColumn(name="id_product_type", referencedColumnName="id_product_type")}
     *      )* 
     */
    private $idProductDependence;   
    
    /**
     * @ORM\ManyToMany(targetEntity="ProductType", mappedBy="idProductDependence")
     */
    private $idProductInvDependence;
    
    /**
     * @ORM\ManyToMany(targetEntity="TransactionType")
     * @ORM\JoinTable(name="product_type_transaction_type",
     *      inverseJoinColumns={@ORM\JoinColumn(name="id_transaction_type", referencedColumnName="id_transaction_type")},
     *      joinColumns={@ORM\JoinColumn(name="id_product_type", referencedColumnName="id_product_type")}
     *      )      
     */
    private $idTransactionType;   
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_dependence_types", type="string", length=255, nullable=true)
     */   
    private $lbDependenceTypes;
    
    
    

    public function __toString()
    {
        return $this->getCdProductType().":".$this->getLbProductType()."";
    }
    /**
     * Get idProductType
     *
     * @return integer 
     */
    public function getIdProductType()
    {
        return $this->idProductType;
    }


    /**
     * Set cdProductType
     *
     * @param string $cdProductType
     * @return ProductType
     */
    public function setCdProductType($cdProductType)
    {
        $this->cdProductType = $cdProductType;
    
        return $this;
    }

    /**
     * Get cdProductType
     *
     * @return string 
     */
    public function getCdProductType()
    {
        return $this->cdProductType;
    }

    /**
     * Set lbProductType
     *
     * @param string $lbProductType
     * @return ProductType
     */
    public function setLbProductType($lbProductType)
    {
        $this->lbProductType = $lbProductType;
    
        return $this;
    }

    /**
     * Get lbProductType
     *
     * @return string 
     */
    public function getLbProductType()
    {
        return $this->lbProductType;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return ProductType
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return ProductType
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtEnd
     *
     * @param \DateTime $dtEnd
     * @return ProductType
     */
    public function setDtEnd($dtEnd)
    {
        $this->dtEnd = $dtEnd;
    
        return $this;
    }

    /**
     * Get dtEnd
     *
     * @return \DateTime 
     */
    public function getDtEnd()
    {
        return $this->dtEnd;
    }

    /**
     * Set lbInstallAccount
     *
     * @param string $lbInstallAccount
     * @return ProductType
     */
    public function setLbInstallAccount($lbInstallAccount)
    {
        $this->lbInstallAccount = $lbInstallAccount;
    
        return $this;
    }

    /**
     * Get lbInstallAccount
     *
     * @return string 
     */
    public function getLbInstallAccount()
    {
        return $this->lbInstallAccount;
    }

    /**
     * Set lbMonthlyAccount
     *
     * @param string $lbMonthlyAccount
     * @return ProductType
     */
    public function setLbMonthlyAccount($lbMonthlyAccount)
    {
        $this->lbMonthlyAccount = $lbMonthlyAccount;
    
        return $this;
    }

    /**
     * Get lbMonthlyAccount
     *
     * @return string 
     */
    public function getLbMonthlyAccount()
    {
        return $this->lbMonthlyAccount;
    }

    /**
     * Set blLegacy
     *
     * @param boolean $blLegacy
     * @return ProductType
     */
    public function setBlLegacy($blLegacy)
    {
        $this->blLegacy = $blLegacy;
    
        return $this;
    }

    /**
     * Get blLegacy
     *
     * @return boolean 
     */
    public function getBlLegacy()
    {
        return $this->blLegacy;
    }

    /**
     * Set blProvisioning
     *
     * @param boolean $blProvisioning
     * @return ProductType
     */
    public function setBlProvisioning($blProvisioning)
    {
        $this->blProvisioning = $blProvisioning;
    
        return $this;
    }

    /**
     * Get blProvisioning
     *
     * @return boolean 
     */
    public function getBlProvisioning()
    {
        return $this->blProvisioning;
    }

    /**
     * Set blBillable
     *
     * @param boolean $blBillable
     * @return ProductType
     */
    public function setBlBillable($blBillable)
    {
        $this->blBillable = $blBillable;
    
        return $this;
    }

    /**
     * Get blBillable
     *
     * @return boolean 
     */
    public function getBlBillable()
    {
        return $this->blBillable;
    }
    
    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return ProductType
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }    

    /**
     * Set idProductCategory
     *
     * @param \Etrali\GinangBundle\Entity\ProductCategory $idProductCategory
     * @return ProductType
     */
    public function setIdProductCategory(\Etrali\GinangBundle\Entity\ProductCategory $idProductCategory = null)
    {
        $this->idProductCategory = $idProductCategory;
    
        return $this;
    }

    /**
     * Get idProductCategory
     *
     * @return \Etrali\GinangBundle\Entity\ProductCategory 
     */
    public function getIdProductCategory()
    {
        return $this->idProductCategory;
    }

    /**
     * Set idBandwidthAssignee
     *
     * @param \Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidthAssignee
     * @return ProductType
     */
    public function setIdBandwidthAssignee(\Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidthAssignee = null)
    {
        $this->idBandwidthAssignee = $idBandwidthAssignee;
    
        return $this;
    }

    /**
     * Get idBandwidthAssignee
     *
     * @return \Etrali\GinangBundle\Entity\BandwidthAssignee 
     */
    public function getIdBandwidthAssignee()
    {
        return $this->idBandwidthAssignee;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idProductCaracs = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idProductDependence = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Add idProductCaracs
     *
     * @param \Etrali\GinangBundle\Entity\ProductCaracs $idProductCaracs
     * @return ProductType
     */
    public function addIdProductCarac(\Etrali\GinangBundle\Entity\ProductCaracs $idProductCaracs)
    {
        $this->idProductCaracs[] = $idProductCaracs;
    
        return $this;
    }

    /**
     * Remove idProductCaracs
     *
     * @param \Etrali\GinangBundle\Entity\ProductCaracs $idProductCaracs
     */
    public function removeIdProductCarac(\Etrali\GinangBundle\Entity\ProductCaracs $idProductCaracs)
    {
        $this->idProductCaracs->removeElement($idProductCaracs);
    }

    /**
     * Get idProductCaracs
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdProductCaracs()
    {
        return $this->idProductCaracs;
    }



    /**
     * Set lbDependenceTypes
     *
     * @param string $lbDependenceTypes
     * @return ProductType
     */
    public function setLbDependenceTypes($lbDependenceTypes)
    {
        $this->lbDependenceTypes = $lbDependenceTypes;
    
        return $this;
    }

    /**
     * Get lbDependenceTypes
     *
     * @return string 
     */
    public function getLbDependenceTypes()
    {
        return $this->lbDependenceTypes;
    }

    /**
     * Add idProductDependence
     *
     * @param \Etrali\GinangBundle\Entity\ProductType $idProductDependence
     * @return ProductType
     */
    public function addIdProductDependence(\Etrali\GinangBundle\Entity\ProductType $idProductDependence)
    {
        $this->idProductDependence[] = $idProductDependence;
    
        return $this;
    }

    /**
     * Remove idProductDependence
     *
     * @param \Etrali\GinangBundle\Entity\ProductType $idProductDependence
     */
    public function removeIdProductDependence(\Etrali\GinangBundle\Entity\ProductType $idProductDependence)
    {
        $this->idProductDependence->removeElement($idProductDependence);
    }

    /**
     * Get idProductDependence
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdProductDependence()
    {
        return $this->idProductDependence;
    }

    /**
     * Add idProductInvDependence
     *
     * @param \Etrali\GinangBundle\Entity\ProductType $idProductInvDependence
     * @return ProductType
     */
    public function addIdProductInvDependence(\Etrali\GinangBundle\Entity\ProductType $idProductInvDependence)
    {
        $this->idProductInvDependence[] = $idProductInvDependence;
    
        return $this;
    }

    /**
     * Remove idProductInvDependence
     *
     * @param \Etrali\GinangBundle\Entity\ProductType $idProductInvDependence
     */
    public function removeIdProductInvDependence(\Etrali\GinangBundle\Entity\ProductType $idProductInvDependence)
    {
        $this->idProductInvDependence->removeElement($idProductInvDependence);
    }

    /**
     * Get idProductInvDependence
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdProductInvDependence()
    {
        return $this->idProductInvDependence;
    }

    /**
     * Set blServicecom
     *
     * @param boolean $blServicecom
     * @return ProductType
     */
    public function setBlServicecom($blServicecom)
    {
        $this->blServicecom = $blServicecom;
    
        return $this;
    }

    /**
     * Get blServicecom
     *
     * @return boolean 
     */
    public function getBlServicecom()
    {
        return $this->blServicecom;
    }

    /**
     * Set blServiceext
     *
     * @param boolean $blServiceext
     * @return ProductType
     */
    public function setBlServiceext($blServiceext)
    {
        $this->blServiceext = $blServiceext;
    
        return $this;
    }

    /**
     * Get blServiceext
     *
     * @return boolean 
     */
    public function getBlServiceext()
    {
        return $this->blServiceext;
    }

    /**
     * Add idTransactionType
     *
     * @param \Etrali\GinangBundle\Entity\TransactionType $idTransactionType
     * @return ProductType
     */
    public function addIdTransactionType(\Etrali\GinangBundle\Entity\TransactionType $idTransactionType)
    {
        $this->idTransactionType[] = $idTransactionType;
    
        return $this;
    }

    /**
     * Remove idTransactionType
     *
     * @param \Etrali\GinangBundle\Entity\TransactionType $idTransactionType
     */
    public function removeIdTransactionType(\Etrali\GinangBundle\Entity\TransactionType $idTransactionType)
    {
        $this->idTransactionType->removeElement($idTransactionType);
    }

    /**
     * Get idTransactionType
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdTransactionType()
    {
        return $this->idTransactionType;
    }

    /**
     * Set blConnected
     *
     * @param boolean $blConnected
     * @return ProductType
     */
    public function setBlConnected($blConnected)
    {
        $this->blConnected = $blConnected;
    
        return $this;
    }

    /**
     * Get blConnected
     *
     * @return boolean 
     */
    public function getBlConnected()
    {
        return $this->blConnected;
    }

    /**
     * Set nbExtremities
     *
     * @param integer $nbExtremities
     * @return ProductType
     */
    public function setNbExtremities($nbExtremities)
    {
        $this->nbExtremities = $nbExtremities;
    
        return $this;
    }

    /**
     * Get nbExtremities
     *
     * @return integer 
     */
    public function getNbExtremities()
    {
        return $this->nbExtremities;
    }

    /**
     * Set nbMaxExtremities
     *
     * @param integer $nbMaxExtremities
     * @return ProductType
     */
    public function setNbMaxExtremities($nbMaxExtremities)
    {
        $this->nbMaxExtremities = $nbMaxExtremities;
    
        return $this;
    }

    /**
     * Get nbMaxExtremities
     *
     * @return integer 
     */
    public function getNbMaxExtremities()
    {
        return $this->nbMaxExtremities;
    }public function getParentBranch() { return NULL; }  }