<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Provider
 *
 * @ORM\Table(name="provider")
 * @ORM\Entity
 */
class Provider
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_provider", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idProvider;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider", type="string", length=10, nullable=false)
     * @Assert\NotBlank()
     * @Assert\MaxLength(10)  
     */
    private $cdProvider;
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_provider", type="string", length=100, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(100)  
     */
    private $lbProvider;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var string
     *
     * @ORM\Column(name="comment", type="string", length=255, nullable=true)
     */
    private $comment;

    /**
     * @var integer
     *
     * @ORM\Column(name="nb_contractual_period", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Contract duration can not be zero")   
     */
    private $nbContractualPeriod;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_provider_account", type="string", length=45, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)   
     */
    private $cdProviderAccount;

    /**
     * @var \NoticePeriod
     *
     * @ORM\ManyToOne(targetEntity="NoticePeriod")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_notice_period", referencedColumnName="id_notice_period")
     * })
     * @Assert\NotNull();     
     */
    private $idNoticePeriod;



    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    /**
     * @var string
     *
     * @ORM\Column(name="carrier_name", type="string", length=255, nullable=true)
     */
    private $carrierName;

    /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="CountryProviderGroup")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_country_provider_group", referencedColumnName="id_country_provider_group")
     * })
     */
    private $idCountryProviderGroup;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \CompanyType
     *
     * @ORM\ManyToOne(targetEntity="CompanyType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_company_type", referencedColumnName="id_company_type")
     * })
     * @Assert\NotNull() 
     */
    private $idCompanyType;
    
    /**
     * @var \BillingFrequency
     *
     * @ORM\ManyToOne(targetEntity="BillingFrequency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_billing_frequency", referencedColumnName="id_billing_frequency")
     * })
     */
    private $idBillingFrequency;    


    /**
     * @var \Currency
     *
     * @ORM\ManyToOne(targetEntity="Currency")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_currency", referencedColumnName="id_currency")
     * })
     */
    private $idCurrency;
    
    /**
     * @var \AddressProvider
     *
     * @ORM\OneToMany(targetEntity="AddressProvider", mappedBy="idProvider",cascade={"persist","remove"}, orphanRemoval=true )   
     * @ORM\OrderBy({"blStatus" = "desc","lbAddress" = "asc"})        
     */
    private $idAddressProvider;
    
    /**
     * @var \ContactProvider
     *
     * @ORM\OneToMany(targetEntity="ContactProvider", mappedBy="idProvider",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"blDeactivated" = "desc","lbLastname" = "asc"})      
     */
    private $idContactProvider;        

    public function getCollections()
    {
        return array("Addresses"=>"AddressProvider","Contacts"=>"ContactProvider");       
    }    
    
    public function getId()
    {
        return $this->getIdProvider();
    }
    
    public function setIdProvider($id)
    {
        return $this->idProvider=$id;
    }
    
    /**
     * Get __toString
     *
     * @return string
     */    
    
    public function __toString()
    {
            return $this->getCdProvider()." : ".$this->getLbProvider();
    }  
    
    public function getTechnicalContacts()
    {
        $res=array();
        foreach ($this->getIdContactProvider() as $contact)
        {
             if ($contact->getIdContactType()->getIdContactType()==3)
                 $res[]=$contact;
        }
        return $res;
    }    
    
    public function getAdminContacts()
    {
        $res=array();
        foreach ($this->getIdContactProvider() as $contact)
        {
             if ($contact->getIdContactType()->getIdContactType()==2)
                 $res[]=$contact;
        }
        return $res;
    }

    public function getUniqueBillingAddress()
    {
        $res=array();
        foreach ($this->getIdAddressProvider() as $addr)
        {
             if ($addr->getIdAddressType()->getIdAddressType()==3)
                 $res[]=$addr;
        }
        if (count($res)==1)
            return $res[0];
        else
            return NULL;
    }

    public function getUniqueBillingContact()
    {
        $res=array();
        foreach ($this->getIdContactProvider() as $contact)
        {
             if ($contact->getIdContactType()->getIdContactType()==4)
                 $res[]=$contact;
        }
        if (count($res)==1)
            return $res[0];
        else
            return NULL;
    }

    public function getDefaultBillingContact()
    {
        $res=array();
        foreach ($this->getIdContactProvider() as $contact)
        {
             if ($contact->getIdContactType()->getIdContactType()==4 && $contact->getblDefault())
                 return $contact;
        }
        return NULL;
    }


public function getParentBranch() { return NULL; }      /**
     * Constructor
     */
    public function __construct()
    {
        $this->idAddressProvider = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idContactProvider = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idProvider
     *
     * @return integer 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set cdProvider
     *
     * @param string $cdProvider
     * @return Provider
     */
    public function setCdProvider($cdProvider)
    {
        $this->cdProvider = $cdProvider;
    
        return $this;
    }

    /**
     * Get cdProvider
     *
     * @return string 
     */
    public function getCdProvider()
    {
        return $this->cdProvider;
    }

    /**
     * Set lbProvider
     *
     * @param string $lbProvider
     * @return Provider
     */
    public function setLbProvider($lbProvider)
    {
        $this->lbProvider = $lbProvider;
    
        return $this;
    }

    /**
     * Get lbProvider
     *
     * @return string 
     */
    public function getLbProvider()
    {
        return $this->lbProvider;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Provider
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Provider
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Provider
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set comment
     *
     * @param string $comment
     * @return Provider
     */
    public function setComment($comment)
    {
        $this->comment = $comment;
    
        return $this;
    }

    /**
     * Get comment
     *
     * @return string 
     */
    public function getComment()
    {
        return $this->comment;
    }

    /**
     * Set nbContractualPeriod
     *
     * @param integer $nbContractualPeriod
     * @return Provider
     */
    public function setNbContractualPeriod($nbContractualPeriod)
    {
        $this->nbContractualPeriod = $nbContractualPeriod;
    
        return $this;
    }

    /**
     * Get nbContractualPeriod
     *
     * @return integer 
     */
    public function getNbContractualPeriod()
    {
        return $this->nbContractualPeriod;
    }

    /**
     * Set cdProviderAccount
     *
     * @param string $cdProviderAccount
     * @return Provider
     */
    public function setCdProviderAccount($cdProviderAccount)
    {
        $this->cdProviderAccount = $cdProviderAccount;
    
        return $this;
    }

    /**
     * Get cdProviderAccount
     *
     * @return string 
     */
    public function getCdProviderAccount()
    {
        return $this->cdProviderAccount;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Provider
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set carrierName
     *
     * @param string $carrierName
     * @return Provider
     */
    public function setCarrierName($carrierName)
    {
        $this->carrierName = $carrierName;
    
        return $this;
    }

    /**
     * Get carrierName
     *
     * @return string 
     */
    public function getCarrierName()
    {
        return $this->carrierName;
    }

    /**
     * Set idNoticePeriod
     *
     * @param \Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod
     * @return Provider
     */
    public function setIdNoticePeriod(\Etrali\GinangBundle\Entity\NoticePeriod $idNoticePeriod = null)
    {
        $this->idNoticePeriod = $idNoticePeriod;
    
        return $this;
    }

    /**
     * Get idNoticePeriod
     *
     * @return \Etrali\GinangBundle\Entity\NoticePeriod 
     */
    public function getIdNoticePeriod()
    {
        return $this->idNoticePeriod;
    }

    /**
     * Set idCountryProviderGroup
     *
     * @param \Etrali\GinangBundle\Entity\CountryProviderGroup $idCountryProviderGroup
     * @return Provider
     */
    public function setIdCountryProviderGroup(\Etrali\GinangBundle\Entity\CountryProviderGroup $idCountryProviderGroup = null)
    {
        $this->idCountryProviderGroup = $idCountryProviderGroup;
    
        return $this;
    }

    /**
     * Get idCountryProviderGroup
     *
     * @return \Etrali\GinangBundle\Entity\CountryProviderGroup 
     */
    public function getIdCountryProviderGroup()
    {
        return $this->idCountryProviderGroup;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Provider
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Provider
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idCompanyType
     *
     * @param \Etrali\GinangBundle\Entity\CompanyType $idCompanyType
     * @return Provider
     */
    public function setIdCompanyType(\Etrali\GinangBundle\Entity\CompanyType $idCompanyType = null)
    {
        $this->idCompanyType = $idCompanyType;
    
        return $this;
    }

    /**
     * Get idCompanyType
     *
     * @return \Etrali\GinangBundle\Entity\CompanyType 
     */
    public function getIdCompanyType()
    {
        return $this->idCompanyType;
    }

    /**
     * Set idBillingFrequency
     *
     * @param \Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency
     * @return Provider
     */
    public function setIdBillingFrequency(\Etrali\GinangBundle\Entity\BillingFrequency $idBillingFrequency = null)
    {
        $this->idBillingFrequency = $idBillingFrequency;
    
        return $this;
    }

    /**
     * Get idBillingFrequency
     *
     * @return \Etrali\GinangBundle\Entity\BillingFrequency 
     */
    public function getIdBillingFrequency()
    {
        return $this->idBillingFrequency;
    }

    /**
     * Set idCurrency
     *
     * @param \Etrali\GinangBundle\Entity\Currency $idCurrency
     * @return Provider
     */
    public function setIdCurrency(\Etrali\GinangBundle\Entity\Currency $idCurrency = null)
    {
        $this->idCurrency = $idCurrency;
    
        return $this;
    }

    /**
     * Get idCurrency
     *
     * @return \Etrali\GinangBundle\Entity\Currency 
     */
    public function getIdCurrency()
    {
        return $this->idCurrency;
    }

    /**
     * Add idAddressProvider
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idAddressProvider
     * @return Provider
     */
    public function addIdAddressProvider(\Etrali\GinangBundle\Entity\AddressProvider $idAddressProvider)
    {
        $this->idAddressProvider[] = $idAddressProvider;
    
        return $this;
    }

    /**
     * Remove idAddressProvider
     *
     * @param \Etrali\GinangBundle\Entity\AddressProvider $idAddressProvider
     */
    public function removeIdAddressProvider(\Etrali\GinangBundle\Entity\AddressProvider $idAddressProvider)
    {
        $this->idAddressProvider->removeElement($idAddressProvider);
    }

    /**
     * Get idAddressProvider
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdAddressProvider()
    {
        return $this->idAddressProvider;
    }

    /**
     * Add idContactProvider
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContactProvider
     * @return Provider
     */
    public function addIdContactProvider(\Etrali\GinangBundle\Entity\ContactProvider $idContactProvider)
    {
        $this->idContactProvider[] = $idContactProvider;
    
        return $this;
    }

    /**
     * Remove idContactProvider
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idContactProvider
     */
    public function removeIdContactProvider(\Etrali\GinangBundle\Entity\ContactProvider $idContactProvider)
    {
        $this->idContactProvider->removeElement($idContactProvider);
    }

    /**
     * Get idContactProvider
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdContactProvider()
    {
        return $this->idContactProvider;
    }
}