<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Route
 *
 * @ORM\Table(name="route")
 * @ORM\Entity
 */
class Route
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_route", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idRoute;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_route", type="string", length=15, nullable=true)
     */
    private $cdRoute;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_route", type="string", length=255, nullable=true)
     */
    private $lbRoute;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     * @Assert\DateTime()
     */
    private $dtUpdate;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \User
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;

    /**
     * @var \CommercialRoute
     *
     * @ORM\ManyToOne(targetEntity="CommercialRoute", inversedBy="idRoute")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_commercial_route", referencedColumnName="id_commercial_route")
     * })
     * @Assert\NotNull()      
     */
    private $idCommercialRoute;  
    

    /**
     * @var \City
     *
     * @ORM\ManyToOne(targetEntity="City")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_city_a", referencedColumnName="id_city")
     * })
     * @Assert\NotNull() 
     */
    private $idCityA;
    
    /**
     * @var \City
     *
     * @ORM\ManyToOne(targetEntity="City")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_city_b", referencedColumnName="id_city")
     * })
     * @Assert\NotNull() 
     */
    private $idCityB;       

    public function getId()
    {
        return $this->getIdRoute();
    }
    
    public function __toString() 
    { 
        return $this->getCdRoute();         
    } 
    
    public function getParentBranch() 
    { 
        return NULL;         
    }      

    /**
     * Get idRoute
     *
     * @return integer 
     */
    public function getIdRoute()
    {
        return $this->idRoute;
    }

    /**
     * Set cdRoute
     *
     * @param string $cdRoute
     * @return Route
     */
    public function setCdRoute($cdRoute)
    {
        $this->cdRoute = $cdRoute;
    
        return $this;
    }

    /**
     * Get cdRoute
     *
     * @return string 
     */
    public function getCdRoute()
    {
        return "".($this->getIdCityA()!=NULL?$this->getIdCityA()->getCdCity():"").($this->getIdCityB()!=NULL?$this->getIdCityB()->getCdCity():"");
    }

    /**
     * Set lbRoute
     *
     * @param string $lbRoute
     * @return Route
     */
    public function setLbRoute($lbRoute)
    {
        $this->lbRoute = $lbRoute;
    
        return $this;
    }

    /**
     * Get lbRoute
     *
     * @return string 
     */
    public function getLbRoute()
    {
        return $this->lbRoute;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Route
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Route
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return Route
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Route
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Route
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idCommercialRoute
     *
     * @param \Etrali\GinangBundle\Entity\CommercialRoute $idCommercialRoute
     * @return Route
     */
    public function setIdCommercialRoute(\Etrali\GinangBundle\Entity\CommercialRoute $idCommercialRoute = null)
    {
        $this->idCommercialRoute = $idCommercialRoute;
    
        return $this;
    }

    /**
     * Get idCommercialRoute
     *
     * @return \Etrali\GinangBundle\Entity\CommercialRoute 
     */
    public function getIdCommercialRoute()
    {
        return $this->idCommercialRoute;
    }
    
    /**
     * Set idCityA
     *
     * @param \Etrali\GinangBundle\Entity\City $idCityA
     * @return Route
     */
    public function setIdCityA(\Etrali\GinangBundle\Entity\City $idCityA = null)
    {
        $this->idCityA = $idCityA;
    
        return $this;
    }

    /**
     * Get idCityA
     *
     * @return \Etrali\GinangBundle\Entity\City 
     */
    public function getIdCityA()
    {
        return $this->idCityA;
    }

    /**
     * Set idCityB
     *
     * @param \Etrali\GinangBundle\Entity\City $idCityB
     * @return Route
     */
    public function setIdCityB(\Etrali\GinangBundle\Entity\City $idCityB = null)
    {
        $this->idCityB = $idCityB;
    
        return $this;
    }

    /**
     * Get idCityB
     *
     * @return \Etrali\GinangBundle\Entity\City 
     */
    public function getIdCityB()
    {
        return $this->idCityB;
    }
}