<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Service
 *
 * @ORM\Table(name="service")
 * @ORM\Entity
 */
class Service  
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_service", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idService;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_service", type="string", length=50, nullable=true)
     */
    private $cdService;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_customer_ref", type="string", length=15, nullable=true)
     */
    private $cdCustomerRef;


    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(name="dt_create", type="datetime", nullable=true)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_order", type="datetime", nullable=true)
     */
    private $dtOrder;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_delivery_requested", type="datetime", nullable=true)
     */
    private $dtDeliveryRequested;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_delivery", type="datetime", nullable=true)
     */
    private $dtDelivery;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_comment", type="string", length=255, nullable=true)
     */
    private $lbComment;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_validated", type="boolean", nullable=true)
     */
    private $blValidated=false;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_llstatus", type="boolean", nullable=true)
     */
    private $blLlstatus=false;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_bbstatus", type="boolean", nullable=true)
     */
    private $blBbstatus=false;    
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_init_terminate", type="datetime", nullable=true)
     */
    private $dtInitTerminate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_init_updown", type="datetime", nullable=true)
     */
    private $dtInitUpdown;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_requested_updwon", type="datetime", nullable=true)
     */
    private $dtRequestedUpdown;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_real_updown", type="datetime", nullable=true)
     */
    private $dtRealUpdown;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_request_terminate", type="datetime", nullable=true)
     */
    private $dtRequestTerminate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_real_terminate", type="datetime", nullable=true)
     */
    private $dtRealTerminate;



    /**
     * @var \Product
     *
     * @ORM\ManyToOne(targetEntity="Product")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_product", referencedColumnName="id_product")
     * })
     * @Assert\NotNull()
     */
    private $idProduct;

    /**
     * @var \Branch
     *
     * @ORM\ManyToOne(targetEntity="Branch")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_branch", referencedColumnName="id_branch")
     * })
     * @Assert\NotNull()
     */
    private $idBranch;


    /**
     * @var \CommercialRoute
     *
     * @ORM\ManyToOne(targetEntity="CommercialRoute")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_commercial_route", referencedColumnName="id_commercial_route")
     * })
     * @Assert\NotNull()     
     */
    private $idCommercialRoute;

    /**
     * @var \BandwidthAssignee
     *
     * @ORM\ManyToOne(targetEntity="BandwidthAssignee")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_old_bandwidth", referencedColumnName="id_bandwidth_assignee")
     * })
     */
    private $idOldBandwidth;

    /**
     * @var \BandwidthAssignee
     *
     * @ORM\ManyToOne(targetEntity="BandwidthAssignee")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_bandwidth", referencedColumnName="id_bandwidth_assignee")
     * })
     */
    private $idBandwidth;

    /**
     * @ORM\ManyToMany(targetEntity="Service", mappedBy="idConnectedServices", cascade={"persist"})
     */
    private $idParentServices;
    
    /**
     * @ORM\ManyToMany(targetEntity="Service", inversedBy="idParentServices", cascade={"persist"})
     * @ORM\JoinTable(name="service_connected_services",
     *      inverseJoinColumns={@ORM\JoinColumn(name="id_connected_services", referencedColumnName="id_service")},
     *      joinColumns={@ORM\JoinColumn(name="id_parent_services", referencedColumnName="id_service")}
     *      )* 
     */
    private $idConnectedServices; 
    
 /**
     * @var \ServiceExtremity
     *
     * @ORM\OneToMany(targetEntity="ServiceExtremity", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"blOld"="asc","blTransferred"="asc","idServiceExtremity" = "asc"})         
     */
    private $idServiceExtremity;
    
 /**
     * @var \TransferPrice
     *
     * @ORM\OneToMany(targetEntity="TransferPrice", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     */
    private $idTransferPrice;    
    
 /**
     * @var \ServiceDevice
     *
     * @ORM\OneToMany(targetEntity="ServiceDevice", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idServiceDevice" = "asc"})         
     */
    private $idServiceDevice;    
    
 /**
     * @var \BillingService
     *
     * @ORM\OneToMany(targetEntity="BillingService", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idBillingService" = "asc"})         
     */
    private $idBillingService;   
    
 /**
     * @var \BillingServiceLine
     *
     * @ORM\OneToMany(targetEntity="BillingServiceLine", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     */
    private $idBillingServiceLine;     
    
   
    
 /**
     * @var \BusinessConferenceGroup
     *
     * @ORM\ManyToOne(targetEntity="BusinessConferenceGroup", inversedBy="idService")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_business_conference_group", referencedColumnName="id_business_conference_group")
     * })     
     */
    private $idBusinessConferenceGroup;    
    
 /**
     * @var \TradExtraDatalinkGroup
     *
     * @ORM\ManyToOne(targetEntity="TradExtraDatalinkGroup", inversedBy="idService")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_trad_extra_datalink_group", referencedColumnName="id_trad_extra_datalink_group")
     * })     
     */
    private $idTradExtraDatalinkGroup;    
    
    /**
     * @var \ServiceCaracs
     *
     * @ORM\OneToMany(targetEntity="ServiceCaracs", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idServiceCaracs" = "asc"})         
     */
    private $idServiceCaracs;    
    
    /**
     * @var \ServiceExtremityTech
     *
     * @ORM\OneToMany(targetEntity="ServiceExtremityTech", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"blOld"="asc","blTransferred"="asc","idServiceExtremityTech" = "asc"})         
     */
    private $idServiceExtremityTech;    
    
    /**
     * @var \Note
     *
     * @ORM\OneToMany(targetEntity="Note", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idNote" = "asc"})         
     */
    private $idNote;       

    /**
     * @var \ServiceOption
     *
     * @ORM\OneToMany(targetEntity="ServiceOption", mappedBy="idService",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idServiceOption" = "asc"})         
     */
    private $idServiceOption;  
    
    /**
     * @var \ServiceTransactions
     *
     * @ORM\OneToMany(targetEntity="ServiceTransactions",mappedBy="idService", cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"dtCreate" = "desc"})         
     */
    private $idServiceTransactions;    
    
 
    
        /**
     * @var \TransactionStatus
     *
     * @ORM\ManyToOne(targetEntity="TransactionStatus")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_transaction_status", referencedColumnName="id_transaction_status")
     * })
     */
    private $idTransactionStatus;
    
    /**
     * @var \TransactionType
     *
     * @ORM\ManyToOne(targetEntity="TransactionType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_transaction_type", referencedColumnName="id_transaction_type")
     * })
     */
    private $idTransactionType;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_operation", type="integer", nullable=true)
     */
    private $nbOperation;    
    
    /**
     * @var \ServiceExtremity
     *
     * @ORM\ManyToOne(targetEntity="ServiceExtremity", cascade={"persist","remove"})
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_transfer_extremity", referencedColumnName="id_service_extremity")
     * })
     */
    private $idTransferExtremity;    
    
    /**
     * @var \ServiceExtremity
     *
     * @ORM\ManyToOne(targetEntity="ServiceExtremity")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_selected_extremity", referencedColumnName="id_service_extremity")
     * })
     */
    private $idSelectedExtremity;   
    
    
    /**
     * @var \ServiceDevice
     *
     * @ORM\ManyToOne(targetEntity="ServiceDevice")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_selected_device", referencedColumnName="id_service_device")
     * })
     */
    private $idSelectedDevice;  
    
        /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated; 
    
    public static function getModifierRoles()
    {
        return array("ROLE_SUPER_ADMINISTRATOR","ROLE_NETWORK_ENGINEER_ADMIN","ROLE_NETWORK_ENGINEER");
    }
    
    public static function getReaderRoles()
    {
        return array("ROLE_SUPER_ADMINISTRATOR","ROLE_ENTMC_INDIA", "ROLE_CSC_FRANCE", "ROLE_NETWORK_ACCOUNTING","ROLE_NETWORK_ADMINISTRATOR","ROLE_NETWORK_ENGINEER_ADMIN","ROLE_NETWORK_ENGINEER","ROLE_MARKETING_PRE_SALES","ROLE_SALES_ADMINISTRATOR");
    }   
    
    public function getId()
    {
        return $this->getIdService();
    }

    public function __toString()
    {
        try
        {
            return $this->getCdService()."";
        }
        catch (\ErrorException $e)
        {
            var_dump($e);
            return "";
        }
    }
    
    public function isNetrecovaConnected()
    {
        foreach ($this->getIdParentServices() as $pserv)
        {
            if ($pserv->getIdProduct()->getIdProductType()->getIdProductType()==5)
                return true;
        }
        return false;
    }    
    
    public function hasParentService($service)
    {
        foreach ($this->getIdParentServices() as $pserv)
        {
            if ($service->getIdService()==$pserv->getIdService())
                return true;
        }
        return false;
    }

    public function getCollections()
    {      
        $productType=$this->getIdProduct()->getIdProductType();
        $role=$GLOBALS['kernel']->getContainer()->get('etrali.security.context');
        $onglets=array();
        
        if ($role->isGranted("ROLE_SUPER_ADMINISTRATOR", $this))
        {
            $onglets=array_merge($onglets,array("Extremities"=>"ServiceExtremity","Transfer prices"=>"TransferPrice","Billing"=>"BillingService")); 
            if ($this->getIdProduct()->getIdProductType()->getIdProductType()==21)
                   $onglets=array_merge($onglets,array("Devices"=>"ServiceDevice"));            
            if ($productType->getBlProvisioning())
            {
                $onglets=array_merge($onglets,array("Technical"=>"ServiceExtremityTech"));
            }
            if ($productType->getBlConnected())
            {
                $onglets=array_merge($onglets,array("Connected services"=>"Service"));  
            }
            $onglets=array_merge($onglets,array("Options"=>"ServiceOption","Progression"=>"ServiceTransactions","Notes"=>"Note"));
        }
        else if($role->isGranted("ROLE_ENTMC_INDIA", $this)||$role->isGranted("ROLE_CSC_FRANCE", $this)||$role->isGranted("ROLE_NETWORK_ACCOUNTING", $this)||
            $role->isGranted("ROLE_NETWORK_ADMINISTRATOR", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER_ADMIN", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER", $this)||$role->isGranted("ROLE_MARKETING_PRE_SALES", $this)||
            $role->isGranted("ROLE_SALES_ADMINISTRATOR", $this))
        {
            $onglets=array_merge($onglets,array("Extremities"=>"ServiceExtremity"));
            if($role->isGranted("ROLE_SUPER_ADMINISTRATOR", $this)||$role->isGranted("ROLE_NETWORK_ACCOUNTING", $this)||$role->isGranted("ROLE_NETWORK_ADMINISTRATOR", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER_ADMIN", $this)||
               $role->isGranted("ROLE_NETWORK_ENGINEER", $this)||$role->isGranted("ROLE_MARKETING_PRE_SALES", $this)||$role->isGranted("ROLE_SALES_ADMINISTRATOR", $this))            
                $onglets=array_merge($onglets,array("Transfer prices"=>"TransferPrice"));
            if($productType->getBlBillable() && ($role->isGranted("ROLE_SUPER_ADMINISTRATOR", $this)||$role->isGranted("ROLE_CSC_FRANCE", $this)||$role->isGranted("ROLE_NETWORK_ACCOUNTING", $this)||
               $role->isGranted("ROLE_NETWORK_ADMINISTRATOR", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER_ADMIN", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER", $this)||$role->isGranted("ROLE_MARKETING_PRE_SALES", $this)||
               $role->isGranted("ROLE_SALES_ADMINISTRATOR", $this)))
            {
                $onglets=array_merge($onglets,array("Billing"=>"BillingService"));
            }
            if ($this->getIdProduct()->getIdProductType()->getIdProductType()==21)
                   $onglets=array_merge($onglets,array("Devices"=>"ServiceDevice"));              
            if ($productType->getBlProvisioning())
            {
                $onglets=array_merge($onglets,array("Technical"=>"ServiceExtremityTech"));               
            }
            if ($productType->getBlConnected())
            {
                $onglets=array_merge($onglets,array("Connected services"=>"Service"));  
            }
            $onglets=array_merge($onglets,array("Options"=>"ServiceOption"));             
            if($role->isGranted("ROLE_SUPER_ADMINISTRATOR", $this)||$role->isGranted("ROLE_NETWORK_ACCOUNTING", $this)||$role->isGranted("ROLE_NETWORK_ADMINISTRATOR", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER_ADMIN", $this)||
               $role->isGranted("ROLE_NETWORK_ENGINEER", $this)||$role->isGranted("ROLE_MARKETING_PRE_SALES", $this)||$role->isGranted("ROLE_SALES_ADMINISTRATOR", $this))
            {
                $onglets=array_merge($onglets,array("Progression"=>"ServiceTransactions"));
            }
            if($role->isGranted("ROLE_SUPER_ADMINISTRATOR", $this)||$role->isGranted("ROLE_CSC_FRANCE", $this)||$role->isGranted("ROLE_NETWORK_ACCOUNTING", $this)||
               $role->isGranted("ROLE_NETWORK_ADMINISTRATOR", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER_ADMIN", $this)||$role->isGranted("ROLE_NETWORK_ENGINEER", $this)||$role->isGranted("ROLE_MARKETING_PRE_SALES", $this)||
               $role->isGranted("ROLE_SALES_ADMINISTRATOR", $this))
            {
                $onglets=array_merge($onglets,array("Notes"=>"Note"));
            }
        }             
        return $onglets;
    }  
       
    public function getHeadInfo()
    {
            $lbparent="";
            $lbaddr="";                
            $cpt=0;
            $retour="<td>".$this->getCdService()."</td><td>".$this->getIdProduct()."</td><td>".$this->getIdBandwidth()."</td>";
            foreach ($this->getIdServiceExtremity() as $extr)
            {
                if ($extr->getIdServiceExtremityOwner()!=NULL)
                {            
                    switch ($extr->getIdServiceExtremityOwner()->getIdLocalLoopExtremityOwner())
                    {
                        case 1:
                            $lbparent=$extr->getIdCustomer()!=NULL?$extr->getIdCustomer():"";
                            $lbaddr=$extr->getIdCustomer()!=NULL?$extr->getIdDeliveryAddress():"";                                               
                        break;
                        case 2:
                            $lbparent=$extr->getIdPop()!=NULL?$extr->getIdPop():"";
                            $lbaddr=$extr->getIdPop()!=NULL?$extr->getIdAddressPop():"";                                  
                        break;
                        case 3:
                            $lbparent=$extr->getIdProvider()!=NULL?$extr->getIdProvider():"";
                            $lbaddr=$extr->getIdProvider()!=NULL?$extr->getIdAddressProvider():"";                                                                             
                        break;        
                    }
                }
                $retour.= "<td>".$lbparent."</td><td>".$lbaddr."</td>";
                $cpt++;                
                if ($cpt==2)
                    break;
            }
            $retour.="<td>".$this->getIdTransactionStatus()."</td>";
            return $retour;
    }  
    
    public function getHeadColumns()
    {
            $retour= "<th>Service ref</th><th>Product</th><th>Bandwidth</th>";
            if (count($this->getIdServiceExtremity())>0)
                $retour.="<th>A-end</th><th>A-end address</th>";            
            if (count($this->getIdServiceExtremity())>1)
                $retour.="<th>B-end</th><th>B-end address</th>";
            $retour.="<th>Status</th>";
            return $retour;
    } 
    
    public function isP2P()
    {
        return $this->getNotOldExtremityCount()<=2;
    }
    
    public function getNotOldExtremityCount()
    {
        $cpt=0;
        foreach ($this->getIdServiceExtremity() as $extr)
        {
             if (!$extr->getBlOld())
                 $cpt++;
        }
        return $cpt;
    }
    
    
    /**
     * Get cdService
     *
     * @return string 
     */
    public function getCdService()
    {
        try
        {
        if ($this->getIdProduct()==NULL)
            return $this->cdService;
        else
        {
            $havecds=array(4,5,6,7,8,9,17,18,20,21,27);
            if (in_array($this->getIdProduct()->getIdProductType()->getIdProductType(),$havecds))
               $prodcd=$this->getIdProduct()->getIdProductType()->getCdProductType ();
            else
               $prodcd="";
            $cpt=0;
            $Aend="";
            $Bend="";
            foreach ($this->getIdServiceExtremity() as $extr)
            {
                if (!$extr->getBlOld())
                {
                    if ($cpt==0)
                    {
                        if ($extr->getIdServiceExtremityOwner()!=NULL)
                        {
                            switch ($extr->getIdServiceExtremityOwner()->getIdLocalLoopExtremityOwner())
                            {
                                case 1:
                                    if ($extr->getIdCustomer()!=NULL && $extr->getIdDeliveryAddress()!=NULL && $extr->getIdDeliveryAddress()->getIdCity()!=NULL)
                                        $Aend=$extr->getIdDeliveryAddress()->getIdCity()->getCdCity();
                                    break;
                                case 2:
                                    if ($extr->getIdPop()!=NULL && $extr->getIdAddressPop()!=NULL && $extr->getIdAddressPop()->getIdCity()!=NULL)
                                        $Aend=$extr->getIdAddressPop()->getIdCity()->getCdCity();
                                    break;
                                case 3:
                                    if ($extr->getIdProvider()!=NULL && $extr->getIdAddressProvider()!=NULL && $extr->getIdAddressProvider()->getIdCity()!=NULL)
                                        $Aend=$extr->getIdAddressProvider()->getIdCity()->getCdCity();
                                    break;                                    
                            }
                        }
                    }
                    else if ($cpt==1 && !in_array($this->getIdProduct()->getIdProductType()->getIdProductType(),$havecds))
                    {
                        if ($extr->getIdServiceExtremityOwner()!=NULL)
                        {
                            switch ($extr->getIdServiceExtremityOwner()->getIdLocalLoopExtremityOwner())
                            {
                                case 1:
                                    if ($extr->getIdCustomer()!=NULL && $extr->getIdDeliveryAddress()!=NULL && $extr->getIdDeliveryAddress()->getIdCity()!=NULL)
                                        $Bend=$extr->getIdDeliveryAddress()->getIdCity()->getCdCity();
                                    break;
                                case 2:
                                    if ($extr->getIdPop()!=NULL && $extr->getIdAddressPop()!=NULL && $extr->getIdAddressPop()->getIdCity()!=NULL)
                                        $Bend=$extr->getIdAddressPop()->getIdCity()->getCdCity();
                                    break;
                                case 3:
                                    if ($extr->getIdProvider()!=NULL && $extr->getIdAddressProvider()!=NULL && $extr->getIdAddressProvider()->getIdCity()!=NULL)
                                        $Bend=$extr->getIdAddressProvider()->getIdCity()->getCdCity();
                                    break;                                    
                            }
                        }
                    }
                    else
                        break;
                    $cpt++;
                }
            }
            return $prodcd.$Aend.$Bend.$this->getIdService();
        }
        }
        catch (Exception $e)
        {
            var_dump($e);
            return "";
        }        
    }    
    
    public function isAvailableForConnection()
    {
        $cdProd=substr($this->getIdProduct()->getCdProduct(),0,3);
        if ($cdProd=="BUA" || $cdProd=="BUI" || $cdProd=="BUC")
        {
            $nbMax=substr($this->getIdProduct()->getCdProduct(),3);
            $nbCurrent=count($this->getIdConnectedServices());
            return $nbCurrent<$nbMax;
        }
        else
             return true;
    }
    
    public function getEditType($type)
    {
        $type->setObject($this);
        $idtrans=$this->getIdTransactionStatus()->getIdTransactionStatus();
        $idtype=$this->getIdTransactionType()->getIdTransactionType();        
        $type->setTransaction($idtype,$idtrans);            
        return $type;
    }
    
    public function hasOffNet()
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==4 && $carac->getValeur()=="1")
                return true;
        }
        return false;
    }
    
    public function getCaracLbConnection()
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==1)
                return $carac->getValeur();
        }
        return NULL;
    }
    
    public function hasCaracLbConnection()
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==1)
                return true;
        }
        return false;
    }
    
    public function hasDtEndToEnd()
    {
        if ($this->isP2P())
        {
            foreach($this->getIdServiceExtremityTech() as $extr)
            {
                foreach ($extr->getIdServiceCaracs() as $carac)
                {
                    if ($carac->getIdProductCaracs()->getIdProductCaracs()==32 && $carac->getValeur()!=NULL)
                        return true;
                }
            }
        }
        else
        {
            foreach($this->getIdServiceExtremityTech() as $extr)
            {
                $found=false;
                foreach ($extr->getIdServiceCaracs() as $carac)
                {
                    if ($carac->getIdProductCaracs()->getIdProductCaracs()==32 && $carac->getValeur()!=NULL)
                        $found=true;
                }
                if (!$found)
                    return false;
            }
            return true;
        }
        return false;
    }    
    
    public function canUpgrade()
    {
        $producttypes=array(3,27,13,19,22,23);
        if (!in_array($this->getIdProduct()->getIdProductType()->getIdProductType(),$producttypes))
                return false;
        $statuses=array(54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        return true;
    }
    
    public function canTransfer()
    {
        $producttypes=array(1,2,3,4,17,5,15,16,6,7,8,9,10,11,12,14,27,13,19,20,21,22,23);
        if (!in_array($this->getIdProduct()->getIdProductType()->getIdProductType(),$producttypes))
                return false;        
        $statuses=array(54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        return true;
    }
    
    public function canTerminate()
    {
        $statuses=array(54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        return true;
    }  
    
    public function canTerminateExtremity()
    {
        $producttypes=array(4,17,5,27);      
        if (!in_array($this->getIdProduct()->getIdProductType()->getIdProductType(),$producttypes))
                return false;        
        $statuses=array(54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        return true;
    }  
    
    public function canTerminateDevice()
    {
        if ($this->getIdProduct()->getIdProductType()->getIdProductType()!=21)
                return false;        
        $statuses=array(54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        return true;
    }      
    
    public function canUpgradeExtremity()
    {
        if ($this->getIdProduct()->getIdProductType()->getIdProductType()!=27)
                return false;        
        $statuses=array(54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        return true;
    } 

    public function canAddExtremity()
    {
        $producttypes=array(4,5,17,18,20,27);
        if (!in_array($this->getIdProduct()->getIdProductType()->getIdProductType(),$producttypes))
                return false;        
        $statuses=array(44,54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        if ($this->getIdServiceExtremity()->count() >= $this->getNumberExtremities())
            return false;
        return true;
    }  
    
    public function canAddDevice()
    {
        if ($this->getIdProduct()->getIdProductType()->getIdProductType()!=21)
                return false;        
        $statuses=array(44,54,65,75,85,96,99,102,105);
        if (!in_array($this->getIdTransactionStatus()->getIdTransactionStatus(),$statuses))
             return false;
        if ($this->getIdServiceExtremity()->count() >= $this->getNumberExtremities())
            return false;
        return true;
    }     
    
    public function getNumberExtremities()
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==14 && $carac->getValeur()!=NULL )
                return $carac->getValeur();
        }
        return 10000;
    }
   
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idParentServices = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idConnectedServices = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idServiceExtremity = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idBillingService = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idServiceCaracs = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idServiceExtremityTech = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idServiceOption = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idServiceTransactions = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idService
     *
     * @return integer 
     */
    public function getIdService()
    {
        return $this->idService;
    }
    
    /**
     * set idService
     * @param integer $id
     * @return Service
     */
    public function setIdService($id)
    {
        return $this->idService=$id;
    }    

    /**
     * Set cdService
     *
     * @param string $cdService
     * @return Service
     */
    public function setCdService($cdService)
    {
        $this->cdService = $cdService;
    
        return $this;
    }



    /**
     * Set cdCustomerRef
     *
     * @param string $cdCustomerRef
     * @return Service
     */
    public function setCdCustomerRef($cdCustomerRef)
    {
        $this->cdCustomerRef = $cdCustomerRef;
    
        return $this;
    }

    /**
     * Get cdCustomerRef
     *
     * @return string 
     */
    public function getCdCustomerRef()
    {
        return $this->cdCustomerRef;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return Service
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtOrder
     *
     * @param \DateTime $dtOrder
     * @return Service
     */
    public function setDtOrder($dtOrder)
    {
        $this->dtOrder = $dtOrder;
    
        return $this;
    }

    /**
     * Get dtOrder
     *
     * @return \DateTime 
     */
    public function getDtOrder()
    {
        return $this->dtOrder;
    }

    /**
     * Set dtDeliveryRequested
     *
     * @param \DateTime $dtDeliveryRequested
     * @return Service
     */
    public function setDtDeliveryRequested($dtDeliveryRequested)
    {
        $this->dtDeliveryRequested = $dtDeliveryRequested;
    
        return $this;
    }

    /**
     * Get dtDeliveryRequested
     *
     * @return \DateTime 
     */
    public function getDtDeliveryRequested()
    {
        return $this->dtDeliveryRequested;
    }

    /**
     * Set dtDelivery
     *
     * @param \DateTime $dtDelivery
     * @return Service
     */
    public function setDtDelivery($dtDelivery)
    {
        $this->dtDelivery = $dtDelivery;
    
        return $this;
    }

    /**
     * Get dtDelivery
     *
     * @return \DateTime 
     */
    public function getDtDelivery()
    {
        return $this->dtDelivery;
    }

    /**
     * Set lbComment
     *
     * @param string $lbComment
     * @return Service
     */
    public function setLbComment($lbComment)
    {
        $this->lbComment = $lbComment;
    
        return $this;
    }

    /**
     * Get lbComment
     *
     * @return string 
     */
    public function getLbComment()
    {
        return $this->lbComment;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Service
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtInitTerminate
     *
     * @param \DateTime $dtInitTerminate
     * @return Service
     */
    public function setDtInitTerminate($dtInitTerminate)
    {
        $this->dtInitTerminate = $dtInitTerminate;
    
        return $this;
    }

    /**
     * Get dtInitTerminate
     *
     * @return \DateTime 
     */
    public function getDtInitTerminate()
    {
        return $this->dtInitTerminate;
    }

    /**
     * Set dtInitUpdown
     *
     * @param \DateTime $dtInitUpdown
     * @return Service
     */
    public function setDtInitUpdown($dtInitUpdown)
    {
        $this->dtInitUpdown = $dtInitUpdown;
    
        return $this;
    }

    /**
     * Get dtInitUpdown
     *
     * @return \DateTime 
     */
    public function getDtInitUpdown()
    {
        return $this->dtInitUpdown;
    }

    /**
     * Set dtRequestedUpdown
     *
     * @param \DateTime $dtRequestedUpdown
     * @return Service
     */
    public function setDtRequestedUpdown($dtRequestedUpdown)
    {
        $this->dtRequestedUpdown = $dtRequestedUpdown;
    
        return $this;
    }

    /**
     * Get dtRequestedUpdown
     *
     * @return \DateTime 
     */
    public function getDtRequestedUpdown()
    {
        return $this->dtRequestedUpdown;
    }

    /**
     * Set dtRealUpdown
     *
     * @param \DateTime $dtRealUpdown
     * @return Service
     */
    public function setDtRealUpdown($dtRealUpdown)
    {
        $this->dtRealUpdown = $dtRealUpdown;
    
        return $this;
    }

    /**
     * Get dtRealUpdown
     *
     * @return \DateTime 
     */
    public function getDtRealUpdown()
    {
        return $this->dtRealUpdown;
    }

    /**
     * Set dtRequestTerminate
     *
     * @param \DateTime $dtRequestTerminate
     * @return Service
     */
    public function setDtRequestTerminate($dtRequestTerminate)
    {
        $this->dtRequestTerminate = $dtRequestTerminate;
    
        return $this;
    }

    /**
     * Get dtRequestTerminate
     *
     * @return \DateTime 
     */
    public function getDtRequestTerminate()
    {
        return $this->dtRequestTerminate;
    }

    /**
     * Set dtRealTerminate
     *
     * @param \DateTime $dtRealTerminate
     * @return Service
     */
    public function setDtRealTerminate($dtRealTerminate)
    {
        $this->dtRealTerminate = $dtRealTerminate;
    
        return $this;
    }

    /**
     * Get dtRealTerminate
     *
     * @return \DateTime 
     */
    public function getDtRealTerminate()
    {
        return $this->dtRealTerminate;
    }

    /**
     * Set nbOperation
     *
     * @param integer $nbOperation
     * @return Service
     */
    public function setNbOperation($nbOperation)
    {
        $this->nbOperation = $nbOperation;
    
        return $this;
    }

    /**
     * Get nbOperation
     *
     * @return integer 
     */
    public function getNbOperation()
    {
        return $this->nbOperation;
    }

    /**
     * Set idProduct
     *
     * @param \Etrali\GinangBundle\Entity\Product $idProduct
     * @return Service
     */
    public function setIdProduct(\Etrali\GinangBundle\Entity\Product $idProduct = null)
    {
        $this->idProduct = $idProduct;
    
        return $this;
    }

    /**
     * Get idProduct
     *
     * @return \Etrali\GinangBundle\Entity\Product 
     */
    public function getIdProduct()
    {
        return $this->idProduct;
    }

    /**
     * Set idBranch
     *
     * @param \Etrali\GinangBundle\Entity\Branch $idBranch
     * @return Service
     */
    public function setIdBranch(\Etrali\GinangBundle\Entity\Branch $idBranch = null)
    {
        $this->idBranch = $idBranch;
    
        return $this;
    }

    /**
     * Get idBranch
     *
     * @return \Etrali\GinangBundle\Entity\Branch 
     */
    public function getIdBranch()
    {
        return $this->idBranch;
    }

    /**
     * Set idCommercialRoute
     *
     * @param \Etrali\GinangBundle\Entity\CommercialRoute $idCommercialRoute
     * @return Service
     */
    public function setIdCommercialRoute(\Etrali\GinangBundle\Entity\CommercialRoute $idCommercialRoute = null)
    {
        $this->idCommercialRoute = $idCommercialRoute;
    
        return $this;
    }

    /**
     * Get idCommercialRoute
     *
     * @return \Etrali\GinangBundle\Entity\CommercialRoute 
     */
    public function getIdCommercialRoute()
    {
        return $this->idCommercialRoute;
    }

    /**
     * Set idOldBandwidth
     *
     * @param \Etrali\GinangBundle\Entity\BandwidthAssignee $idOldBandwidth
     * @return Service
     */
    public function setIdOldBandwidth(\Etrali\GinangBundle\Entity\BandwidthAssignee $idOldBandwidth = null)
    {
        $this->idOldBandwidth = $idOldBandwidth;
    
        return $this;
    }

    /**
     * Get idOldBandwidth
     *
     * @return \Etrali\GinangBundle\Entity\BandwidthAssignee
     */
    public function getIdOldBandwidth()
    {
        return $this->idOldBandwidth;
    }

    /**
     * Set idBandwidth
     *
     * @param \Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidth
     * @return Service
     */
    public function setIdBandwidth(\Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidth = null)
    {
        $this->idBandwidth = $idBandwidth;
    
        return $this;
    }

    /**
     * Get idBandwidth
     *
     * @return \Etrali\GinangBundle\Entity\BandwidthAssignee 
     */
    public function getIdBandwidth()
    {
        return $this->idBandwidth;
    }

    /**
     * Add idParentServices
     *
     * @param \Etrali\GinangBundle\Entity\Service $idParentServices
     * @return Service
     */
    public function addIdParentService(\Etrali\GinangBundle\Entity\Service $idParentServices)
    {
        $this->idParentServices[] = $idParentServices;
    
        return $this;
    }

    /**
     * Remove idParentServices
     *
     * @param \Etrali\GinangBundle\Entity\Service $idParentServices
     */
    public function removeIdParentService(\Etrali\GinangBundle\Entity\Service $idParentServices)
    {
        $this->idParentServices->removeElement($idParentServices);
    }

    /**
     * Get idParentServices
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdParentServices()
    {
        return $this->idParentServices;
    }

    /**
     * Add idConnectedServices
     *
     * @param \Etrali\GinangBundle\Entity\Service $idConnectedServices
     * @return Service
     */
    public function addIdConnectedService(\Etrali\GinangBundle\Entity\Service $idConnectedServices)
    {
        $this->idConnectedServices[] = $idConnectedServices;
    
        return $this;
    }

    /**
     * Remove idConnectedServices
     *
     * @param \Etrali\GinangBundle\Entity\Service $idConnectedServices
     */
    public function removeIdConnectedService(\Etrali\GinangBundle\Entity\Service $idConnectedServices)
    {
        $this->idConnectedServices->removeElement($idConnectedServices);
    }

    /**
     * Get idConnectedServices
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdConnectedServices()
    {
        return $this->idConnectedServices;
    }

    /**
     * Add idServiceExtremity
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremity $idServiceExtremity
     * @return Service
     */
    public function addIdServiceExtremity(\Etrali\GinangBundle\Entity\ServiceExtremity $idServiceExtremity)
    {
        $this->idServiceExtremity[] = $idServiceExtremity;
    
        return $this;
    }

    /**
     * Remove idServiceExtremity
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremity $idServiceExtremity
     */
    public function removeIdServiceExtremity(\Etrali\GinangBundle\Entity\ServiceExtremity $idServiceExtremity)
    {
        $this->idServiceExtremity->removeElement($idServiceExtremity);
    }

    /**
     * Get idServiceExtremity
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceExtremity()
    {
        return $this->idServiceExtremity;
    }

    /**
     * Add idBillingService
     *
     * @param \Etrali\GinangBundle\Entity\BillingService $idBillingService
     * @return Service
     */
    public function addIdBillingService(\Etrali\GinangBundle\Entity\BillingService $idBillingService)
    {
        $this->idBillingService[] = $idBillingService;
    
        return $this;
    }

    /**
     * Remove idBillingService
     *
     * @param \Etrali\GinangBundle\Entity\BillingService $idBillingService
     */
    public function removeIdBillingService(\Etrali\GinangBundle\Entity\BillingService $idBillingService)
    {
        $this->idBillingService->removeElement($idBillingService);
    }

    /**
     * Get idBillingService
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingService()
    {
        return $this->idBillingService;
    }

    /**
     * Add idServiceCaracs
     *
     * @param \Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs
     * @return Service
     */
    public function addIdServiceCarac(\Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs)
    {
        $this->idServiceCaracs[] = $idServiceCaracs;
    
        return $this;
    }

    /**
     * Remove idServiceCaracs
     *
     * @param \Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs
     */
    public function removeIdServiceCarac(\Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs)
    {
        $this->idServiceCaracs->removeElement($idServiceCaracs);
    }

    /**
     * Get idServiceCaracs
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceCaracs()
    {
        return $this->idServiceCaracs;
    }

    /**
     * Add idServiceExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech
     * @return Service
     */
    public function addIdServiceExtremityTech(\Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech)
    {
        $this->idServiceExtremityTech[] = $idServiceExtremityTech;
    
        return $this;
    }

    /**
     * Remove idServiceExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech
     */
    public function removeIdServiceExtremityTech(\Etrali\GinangBundle\Entity\ServiceExtremityTech $idServiceExtremityTech)
    {
        $this->idServiceExtremityTech->removeElement($idServiceExtremityTech);
    }

    /**
     * Get idServiceExtremityTech
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceExtremityTech()
    {
        return $this->idServiceExtremityTech;
    }

    /**
     * Add idServiceOption
     *
     * @param \Etrali\GinangBundle\Entity\ServiceOption $idServiceOption
     * @return Service
     */
    public function addIdServiceOption(\Etrali\GinangBundle\Entity\ServiceOption $idServiceOption)
    {
        $this->idServiceOption[] = $idServiceOption;
    
        return $this;
    }

    /**
     * Remove idServiceOption
     *
     * @param \Etrali\GinangBundle\Entity\ServiceOption $idServiceOption
     */
    public function removeIdServiceOption(\Etrali\GinangBundle\Entity\ServiceOption $idServiceOption)
    {
        $this->idServiceOption->removeElement($idServiceOption);
    }

    /**
     * Get idServiceOption
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceOption()
    {
        return $this->idServiceOption;
    }

    /**
     * Add idServiceTransactions
     *
     * @param \Etrali\GinangBundle\Entity\ServiceTransactions $idServiceTransactions
     * @return Service
     */
    public function addIdServiceTransaction(\Etrali\GinangBundle\Entity\ServiceTransactions $idServiceTransactions)
    {
        $this->idServiceTransactions[] = $idServiceTransactions;
    
        return $this;
    }

    /**
     * Remove idServiceTransactions
     *
     * @param \Etrali\GinangBundle\Entity\ServiceTransactions $idServiceTransactions
     */
    public function removeIdServiceTransaction(\Etrali\GinangBundle\Entity\ServiceTransactions $idServiceTransactions)
    {
        $this->idServiceTransactions->removeElement($idServiceTransactions);
    }

    /**
     * Get idServiceTransactions
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceTransactions()
    {
        return $this->idServiceTransactions;
    }

    /**
     * Set idTransactionStatus
     *
     * @param \Etrali\GinangBundle\Entity\TransactionStatus $idTransactionStatus
     * @return Service
     */
    public function setIdTransactionStatus(\Etrali\GinangBundle\Entity\TransactionStatus $idTransactionStatus = null)
    {
        $this->idTransactionStatus = $idTransactionStatus;
    
        return $this;
    }

    /**
     * Get idTransactionStatus
     *
     * @return \Etrali\GinangBundle\Entity\TransactionStatus 
     */
    public function getIdTransactionStatus()
    {
        return $this->idTransactionStatus;
    }

    /**
     * Set idTransactionType
     *
     * @param \Etrali\GinangBundle\Entity\TransactionType $idTransactionType
     * @return Service
     */
    public function setIdTransactionType(\Etrali\GinangBundle\Entity\TransactionType $idTransactionType = null)
    {
        $this->idTransactionType = $idTransactionType;
    
        return $this;
    }

    /**
     * Get idTransactionType
     *
     * @return \Etrali\GinangBundle\Entity\TransactionType 
     */
    public function getIdTransactionType()
    {
        return $this->idTransactionType;
    }

    /**
     * Set idTransferExtremity
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremity $idTransferExtremity
     * @return Service
     */
    public function setIdTransferExtremity(\Etrali\GinangBundle\Entity\ServiceExtremity $idTransferExtremity = null)
    {
        $this->idTransferExtremity = $idTransferExtremity;
    
        return $this;
    }

    /**
     * Get idTransferExtremity
     *
     * @return \Etrali\GinangBundle\Entity\ServiceExtremity 
     */
    public function getIdTransferExtremity()
    {
        return $this->idTransferExtremity;
    }

    /**
     * Set idSelectedExtremity
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremity $idSelectedExtremity
     * @return Service
     */
    public function setIdSelectedExtremity(\Etrali\GinangBundle\Entity\ServiceExtremity $idSelectedExtremity = null)
    {
        $this->idSelectedExtremity = $idSelectedExtremity;
    
        return $this;
    }

    /**
     * Get idSelectedExtremity
     *
     * @return \Etrali\GinangBundle\Entity\ServiceExtremity 
     */
    public function getIdSelectedExtremity()
    {
        return $this->idSelectedExtremity;
    }

    /**
     * Add idNote
     *
     * @param \Etrali\GinangBundle\Entity\Note $idNote
     * @return Service
     */
    public function addIdNote(\Etrali\GinangBundle\Entity\Note $idNote)
    {
        $this->idNote[] = $idNote;
    
        return $this;
    }

    /**
     * Remove idNote
     *
     * @param \Etrali\GinangBundle\Entity\Note $idNote
     */
    public function removeIdNote(\Etrali\GinangBundle\Entity\Note $idNote)
    {
        $this->idNote->removeElement($idNote);
    }

    /**
     * Get idNote
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdNote()
    {
        return $this->idNote;
    }

    /**
     * Set blValidated
     *
     * @param boolean $blValidated
     * @return Service
     */
    public function setBlValidated($blValidated)
    {
        $this->blValidated = $blValidated;
    
        return $this;
    }

    /**
     * Get blValidated
     *
     * @return boolean 
     */
    public function getBlValidated()
    {
        return $this->blValidated;
    }

    /**
     * Add idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     * @return Service
     */
    public function addIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine[] = $idBillingServiceLine;
    
        return $this;
    }

    /**
     * Remove idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     */
    public function removeIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine->removeElement($idBillingServiceLine);
    }

    /**
     * Get idBillingServiceLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingServiceLine()
    {
        return $this->idBillingServiceLine;
    }

    /**
     * Set blLlstatus
     *
     * @param boolean $blLlstatus
     * @return Service
     */
    public function setBlLlstatus($blLlstatus)
    {
        $this->blLlstatus = $blLlstatus;
    
        return $this;
    }

    /**
     * Get blLlstatus
     *
     * @return boolean 
     */
    public function getBlLlstatus()
    {
        return $this->blLlstatus;
    }

    /**
     * Set blBbstatus
     *
     * @param boolean $blBbstatus
     * @return Service
     */
    public function setBlBbstatus($blBbstatus)
    {
        $this->blBbstatus = $blBbstatus;
    
        return $this;
    }

    /**
     * Get blBbstatus
     *
     * @return boolean 
     */
    public function getBlBbstatus()
    {
        return $this->blBbstatus;
    }public function getParentBranch() { return NULL; }  
    /**
     * Add idServiceDevice
     *
     * @param \Etrali\GinangBundle\Entity\ServiceDevice $idServiceDevice
     * @return Service
     */
    public function addIdServiceDevice(\Etrali\GinangBundle\Entity\ServiceDevice $idServiceDevice)
    {
        $this->idServiceDevice[] = $idServiceDevice;
    
        return $this;
    }

    /**
     * Remove idServiceDevice
     *
     * @param \Etrali\GinangBundle\Entity\ServiceDevice $idServiceDevice
     */
    public function removeIdServiceDevice(\Etrali\GinangBundle\Entity\ServiceDevice $idServiceDevice)
    {
        $this->idServiceDevice->removeElement($idServiceDevice);
    }

    /**
     * Get idServiceDevice
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceDevice()
    {
        return $this->idServiceDevice;
    }

    /**
     * Set idSelectedDevice
     *
     * @param \Etrali\GinangBundle\Entity\ServiceDevice $idSelectedDevice
     * @return Service
     */
    public function setIdSelectedDevice(\Etrali\GinangBundle\Entity\ServiceDevice $idSelectedDevice = null)
    {
        $this->idSelectedDevice = $idSelectedDevice;
    
        return $this;
    }
 
    /**
     * Get idSelectedDevice
     *
     * @return \Etrali\GinangBundle\Entity\ServiceDevice 
     */
    public function getIdSelectedDevice()
    {
        return $this->idSelectedDevice;
    }


    /**
     * Set idTradExtraDatalinkGroup
     *
     * @param \Etrali\GinangBundle\Entity\TradExtraDatalinkGroup $idTradExtraDatalinkGroup
     * @return Service
     */
    public function setIdTradExtraDatalinkGroup(\Etrali\GinangBundle\Entity\TradExtraDatalinkGroup $idTradExtraDatalinkGroup = null)
    {
        $this->idTradExtraDatalinkGroup = $idTradExtraDatalinkGroup;
    
        return $this;
    }

    /**
     * Get idTradExtraDatalinkGroup
     *
     * @return \Etrali\GinangBundle\Entity\TradExtraDatalinkGroup 
     */
    public function getIdTradExtraDatalinkGroup()
    {
        return $this->idTradExtraDatalinkGroup;
    }

    /**
     * Set idBusinessConferenceGroup
     *
     * @param \Etrali\GinangBundle\Entity\BusinessConferenceGroup $idBusinessConferenceGroup
     * @return Service
     */
    public function setIdBusinessConferenceGroup(\Etrali\GinangBundle\Entity\BusinessConferenceGroup $idBusinessConferenceGroup = null)
    {
        $this->idBusinessConferenceGroup = $idBusinessConferenceGroup;
    
        return $this;
    }

    /**
     * Get idBusinessConferenceGroup
     *
     * @return \Etrali\GinangBundle\Entity\BusinessConferenceGroup 
     */
    public function getIdBusinessConferenceGroup()
    {
        return $this->idBusinessConferenceGroup;
    }

    /**
     * Add idTransferPrice
     *
     * @param \Etrali\GinangBundle\Entity\TransferPrice $idTransferPrice
     * @return Service
     */
    public function addIdTransferPrice(\Etrali\GinangBundle\Entity\TransferPrice $idTransferPrice)
    {
        $this->idTransferPrice[] = $idTransferPrice;
    
        return $this;
    }

    /**
     * Remove idTransferPrice
     *
     * @param \Etrali\GinangBundle\Entity\TransferPrice $idTransferPrice
     */
    public function removeIdTransferPrice(\Etrali\GinangBundle\Entity\TransferPrice $idTransferPrice)
    {
        $this->idTransferPrice->removeElement($idTransferPrice);
    }

    /**
     * Get idTransferPrice
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdTransferPrice()
    {
        return $this->idTransferPrice;
    }
    
    /**
     * 
     * @return boolean
     */
    public function isSplitBilling(){        
        $customer = null;      
        foreach ($this->idServiceExtremity as $serviceExtremity) {
            if($serviceExtremity->getBillingServiceActive() && $serviceExtremity->getBillingServiceActive()->getIdCustomer()){
                if(!$customer)
                    $customer = $serviceExtremity->getBillingServiceActive()->getIdCustomer()->getIdCustomer();
                else{
                    $customer2 = $serviceExtremity->getBillingServiceActive()->getIdCustomer()->getIdCustomer();
                    if($customer != $customer2)
                        return true;
                }
            }
        }
        
        return false;
    }
    

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Service
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}