<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * ServiceDevice
 *
 * @ORM\Table(name="service_device")
 * @ORM\Entity
 */
class ServiceDevice
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_service_device", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idServiceDevice;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_service_device", type="string", length=45, nullable=true)
     * @Assert\NotBlank()
     */
    private $cdServiceDevice;

    /**
     * @var string
     *
     * @ORM\Column(name="nb_serial", type="string", length=30, nullable=true)
     */
    private $nbSerial;
    
    /**
     * @var string
     *
     * @ORM\Column(name="lb_username", type="string", length=50, nullable=true)
     */
    private $lbUsername;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_init", type="datetime", nullable=true)
     */
    private $dtInit;
    
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_requested", type="datetime", nullable=true)
     */
    private $dtRequested;    

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_init_terminate", type="datetime", nullable=true)
     */
    private $dtInitTerminate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_real_terminate", type="datetime", nullable=true)
     */
    private $dtRealTerminate;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_inservice", type="datetime", nullable=true)
     */
    private $dtInservice;
  
    /**
     * @var \Service
     *
     * @ORM\ManyToOne(targetEntity="Service", inversedBy="idServiceDevice")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_service", referencedColumnName="id_service")
     * })
     */
    private $idService;

    /**
     * @var \ServiceDeviceType
     *
     * @ORM\ManyToOne(targetEntity="ServiceDeviceType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_service_device_type", referencedColumnName="id_service_device_type")
     * })
     * @Assert\NotNull()
     */
    private $idServiceDeviceType;
    
    /**
     * @var \BandwidthAssignee
     *
     * @ORM\ManyToOne(targetEntity="BandwidthAssignee")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_bandwidth", referencedColumnName="id_bandwidth_assignee")
     * })
     * @Assert\NotNull()
     */
    private $idBandwidth; 
    
    /**
     * 
     * @ORM\ManyToMany(targetEntity="BillingServiceLine", mappedBy="idServiceDevice") 
     */
    private $idBillingServiceLine;    
    
      /**
     * @var \TransferPrice
     *
     * @ORM\OneToOne(targetEntity="TransferPrice", mappedBy="idServiceDevice")
     */    
    private $idTransferPrice;      
    
    /**
     * 
     * @return string
     */ 
    public function __toString()
    {
        try
        {
            return $this->getCdServiceDevice()."";
        }
        catch (\ErrorException $e)
        {
            var_dump($e);
            return "";
        }        

    }

    public function getHeadInfo()
    {
            $retour= "<td >".$this->getCdServiceDevice()."</td><td>".$this->getIdBandwidth()."</td><td>";
            if ($this->getIdService()->canTerminateDevice() && $this->getDtRealTerminate()==NULL)
                $retour.="<button type='button' id='device_terminate_button' class='device_terminate_button btn btn-link' data-id='".$this->getIdServiceDevice()."'><i class='icones_actions_cloture'></i></button>";
            $retour.="</td>";            
            return $retour;
    }  
    
    public function getHeadColumns()
    {
           $retour= "<th>Device ref</th><th>Bandwidth</th>";            
           $retour.="<th></th>";
            return $retour;
    } 
 
    
    public function getEditType($type)
    {
        $idtrans=$this->getIdService()->getIdTransactionStatus()->getIdTransactionStatus();
        $idtype=$this->getIdService()->getIdTransactionType()->getIdTransactionType();        
        $type->setTransaction($idtype,$idtrans);  
        $type->setOld(false);
        $type->setTransfer(false);        
        $type->setObject($this);          
        return $type;
    }
    
    
    
    /**
     * Get cdServiceDevice
     *
     * @return string 
     */
    public function getCdServiceDevice()
    {
       try
        {
            if ($this->getIdService()->getIdProduct()==NULL)
                return $this->cdServiceDevice;
            else
            {
                $prodcd="FTU";
                $cpt=0;
                $Aend="";
                $Bend="";
                $extr=$this->getIdService()->getIdServiceExtremity()->first();
                if ($extr->getIdServiceExtremityOwner()!=NULL)
                {
                    switch ($extr->getIdServiceExtremityOwner()->getIdLocalLoopExtremityOwner())
                    {
                        case 1:
                            if ($extr->getIdCustomer()!=NULL && $extr->getIdDeliveryAddress()!=NULL && $extr->getIdDeliveryAddress()->getIdCity()!=NULL)
                                $Aend=$extr->getIdDeliveryAddress()->getIdCity()->getCdCity();
                            break;
                        case 2:
                            if ($extr->getIdPop()!=NULL && $extr->getIdAddressPop()!=NULL && $extr->getIdAddressPop()->getIdCity()!=NULL)
                                $Aend=$extr->getIdAddressPop()->getIdCity()->getCdCity();
                            break;
                        case 3:
                            if ($extr->getIdProvider()!=NULL && $extr->getIdAddressProvider()!=NULL && $extr->getIdAddressProvider()->getIdCity()!=NULL)
                                $Aend=$extr->getIdAddressProvider()->getIdCity()->getCdCity();
                            break;                                    
                    }
                }                

                return $prodcd.$Aend.$this->getIdService().substr($this->cdServiceDevice,0,1);
            }
        }
        catch (Exception $e)
        {
            var_dump($e);
            return "";
        }              
    }
    
    /**
     * 
     * @return Branch
     */
    public function getParentBranch() {
        if($this->getIdService()!=null)
            return $this->getIdService()->getIdBranch();
        return NULL;
    }
    
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idServiceCaracs = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idBillingServiceLine = new \Doctrine\Common\Collections\ArrayCollection();
        $this->idBillingOneShot = new \Doctrine\Common\Collections\ArrayCollection();
    }
    


    /**
     * Get idServiceDevice
     *
     * @return integer 
     */
    public function getIdServiceDevice()
    {
        return $this->idServiceDevice;
    }

    /**
     * Set cdServiceDevice
     *
     * @param string $cdServiceDevice
     * @return ServiceDevice
     */
    public function setCdServiceDevice($cdServiceDevice)
    {
        $this->cdServiceDevice = $cdServiceDevice;
    
        return $this;
    }

    /**
     * Set nbSerial
     *
     * @param string $nbSerial
     * @return ServiceDevice
     */
    public function setNbSerial($nbSerial)
    {
        $this->nbSerial = $nbSerial;
    
        return $this;
    }

    /**
     * Get nbSerial
     *
     * @return string 
     */
    public function getNbSerial()
    {
        return $this->nbSerial;
    }

    /**
     * Set lbUsername
     *
     * @param string $lbUsername
     * @return ServiceDevice
     */
    public function setLbUsername($lbUsername)
    {
        $this->lbUsername = $lbUsername;
    
        return $this;
    }

    /**
     * Get lbUsername
     *
     * @return string 
     */
    public function getLbUsername()
    {
        return $this->lbUsername;
    }

    /**
     * Set dtInit
     *
     * @param \DateTime $dtInit
     * @return ServiceDevice
     */
    public function setDtInit($dtInit)
    {
        $this->dtInit = $dtInit;
    
        return $this;
    }

    /**
     * Get dtInit
     *
     * @return \DateTime 
     */
    public function getDtInit()
    {
        return $this->dtInit;
    }

    /**
     * Set dtRequested
     *
     * @param \DateTime $dtRequested
     * @return ServiceDevice
     */
    public function setDtRequested($dtRequested)
    {
        $this->dtRequested = $dtRequested;
    
        return $this;
    }

    /**
     * Get dtRequested
     *
     * @return \DateTime 
     */
    public function getDtRequested()
    {
        return $this->dtRequested;
    }

    /**
     * Set dtInitTerminate
     *
     * @param \DateTime $dtInitTerminate
     * @return ServiceDevice
     */
    public function setDtInitTerminate($dtInitTerminate)
    {
        $this->dtInitTerminate = $dtInitTerminate;
    
        return $this;
    }

    /**
     * Get dtInitTerminate
     *
     * @return \DateTime 
     */
    public function getDtInitTerminate()
    {
        return $this->dtInitTerminate;
    }

    /**
     * Set dtRealTerminate
     *
     * @param \DateTime $dtRealTerminate
     * @return ServiceDevice
     */
    public function setDtRealTerminate($dtRealTerminate)
    {
        $this->dtRealTerminate = $dtRealTerminate;
    
        return $this;
    }

    /**
     * Get dtRealTerminate
     *
     * @return \DateTime 
     */
    public function getDtRealTerminate()
    {
        return $this->dtRealTerminate;
    }

    /**
     * Set dtInservice
     *
     * @param \DateTime $dtInservice
     * @return ServiceDevice
     */
    public function setDtInservice($dtInservice)
    {
        $this->dtInservice = $dtInservice;
    
        return $this;
    }

    /**
     * Get dtInservice
     *
     * @return \DateTime 
     */
    public function getDtInservice()
    {
        return $this->dtInservice;
    }

    /**
     * Set idService
     *
     * @param \Etrali\GinangBundle\Entity\Service $idService
     * @return ServiceDevice
     */
    public function setIdService(\Etrali\GinangBundle\Entity\Service $idService = null)
    {
        $this->idService = $idService;
    
        return $this;
    }

    /**
     * Get idService
     *
     * @return \Etrali\GinangBundle\Entity\Service 
     */
    public function getIdService()
    {
        return $this->idService;
    }

    /**
     * Set idServiceDeviceType
     *
     * @param \Etrali\GinangBundle\Entity\ServiceDeviceType $idServiceDeviceType
     * @return ServiceDevice
     */
    public function setIdServiceDeviceType(\Etrali\GinangBundle\Entity\ServiceDeviceType $idServiceDeviceType = null)
    {
        $this->idServiceDeviceType = $idServiceDeviceType;
    
        return $this;
    }

    /**
     * Get idServiceDeviceType
     *
     * @return \Etrali\GinangBundle\Entity\ServiceDeviceType 
     */
    public function getIdServiceDeviceType()
    {
        return $this->idServiceDeviceType;
    }

    /**
     * Set idBandwidth
     *
     * @param \Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidth
     * @return ServiceDevice
     */
    public function setIdBandwidth(\Etrali\GinangBundle\Entity\BandwidthAssignee $idBandwidth = null)
    {
        $this->idBandwidth = $idBandwidth;
    
        return $this;
    }

    /**
     * Get idBandwidth
     *
     * @return \Etrali\GinangBundle\Entity\BandwidthAssignee 
     */
    public function getIdBandwidth()
    {
        return $this->idBandwidth;
    }

    /**
     * Add idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     * @return ServiceDevice
     */
    public function addIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine[] = $idBillingServiceLine;
    
        return $this;
    }

    /**
     * Remove idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     */
    public function removeIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine->removeElement($idBillingServiceLine);
    }

    /**
     * Get idBillingServiceLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingServiceLine()
    {
        return $this->idBillingServiceLine;
    }

    /**
     * Set idTransferPrice
     *
     * @param \Etrali\GinangBundle\Entity\TransferPrice $idTransferPrice
     * @return ServiceDevice
     */
    public function setIdTransferPrice(\Etrali\GinangBundle\Entity\TransferPrice $idTransferPrice = null)
    {
        $this->idTransferPrice = $idTransferPrice;
    
        return $this;
    }

    /**
     * Get idTransferPrice
     *
     * @return \Etrali\GinangBundle\Entity\TransferPrice 
     */
    public function getIdTransferPrice()
    {
        return $this->idTransferPrice;
    }
}