<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * ServiceExtremityTech
 *
 * @ORM\Table(name="service_extremity_tech")
 * @ORM\Entity
 */
class ServiceExtremityTech
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_service_extremity_tech", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idServiceExtremityTech;

    /**
     * @var string
     *
     * @ORM\Column(name="cm_comment", type="text", nullable=true)
     */
    private $cmComment;


    /**
     * @var \Contact
     *
     * @ORM\ManyToOne(targetEntity="Contact")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_technical_contact", referencedColumnName="id_contact")
     * })
     */
    private $idTechnicalContact;
    
    /**
     * @var \ContactProvider
     *
     * @ORM\ManyToOne(targetEntity="ContactProvider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_technical_contact_provider", referencedColumnName="id_contact_provider")
     * })
     */
    private $idTechnicalContactProvider; 
    
    /**
     * @var \ContactPop
     *
     * @ORM\ManyToOne(targetEntity="ContactPop")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_technical_contact_pop", referencedColumnName="id_contact_pop")
     * })
     */
    private $idTechnicalContactPop;  
    

    /**
     * @var \Service
     *
     * @ORM\ManyToOne(targetEntity="Service", inversedBy="idServiceExtremityTech")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_service", referencedColumnName="id_service")
     * })
     */    
    private $idService;
    
    /**
     * @var \ServiceExtremity
     *
     * @ORM\OneToOne(targetEntity="ServiceExtremity", inversedBy="idServiceExtremityTech")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_service_extremity", referencedColumnName="id_service_extremity")
     * })
     */    
    private $idServiceExtremity; 
    
    /**
     * @var \Customer
     *
     * @ORM\ManyToOne(targetEntity="Customer")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_customer", referencedColumnName="id_customer")
     * })
     */
    private $idCustomer;
    
    /**
     * @var \Provider
     *
     * @ORM\ManyToOne(targetEntity="Provider")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_provider", referencedColumnName="id_provider")
     * })
     */
    private $idProvider;
    
    /**
     * @var \Pop
     *
     * @ORM\ManyToOne(targetEntity="Pop")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_pop", referencedColumnName="id_pop")
     * })
     */
    private $idPop;
    
    /**
     * @var \LocalLoopExtremityOwner
     *
     * @ORM\ManyToOne(targetEntity="LocalLoopExtremityOwner")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_service_extremity_owner", referencedColumnName="id_local_loop_extremity_owner")
     * })
     */
    private $idServiceExtremityOwner;   
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_old", type="boolean", nullable=true)
     */
    private $blOld=false; 
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_transferred", type="boolean", nullable=true)
     */
    private $blTransferred=false;      
    
    
    /**
     * @var \ServiceCaracs
     *
     * @ORM\OneToMany(targetEntity="ServiceCaracs", mappedBy="idServiceExtremityTech",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idServiceCaracs" = "asc"})         
     */
    private $idServiceCaracs;  
    
    /**
     * @var \ServiceExtremityTech
     *
     * @ORM\OneToOne(targetEntity="ServiceExtremityTech")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_old_service_extremity_tech", referencedColumnName="id_service_extremity_tech")
     * })
     */    
    private $idOldServiceExtremityTech;     
    
    /**
     * @var \LocalLoop
     *
     * @ORM\ManyToOne(targetEntity="LocalLoop", inversedBy="idServiceExtremityTech")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_local_loop", referencedColumnName="id_local_loop")
     * })
     */
    private $idLocalLoop;     
    
    
    
    /**
     * @var \Ts
     *
     * @ORM\OneToMany(targetEntity="Ts",mappedBy="idServiceExtremityTech",cascade={"persist","remove"}, orphanRemoval=true)
     */
    private $idTs;
    
        /**
     * @var \Vlan
     *
     * @ORM\OneToOne(targetEntity="Vlan", inversedBy="idServiceExtremityTech")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_vlan", referencedColumnName="id_vlan")
     * })
     */
    private $idVlan;    
    
    /**
     * @var \PortInstance
     *
     * @ORM\ManyToOne(targetEntity="PortInstance", inversedBy="idServiceExtremityTech")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_port_instance", referencedColumnName="id_port_instance")
     * })
     */
    private $idPortInstance;   
    
    
    /**
     * @var string
     *
     * @ORM\Column(name="id_connection_path", type="string", length=1000, nullable=true)
     */
    private $idConnectionPath;
    
    /**
     * @var \LocalLoopExtremityAdditional
     *
     * @ORM\OneToMany(targetEntity="LocalLoopExtremityAdditional", mappedBy="idServiceExtremityTech",cascade={"persist","remove"}, orphanRemoval=true )  
     * @ORM\OrderBy({"idLocalLoopExtremityAdditional" = "asc"})         
     */
    private $idLocalLoopExtremityAdditional;

    public function __toString() {
        return ($this->getIdServiceExtremity()!=NULL?$this->getIdServiceExtremity():"")."";
    }
    
    public function getHeadInfo()
    {
        $lbparent="";
      
        if ($this->getIdServiceExtremityOwner()!=NULL)
        {          
            switch ($this->getIdServiceExtremity()->getIdServiceExtremityOwner()->getIdLocalLoopExtremityOwner())
            {
                case 1:
                    $lbparent=$this->getIdServiceExtremity()->getIdCustomer()!=NULL?$this->getIdServiceExtremity()->getIdCustomer():"";                              
                break;
                case 2:
                    $lbparent=$this->getIdServiceExtremity()->getIdPop()!=NULL?$this->getIdServiceExtremity()->getIdPop():""; 
                break;
                case 3:
                    $lbparent=$this->getIdServiceExtremity()->getIdProvider()!=NULL?$this->getIdServiceExtremity()->getIdProvider():"";                                              
                break;        
            }    
        }
            $path=$this->getIdPortInstance()!=NULL?\Etrali\GinangBundle\EtraliGinangBundle::getUnlinkedConnectionPath($this->getIdConnectionPath(), $this->getIdPortInstance()):"";
            return "<td>".$this->getIdServiceExtremity()->getCdServiceExtremity()."</td><td>".$lbparent."</td><td>".$path."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Extremity Ref</th><th>Customer/Provider/Pop</th><th>Incoming connection path</th>";
    } 
    
    public function hasTsByNumber($number)
    {
        foreach ($this->getIdTs() as $bbts) {
            if ($bbts->getNbTs() == $number)
                return true;
        }
        return false;
    }
        
   
    
    public function getCdPipeId()
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==30)
                return $carac->getValeur();
        }
        return NULL;
    } 
    
    public function getDtBackboneProgram()
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==31)
                return $carac->getValeur();
        }
        return NULL;
    }    

    public function retreiveTechnicalRoute()
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==42 && $carac->getValeur()!=NULL)
                return $carac->getValeur();
        }
        return NULL;
    }      
    
    public function setTechnicalRoute($idRoute)
    {
        foreach ($this->getIdServiceCaracs() as $carac)
        {
            if ($carac->getIdProductCaracs()->getIdProductCaracs()==42)
                $carac->setValeur($idRoute);
        }
    }    
        

    public function hasDtEndToEnd()
    {
            foreach ($this->getIdServiceCaracs() as $carac)
            {
                if ($carac->getIdProductCaracs()->getIdProductCaracs()==32 && $carac->getValeur()!=NULL)
                    return true;
            }
            return false;
    }
    
    /**
     * 
     * @return null
     */
    public function getDtEndToEnd()
    {
            foreach ($this->getIdServiceCaracs() as $carac)
            {
                if ($carac->getIdProductCaracs()->getIdProductCaracs()==32)
                    return $carac->getValeur();
            }
            return null;
    }
    
    /**
     * This method is here to make your life better, so overwrite  it
     *
     * @param \Symfony\Component\Form\Form $form the valid form
     */
    public function preSave(\Symfony\Component\Form\Form $form,$em)
    {    
        foreach ($this->getIdLocalLoopExtremityAdditional() as $extradd)
            $extradd->setIdServiceExtremityTech($this);
        foreach ($this->getIdServiceCaracs() as $service_carac)
        {
            if ($service_carac->getIdProductCaracs()->getNbLocation()==2 && isset($form[$service_carac->getIdProductCaracs()->getLbField()]))
            {
                if (is_object($form[$service_carac->getIdProductCaracs()->getLbField()]->getData()) && substr(get_class($form[$service_carac->getIdProductCaracs()->getLbField()]->getData()),0,27)=="Etrali\\GinangBundle\\Entity\\")
                {
                    $getter="get".ucfirst($service_carac->getIdProductCaracs()->getLbField());
                    if (method_exists($form[$service_carac->getIdProductCaracs()->getLbField()]->getData(),$getter ))
                        $service_carac->setValeur($form[$service_carac->getIdProductCaracs()->getLbField()]->getData()->$getter());
                    else
                        $service_carac->setValeur($form[$service_carac->getIdProductCaracs()->getLbField()]->getData()->getId());    
                    
                    /** handle connected services * /
                     * 
                     */
                    $connected=array(44,46,47,48,49,50);
                    if (in_array($service_carac->getIdProductCaracs()->getIdProductCaracs(),$connected))
                    {
                        $this->getIdService()->addIdParentService($form[$service_carac->getIdProductCaracs()->getLbField()]->getData());
                    }                       
                }                    
                else if ($form[$service_carac->getIdProductCaracs()->getLbField()]->getData() instanceof \Datetime)
                    $service_carac->setValeur($form[$service_carac->getIdProductCaracs()->getLbField()]->getData()->format("Y-m-d H:i:s"));
                else
                    $service_carac->setValeur($form[$service_carac->getIdProductCaracs()->getLbField()]->getData());
            }
        } 
        $em->persist($this->getIdService());
        $em->flush();        
    }
    
    /**
     * This method is here to make your life better, so overwrite  it
     *
     * @param \Symfony\Component\Form\Form $form the valid form
     */
    public function postSave(\Symfony\Component\Form\Form $form,$em)
    {
        if ($this->getIdConnectionPath() != NULL && $this->getIdConnectionPath()!="")
        {
            if (strpos($this->getIdConnectionPath(),"/vlan:")!==FALSE)
            {
                $tab=explode("/",$this->getIdConnectionPath());
                $tab2=explode(":",$tab[0]);
                $portid=$tab2[1];
                
                $tab2=explode(":",$tab[1]);
                $vlanref=$tab2[1];
                
                if ($this->getIdVlan()->getLbVlan()!=$vlanref)
                {
                    $PortInstance=$em->getRepository('EtraliGinangBundle:PortInstance')->find($portid);
                    $vlan=new Vlan();
                    $vlan->setIdPortInstance($PortInstance);
                    $vlan->setLbVlan($vlanref);
                    $vlan->setIdServiceExtremityTech($this);
                    $em->persist($vlan);
                }                
            }
            else if (strpos($this->getIdConnectionPath(),"/timeslot:")!==FALSE)
            {
                $tab=explode("/",$this->getIdConnectionPath());
                $tab2=explode(":",$tab[0]);
                $portid=$tab2[1];
                
                $tab2=explode(":",$tab[1]);
                $ts=$tab2[1];
                
                $timeslots=explode(",",$ts);
                
                $PortInstance=$em->getRepository('EtraliGinangBundle:PortInstance')->find($portid);
                foreach ($timeslots as $timeslot)
                {
                        $portts=$PortInstance->getTsByNumber($timeslot);                        
                        $portts->setIdServiceExtremityTech($this);
                }
                $em->persist($portts);                                
            }
            else 
            {
                $tab=explode(":",$this->getIdConnectionPath());
                $portid=$tab[1];
                
                $PortInstance=$em->getRepository('EtraliGinangBundle:PortInstance')->find($portid);

                $this->setIdPortInstance($PortInstance);
                $em->persist(ServiceExtremityTech);
            }            
        }
      
        foreach ($this->getIdServiceCaracs() as $service_carac)
        {
            $em->persist($service_carac);
        }        
        $em->flush();
    }    

    public function getEditType($type)
    {
        $idtrans=$this->getIdService()->getIdTransactionStatus()->getIdTransactionStatus();
        $idtype=$this->getIdService()->getIdTransactionType()->getIdTransactionType();        
        $type->setTransaction($idtype,$idtrans);  
        $type->setOld($this->getIdService()->getIdTransferExtremity()!=NULL &&  $this->getIdService()->getIdTransferExtremity()->getIdOldExtremity()!=NULL && $this->getIdService()->getIdTransferExtremity()->getIdOldExtremity()->getIdServiceExtremity()==$this->getIdServiceExtremity()->getIdServiceExtremity());        
        $type->setTransfer($this->getIdService()->getIdTransferExtremity()!=NULL &&  $this->getIdService()->getIdTransferExtremity()->getIdServiceExtremity()==$this->getIdServiceExtremity()->getIdServiceExtremity());                
        $type->setObject($this); 
        return $type;
    }

    /**
     * 
     * @return Branch
     */
    public function getParentBranch() {
        if($this->getIdService()!=null)
            return $this->getIdService()->getIdBranch();
        return NULL;
    }
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idServiceCaracs = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idServiceExtremityTech
     *
     * @return integer 
     */
    public function getIdServiceExtremityTech()
    {
        return $this->idServiceExtremityTech;
    }

    /**
     * Set cmComment
     *
     * @param string $cmComment
     * @return ServiceExtremityTech
     */
    public function setCmComment($cmComment)
    {
        $this->cmComment = $cmComment;
    
        return $this;
    }

    /**
     * Get cmComment
     *
     * @return string 
     */
    public function getCmComment()
    {
        return $this->cmComment;
    }

    /**
     * Set blOld
     *
     * @param boolean $blOld
     * @return ServiceExtremityTech
     */
    public function setBlOld($blOld)
    {
        $this->blOld = $blOld;
    
        return $this;
    }

    /**
     * Get blOld
     *
     * @return boolean 
     */
    public function getBlOld()
    {
        return $this->blOld;
    }

    /**
     * Set blTransferred
     *
     * @param boolean $blTransferred
     * @return ServiceExtremityTech
     */
    public function setBlTransferred($blTransferred)
    {
        $this->blTransferred = $blTransferred;
    
        return $this;
    }

    /**
     * Get blTransferred
     *
     * @return boolean 
     */
    public function getBlTransferred()
    {
        return $this->blTransferred;
    }

    /**
     * Set idTechnicalContact
     *
     * @param \Etrali\GinangBundle\Entity\Contact $idTechnicalContact
     * @return ServiceExtremityTech
     */
    public function setIdTechnicalContact(\Etrali\GinangBundle\Entity\Contact $idTechnicalContact = null)
    {
        $this->idTechnicalContact = $idTechnicalContact;
    
        return $this;
    }

    /**
     * Get idTechnicalContact
     *
     * @return \Etrali\GinangBundle\Entity\Contact 
     */
    public function getIdTechnicalContact()
    {
        return $this->idTechnicalContact;
    }

    /**
     * Set idTechnicalContactProvider
     *
     * @param \Etrali\GinangBundle\Entity\ContactProvider $idTechnicalContactProvider
     * @return ServiceExtremityTech
     */
    public function setIdTechnicalContactProvider(\Etrali\GinangBundle\Entity\ContactProvider $idTechnicalContactProvider = null)
    {
        $this->idTechnicalContactProvider = $idTechnicalContactProvider;
    
        return $this;
    }

    /**
     * Get idTechnicalContactProvider
     *
     * @return \Etrali\GinangBundle\Entity\ContactProvider 
     */
    public function getIdTechnicalContactProvider()
    {
        return $this->idTechnicalContactProvider;
    }

    /**
     * Set idTechnicalContactPop
     *
     * @param \Etrali\GinangBundle\Entity\ContactPop $idTechnicalContactPop
     * @return ServiceExtremityTech
     */
    public function setIdTechnicalContactPop(\Etrali\GinangBundle\Entity\ContactPop $idTechnicalContactPop = null)
    {
        $this->idTechnicalContactPop = $idTechnicalContactPop;
    
        return $this;
    }

    /**
     * Get idTechnicalContactPop
     *
     * @return \Etrali\GinangBundle\Entity\ContactPop 
     */
    public function getIdTechnicalContactPop()
    {
        return $this->idTechnicalContactPop;
    }

    /**
     * Set idService
     *
     * @param \Etrali\GinangBundle\Entity\Service $idService
     * @return ServiceExtremityTech
     */
    public function setIdService(\Etrali\GinangBundle\Entity\Service $idService = null)
    {
        $this->idService = $idService;
    
        return $this;
    }

    /**
     * Get idService
     *
     * @return \Etrali\GinangBundle\Entity\Service 
     */
    public function getIdService()
    {
        return $this->idService;
    }

    /**
     * Set idServiceExtremity
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremity $idServiceExtremity
     * @return ServiceExtremityTech
     */
    public function setIdServiceExtremity(\Etrali\GinangBundle\Entity\ServiceExtremity $idServiceExtremity = null)
    {
        $this->idServiceExtremity = $idServiceExtremity;
    
        return $this;
    }

    /**
     * Get idServiceExtremity
     *
     * @return \Etrali\GinangBundle\Entity\ServiceExtremity 
     */
    public function getIdServiceExtremity()
    {
        return $this->idServiceExtremity;
    }

    /**
     * Set idCustomer
     *
     * @param \Etrali\GinangBundle\Entity\Customer $idCustomer
     * @return ServiceExtremityTech
     */
    public function setIdCustomer(\Etrali\GinangBundle\Entity\Customer $idCustomer = null)
    {
        $this->idCustomer = $idCustomer;
    
        return $this;
    }

    /**
     * Get idCustomer
     *
     * @return \Etrali\GinangBundle\Entity\Customer 
     */
    public function getIdCustomer()
    {
        return $this->idCustomer;
    }

    /**
     * Set idProvider
     *
     * @param \Etrali\GinangBundle\Entity\Provider $idProvider
     * @return ServiceExtremityTech
     */
    public function setIdProvider(\Etrali\GinangBundle\Entity\Provider $idProvider = null)
    {
        $this->idProvider = $idProvider;
    
        return $this;
    }

    /**
     * Get idProvider
     *
     * @return \Etrali\GinangBundle\Entity\Provider 
     */
    public function getIdProvider()
    {
        return $this->idProvider;
    }

    /**
     * Set idPop
     *
     * @param \Etrali\GinangBundle\Entity\Pop $idPop
     * @return ServiceExtremityTech
     */
    public function setIdPop(\Etrali\GinangBundle\Entity\Pop $idPop = null)
    {
        $this->idPop = $idPop;
    
        return $this;
    }

    /**
     * Get idPop
     *
     * @return \Etrali\GinangBundle\Entity\Pop 
     */
    public function getIdPop()
    {
        return $this->idPop;
    }

    /**
     * Set idServiceExtremityOwner
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityOwner $idServiceExtremityOwner
     * @return ServiceExtremityTech
     */
    public function setIdServiceExtremityOwner(\Etrali\GinangBundle\Entity\LocalLoopExtremityOwner $idServiceExtremityOwner = null)
    {
        $this->idServiceExtremityOwner = $idServiceExtremityOwner;
    
        return $this;
    }

    /**
     * Get idServiceExtremityOwner
     *
     * @return \Etrali\GinangBundle\Entity\LocalLoopExtremityOwner 
     */
    public function getIdServiceExtremityOwner()
    {
        return $this->idServiceExtremityOwner;
    }

    /**
     * Add idServiceCaracs
     *
     * @param \Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs
     * @return ServiceExtremityTech
     */
    public function addIdServiceCarac(\Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs)
    {
        $this->idServiceCaracs[] = $idServiceCaracs;
    
        return $this;
    }

    /**
     * Remove idServiceCaracs
     *
     * @param \Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs
     */
    public function removeIdServiceCarac(\Etrali\GinangBundle\Entity\ServiceCaracs $idServiceCaracs)
    {
        $this->idServiceCaracs->removeElement($idServiceCaracs);
    }

    /**
     * Get idServiceCaracs
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdServiceCaracs()
    {
        return $this->idServiceCaracs;
    }

    /**
     * Set idOldServiceExtremityTech
     *
     * @param \Etrali\GinangBundle\Entity\ServiceExtremityTech $idOldServiceExtremityTech
     * @return ServiceExtremityTech
     */
    public function setIdOldServiceExtremityTech(\Etrali\GinangBundle\Entity\ServiceExtremityTech $idOldServiceExtremityTech = null)
    {
        $this->idOldServiceExtremityTech = $idOldServiceExtremityTech;
    
        return $this;
    }

    /**
     * Get idOldServiceExtremityTech
     *
     * @return \Etrali\GinangBundle\Entity\ServiceExtremityTech 
     */
    public function getIdOldServiceExtremityTech()
    {
        return $this->idOldServiceExtremityTech;
    }

    /**
     * Set idLocalLoop
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoop $idLocalLoop
     * @return ServiceExtremityTech
     */
    public function setIdLocalLoop(\Etrali\GinangBundle\Entity\LocalLoop $idLocalLoop = null)
    {
        $this->idLocalLoop = $idLocalLoop;
    
        return $this;
    }

    /**
     * Get idLocalLoop
     *
     * @return \Etrali\GinangBundle\Entity\LocalLoop 
     */
    public function getIdLocalLoop()
    {
        return $this->idLocalLoop;
    }



    /**
     * Set idTs
     *
     * @param \Etrali\GinangBundle\Entity\Ts $idTs
     * @return ServiceExtremityTech
     */
    public function setIdTs(\Etrali\GinangBundle\Entity\Ts $idTs = null)
    {
        $this->idTs = $idTs;
    
        return $this;
    }

    /**
     * Get idTs
     *
     * @return \Etrali\GinangBundle\Entity\Ts 
     */
    public function getIdTs()
    {
        return $this->idTs;
    }

    /**
     * Set idVlan
     *
     * @param \Etrali\GinangBundle\Entity\Vlan $idVlan
     * @return ServiceExtremityTech
     */
    public function setIdVlan(\Etrali\GinangBundle\Entity\Vlan $idVlan = null)
    {
        $this->idVlan = $idVlan;
    
        return $this;
    }

    /**
     * Get idVlan
     *
     * @return \Etrali\GinangBundle\Entity\Vlan 
     */
    public function getIdVlan()
    {
        return $this->idVlan;
    }

    /**
     * Set idPortInstance
     *
     * @param \Etrali\GinangBundle\Entity\PortInstance $idPortInstance
     * @return ServiceExtremityTech
     */
    public function setIdPortInstance(\Etrali\GinangBundle\Entity\PortInstance $idPortInstance = null)
    {
        $this->idPortInstance = $idPortInstance;
    
        return $this;
    }

    /**
     * Get idPortInstance
     *
     * @return \Etrali\GinangBundle\Entity\PortInstance 
     */
    public function getIdPortInstance()
    {
        return $this->idPortInstance;
    }

    /**
     * Set idConnection
     *
     * @param string $idConnection
     * @return ServiceExtremityTech
     */
    public function setIdConnection($idConnection)
    {
        $this->idConnection = $idConnection;
    
        return $this;
    }

    /**
     * Get idConnection
     *
     * @return string 
     */
    public function getIdConnection()
    {
        return $this->idConnection;
    }

    /**
     * Set idConnectionPath
     *
     * @param string $idConnectionPath
     * @return ServiceExtremityTech
     */
    public function setIdConnectionPath($idConnectionPath)
    {
        $this->idConnectionPath = $idConnectionPath;
    
        return $this;
    }

    /**
     * Get idConnectionPath
     *
     * @return string 
     */
    public function getIdConnectionPath()
    {
        return $this->idConnectionPath;
    }

    /**
     * Add idTs
     *
     * @param \Etrali\GinangBundle\Entity\Ts $idTs
     * @return ServiceExtremityTech
     */
    public function addIdT(\Etrali\GinangBundle\Entity\Ts $idTs)
    {
        $this->idTs[] = $idTs;
    
        return $this;
    }

    /**
     * Remove idTs
     *
     * @param \Etrali\GinangBundle\Entity\Ts $idTs
     */
    public function removeIdT(\Etrali\GinangBundle\Entity\Ts $idTs)
    {
        $this->idTs->removeElement($idTs);
    }

    /**
     * Add idLocalLoopExtremityAdditional
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional
     * @return ServiceExtremityTech
     */
    public function addIdLocalLoopExtremityAdditional(\Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional)
    {
        $this->idLocalLoopExtremityAdditional[] = $idLocalLoopExtremityAdditional;
    
        return $this;
    }

    /**
     * Remove idLocalLoopExtremityAdditional
     *
     * @param \Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional
     */
    public function removeIdLocalLoopExtremityAdditional(\Etrali\GinangBundle\Entity\LocalLoopExtremityAdditional $idLocalLoopExtremityAdditional)
    {
        $this->idLocalLoopExtremityAdditional->removeElement($idLocalLoopExtremityAdditional);
    }

    /**
     * Get idLocalLoopExtremityAdditional
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdLocalLoopExtremityAdditional()
    {
        return $this->idLocalLoopExtremityAdditional;
    }
}