<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * ServiceOption
 *
 * @ORM\Table(name="service_option")
 * @ORM\Entity
 */
class ServiceOption
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_service_option", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idServiceOption;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_option", type="string", nullable=true)
     * @Assert\NotBlank()
     */
    private $cdOption;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_option", type="string", nullable=true)
     */
    private $lbOption;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="nb_quantity", type="integer", nullable=false)
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Quantity can not be zero")  * 
     */
    private $nbQuantity;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create") 
     * @ORM\Column(name="dt_create", type="datetime", nullable=false)
     */
    private $dtCreate;

    /**
     * @var \DateTime
     *
     * @Gedmo\Timestampable(on="update")     
     * @ORM\Column(name="dt_update", type="datetime", nullable=true)
     */
    private $dtUpdate;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_billable", type="boolean", nullable=false)
     */
    private $blBillable=true;    

    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=false)
     */
    private $blDeactivated=true;

    /**
     * @var \OptionType
     *
     * @ORM\ManyToOne(targetEntity="OptionType")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_option_type", referencedColumnName="id_option_type")
     * })
     */
    private $idOptionType;

    /**
     * @var \Service
     *
     * @ORM\ManyToOne(targetEntity="Service",inversedBy="idServiceOption")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_service", referencedColumnName="id_service")
     * })
     */
    private $idService;

    /**
     * @var \BillingServiceLine
     *
     * @ORM\OneToMany(targetEntity="BillingServiceLine", mappedBy="idServiceOption",cascade={"persist","remove"})  
     * @ORM\OrderBy({"idBillingServiceLine" = "asc"})         
     */
    private $idBillingServiceLine;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;     
    
   public function __toString()
    {
        return $this->getCdOption().":".$this->getLbOption();
    }
    
    

    public function getHeadInfo()
    {
            return "<td>".$this->getCdOption()."</td><td >".$this->getLbOption()."</td><td >".$this->getNbQuantity()."</td>";
    }  
    
    public function getHeadColumns()
    {
            return "<th>Ref</th><th>Description</th><th>Quantity</th>";
    }   

    /**
     * Get idServiceOptions
     *
     * @return integer 
     */
    public function getIdServiceOptions()
    {
        return $this->idServiceOptions;
    }

    /**
     * Set nbQuantity
     *
     * @param integer $nbQuantity
     * @return ServiceOption
     */
    public function setNbQuantity($nbQuantity)
    {
        $this->nbQuantity = $nbQuantity;
    
        return $this;
    }

    /**
     * Get nbQuantity
     *
     * @return integer 
     */
    public function getNbQuantity()
    {
        return $this->nbQuantity;
    }

    /**
     * Set dtCreate
     *
     * @param \DateTime $dtCreate
     * @return ServiceOption
     */
    public function setDtCreate($dtCreate)
    {
        $this->dtCreate = $dtCreate;
    
        return $this;
    }

    /**
     * Get dtCreate
     *
     * @return \DateTime 
     */
    public function getDtCreate()
    {
        return $this->dtCreate;
    }

    /**
     * Set dtUpdate
     *
     * @param \DateTime $dtUpdate
     * @return ServiceOption
     */
    public function setDtUpdate($dtUpdate)
    {
        $this->dtUpdate = $dtUpdate;
    
        return $this;
    }

    /**
     * Get dtUpdate
     *
     * @return \DateTime 
     */
    public function getDtUpdate()
    {
        return $this->dtUpdate;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return ServiceOption
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set idOptionType
     *
     * @param \Etrali\GinangBundle\Entity\OptionType $idOptionType
     * @return ServiceOption
     */
    public function setIdOptionType(\Etrali\GinangBundle\Entity\OptionType $idOptionType = null)
    {
        $this->idOptionType = $idOptionType;
    
        return $this;
    }

    /**
     * Get idOptionType
     *
     * @return \Etrali\GinangBundle\Entity\OptionType 
     */
    public function getIdOptionType()
    {
        return $this->idOptionType;
    }

    /**
     * Set idService
     *
     * @param \Etrali\GinangBundle\Entity\Service $idService
     * @return ServiceOption
     */
    public function setIdService(\Etrali\GinangBundle\Entity\Service $idService = null)
    {
        $this->idService = $idService;
    
        return $this;
    }

    /**
     * Get idService
     *
     * @return \Etrali\GinangBundle\Entity\Service 
     */
    public function getIdService()
    {
        return $this->idService;
    }

    /**
     * Get idServiceOption
     *
     * @return integer 
     */
    public function getIdServiceOption()
    {
        return $this->idServiceOption;
    }

    /**
     * Set cdOption
     *
     * @param string $cdOption
     * @return ServiceOption
     */
    public function setCdOption($cdOption)
    {
        $this->cdOption = $cdOption;
    
        return $this;
    }

    /**
     * Get cdOption
     *
     * @return string 
     */
    public function getCdOption()
    {
        return $this->cdOption;
    }

    /**
     * Set lbOption
     *
     * @param string $lbOption
     * @return ServiceOption
     */
    public function setLbOption($lbOption)
    {
        $this->lbOption = $lbOption;
    
        return $this;
    }

    /**
     * Get lbOption
     *
     * @return string 
     */
    public function getLbOption()
    {
        return $this->lbOption;
    }

    /**
     * Set blBillable
     *
     * @param boolean $blBillable
     * @return ServiceOption
     */
    public function setBlBillable($blBillable)
    {
        $this->blBillable = $blBillable;
    
        return $this;
    }

    /**
     * Get blBillable
     *
     * @return boolean 
     */
    public function getBlBillable()
    {
        return $this->blBillable;
    }
    
    /**
     * 
     * @return null
     */
    public function getParentBranch() 
    { 
        return NULL;         
    }      
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idBillingServiceLine = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Add idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     * @return ServiceOption
     */
    public function addIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine[] = $idBillingServiceLine;
    
        return $this;
    }

    /**
     * Remove idBillingServiceLine
     *
     * @param \Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine
     */
    public function removeIdBillingServiceLine(\Etrali\GinangBundle\Entity\BillingServiceLine $idBillingServiceLine)
    {
        $this->idBillingServiceLine->removeElement($idBillingServiceLine);
    }

    /**
     * Get idBillingServiceLine
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdBillingServiceLine()
    {
        return $this->idBillingServiceLine;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return ServiceOption
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }
}