<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * Slot
 *
 * @ORM\Table(name="slot")
 * @ORM\Entity
 */
class Slot
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_slot", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idSlot;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_slot", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)    
     */
    private $cdSlot;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_slot", type="string", length=100, nullable=true)
     */
    private $lbSlot;

    /**
     * @var string
     *
     * @ORM\Column(name="url_image", type="string", length=100, nullable=true)
     */
    private $urlImage;


    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_slot_for_ref", type="boolean", nullable=true)
     */
    private $blSlotForRef;     
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nb_number", type="integer", nullable=false)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Slot number can not be zero")    
     */
    private $nbNumber=1000000;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_card_horizontal", type="boolean", nullable=true)
     */
    private $blCardHorizontal;  
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nb_cards", type="integer", nullable=true)
     * @Assert\Regex("/^[0-9]+$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Number of cards can not be zero")   
     */
    private $nbCards;    
    
    /**
     * @var \Equipment
     *
     * @ORM\ManyToOne(targetEntity="Equipment", inversedBy="idSlot")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_equipment", referencedColumnName="id_equipment")
     * })
     */
    private $idEquipment; 
      
    /**
     * @var \Card
     *
     * @ORM\OneToMany(targetEntity="Card", mappedBy="idSlot",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"nbNumber" = "ASC"}) 
     */
    private $idCard;     
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_model", type="boolean", nullable=true)
     */
    private $blModel=true;     
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel", inversedBy="idSlot")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     */
    private $idComplexModel;   
    
    
    /**
     * @return string
     *
     */
    public function __toString()
    {
        return $this->lbSlot.'';
    }       

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCard = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Clone function. Clones an entity and all necessary ManyToOne relations. 
     * Parent entities are not cloned but only children
     *
     * @return Slot
     */    
    public function duplique() {
        if ($this->idSlot) {
            $this->idSlot=null;
            $ac = new ArrayCollection();   
            foreach ($this->idCard as $elem)
            {
                $cloneElem=clone $elem;
                $cloneElem->duplique();                     $ac->add($cloneElem);                
                $cloneElem->setIdSlot($this); 
            } 
            $this->idCard=$ac;
        }
    }
    
   /**
     * Set idCard
     *
     * @param \Doctrine\Common\Collections\Collection  $idCard
     * @return Slot
     */
    public function setIdCard(\Doctrine\Common\Collections\Collection $idCard = null)
    {
        $this->idCard = $idCard;
    
        return $this;
    }   
    
    /**
     * Get idSlot
     *
     * @return integer 
     */
    public function getIdSlot()
    {
        return $this->idSlot;
    }

    /**
     * Set cdSlot
     *
     * @param string $cdSlot
     * @return Slot
     */
    public function setCdSlot($cdSlot)
    {
        $this->cdSlot = $cdSlot;
    
        return $this;
    }

    /**
     * Get cdSlot
     *
     * @return string 
     */
    public function getCdSlot()
    {
        return $this->cdSlot;
    }

    /**
     * Set lbSlot
     *
     * @param string $lbSlot
     * @return Slot
     */
    public function setLbSlot($lbSlot)
    {
        $this->lbSlot = $lbSlot;
    
        return $this;
    }

    /**
     * Get lbSlot
     *
     * @return string 
     */
    public function getLbSlot()
    {
        return $this->lbSlot;
    }

    /**
     * Set urlImage
     *
     * @param string $urlImage
     * @return Slot
     */
    public function setUrlImage($urlImage)
    {
        $this->urlImage = $urlImage;
    
        return $this;
    }

    /**
     * Get urlImage
     *
     * @return string 
     */
    public function getUrlImage()
    {
        return $this->urlImage;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return Slot
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return Slot
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set blSlotForRef
     *
     * @param boolean $blSlotForRef
     * @return Slot
     */
    public function setBlSlotForRef($blSlotForRef)
    {
        $this->blSlotForRef = $blSlotForRef;
    
        return $this;
    }

    /**
     * Get blSlotForRef
     *
     * @return boolean 
     */
    public function getBlSlotForRef()
    {
        return $this->blSlotForRef;
    }

    /**
     * Set nbNumber
     *
     * @param integer $nbNumber
     * @return Slot
     */
    public function setNbNumber($nbNumber)
    {
        $this->nbNumber = $nbNumber;
    
        return $this;
    }

    /**
     * Get nbNumber
     *
     * @return integer 
     */
    public function getNbNumber()
    {
        return $this->nbNumber;
    }

    /**
     * Set blCardHorizontal
     *
     * @param boolean $blCardHorizontal
     * @return Slot
     */
    public function setBlCardHorizontal($blCardHorizontal)
    {
        $this->blCardHorizontal = $blCardHorizontal;
    
        return $this;
    }

    /**
     * Get blCardHorizontal
     *
     * @return boolean 
     */
    public function getBlCardHorizontal()
    {
        return $this->blCardHorizontal;
    }

    /**
     * Set nbCards
     *
     * @param integer $nbCards
     * @return Slot
     */
    public function setNbCards($nbCards)
    {
        $this->nbCards = $nbCards;
    
        return $this;
    }

    /**
     * Get nbCards
     *
     * @return integer 
     */
    public function getNbCards()
    {
        return $this->nbCards;
    }

    /**
     * Set blModel
     *
     * @param boolean $blModel
     * @return Slot
     */
    public function setBlModel($blModel)
    {
        $this->blModel = $blModel;
    
        return $this;
    }

    /**
     * Get blModel
     *
     * @return boolean 
     */
    public function getBlModel()
    {
        return $this->blModel;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return Slot
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return Slot
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idEquipment
     *
     * @param \Etrali\GinangBundle\Entity\Equipment $idEquipment
     * @return Slot
     */
    public function setIdEquipment(\Etrali\GinangBundle\Entity\Equipment $idEquipment = null)
    {
        $this->idEquipment = $idEquipment;
    
        return $this;
    }

    /**
     * Get idEquipment
     *
     * @return \Etrali\GinangBundle\Entity\Equipment 
     */
    public function getIdEquipment()
    {
        return $this->idEquipment;
    }

    /**
     * Add idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     * @return Slot
     */
    public function addIdCard(\Etrali\GinangBundle\Entity\Card $idCard)
    {
        $this->idCard[] = $idCard;
    
        return $this;
    }

    /**
     * Remove idCard
     *
     * @param \Etrali\GinangBundle\Entity\Card $idCard
     */
    public function removeIdCard(\Etrali\GinangBundle\Entity\Card $idCard)
    {
        $this->idCard->removeElement($idCard);
    }

    /**
     * Get idCard
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCard()
    {
        return $this->idCard;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return Slot
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }
public function getParentBranch() { return NULL; }  }