<?php

namespace Etrali\GinangBundle\Entity;
use Symfony\Component\Validator\Constraints as Assert;
use \Doctrine\Common\Collections\ArrayCollection as ArrayCollection;
use Doctrine\ORM\Mapping as ORM; use Gedmo\Mapping\Annotation as Gedmo;

/**
 * SlotInstance
 *
 * @ORM\Table(name="slot_instance")
 * @ORM\Entity
 */
class SlotInstance
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id_slot_instance", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $idSlotInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="cd_slot_instance", type="string", length=15, nullable=true)
     * @Assert\NotBlank()
     * @Assert\MaxLength(20)    
     */
    private $cdSlotInstance;

    /**
     * @var string
     *
     * @ORM\Column(name="lb_slot_instance", type="string", length=100, nullable=true)
     */
    private $lbSlotInstance;



    /**
     * @var boolean
     *
     * @ORM\Column(name="bl_deactivated", type="boolean", nullable=true)
     */
    private $blDeactivated=true;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_create_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="create")	
     */
    private $idUserCreateBy;

    /**
     * @var \Myuser
     *
     * @ORM\ManyToOne(targetEntity="Myuser")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_user_update_by", referencedColumnName="id")
     * })
     * @Gedmo\Blameable(on="update")
     */
    private $idUserUpdateBy;


    /**
     * @var \DateTime
     *
     * @ORM\Column(name="dt_deactivated", type="datetime", nullable=true)
     */
    private $dtDeactivated;

        
    /**
     * @var \EquipmentInstance
     *
     * @ORM\ManyToOne(targetEntity="EquipmentInstance", inversedBy="idSlotInstance")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_equipment_instance", referencedColumnName="id_equipment_instance")
     * })
     */
    private $idEquipmentInstance; 
      
    /**
     * @var \CardInstance
     *
     * @ORM\OneToMany(targetEntity="CardInstance", mappedBy="idSlotInstance",cascade={"persist","remove"}, orphanRemoval=true )
     * @ORM\OrderBy({"nbNumber" = "ASC"}) 
     */
    private $idCardInstance;     
    
    /**
     * @var \Slot
     *
     * @ORM\ManyToOne(targetEntity="Slot")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_slot", referencedColumnName="id_slot")
     * })   
     */
    private $idSlot;    
    
     /**
     * @var integer
     *
     * @ORM\Column(name="nb_number", type="integer", nullable=false)
     * @Assert\Regex("/^[0-9]*$/")
     * @Assert\Range(
     *      min = "1",
     *      minMessage = "Slot number can not be zero")    
     */
    private $nbNumber=1000000;    
    
    /**
     * @var \ComplexModel
     *
     * @ORM\ManyToOne(targetEntity="ComplexModel")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="id_complex_model", referencedColumnName="id_complex_model")
     * })
     * @Assert\NotNull()     
     */
    private $idComplexModel;      
    
    /**
     * @return string
     *
     */
    public function __toString()
    {
        return $this->lbSlotInstance.'';
    }      


    /**
     * Constructor
     */
    public function __construct()
    {
        $this->idCardInstance = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Get idSlotInstance
     *
     * @return integer 
     */
    public function getIdSlotInstance()
    {
        return $this->idSlotInstance;
    }

    /**
     * Set cdSlotInstance
     *
     * @param string $cdSlotInstance
     * @return SlotInstance
     */
    public function setCdSlotInstance($cdSlotInstance)
    {
        $this->cdSlotInstance = $cdSlotInstance;
    
        return $this;
    }

    /**
     * Get cdSlotInstance
     *
     * @return string 
     */
    public function getCdSlotInstance()
    {
        return $this->cdSlotInstance;
    }

    /**
     * Set lbSlotInstance
     *
     * @param string $lbSlotInstance
     * @return SlotInstance
     */
    public function setLbSlotInstance($lbSlotInstance)
    {
        $this->lbSlotInstance = $lbSlotInstance;
    
        return $this;
    }

    /**
     * Get lbSlotInstance
     *
     * @return string 
     */
    public function getLbSlotInstance()
    {
        return $this->lbSlotInstance;
    }

    /**
     * Set blDeactivated
     *
     * @param boolean $blDeactivated
     * @return SlotInstance
     */
    public function setBlDeactivated($blDeactivated)
    {
        $this->blDeactivated = $blDeactivated;
    
        return $this;
    }

    /**
     * Get blDeactivated
     *
     * @return boolean 
     */
    public function getBlDeactivated()
    {
        return $this->blDeactivated;
    }

    /**
     * Set dtDeactivated
     *
     * @param \DateTime $dtDeactivated
     * @return SlotInstance
     */
    public function setDtDeactivated($dtDeactivated)
    {
        $this->dtDeactivated = $dtDeactivated;
    
        return $this;
    }

    /**
     * Get dtDeactivated
     *
     * @return \DateTime 
     */
    public function getDtDeactivated()
    {
        return $this->dtDeactivated;
    }

    /**
     * Set idUserCreateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserCreateBy
     * @return SlotInstance
     */
    public function setIdUserCreateBy(\Etrali\GinangBundle\Entity\Myuser $idUserCreateBy = null)
    {
        $this->idUserCreateBy = $idUserCreateBy;
    
        return $this;
    }

    /**
     * Get idUserCreateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserCreateBy()
    {
        return $this->idUserCreateBy;
    }

    /**
     * Set idUserUpdateBy
     *
     * @param \Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy
     * @return SlotInstance
     */
    public function setIdUserUpdateBy(\Etrali\GinangBundle\Entity\Myuser $idUserUpdateBy = null)
    {
        $this->idUserUpdateBy = $idUserUpdateBy;
    
        return $this;
    }

    /**
     * Get idUserUpdateBy
     *
     * @return \Etrali\GinangBundle\Entity\Myuser 
     */
    public function getIdUserUpdateBy()
    {
        return $this->idUserUpdateBy;
    }

    /**
     * Set idEquipmentInstance
     *
     * @param \Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance
     * @return SlotInstance
     */
    public function setIdEquipmentInstance(\Etrali\GinangBundle\Entity\EquipmentInstance $idEquipmentInstance = null)
    {
        $this->idEquipmentInstance = $idEquipmentInstance;
    
        return $this;
    }

    /**
     * Get idEquipmentInstance
     *
     * @return \Etrali\GinangBundle\Entity\EquipmentInstance 
     */
    public function getIdEquipmentInstance()
    {
        return $this->idEquipmentInstance;
    }

    /**
     * Add idCardInstance
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idCardInstance
     * @return SlotInstance
     */
    public function addIdCardInstance(\Etrali\GinangBundle\Entity\CardInstance $idCardInstance)
    {
        $this->idCardInstance[] = $idCardInstance;
    
        return $this;
    }

    /**
     * Remove idCardInstance
     *
     * @param \Etrali\GinangBundle\Entity\CardInstance $idCardInstance
     */
    public function removeIdCardInstance(\Etrali\GinangBundle\Entity\CardInstance $idCardInstance)
    {
        $this->idCardInstance->removeElement($idCardInstance);
    }

    /**
     * Get idCardInstance
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getIdCardInstance()
    {
        return $this->idCardInstance;
    }

    /**
     * Set idSlot
     *
     * @param \Etrali\GinangBundle\Entity\Slot $idSlot
     * @return SlotInstance
     */
    public function setIdSlot(\Etrali\GinangBundle\Entity\Slot $idSlot = null)
    {
        $this->idSlot = $idSlot;
    
        return $this;
    }

    /**
     * Get idSlot
     *
     * @return \Etrali\GinangBundle\Entity\Slot 
     */
    public function getIdSlot()
    {
        return $this->idSlot;
    }

    /**
     * Set nbNumber
     *
     * @param integer $nbNumber
     * @return SlotInstance
     */
    public function setNbNumber($nbNumber)
    {
        $this->nbNumber = $nbNumber;
    
        return $this;
    }

    /**
     * Get nbNumber
     *
     * @return integer 
     */
    public function getNbNumber()
    {
        return $this->nbNumber;
    }

    /**
     * Set idComplexModel
     *
     * @param \Etrali\GinangBundle\Entity\ComplexModel $idComplexModel
     * @return SlotInstance
     */
    public function setIdComplexModel(\Etrali\GinangBundle\Entity\ComplexModel $idComplexModel = null)
    {
        $this->idComplexModel = $idComplexModel;
    
        return $this;
    }

    /**
     * Get idComplexModel
     *
     * @return \Etrali\GinangBundle\Entity\ComplexModel 
     */
    public function getIdComplexModel()
    {
        return $this->idComplexModel;
    }
public function getParentBranch() { return NULL; }  }