<?php

namespace Admingenerator\GeneratorBundle\EventListener;

use Symfony\Component\DependencyInjection\ContainerInterface;

use Symfony\Component\Yaml\Yaml;

use Symfony\Component\HttpKernel\HttpKernelInterface;

use Symfony\Component\HttpKernel\Event\GetResponseEvent;

use Admingenerator\GeneratorBundle\Exception\NotAdminGeneratedException;
use Symfony\Component\Finder\Finder;

class ControllerListener
{
    protected $container;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    public function onKernelRequest(GetResponseEvent $event)
    {
        
/*        $fp=fopen("/var/www/ginang/log.txt","a");
        fputs($fp,microtime().' : Start kernel Request');        */
        if (HttpKernelInterface::MASTER_REQUEST === $event->getRequestType()) {

            if ($this->container->getParameter('kernel.environment')!="prod" || !file_exists($this->container->getParameter('kernel.root_dir').'/cache/prod/Admingenerated'))
            {
                try {
                    $controller = $event->getRequest()->attributes->get('_controller');

                    if (strstr($controller, '::')) { //Check if its a "real controller" not assetic for example
                        $generatorYaml = $this->getGeneratorYml($controller);
                        //fputs($fp,microtime().' : After get generator yml'); 
                        $generator = $this->getGenerator($generatorYaml);
                        //fputs($fp,microtime().' : After get generator'); 
                        $generator->setGeneratorYml($generatorYaml);
                        //fputs($fp,microtime().' : After set generator yml'); 
                        $generator->setBaseGeneratorName($this->getBaseGeneratorName($controller));
    //                    fputs($fp,microtime().' : After set base generator'); 
                        $generator->build();
      //                  fputs($fp,microtime().' : After build'); 
                    }
                } catch (NotAdminGeneratedException $e) {
                    //Lets the word running this is not an admin generated module
                }
            }
        }

        if ($this->container->hasParameter('admingenerator.twig')) {
            $twig_params = $this->container->getParameter('admingenerator.twig');
    //        fputs($fp,microtime().' : After twig params'); 
            if (isset($twig_params['date_format'])) {
                $this->container->get('twig')->getExtension('core')->setDateFormat($twig_params['date_format'], '%d days');
            }

            if (isset($twig_params['number_format'])) {
                $this->container->get('twig')->getExtension('core')->setNumberFormat($twig_params['number_format']['decimal'], $twig_params['number_format']['decimal_point'], $twig_params['number_format']['thousand_separator']);
            }
        }
      /*  fputs($fp,microtime().' : After end'); 
        fclose($fp);*/
    }

    protected function getGenerator($generatorYaml)
    {
        $yaml = Yaml::parse($generatorYaml);

        return $this->container->get($yaml['generator']);
    }

    protected function getBaseGeneratorName($controller)
    {
        preg_match('/(.+)Controller(.+)::.+/', $controller, $matches);

        //Find if its a name-generator or generator.yml
        if (isset($matches[2]) && strstr($matches[2], '\\')) {
            if (3 != count(explode('\\', $matches[2]))) {
                return '';
            }

            list($firstSlash, $generatorName) = explode('\\', $matches[2], 3);

            return $generatorName;
        }

        return '';
    }

    /**
     * @todo Find objects in vendor dir
     */
    protected function getGeneratorYml($controller)
    {
        preg_match('/(.+)?Controller.+::.+/', $controller, $matches);
        $dir = str_replace('\\', DIRECTORY_SEPARATOR, $matches[1]);

        $generatorName  = $this->getBaseGeneratorName($controller) ? $this->getBaseGeneratorName($controller).'-' : '';
        $generatorName .= 'generator.yml';

        $finder = new Finder();
        $finder->files()
               ->name($generatorName);

        if (is_dir($src = realpath($this->container->getParameter('kernel.root_dir').'/../src/'.$dir.'/Resources/config'))) {
            $namespace_directory = $src;
        } else {
            $namespace_directory = realpath($this->container->getParameter('kernel.root_dir').'/../vendor/bundles/'.$dir.'/Resources/config');
        }

        if (is_dir($namespace_directory)) {
            $finder->in($namespace_directory);
            $it = $finder->getIterator();
            $it->rewind();

            if ($it->valid()) {
                return $it->current()->getRealpath();
            }
        }

        throw new NotAdminGeneratedException;
    }

}
