<?php

namespace Admingenerator\GeneratorBundle\QueryFilter;

class DoctrineQueryFilter extends BaseQueryFilter
{

    public function addDefaultFilter($field, $value)
    {

        if (!is_array($value))
        {
            $this->query->andWhere(sprintf('q.%s = :%s',$field, $field));
            $this->query->setParameter($field, $value);
        }
        else
        {          
            if (isset($value["from"]) && trim($value["from"])!="")
            {
                $this->query->andWhere('q.'.$field." ".$value["fromop"].' '.$value["from"]);
            }
            if (isset($value["to"]) && trim($value["to"])!="")
            {
                $this->query->andWhere('q.'.$field." ".$value["toop"].' '.$value["to"]);
            }

        }
    }
    
    public function addEntityFilter($field, $value)
    {            
            $this->query->innerJoin(sprintf('q.%s',$field),$field.'ent');
            $this->query->andWhere(sprintf($field.'ent.%s = :%s',$field, $field));
            $getter="get".ucfirst($field);
            $this->query->setParameter($field, $value->$getter());
    }    
      

    public function addBooleanFilter($field, $value)
    {
        if ("" !== $value) {
            $this->query->andWhere(sprintf('q.%s = :%s',$field, $field));
            $this->query->setParameter($field, $value);
        }
    }

    public function addStringFilter($field, $value)
    {

        if (!is_array($value))
        {
            $this->query->andWhere(sprintf('q.%s LIKE :%s',$field, $field));
            $this->query->setParameter($field, '%'.$value.'%');
        }  
        else
        {
        if (isset($value["val"]) && "" != trim($value["val"])) {            
            switch ($value["valop"])
            {
                case 0:
                    $this->query->andWhere(sprintf('q.%s LIKE :%s',$field, $field));
                    $this->query->setParameter($field, '%'.$value["val"].'%');                        
                    break;
                case 1:
                    $this->query->andWhere(sprintf('q.%s = :%s',$field, $field));
                    $this->query->setParameter($field, $value["val"]);                        
                    break;   
                case 2:
                    $this->query->andWhere(sprintf('q.%s LIKE :%s',$field, $field));
                    $this->query->setParameter($field, $value["val"].'%');                        
                    break;            
                case 3:
                    $this->query->andWhere(sprintf('q.%s LIKE :%s',$field, $field));
                    $this->query->setParameter($field, '%'.$value["val"]);                        
                    break;            
                case 4:
                    $this->query->andWhere(sprintf('q.%s NOT LIKE :%s',$field, $field));
                    $this->query->setParameter($field, '%'.$value["val"].'%');                        
                    break;            
                case 5:
                    $this->query->andWhere(sprintf('q.%s <> :%s',$field, $field));
                    $this->query->setParameter($field, $value["val"]);                        
                    break; 
                case 6:
                    $this->query->andWhere(sprintf('q.%s NOT LIKE :%s',$field, $field));
                    $this->query->setParameter($field, $value["val"].'%');                        
                    break;            
                case 7:
                    $this->query->andWhere(sprintf('q.%s NOT LIKE :%s',$field, $field));
                    $this->query->setParameter($field, '%'.$value["val"]);                        
                    break;              
            }
        }
        }
    }

    public function addTextFilter($field, $value)
    {
        $this->addStringFilter($field, $value);
    }

    public function addCollectionFilter($field, $value)
    {
        if (!is_array($value)) {
            $value = array($value->getId());
        }

        if (strstr($field, '.')) {
            list($table, $field) = explode('.', $field);
        } else {
            $table = $field;
            $field = 'id';
        }

        $this->query->leftJoin('q.'.$table, $table);
        $this->query->groupBy('q.id');
        $this->query->andWhere(sprintf('%s.%s IN (:%s)',$table, $field, $table.'_'.$field));
        $this->query->setParameter($table.'_'.$field, $value);

    }

    public function addDateFilter($field, $value, $format = 'Y-m-d')
    {
        if (is_array($value)) {
            if ($value['from']) {
                $this->query->andWhere(sprintf('q.%s >= :%s_from',$field, $field ));
                $this->query->setParameter($field.'_from' , $value['from']->format($format));
            }

            if ($value['to']) {
                $this->query->andWhere(sprintf('q.%s <= :%s_to',$field, $field ));
                $this->query->setParameter($field.'_to' , $value['to']->format($format));
            }

        } elseif ($value instanceof \DateTime) {
            $this->query->andWhere(sprintf('q.%s = :%s',$field, $field ));
            $this->query->setParameter($field, $value->format($format));
        }
    }

    public function addDatetimeFilter($field, $value)
    {
        $this->addDateFilter($field, $value, 'Y-m-d H:i:s');
    }
}
