<?php

namespace Admingenerator\GeneratorBundle\Routing;

use Symfony\Component\Config\Loader\FileLoader;
use Symfony\Component\Config\Resource\FileResource;
use Symfony\Component\Routing\RouteCollection;
use Symfony\Component\Routing\Route;

class RoutingLoader extends FileLoader
{
    // Assoc beetween a controller and is route path
    //@todo make an object for this
    protected $actions = array(
        'searchlist'=>array(
                    'pattern'      => '/searchlist',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',            
            ),
        'list' => array( 
                    'pattern'      => '/',
                    'defaults'     => array(),
                    'requirements' => array(),
                ),
        'batch' => array(
                    'pattern'      => '/batch',
                    'defaults'     => array(),
                    'requirements' => array(
                        '_method' => 'POST'
                    ),
                    'controller'   => 'list',
                ),
        'delete' => array(
                    'pattern'      => '/{pk}/delete',
                    'defaults'     => array(),
                    'requirements' => array(),
                ),
        'deactivate' => array(
                    'pattern'      => '/{pk}/deactivate',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'delete',            
                ),        
        'edit' => array(
                    'pattern'      => '/{pk}/edit',
                    'defaults'     => array(),
                    'requirements' => array(),
                ),   
        'editall' => array(
                    'pattern'      => '/{pk}/{collName}/{typeName}/editall',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'edit',   
                ), 
        'updateall' => array(
                    'pattern'      => '/{pk}/{collName}/{typeName}/updateall',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'edit',
                ),        
        'update' => array(
                    'pattern'      => '/{pk}/update',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'edit',
                ),
        'show' => array(
                    'pattern'      => '/{pk}/show',
                    'defaults'     => array(),
                    'requirements' => array()
                ),
        'new' => array(
                    'pattern'      => '/new',
                    'defaults'     => array(),
                    'requirements' => array(),
                ),
        'create' => array(
                    'pattern'      => '/create',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'new',
                ),
        'filters' => array(
                    'pattern'      => '/filter',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',
                ),
        'preference' => array(
                    'pattern'      => '/preference',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',
                ),            
        'setpreference' => array(
                    'pattern'      => '/setpreference',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',
            ),
        'import' => array(
                    'pattern'      => '/import',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',
            ),   
        'doimport' => array(
                    'pattern'      => '/doimport',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',
            ),         
        'export' => array(
                    'pattern'      => '/export',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',            
                ),          
        'scopes' => array(
                    'pattern'      => '/scope/{group}/{scope}',
                    'defaults'     => array(),
                    'requirements' => array(),
                    'controller'   => 'list',
                ),
    );

    public function load($resource, $type = null)
    {
        $collection = new RouteCollection();

        $resource = str_replace('\\', '/', $resource);
        $namespace = $this->getNamespaceFromResource($resource);
        $bundle_name = $this->getBundleNameFromResource($resource);

        foreach ($this->actions as $controller => $datas) {
            $action = 'index';

            $loweredNamespace = str_replace(array('/', '\\'), '_', $namespace);
            if ($controller_folder = $this->getControllerFolder($resource)) {
                $route_name = $loweredNamespace . '_' . $bundle_name . '_' . $controller_folder . '_' . $controller;
            } else {
                $route_name = $loweredNamespace . '_' . $bundle_name . '_' . $controller;
            }

            if (isset($datas['controller'])) {
                $action     = $controller;
                $controller = $datas['controller'];
            }

            $controllerName = $resource.ucfirst($controller).'Controller.php';
            if (is_file($controllerName)) {
                if ($controller_folder) {
                    $datas['defaults']['_controller'] = $namespace . '\\'
                            . $bundle_name . '\\Controller\\'
                            . $controller_folder . '\\'
                            . ucfirst($controller) . 'Controller::'
                            . $action . 'Action';
                } else {
                    $datas['defaults']['_controller'] = $loweredNamespace
                            . $bundle_name . ':'
                            . ucfirst($controller) . ':' . $action;
                }
                $route = new Route($datas['pattern'], $datas['defaults'], $datas['requirements']);
                $collection->add($route_name, $route);
                $collection->addResource(new FileResource($controllerName));
            }
        }

        // Import other routes from a controller directory (@Route annotation)
        if ($controller_folder) {
            $annotationRouteName = '@' . $namespace . $bundle_name . '/Controller/' . $controller_folder . '/';
            $collection->addCollection($this->import($annotationRouteName, 'annotation'));
        }

        return $collection;
    }

    public function supports($resource, $type = null)
    {
        return 'admingenerator' == $type;
    }

    protected function getControllerFolder($resource)
    {
        preg_match('#.+/.+Bundle/Controller?/(.*?)/?$#', $resource, $matches);

        return $matches[1];
    }

    protected function getBundleNameFromResource($resource)
    {
        preg_match('#.+/(.+Bundle)/Controller?/(.*?)/?$#', $resource, $matches);

        return $matches[1];
    }

    protected function getNamespaceFromResource($resource)
    {
        preg_match('#.+/(.+)/(.+Bundle)/Controller?/(.*?)/?$#', $resource, $matches);

        return str_replace('/', '\\', $matches[1]);
    }
}
